searchData={"items":[{"type":"module","doc":"`Image` is based upon the fabulous\n[vix](https://hex.pm/packages/vix) library that provides a [libvips](https://www.libvips.org)\nwrapper for Elixir.\n\n`Image` is intended to provide well-documented common image processing functions in\nan idiomatic Elixir functional style as a layer above the very comprehensive set\nof functions in `Vix` and `libvips`.\n\nIn a very simple image resizing\n[benchmark](https://github.com/kipcole9/image/blob/main/bench/image_resize.exs),\n`Image` is approximately 2 to 3 times faster than `Mogrify` and uses about 5 times\nless memory.","title":"Image","ref":"Image.html"},{"type":"function","doc":"Add an alpha band to an image.","title":"Image.add_alpha/2","ref":"Image.html#add_alpha/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `alpha_image` is any single-band image\n  that will be added as an alpha image to\n  `image`\n\nOR\n\n* an integer in the range `0..255` that represents\n  the level of transparency of the alpha band. `0`\n  represents fully opaque and `255` represents fully\n  transparent. The atoms `:opaque` and `:transparent`\n  may also be provided representing the values of\n  `0` and `255` respectively.","title":"Arguments - Image.add_alpha/2","ref":"Image.html#add_alpha/2-arguments"},{"type":"function","doc":"* `{:ok, image_with_added_alpha_band}` or\n\n* `{:error, reason}`","title":"Returns - Image.add_alpha/2","ref":"Image.html#add_alpha/2-returns"},{"type":"function","doc":"Add an alpha band to an image.","title":"Image.add_alpha!/2","ref":"Image.html#add_alpha!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `alpha_image` is any single-band image\n  that will be added as an alpha image to\n  `image`\n\nOR\n\n* `:color` which defines the color of the alpha\n  image. This can be specified as a single integer\n  which will be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.","title":"Arguments - Image.add_alpha!/2","ref":"Image.html#add_alpha!/2-arguments"},{"type":"function","doc":"If `color` is provided then the alpha layer determines\nthe level of transparency of `image`.\n\nWhite (RGB color 255) means that `image` will be opaque.\nBlack (the default, RGB 0) means that `image` will be transparent.\nOther colors will determine the level of transparency\nbetween the two.","title":"Note - Image.add_alpha!/2","ref":"Image.html#add_alpha!/2-note"},{"type":"function","doc":"* `image_with_added_alpha_band` or\n\n* raises an exception.","title":"Returns - Image.add_alpha!/2","ref":"Image.html#add_alpha!/2-returns"},{"type":"function","doc":"Returns the band number of the alpha\nchannel of an image, or nil if it doesn't\nhave one.\n\nThe determination is a heuristic so certainty\ncannot be guaranteed.","title":"Image.alpha_band/1","ref":"Image.html#alpha_band/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.alpha_band/1","ref":"Image.html#alpha_band/1-arguments"},{"type":"function","doc":"* An integer in the range `1..4` depending\n  on the image interpretation. Returns `nil`\n  if there is no alpha band. The integer\n  is a 0-based offset and can therefore be\n  directly used to access the band. For example\n  `image[alpha_band(image)]`.","title":"Returns - Image.alpha_band/1","ref":"Image.html#alpha_band/1-returns"},{"type":"function","doc":"Applies a tone curve to an image.\n\nA [tone curve](https://en.wikipedia.org/wiki/Curve_(tonality))\nis typically used to affect overall image contrast. It\nis a function to adjust brightness and contrast by controlling the\ninput-output density curve for each band of an image.","title":"Image.apply_tone_curve/2","ref":"Image.html#apply_tone_curve/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.apply_tone_curve/2","ref":"Image.html#apply_tone_curve/2-arguments"},{"type":"function","doc":"* `:black_point` is an integer between `0`\n  (the default) and `100` indicating the darkest\n  and most dense black area of the image will\n  lie in the overall range of the image.\n\n* `:white_point` is an integer between `0`\n  and `100` (the default) indicating the lightest\n  area of the image will lie in the overall range\n  of the image.\n\n* `:shadow_point` is the point on the tone curve\n  around which the shadow values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.2`.\n\n* `:mid_point` is the point on the tone curve\n  around which the mid tone values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.5`.\n\n* `:highlight_point` is the point on the tone curve\n  around which the highlight values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.8`.\n\n* `:shadows` indicates by how much the shadows should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.\n\n* `:mid_points` indicates by how much the mid tones should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.\n\n* `:highlights` indicates by how much the highlights should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.","title":"Options - Image.apply_tone_curve/2","ref":"Image.html#apply_tone_curve/2-options"},{"type":"function","doc":"* `{:ok, tone_mapped_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.apply_tone_curve/2","ref":"Image.html#apply_tone_curve/2-returns"},{"type":"function","doc":"Applies a tone curve to an image or raises\nan exception.\n\nA [tone curve](https://en.wikipedia.org/wiki/Curve_(tonality))\nis typically used to affect overall image contrast. It\nis a function to adjust brightness and contrast by controlling the\ninput-output density curve for each band of an image.","title":"Image.apply_tone_curve!/2","ref":"Image.html#apply_tone_curve!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.apply_tone_curve!/2","ref":"Image.html#apply_tone_curve!/2-arguments"},{"type":"function","doc":"* `:black_point` is an integer between `0`\n  (the default) and `100` indicating the darkest\n  and most dense black area of the image will\n  lie in the overall range of the image.\n\n* `:white_point` is an integer between `0`\n  and `100` (the default) indicating the lightest\n  area of the image will lie in the overall range\n  of the image.\n\n* `:shadow_point` is the point on the tone curve\n  around which the shadow values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.2`.\n\n* `:mid_point` is the point on the tone curve\n  around which the mid tone values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.5`.\n\n* `:highlight_point` is the point on the tone curve\n  around which the highlight values are tone mapped. The\n  value is between `0.0` and `1.0`. The default is\n  `0.8`.\n\n* `:shadows` indicates by how much the shadows should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.\n\n* `:mid_points` indicates by how much the mid tones should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.\n\n* `:highlights` indicates by how much the highlights should be\n  adjusted. The value is in the range `-30` to `30`.\n  The default is `0`.","title":"Options - Image.apply_tone_curve!/2","ref":"Image.html#apply_tone_curve!/2-options"},{"type":"function","doc":"* `tone_mapped_image` or\n\n* raises an exception.","title":"Returns - Image.apply_tone_curve!/2","ref":"Image.html#apply_tone_curve!/2-returns"},{"type":"function","doc":"Returns the aspect of an image.","title":"Image.aspect/2","ref":"Image.html#aspect/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `options` is a keyword list of options","title":"Arguments - Image.aspect/2","ref":"Image.html#aspect/2-arguments"},{"type":"function","doc":"* `:square_ratio` indicates when an image\n  is to be considered square. It is a floating\n  point indicator of the ratio between the width\n  and height below which the image is considered\n  square. The default is `0.0` meaning that the\n  dimensions must be exactly equal in order for\n  the image to be considered square.","title":"Options - Image.aspect/2","ref":"Image.html#aspect/2-options"},{"type":"function","doc":"* Either `:landscape`, `:portrait` or `:square`.","title":"Returns - Image.aspect/2","ref":"Image.html#aspect/2-returns"},{"type":"function","doc":"iex> puppy = Image.open!(Path.expand(\"test/support/images/puppy.webp\"))\n    iex> Image.aspect(puppy, square_ratio: 0.05)\n    :landscape","title":"Example - Image.aspect/2","ref":"Image.html#aspect/2-example"},{"type":"function","doc":"Rotate an image based upon the orientation\ninformation in an image's EXIF data.","title":"Image.autorotate/1","ref":"Image.html#autorotate/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.autorotate/1","ref":"Image.html#autorotate/1-arguments"},{"type":"function","doc":"* `{:ok, {auto_rotated_image, flags}}` or\n\n* `{:error, reason}`","title":"Returns - Image.autorotate/1","ref":"Image.html#autorotate/1-returns"},{"type":"function","doc":"A two-entry `Keyword.t` is returned indicating what actions\nwere taken:\n\n* `:flip` which is a boolean indicating if the image\n  was flipped or not and\n\n* `:angle` through which the image was rotated.\n  This value will be one of `0`, `90`, `180` or\n  `270` representing the degrees of rotation.","title":"Flags - Image.autorotate/1","ref":"Image.html#autorotate/1-flags"},{"type":"function","doc":"Rotate an image based upon the orientation\ninformation in an image's EXIF data. Returns\na potentially rotated image or raises and\nexception.","title":"Image.autorotate!/1","ref":"Image.html#autorotate!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.autorotate!/1","ref":"Image.html#autorotate!/1-arguments"},{"type":"function","doc":"* `auto_rotated_image` or\n\n* raises an exception.","title":"Returns - Image.autorotate!/1","ref":"Image.html#autorotate!/1-returns"},{"type":"function","doc":"Make a circular, squircular or square image intended to be used\nas an avatar image.\n\nThe image is resized and all metadata is removed\nfrom the image. The image will be cropped to a square\nshape and then depending on the `:shape` option\na circular or squircular mask may be applied.","title":"Image.avatar/2","ref":"Image.html#avatar/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options. The\n  default is `[shape: :circle, crop: :none, size: 180]`.","title":"Arguments - Image.avatar/2","ref":"Image.html#avatar/2-arguments"},{"type":"function","doc":"* `:size` is the diameter in pixels of the avatar (in the case of\n  `shape: :circle` or `shape; :squircle`. It is the width/height in\n  pixels in the case of a `shape: :square` avatar.\n  The default value is `180`.\n\n* `:shape` defines shape of the avatar\n  which can be either `:circle` (the default), `:squircle`\n  or `:square`.  In each case the image is first\n  cropped to a square shape. Then if the\n  format is `:circle` or `:squircle` an appropriate image\n  mask is applied.\n\n* `:crop_focus` is one of `:center`, `:entropy`,\n  `:attention`, `:low`, `:high`. The default is `:center`.\n  For details see `t:Image.Options.Crop.crop_focus/0`.","title":"Options - Image.avatar/2","ref":"Image.html#avatar/2-options"},{"type":"function","doc":"* `{:ok, avatar_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.avatar/2","ref":"Image.html#avatar/2-returns"},{"type":"function","doc":"Make a circular, squircular or square image intended to be used\nas an avatar image or raise an exception.\n\nThe image is resized and all metadata is removed\nfrom the image. The image will be cropped to a square\nshape and then depending on the `:shape` option\na circular or squirclar mask may be applied.","title":"Image.avatar!/2","ref":"Image.html#avatar!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options. The\n  default is `[shape: :circle, crop: :none, size: 180]`.","title":"Arguments - Image.avatar!/2","ref":"Image.html#avatar!/2-arguments"},{"type":"function","doc":"* `:size` is the diameter in pixels of the avatar (in the case of\n  `shape: :circle` or `shape; :squircle`. It is the width/height in\n  pixels in the case of a `shape: :square` avatar.\n  The default value is `180`.\n\n* `:shape` defines shape of the avatar\n  which can be either `:circle` (the default), `:squircle`\n  or `:square`.  In each case the image is first\n  cropped to a square shape. Then if the\n  format is `:circle` or `:squircle` an appropriate image\n  mask is applied.\n\n* `:crop_focus` is one of `:center`, `:entropy`,\n  `:attention`, `:low`, `:high`. The default is `:center`.\n  For details see `t:Image.Options.Crop.crop_focus/0`.","title":"Options - Image.avatar!/2","ref":"Image.html#avatar!/2-options"},{"type":"function","doc":"* `avatar_image` or\n\n* raises an exception.","title":"Returns - Image.avatar!/2","ref":"Image.html#avatar!/2-returns"},{"type":"function","doc":"Returns the average color of an image.\n\nThe average is calculated for each band\nof an image and then combined.","title":"Image.average/1","ref":"Image.html#average/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.average/1","ref":"Image.html#average/1-arguments"},{"type":"function","doc":"* A list of average pixel values which can\n  be interpreted as the average color of the\n  image.","title":"Returns - Image.average/1","ref":"Image.html#average/1-returns"},{"type":"function","doc":"iex> Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n      ...> |> Image.average()\n      [66, 86, 106]","title":"Example - Image.average/1","ref":"Image.html#average/1-example"},{"type":"function","doc":"Returns the average color of an image or\nraises and exception.\n\nThe average is calculated for each band\nof an image and then combined.","title":"Image.average!/1","ref":"Image.html#average!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.average!/1","ref":"Image.html#average!/1-arguments"},{"type":"function","doc":"* A list of average pixel values which can\n  be interpreted as the average color of the\n  image.","title":"Returns - Image.average!/1","ref":"Image.html#average!/1-returns"},{"type":"function","doc":"iex> Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n      ...> |> Image.average!()\n      [66, 86, 106]","title":"Example - Image.average!/1","ref":"Image.html#average!/1-example"},{"type":"function","doc":"Returns the band format of an image.","title":"Image.band_format/1","ref":"Image.html#band_format/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.band_format/1","ref":"Image.html#band_format/1-arguments"},{"type":"function","doc":"* The band format of the image in `Nx` notation.","title":"Returns - Image.band_format/1","ref":"Image.html#band_format/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Singapore-2016-09-5887.jpg\")\n      iex> Image.band_format(image)\n      {:u, 8}","title":"Examples - Image.band_format/1","ref":"Image.html#band_format/1-examples"},{"type":"function","doc":"Return the number of bands in an image.\n\nA band is sometimes referred to as a\nchannel.\n\nNote than bands are 0-indexed. That is, the\nfirst band is band 0, the second band is\nband 1 and so on.","title":"Image.bands/1","ref":"Image.html#bands/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.bands/1","ref":"Image.html#bands/1-arguments"},{"type":"function","doc":"* An integer number of bands in the image.","title":"Returns - Image.bands/1","ref":"Image.html#bands/1-returns"},{"type":"function","doc":"Applies a gaussian blur to an image.","title":"Image.blur/2","ref":"Image.html#blur/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.blur/2","ref":"Image.html#blur/2-arguments"},{"type":"function","doc":"* `:sigma` is the `float` size of the mask\n  to use. A larger number makes the image more\n  blurry. A range between `1.0` and `10.0`\n  is normally appropriate. The default is\n  `5`.\n\n* `:min_amplitude` is a `float` that determines\n  the accuracy of the mask. The default is `0.2`.\n  A smaller number will generate a larger, more\n  accurate mask,","title":"Options - Image.blur/2","ref":"Image.html#blur/2-options"},{"type":"function","doc":"* `{:ok, blurred_image}` or\n\n* `{:error reason}`","title":"Returns - Image.blur/2","ref":"Image.html#blur/2-returns"},{"type":"function","doc":"Applies a gaussian blur to an image.","title":"Image.blur!/2","ref":"Image.html#blur!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.blur!/2","ref":"Image.html#blur!/2-arguments"},{"type":"function","doc":"* `:sigma` is the `float` size of the mask\n  to use. A larger number makes the image more\n  blurry. A range between `1.0` and `10.0`\n  is normally appropriate. The default is\n  `5`.\n\n* `:min_amplitude` is a `float` that determines\n  the accuracy of the mask. The default is `0.2`.\n  A smaller number will generate a larger, more\n  accurate mask,","title":"Options - Image.blur!/2","ref":"Image.html#blur!/2-options"},{"type":"function","doc":"* `blurred_image` or\n\n* raises an exception.","title":"Returns - Image.blur!/2","ref":"Image.html#blur!/2-returns"},{"type":"function","doc":"Apply a percentage adjustment to an image's brightness\n(luminance).\n\nThe image is converted to the `lch` color space, multiplies the\nluminance band by the provided float percentage and converts\nthe image back to its original color space.","title":"Image.brightness/2","ref":"Image.html#brightness/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `brightness` is any float greater than `0.0`. A number less\n  than `1.0` means reduce brightness. A number greater than `1.0`\n  means increas brightness.","title":"Arguments - Image.brightness/2","ref":"Image.html#brightness/2-arguments"},{"type":"function","doc":"* `{:ok, adjusted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.brightness/2","ref":"Image.html#brightness/2-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/cat.png\")\n    iex> {:ok, _brighter_image} = Image.brightness(image, 1.5)","title":"Example - Image.brightness/2","ref":"Image.html#brightness/2-example"},{"type":"function","doc":"Apply a percentage adjustment to an image's brightness\n(luminance) or raises an exception.\n\nThe image is converted to the `lch` color space, multiplies the\nluminance band by the provided float percentage and converts\nthe image back to its original color space.","title":"Image.brightness!/2","ref":"Image.html#brightness!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `brightness` is any float greater than `0.0`. A number less\n  than `1.0` means reduce brightness. A number greater than `1.0`\n  means increas brightness.","title":"Arguments - Image.brightness!/2","ref":"Image.html#brightness!/2-arguments"},{"type":"function","doc":"* `adjusted_image` or\n\n* raises an exception.","title":"Returns - Image.brightness!/2","ref":"Image.html#brightness!/2-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/cat.png\")\n    iex> _brighter_image = Image.brightness!(image, 1.5)","title":"Example - Image.brightness!/2","ref":"Image.html#brightness!/2-example"},{"type":"function","doc":"Casts an image from one band format to another.\n\nThe band format is the numeric type of each pixel.\nIn the common case of `sRGB` images, the format is\n`{:u, 8}` meaning unsigned 8-bit values.","title":"Image.cast/2","ref":"Image.html#cast/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `band_format` is any known band format. See\n  `Image.BandFormat.known_band_formats/0`.","title":"Arguments - Image.cast/2","ref":"Image.html#cast/2-arguments"},{"type":"function","doc":"* `{:ok, cast_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.cast/2","ref":"Image.html#cast/2-returns"},{"type":"function","doc":"Casts an image from one band format to another or\nraises an exception.\n\nThe band format is the numeric type of each pixel.\nIn the common case of `sRGB` images, the format is\n`{:u, 8}` meaning unsigned 8-bit values.","title":"Image.cast!/2","ref":"Image.html#cast!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `band_format` is any known band format. See\n  `Image.BandFormat.known_band_formats/0`.","title":"Arguments - Image.cast!/2","ref":"Image.html#cast!/2-arguments"},{"type":"function","doc":"* `cast_image` or\n\n* raises an exception.","title":"Returns - Image.cast!/2","ref":"Image.html#cast!/2-returns"},{"type":"function","doc":"Crops the center from an image.","title":"Image.center_crop/3","ref":"Image.html#center_crop/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `width` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `width` is an integer it is the absolute number\n  of pixels. If `width` is a float it is the fraction\n  of the original image width.\n\n* `height` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `height` is an integer it is the absolute number\n  of pixels. If `height` is a float it is the fraction\n  of the original image height.","title":"Arguments - Image.center_crop/3","ref":"Image.html#center_crop/3-arguments"},{"type":"function","doc":"* An error will be returned if `width` and `height` are\n  not equal to or smaller than the `image` dimensions.\n\n* This function is a convenience function equivalent to\n  calling `Image.crop(image, :center, :middle, width, height)`.","title":"Notes - Image.center_crop/3","ref":"Image.html#center_crop/3-notes"},{"type":"function","doc":"* `{:ok, cropped_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.center_crop/3","ref":"Image.html#center_crop/3-returns"},{"type":"function","doc":"Crops the center from an image.","title":"Image.center_crop!/3","ref":"Image.html#center_crop!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `width` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `width` is an integer it is the absolute number\n  of pixels. If `width` is a float it is the fraction\n  of the original image width.\n\n* `height` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `height` is an integer it is the absolute number\n\n  of pixels. If `height` is a float it is the fraction\n  of the original image height.","title":"Arguments - Image.center_crop!/3","ref":"Image.html#center_crop!/3-arguments"},{"type":"function","doc":"* An error will be returned if `width` and `height` are\n  not equal to or smaller than the `image` dimensions.\n\n* This function is a convenience function equivalent to\n  calling `Image.crop!(image, :center, :middle, width, height)`.","title":"Notes - Image.center_crop!/3","ref":"Image.html#center_crop!/3-notes"},{"type":"function","doc":"* `cropped_image` or\n\n* raises an exception.","title":"Returns - Image.center_crop!/3","ref":"Image.html#center_crop!/3-returns"},{"type":"function","doc":"Automatically determine the chroma key\ncolor of an image.\n\nThe top left 10x10 pixels of the flattened\nimage are averaged to produce a color sample\nthat can then be used by `Image.chroma_mask/2`,\n`Image.chroma_key/2` and `Image.trim/2`.","title":"Image.chroma_color/1","ref":"Image.html#chroma_color/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Argument - Image.chroma_color/1","ref":"Image.html#chroma_color/1-argument"},{"type":"function","doc":"* An RGB color as a three-element list of\n  integers.","title":"Returns - Image.chroma_color/1","ref":"Image.html#chroma_color/1-returns"},{"type":"function","doc":"Chroma key an image.\n\nChroma keying is the process of removing a background color\nfrom an image resulting in a foreground image that may\nbe composited over another image.\n\nIf the image already has an alpha band then the\nimage is flattened before adding the image mask\nas a new alpha band.","title":"Image.chroma_key/2","ref":"Image.html#chroma_key/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.chroma_key/2","ref":"Image.html#chroma_key/2-arguments"},{"type":"function","doc":"There are two masking strategies available: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be masked. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold` is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n*  `:less_than` is an RGB color which represents the lower\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.chroma_key/2","ref":"Image.html#chroma_key/2-options"},{"type":"function","doc":"Chroma key an image and return an image or\nraise an exception.\n\nChroma keying is the process of removing a background color\nfrom an image resulting in a foreground image that may\nbe composited over another image.\n\nIf the image already has an alpha band then the\nimage is flattened before adding the image mask\nas a new alpha band.","title":"Image.chroma_key!/2","ref":"Image.html#chroma_key!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.chroma_key!/2","ref":"Image.html#chroma_key!/2-arguments"},{"type":"function","doc":"There are two masking strategies available: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be masked. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold` is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n*  `:less_than` is an RGB color which represents the lower\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.chroma_key!/2","ref":"Image.html#chroma_key!/2-options"},{"type":"function","doc":"Return a chroma-based masked image.\n\nChroma masking is the process of removing a background color\nfrom an image and returning the remaining content as an alpha\nmask.\n\nThe masking is done in the LCh color space since it's perceptually\nmore uniform.  The returned mask in reverted to the interpretation\nof the original image.","title":"Image.chroma_mask/2","ref":"Image.html#chroma_mask/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.chroma_mask/2","ref":"Image.html#chroma_mask/2-arguments"},{"type":"function","doc":"There are two masking strategies available: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be masked. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold`is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n * `:less_than` is an RGB color which represents the lower\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.chroma_mask/2","ref":"Image.html#chroma_mask/2-options"},{"type":"function","doc":"Return a chroma-based masked image or raises\nan exception.\n\nChroma masking is the process of removing a background color\nfrom an image and returning the remaining content as an alpha\nmask.","title":"Image.chroma_mask!/2","ref":"Image.html#chroma_mask!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.chroma_mask!/2","ref":"Image.html#chroma_mask!/2-arguments"},{"type":"function","doc":"There are two masking strategies available: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be masked. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold`is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n * `:less_than` is an RGB color which represents the lower\n   end of the color range to be masked. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.chroma_mask!/2","ref":"Image.html#chroma_mask!/2-options"},{"type":"function","doc":"Apply a circular mask to an image.\n\nThe returned image has an alpha\nband masking the circular image.\n\nAs a result, it is best saved to a\nformat, like `.png` that supports\nalpha transparency.\n\nNote that `.jpg` files do not support\nalpha transparency.","title":"Image.circle/2","ref":"Image.html#circle/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.circle/2","ref":"Image.html#circle/2-arguments"},{"type":"function","doc":"* `{:ok, circular_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.circle/2","ref":"Image.html#circle/2-returns"},{"type":"function","doc":"Apply a circular mask to an image\nreturning an image or raising an\nexception.\n\nThe returned image has an alpha\nband masking the circular image.\n\nAs a result, it is best saved to a\nformat, like `.png` that supports\nalpha transparency.\n\nNote that `.jpg` files do not support\nalpha transparency.","title":"Image.circle!/2","ref":"Image.html#circle!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.circle!/2","ref":"Image.html#circle!/2-arguments"},{"type":"function","doc":"* `circular_image` or\n\n* raises an exception.","title":"Returns - Image.circle!/2","ref":"Image.html#circle!/2-returns"},{"type":"function","doc":"Returns the image colorspace.\n\nThe colorspace is how `Image` understands\nthe image data. For example, `:srgb`, `:cmyk` or\n`:bw`.\n\nFor most common web applications, the\ncolorspace will be `:srgb`.","title":"Image.colorspace/1","ref":"Image.html#colorspace/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.colorspace/1","ref":"Image.html#colorspace/1-arguments"},{"type":"function","doc":"* The image colorspace as an atom.","title":"Returns - Image.colorspace/1","ref":"Image.html#colorspace/1-returns"},{"type":"function","doc":"* See also `Image.Interpretation.known_interpretations/0`","title":"Notes - Image.colorspace/1","ref":"Image.html#colorspace/1-notes"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Kamchatka-2019-8754.jpg\")\n    iex> Image.colorspace(image)\n    :srgb","title":"Example - Image.colorspace/1","ref":"Image.html#colorspace/1-example"},{"type":"function","doc":"Compare two images using a particular comparison metric\nreturning a score indicating the similarity of the images.","title":"Image.compare/3","ref":"Image.html#compare/3"},{"type":"function","doc":"* `image_1` is any `t:Vix.Vips.Image.t/0`.\n\n* `image_2` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.compare/3","ref":"Image.html#compare/3-arguments"},{"type":"function","doc":"* `:metric` indicates which comparison metric to use. The default\n  is `:ae`. The valid metrics are:\n\n  * [:ae](https://en.wikipedia.org/wiki/Sum_of_absolute_differences) which returns\n    the absolute nuber of pixels that are different between the two images.\n    The returned value is conformed to the range of the underlying image format.\n    Therefore the returned value is between `0.0` (images appear to be the same)\n    and `1.0` (meaning the images appear completely different).\n\n  * [:rmse](https://en.wikipedia.org/wiki/Root-mean-square_deviation) is the root\n    mean square error. The returned value is conformed to the range of\n    the underlying image format. Therefore the returned value is between `0.0`\n    (images appear to be the same) and `1.0` (meaning the images appear\n    completely different),\n\n  * [:mse](https://en.wikipedia.org/wiki/Mean_squared_error) which\n    is the mean squared error (default). The returned value is a float\n    indicating how similar the images are. A value of\n    `0.0` means the images are the same. The number itself it simply a\n    measure of the error difference between images. A larger number means\n    the two images are less similar but the number itself cannot be\n    interpreted as a percentage value.\n\n* `:difference_color` is the color to be used for the pixels that are\n  different between the two images. This can be specified as a single integer\n  which will be applied to all bands, or a list of integers representing\n  he color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of the form `#rrggbb`. The default\n  is `:red`.\n\n* `:difference_boost` is a float multiplier that is applied to the difference\n  image. This has the effect of boosting the overall brightness of the difference\n  pixels making them stand out more against the background image. The default\n  is `1.5`.\n\n* `:saturation` is a float between `0.0` and `1.0` that is applied to the\n  base image when overlaying the difference image. This may help the difference\n  pixels become more obvious. The default ia `1.0` meaning no change in\n  saturation.\n\n* `:brightness` is a float between `0.0` and `1.0` that is applied to the\n  base image when overlaying the difference image. This may help the difference\n  pixels become more obvious. The default ia `1.0` meaning no change in\n  brightness.","title":"Options - Image.compare/3","ref":"Image.html#compare/3-options"},{"type":"function","doc":"* The images are conformed to the band format of the\n  first image before comparison and cast up to the smallest common\n  format.\n\n* If the images differ in size, the smaller image is enlarged\n  to match the larger by adding zero pixels along the bottom and right.\n\n* If the number of bands differs, one of the images must have one band.\n  In this case, an n-band image is formed from the one-band image by joining\n  `n` copies of the one-band image together, and then the two n-band images\n  are operated upon.\n\n* The two input images are cast up to the smallest common format.","title":"Notes - Image.compare/3","ref":"Image.html#compare/3-notes"},{"type":"function","doc":"* `{:ok, comparison_score}` or\n\n* `{:error, reason}`","title":"Returns - Image.compare/3","ref":"Image.html#compare/3-returns"},{"type":"function","doc":"Compose two images together, or an image and a list of\nimages compositions, to form a new image.","title":"Image.compose/3","ref":"Image.html#compose/3"},{"type":"function","doc":"* `base_image` is any `t:Vix.Vips.Image.t/0`.\n\n* `overlay_image` is any `t:Vix.Vips.Image.t/0` that will\n  be composed over the top of `base_image`. It can also\n  be a list of `t:composition/0`s that allow for multiple\n  images to be composed in a single call.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.compose/3","ref":"Image.html#compose/3-arguments"},{"type":"function","doc":"* `:blend_mode` is the manner in which the two\n  images are composited. See `t:Image.BlendMode.t/0`.\n  The default is `:over` which is the most common blend\n  mode.\n\n* `:x` is the offset (0-based) which, if zero or positive,\n  from the *left* of the `base_image`. If negative is is\n  the offset from the *right* of the `base_image`.\n  where the `overlay_image` will be placed. It may also be\n  one of the keywords `:left`, `:right` or `:center`. The\n  default is `:center`.\n\n* `:y` is the offset (0-based) which, if zero or positive,\n  from the *top* of the `base_image`. If negative is is\n  the offset from the *bottom* of the `base_image`.\n  where the `overlay_image` will be placed.  It may also be\n  one of the keywords `:top`, `:bottom` or `:middle`. The\n  default is `:middle`.","title":"Options for a single overlay image - Image.compose/3","ref":"Image.html#compose/3-options-for-a-single-overlay-image"},{"type":"function","doc":"When `overlay_image` is an `image_list`, each entry in\nthe list is either a `t:Vix.Vips.Image.t/0` or a\n`t:Image.composition_list/0`. A composition supports the specification\nof how a particular image is composed onto the base image.\n\n* `:x` describes the absolute `x` offset on the\n  base image where this image will be placed. If\n  this option is set to `:left`, `:center` or\n  `:right` then the `x` position will be calculated\n  relative to the base image. If `:x` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dx`.\n\n* `:y` describes the absolute `y` offset on the\n  base image where this image will be placed. If\n  this option is set to `:top`, `:middle` or\n  `:bottom` then the `y` position will be calculated\n  relative to the base image. If `:y` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dy`.\n\n* `:dx` describes the relative offset used to calculate\n  the `x` value. `:dx` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:x_baseline` option. If `:x` is also\n  specified then `:x` is first calculated, then `:dx` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:dy` describes the relative offset used to calculate\n  the `y` value. `:dy` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:y_baseline` option. If `:y` is also\n  specified then `:y` is first calculated, then `:dy` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:blend_mode` is the `t:Image.BlendMode.t/0` used when\n  composing this image over its base image. The default\n  is `:over` which is appropriate for most use cases.\n\n* `:x_baseline` establishes the baseline on the\n  previously composed image from which `:dx` is\n  calculated. The default is `:right`.\n\n* `:y_baseline` establishes the baseline on the\n  previously composed image from which `:dy` is\n  calculated. The default is `:bottom`.","title":"Composition list options - Image.compose/3","ref":"Image.html#compose/3-composition-list-options"},{"type":"function","doc":"* `{:ok, composed_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.compose/3","ref":"Image.html#compose/3-returns"},{"type":"function","doc":"# Compose images over a base image using\n    # absolute coordinates from the base image\n    # to place each overlay image.\n\n    #=> {:ok, image} = Image.compose(base_image, polygon, x: :middle, y: :top)\n    #=> {:ok, image} = Image.compose(image, explore_new, x: 260, y: 200)\n    #=> {:ok, image} = Image.compose(image, places, x: 260, y: 260)\n    #=> {:ok, image} = Image.compose(image, blowout, x: 260, y: 340)\n    #=> {:ok, image} = Image.compose(image, start_saving, x: 260, y: 400)\n\n    # Compose images over a base image\n    # using a composition list and coordinates\n    # that are either absolute with respect to the\n    # base image or relative to the previously\n    # composed image.\n\n    #=> Image.compose(base_image, [\n    ..>   {polygon, x: :center, y: :top},\n    ..>   {explore_new, y_baseline: :top, x_baseline: :left, dx: 20, dy: 200},\n    ..>   {places, dy: 10},\n    ..>   {blowout, dy: 20},\n    ..>   {start_saving, dy: 50}\n    ..> ])","title":"Examples - Image.compose/3","ref":"Image.html#compose/3-examples"},{"type":"function","doc":"Compose two images together to form a new image or\nraise an exception.","title":"Image.compose!/3","ref":"Image.html#compose!/3"},{"type":"function","doc":"* `base_image` is any `t:Vix.Vips.Image.t/0`.\n\n* `overlay_image` is any `t:Vix.Vips.Image.t/0` that will\n  be composed over the top of `base_image`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.compose!/3","ref":"Image.html#compose!/3-arguments"},{"type":"function","doc":"* `:blend_mode` is the manner in which the two\n  images are composited. See `t:Image.BlendMode.t/0`.\n  The default is `:over` which is the most common blend\n  mode.\n\n* `:x` is the offset (0-based) which, if zero or positive,\n  from the *left* of the `base_image`. If negative is is\n  the offset from the *right* of the `base_image`.\n  where the `overlay_image` will be placed. It may also be\n  one of the keywords `:left`, `:right` or `:center`. The\n  default is `:center`.\n\n* `:y` is the offset (0-based) which, if zero or positive,\n  from the *top* of the `base_image`. If negative is is\n  the offset from the *bottom* of the `base_image`.\n  where the `overlay_image` will be placed.  It may also be\n  one of the keywords `:top`, `:bottom` or `:middle`. The\n  default is `:middle`.","title":"Options - Image.compose!/3","ref":"Image.html#compose!/3-options"},{"type":"function","doc":"When `overlay_image` is an `image_list`, each entry in\nthe list is either a `t:Vix.Vips.Image.t/0` or a\n`t:Image.composition_list/0`. A composition supports the specification\nof how a particular image is composed onto the base image.\n\n* `:x` describes the absolute `x` offset on the\n  base image where this image will be placed. If\n  this option is set to `:left`, `:center` or\n  `:right` then the `x` position will be calculated\n  relative to the base image. If `:x` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dx`.\n\n* `:y` describes the absolute `y` offset on the\n  base image where this image will be placed. If\n  this option is set to `:top`, `:middle` or\n  `:bottom` then the `y` position will be calculated\n  relative to the base image. If `:y` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dy`.\n\n* `:dx` describes the relative offset used to calculate\n  the `x` value. `:dx` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:x_baseline` option. If `:x` is also\n  specified then `:x` is first calculated, then `:dx` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:dy` describes the relative offset used to calculate\n  the `y` value. `:dy` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:y_baseline` option. If `:y` is also\n  specified then `:y` is first calculated, then `:dy` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:blend_mode` is the `t:Image.BlendMode.t/0` used when\n  composing this image over its base image. The default\n  is `:over` which is appropriate for most use cases.\n\n* `:x_baseline` establishes the baseline on the\n  previously composed image from which `:dx` is\n  calculated. The default is `:right`.\n\n* `:y_baseline` establishes the baseline on the\n  previously composed image from which `:dy` is\n  calculated. The default is `:bottom`.","title":"Composition list options - Image.compose!/3","ref":"Image.html#compose!/3-composition-list-options"},{"type":"function","doc":"* `composed_image` or\n\n* raises an exception","title":"Returns - Image.compose!/3","ref":"Image.html#compose!/3-returns"},{"type":"function","doc":"# Compose images over a base image using\n    # absolute  coordinates from the base image\n    # to place each overlay image\n    #=> base_image\n    ..> |> Image.compose!(polygon, x: :middle, y: :top)\n    ..> |> Image.compose!(explore_new, x: 260, y: 200)\n    ..> |> Image.compose!(places, x: 260, y: 260)\n    ..> |> Image.compose!(blowout, x: 260, y: 340)\n    ..> |> Image.compose!(start_saving, x: 260, y: 400)\n\n    # Compose images over a base image\n    # using a composition list and coordinates\n    # that are either absolute with respect to the\n    # base image or relative to the previously\n    # composed image\n    #=> base_image\n    ..> |> Image.compose!([\n    ..>   {polygon, x: :center, y: :top},\n    ..>   {explore_new, y_baseline: :top, x_baseline: :left, dx: 20, dy: 200},\n    ..>   {places, dy: 10},\n    ..>   {blowout, dy: 20},\n    ..>   {start_saving, dy: 50}\n    ..> ])","title":"Examples - Image.compose!/3","ref":"Image.html#compose!/3-examples"},{"type":"function","doc":"Apply a percentage adjustment to an image's contrast.\n\nThis is a simple implementation that applies a linear\nfunction to the image. In most cases, `Image.apply_tone_curve/2`\nshould be preferred for making constrast adjustments.\n\nSmall increments can have a dramatic affect on the image;\ncontrast in the range of approximately `0.5` to `1.5` are\nlikely to meet most requirement.","title":"Image.contrast/2","ref":"Image.html#contrast/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `contrast` is any float greater than `0.0`. A number less\n  than `1.0` means reduce contrast. A number greater than `1.0`\n  means increase contrast.","title":"Arguments - Image.contrast/2","ref":"Image.html#contrast/2-arguments"},{"type":"function","doc":"* `{:ok, adjusted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.contrast/2","ref":"Image.html#contrast/2-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/cat.png\")\n    iex> {:ok, _image_with_more_contrast} = Image.contrast(image, 1.2)","title":"Example - Image.contrast/2","ref":"Image.html#contrast/2-example"},{"type":"function","doc":"Apply a percentage adjustment to an image's contrast or\nraises and exception.\n\nThis is a simple implementation that applies a linear\nfunction to the image. In most cases, `Image.apply_tone_curve/2`\nshould be preferred for making constrast adjustments.\n\nSmall increments can have a dramatic affect on the image;\ncontrast in the range of approximately `0.5` to `1.5` are\nlikely to meet most requirement.","title":"Image.contrast!/2","ref":"Image.html#contrast!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `contrast` is any float greater than `0.0`. A number less\n  than `1.0` means reduce contrast. A number greater than `1.0`\n  means increase contrast.","title":"Arguments - Image.contrast!/2","ref":"Image.html#contrast!/2-arguments"},{"type":"function","doc":"* `adjusted_image` or\n\n* raises an exception.","title":"Returns - Image.contrast!/2","ref":"Image.html#contrast!/2-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/cat.png\")\n    iex> _image_with_more_contrast = Image.contrast!(image, 1.2)","title":"Example - Image.contrast!/2","ref":"Image.html#contrast!/2-example"},{"type":"function","doc":"Convert an image alpha band into a mask.\n\nTakes an image, extracts its alpha band\nwhich holds the opacity information and\ninverts the content to produce a mask.","title":"Image.convert_alpha_to_mask/1","ref":"Image.html#convert_alpha_to_mask/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.convert_alpha_to_mask/1","ref":"Image.html#convert_alpha_to_mask/1-arguments"},{"type":"function","doc":"* `{:ok, mask}` or\n\n* `{:error, reason}`","title":"Returns - Image.convert_alpha_to_mask/1","ref":"Image.html#convert_alpha_to_mask/1-returns"},{"type":"function","doc":"Convert an image alpha band into a mask returning\nan image or raising an exception.\n\nTakes an image, extracts its alpha band\nwhich holds the opacity information and\ninverts the content to produce a mask.","title":"Image.convert_alpha_to_mask!/1","ref":"Image.html#convert_alpha_to_mask!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.convert_alpha_to_mask!/1","ref":"Image.html#convert_alpha_to_mask!/1-arguments"},{"type":"function","doc":"* `mask` image or\n\n* raises an exception","title":"Returns - Image.convert_alpha_to_mask!/1","ref":"Image.html#convert_alpha_to_mask!/1-returns"},{"type":"function","doc":"Crop an image.","title":"Image.crop/2","ref":"Image.html#crop/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `quadrilateral` is a list of four 2-tuples\n  representing the points of the bounding rectangle. The\n  points must be ordered as `[top_left, top_right, bottom_right, bottom_left]`\n  Each point is of the form `{x, y}` where `x` is the\n  0-based offset from the left of the image and `y` is\n  the 0-based offset from the top of the image.","title":"Arguments - Image.crop/2","ref":"Image.html#crop/2-arguments"},{"type":"function","doc":"* `{:ok, cropped_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.crop/2","ref":"Image.html#crop/2-returns"},{"type":"function","doc":"The bounding box must be a rectangle, not an\narbitrary quadrilateral. If required, use `Image.warp_perspective/4`\nprior to cropping.","title":"Note - Image.crop/2","ref":"Image.html#crop/2-note"},{"type":"function","doc":"Crop an image.","title":"Image.crop/5","ref":"Image.html#crop/5"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `left` is the top edge of crop area as an\n  integer or a float in the range `-1.0..1.0`.\n  If `left` is an integer it is the absolute number\n  of pixels. If `left` is a float it's a fraction of the width\n  of the image. If `left` is positive it is relative to\n  the left edge of the image. If it's negative it's\n  relative to the right edge of the image. `left` may\n  also be one of `:left`, `:center` and `:right`\n  indicating the crop is relative to the left, center\n  or right of the image.\n\n* `top` is the top edge of crop area as an\n  integer or a float in the range `-1.0..1.0`.\n  If `top` is an integer it is the absolute number of\n  pixels. If `top` is a float it's a fraction of the height\n  of the image. If `top` is positive it is relative to\n  the top edge of the image. If it's negative it's\n  relative to the bottom edge of the image. `top` may\n  also be one of `:top`, `:middle` and `:bottom`\n  indicating the crop is relative to the top, middle\n  or bottom of the image.\n\n* `width` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `width` is an integer it is the absolute number\n  of pixels. If `width` is a float it's the fraction\n  of the original image width.\n\n* `height` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `height` is an integer it's the absolute number\n  of pixels. If `height` is a float it's the fraction\n  of the original image height.","title":"Arguments - Image.crop/5","ref":"Image.html#crop/5-arguments"},{"type":"function","doc":"* `left` is 0-indexed. That is, the leftmost\n  edge of the image starts at `0`.\n\n* `top` is 0-indexed. That is, the topmost\n  edge of the image starts at `0`.\n\n* If the image has multiple pages, like an animated\n  `.gif` or `.webp` then each page is extracted,\n  cropped and then the image reassembled.","title":"Notes - Image.crop/5","ref":"Image.html#crop/5-notes"},{"type":"function","doc":"* `{:ok, cropped_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.crop/5","ref":"Image.html#crop/5-returns"},{"type":"function","doc":"Crop an image or raises an exception.","title":"Image.crop!/2","ref":"Image.html#crop!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `quadrilateral` is a list of four 2-tuples\n  representing the points of the bounding rectangle. The\n  points must be ordered as `[top_left, top_right, bottom_right, bottom_left]`\n  Each point is of the form `{x, y}` where `x` is the\n  0-based offset from the left of the image and `y` is\n  the 0-based offset from the top of the image.","title":"Arguments - Image.crop!/2","ref":"Image.html#crop!/2-arguments"},{"type":"function","doc":"* `cropped_image` or\n\n* raises an exception.","title":"Returns - Image.crop!/2","ref":"Image.html#crop!/2-returns"},{"type":"function","doc":"The bounding box must be a rectangle, not an\narbitrary quadrilateral. If required, use `Image.warp_perspective/4`\nprior to cropping.","title":"Note - Image.crop!/2","ref":"Image.html#crop!/2-note"},{"type":"function","doc":"Crop an image returning a cropped image\nor raising an exception.","title":"Image.crop!/5","ref":"Image.html#crop!/5"},{"type":"function","doc":"* `left` is the top edge of crop area as an\n  integer or a float in the range `-1.0..1.0`.\n  If `left` is an integer it is the absolute number\n  of pixels. If `left` a float is fraction of the width\n  of the image. If `left` is positive it is relative to\n  the left edge of the image. If it is negative it is\n  relative to the right edge of the image. `left` may\n  also be one of `:left`, `:center` and `:right`\n  indicating the crop is relative to the left, center\n  or right of the image.\n\n* `top` is the top edge of crop area as an\n  integer or a float in the range `-1.0..1.0`.\n  If `top` is an integer it is the absolute number of\n  pixels. If `top` is a float is fraction of the height\n  of the image. If `top` is positive it is relative to\n  the top edge of the image. If it is negative it is\n  relative to the bottom edge of the image. `top` may\n  also be one of `:top`, `:middle` and `:bottom`\n  indicating the crop is relative to the top, middle\n  or bottom of the image.\n\n* `width` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `width` is an integer it is the absolute number\n  of pixels. If `width` is a float it is the fraction\n  of the original image width.\n\n* `height` is the width of area remaining as a\n  positive integer or float in the range `0.0..1.0`.\n  If `height` is an integer it is the absolute number\n  of pixels. If `height` is a float it is the fraction\n  of the original image height.","title":"Arguments - Image.crop!/5","ref":"Image.html#crop!/5-arguments"},{"type":"function","doc":"* `cropped_image` or\n\n* raises an exception.","title":"Returns - Image.crop!/5","ref":"Image.html#crop!/5-returns"},{"type":"function","doc":"Returns the [color difference](https://en.wikipedia.org/wiki/Color_difference)\nbetween two colors calculated using the\n[CIE](https://cie.co.at) [ΔE*](https://en.wikipedia.org/wiki/Color_difference#CIELAB_ΔE*)\nalgorithms.\n\nThe available difference algorithms are:\n\n* [CIDE2000](https://en.wikipedia.org/wiki/Color_difference#CIEDE2000)\n* [CIE CMC](https://en.wikipedia.org/wiki/Color_difference#CMC_l:c_(1984))\n* [CIE 1976](https://en.wikipedia.org/wiki/Color_difference#CIE76)","title":"Image.delta_e/3","ref":"Image.html#delta_e/3"},{"type":"function","doc":"* `color_1` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. Lastly, the\n  color can be supplied as a hex string like `#ffe4e1`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `color_2` which is specified in the same manner as `color_1`.\n\n* `version` is one of `:de00` (the default), `:decmc` or `:de76`.","title":"Arguments - Image.delta_e/3","ref":"Image.html#delta_e/3-arguments"},{"type":"function","doc":"* `{:ok, int_distance}` where `int_distance` is `0`\n  when the colors are identical and `100` when they are completely\n  different.\n\n* `{:error, reason}`.","title":"Returns - Image.delta_e/3","ref":"Image.html#delta_e/3-returns"},{"type":"function","doc":"iex> Image.delta_e([0,0,0], [0,0,0])\n    {:ok, 0.0}\n\n    iex> Image.delta_e([0,0,0], [255,255,255])\n    {:ok, 100.0}\n\n    iex> Image.delta_e([0,0,0], :misty_rose)\n    {:ok, 90.15503692626953}\n\n    iex> Image.delta_e(:green, :misty_rose)\n    {:ok, 52.937347412109375}\n\n    iex> Image.delta_e(:green, :misty_rose, :de76)\n    {:ok, 88.5516128540039}","title":"Examples - Image.delta_e/3","ref":"Image.html#delta_e/3-examples"},{"type":"function","doc":"Returns the [color difference](https://en.wikipedia.org/wiki/Color_difference)\nbetween two colors calculated using the\n[CIE](https://cie.co.at) [ΔE*](https://en.wikipedia.org/wiki/Color_difference#CIELAB_ΔE*)\nalgorithms or raises an exception.\n\nThe available difference algorithms are:\n\n* [CIDE2000](https://en.wikipedia.org/wiki/Color_difference#CIEDE2000)\n* [CIE CMC](https://en.wikipedia.org/wiki/Color_difference#CMC_l:c_(1984))\n* [CIE 1976](https://en.wikipedia.org/wiki/Color_difference#CIE76)","title":"Image.delta_e!/3","ref":"Image.html#delta_e!/3"},{"type":"function","doc":"* `color_1` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. Lastly, the\n  color can be supplied as a hex string like `#ffe4e1`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `color_2` which is specified in the same manner as `color_1`.\n\n* `version` is one of `:de00` (the default), `:decmc` or `:de76`.","title":"Arguments - Image.delta_e!/3","ref":"Image.html#delta_e!/3-arguments"},{"type":"function","doc":"* `{:ok, int_distance}` where `int_distance` is `0`\n  when the colors are identical and `100` when they are completely\n  different.\n\n* `{:error, reason}`.","title":"Returns - Image.delta_e!/3","ref":"Image.html#delta_e!/3-returns"},{"type":"function","doc":"iex> Image.delta_e!([0,0,0], [0,0,0])\n    0.0\n\n    iex> Image.delta_e!([0,0,0], [255,255,255])\n    100.0\n\n    iex> Image.delta_e!([0,0,0], :misty_rose)\n    90.15503692626953\n\n    iex> Image.delta_e!(:green, :misty_rose)\n    52.937347412109375\n\n    iex> Image.delta_e!(:green, :misty_rose, :de76)\n    88.5516128540039","title":"Examples - Image.delta_e!/3","ref":"Image.html#delta_e!/3-examples"},{"type":"function","doc":"Returns a 64-bit (for a has size of the default 64) difference hash as a\nbinary.\n\nImage hashes can be used to compare the similarity\nof images. See `Image.hamming_distance/2`.\n\ndhash is generates a \"difference hash\" for a given image. This\nis a perceptual hash based on Neal Krawetz's dHash algorithm in\na [Hacker Factor](http://www.hackerfactor.com/blog/index.php?/archives/529-Kind-of-Like-That.html)\nblog entry.\n\nThe code is adapted from the Ruby implementation in\n[dhash-vips](https://github.com/Nakilon/dhash-vips).","title":"Image.dhash/2","ref":"Image.html#dhash/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `hash_size_bits` is the size in bits of the returned hash.\n  The default is `64`. The returned binary is only\n  guaranteed to be the provided size if `sqrt(hash_size_bits)` is\n  an integer.","title":"Arguments - Image.dhash/2","ref":"Image.html#dhash/2-arguments"},{"type":"function","doc":"* `{:ok, 64-bit binary}` or\n\n* `{:error, reason}`","title":"Returns - Image.dhash/2","ref":"Image.html#dhash/2-returns"},{"type":"function","doc":"iex> {:ok, image} = Image.open(\"./test/support/images/Kamchatka-2019-8754.jpg\")\n      iex> Image.dhash(image)\n      {:ok, <<227, 127, 61, 34, 206, 143, 156, 122>>}","title":"Example - Image.dhash/2","ref":"Image.html#dhash/2-example"},{"type":"function","doc":"","title":"Image.dhash_pixels/3","ref":"Image.html#dhash_pixels/3"},{"type":"function","doc":"Dilate an image mask, adding a pixels to the\nedge of the mask.\n\nMask is used in the sense of an image, potentially\nwuth an alpha band. The results on\nother image types is undefined.\n\nThe added pixels are the same color as the edge\npixels in the mask.","title":"Image.dilate/2","ref":"Image.html#dilate/2"},{"type":"function","doc":"* `image` is any non-complex `t:Vix.Vips.Image.t/0`.\n\n* `radius` is an integer in the range `1..100`\n  representing the approximate number of\n  pixels to dilate. The default is `1`.","title":"Arguments - Image.dilate/2","ref":"Image.html#dilate/2-arguments"},{"type":"function","doc":"* `{:ok, dilated_mask}` or\n\n* `{:error, reason}`","title":"Returns - Image.dilate/2","ref":"Image.html#dilate/2-returns"},{"type":"function","doc":"* Dilate works for any non-complex image type, with any\n  number of bands. The input is dilated by copying\n  edge pixels before performing the operation so that\n  the output image has the same size as the input.\n\n* Edge pixels in the output image are only\n  approximate.\n\n* The dilation is implemented as a [rank filter](https://www.sciencedirect.com/science/article/abs/pii/S0031320301000474?via%3Dihub).","title":"Notes - Image.dilate/2","ref":"Image.html#dilate/2-notes"},{"type":"function","doc":"Dilate an image mask, adding a pixels to the\nedge of the mask or raising an exception.\n\nMask is used in the sense of an image, potentially\nwuth an alpha band. The results on\nother image types is undefined.\n\nThe added pixels are the same color as the edge\npixels in the mask.","title":"Image.dilate!/2","ref":"Image.html#dilate!/2"},{"type":"function","doc":"* `image` is any non-complex `t:Vix.Vips.Image.t/0`.\n\n* `radius` is an integer in the range `1..100`\n  representing the approximate number of\n  pixels to dilate. The default is `1`.","title":"Arguments - Image.dilate!/2","ref":"Image.html#dilate!/2-arguments"},{"type":"function","doc":"* `dilated_mask` or\n\n* raises an exception.","title":"Returns - Image.dilate!/2","ref":"Image.html#dilate!/2-returns"},{"type":"function","doc":"* Dilate works for any non-complex image type, with any\n  number of bands. The input is dilated by copying\n  edge pixels before performing the operation so that\n  the output image has the same size as the input.\n\n* Edge pixels in the output image are only\n  approximate.\n\n* The dilation is implemented as a [rank filter](https://www.sciencedirect.com/science/article/abs/pii/S0031320301000474?via%3Dihub).","title":"Notes - Image.dilate!/2","ref":"Image.html#dilate!/2-notes"},{"type":"function","doc":"Returns the dominant sRGB color of an image.","title":"Image.dominant_color/2","ref":"Image.html#dominant_color/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.dominant_color/2","ref":"Image.html#dominant_color/2-arguments"},{"type":"function","doc":"* `:bins` is an integer number of color\n  frequency bins the image is divided into.\n  The default is `16`.\n\n* `:top_n` returns the top `n` most\n  dominant colors in the image. The default\n  is `1`.","title":"Options - Image.dominant_color/2","ref":"Image.html#dominant_color/2-options"},{"type":"function","doc":"* `{:ok, [r, g, b]}` or\n\n* `{:error, reason}`","title":"Returns - Image.dominant_color/2","ref":"Image.html#dominant_color/2-returns"},{"type":"function","doc":"* `image` will be converted to the `:srgb` colorspace\n  and the dominant color will be returned as an sRGB\n  list.","title":"Notes - Image.dominant_color/2","ref":"Image.html#dominant_color/2-notes"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n    iex> Image.dominant_color(image)\n    {:ok, [8, 8, 24]}\n\n    iex> image = Image.open!(\"./test/support/images/image_with_alpha2.png\")\n    iex> Image.dominant_color(image)\n    {:ok, [88, 88, 88]}","title":"Example - Image.dominant_color/2","ref":"Image.html#dominant_color/2-example"},{"type":"function","doc":"Returns the dominant sRGB color of an image\nor raises an exception.","title":"Image.dominant_color!/2","ref":"Image.html#dominant_color!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.dominant_color!/2","ref":"Image.html#dominant_color!/2-arguments"},{"type":"function","doc":"* `:bins` is an integer number of color\n  frequency bins the image is divided into.\n  The default is `16`.\n\n* `:top_n` returns the top `n` most\n  dominant colors in the image. The default\n  is `1`.","title":"Options - Image.dominant_color!/2","ref":"Image.html#dominant_color!/2-options"},{"type":"function","doc":"* `{:ok, [r, g, b]}` or\n\n* raises an exception.","title":"Returns - Image.dominant_color!/2","ref":"Image.html#dominant_color!/2-returns"},{"type":"function","doc":"* `image` will be converted to the `:srgb` colorspace\n  and the dominant color will be returned as an sRGB\n  list.","title":"Notes - Image.dominant_color!/2","ref":"Image.html#dominant_color!/2-notes"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n    iex> Image.dominant_color!(image)\n    [8, 8, 24]\n\n    iex> image = Image.open!(\"./test/support/images/image_with_alpha2.png\")\n    iex> Image.dominant_color!(image)\n    [88, 88, 88]","title":"Example - Image.dominant_color!/2","ref":"Image.html#dominant_color!/2-example"},{"type":"function","doc":"Embeds an image in a larger image canvas, generating\naddition border pixels if required.","title":"Image.embed/4","ref":"Image.html#embed/4"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `width` is the width in pixels of the canvas\n  image.\n\n* `height` is the height in pixels of the canvas\n  image.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.embed/4","ref":"Image.html#embed/4-arguments"},{"type":"function","doc":"* `:x` is the x-offset into the canvas image\n  where `image` will be embedded. The value may be\n  a positive integer indicating a 0-based offset from\n  the left of the canvas or a negative integer indicating\n  a 1-based offset from the right side of the image.\n  It may also be `:center` (the default) in which case the\n  image will be centered horizontally within the canvas.\n\n* `:y` is the y-offset into the canvas image\n  where `image` will be embedded. The value may be\n  a positive integer indicating a 0-based offset from\n  the top of the canvas or a negative integer indicating\n  a 1-based offset from the bottom of the image.\n  It may also be `:center` (the default) in which case the\n  image will be centered vertically within the canvas.\n\n* `:background_color` defines the color of the generated background\n  pixels. This can be specified as a single integer which will\n  be applied to all bands, or a list of integers representing\n  the color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of\n  the form `#rrggbb`. The default is `:black`. `:background` can\n  also be set to `:average` in which case the background will be\n  the average color of the base image. See also `Image.Color.color_map/0`\n  and `Image.Color.rgb_color/1`.\n\n* `:background_transparency` defines the transparency of the\n  `:background` pixels when `image` has an alpha band.\n  The default is `:opaque`. The values are an integer in the\n  range `0..255` where `0` is transparent and `255` is opaque.\n  The number can also be a float in the range `0.0` to `1.0`.\n  In this case the float is converted to an integer in the range\n  `0..255`. Lastly, the atoms `:transparent` and `:opaque` can\n  also be used.\n\n* `:extend_mode` determines how any additional pixels\n  are generated. The values are:\n\n  * `:black` (the default if no `background_color` is specified)\n    meaning the generated pixels are black.\n  * `:white` meaning the generated pixels are white.\n  * `:copy` means the generated pixels take the value of the\n    nearest edge pixel of the base image.\n  * `:repeat` means the generated pixels are tiles from the\n    base image.\n  * `:mirror` means the generated pixels are reflected tiles of\n    the base image.\n  * `:background` means the generated pixels are the `:background_color`\n    color set in `options`. This is the default if a `background_color`\n    is specified.","title":"Options - Image.embed/4","ref":"Image.html#embed/4-options"},{"type":"function","doc":"* `{:ok, embedded_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.embed/4","ref":"Image.html#embed/4-returns"},{"type":"function","doc":"Embeds an image in a larger image canvas, generating\naddition border pixels if required.","title":"Image.embed!/4","ref":"Image.html#embed!/4"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `width` is the width in pixels of the canvas\n  image.\n\n* `height` is the height in pixels of the canvas\n  image.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.embed!/4","ref":"Image.html#embed!/4-arguments"},{"type":"function","doc":"See `Image.embed/4`.","title":"Options - Image.embed!/4","ref":"Image.html#embed!/4-options"},{"type":"function","doc":"* `embedded_image` or\n\n* raises an exception.","title":"Returns - Image.embed!/4","ref":"Image.html#embed!/4-returns"},{"type":"function","doc":"Equalizes the histogram of an imaage.\n\nEqualization is the process of expanding the\ntone range of an image by stretching the darkest\ntones towards black and the lightest tones towards\nwhite. As a result, equalization affects overall\nimage contrast.","title":"Image.equalize/2","ref":"Image.html#equalize/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `bands` determines which bands are equalized. The\n  value may be one of:\n\n  * `:all` (defaalt) means that all bands are eqalized\n    such that the darkest tones are expanded to black and the\n    lightest tones are expanded to white.\n\n  * `:each` means that each band is equalized individually\n    such that each band is expanded to fill the range\n    between 5% and 95% of the available tone range. Since\n    each band is equalized separately there may be some\n    color shifts detected.\n\n  * `:luminance` means that only the luminance band is\n    equqlized to fill between 1% and 99% of the tone range.\n    The image is converted to the `:lab` color space, the\n    `l` band is equalized and the image is converted back to\n    its origianal color space.","title":"Arguments - Image.equalize/2","ref":"Image.html#equalize/2-arguments"},{"type":"function","doc":"* `{:ok, adjusted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.equalize/2","ref":"Image.html#equalize/2-returns"},{"type":"function","doc":"Apply a global contrast adjustment to an image\nor raises an exception.\n\nEqualization is the process of expanding the\ntone range of an image by stretching the darkest\ntones towards black and the lightest tones towards\nwhite. As a result, equalization affects overall\nimage contrast.","title":"Image.equalize!/2","ref":"Image.html#equalize!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `bands` determines which bands are equalized. The\n  value may be one of:\n\n  * `:all` (defaalt) means that all bands are eqalized\n    such that the darkest tones are expanded to black and the\n    lightest tones are expanded to white.\n\n  * `:each` means that each band is equalized individually\n    such that each band is expanded to fill the range\n    between 5% and 95% of the available tone range. Since\n    each band is equalized separately there may be some\n    color shifts detected.\n\n  * `:luminance` means that only the luminance band is\n    equqlized to fill between 1% and 99% of the tone range.\n    The image is converted to the `:lab` color space, the\n    `l` band is equalized and the image is converted back to\n    its origianal color space.","title":"Arguments - Image.equalize!/2","ref":"Image.html#equalize!/2-arguments"},{"type":"function","doc":"* `adjusted_image` or\n\n* raises an exception.","title":"Returns - Image.equalize!/2","ref":"Image.html#equalize!/2-returns"},{"type":"function","doc":"Erode an image mask, removing pixels from the\nedge of the mask.\n\nMask is used in the sense of an image, potentially\nwuth an alpha band. The results on\nother image types is undefined.","title":"Image.erode/2","ref":"Image.html#erode/2"},{"type":"function","doc":"* `image` is any non-complex `t:Vix.Vips.Image.t/0`.\n\n* `radius` is an integer in the range `1..100`\n  representing the approximate number of\n  pixels to erode. The default is `1`.","title":"Arguments - Image.erode/2","ref":"Image.html#erode/2-arguments"},{"type":"function","doc":"* `{:ok, eroded_mask}` or\n\n* `{:error, reason}`","title":"Returns - Image.erode/2","ref":"Image.html#erode/2-returns"},{"type":"function","doc":"* Erode works for any non-complex image type, with any\n  number of bands. The input is eroded by copying\n  edge pixels before performing the operation so that\n  the output image has the same size as the input.\n\n* Edge pixels in the output image are only\n  approximate.\n\n* The erosion is implemented as a [rank filter](https://www.sciencedirect.com/science/article/abs/pii/S0031320301000474?via%3Dihub).","title":"Notes - Image.erode/2","ref":"Image.html#erode/2-notes"},{"type":"function","doc":"Erode an image mask, removing pixels from the\nedge of the mask or raising an exception.\n\nMask is used in the sense of an image, potentially\nwuth an alpha band. The results on\nother image types is undefined.","title":"Image.erode!/2","ref":"Image.html#erode!/2"},{"type":"function","doc":"* `image` is any non-complex `t:Vix.Vips.Image.t/0`.\n\n* `radius` is an integer in the range `1..100`\n  representing the approximate number of\n  pixels to erode. The default is `1`.","title":"Arguments - Image.erode!/2","ref":"Image.html#erode!/2-arguments"},{"type":"function","doc":"* `eroded_mask` or\n\n* raises an exception","title":"Returns - Image.erode!/2","ref":"Image.html#erode!/2-returns"},{"type":"function","doc":"* Erode works for any non-complex image type, with any\n  number of bands. The input is eroded by copying\n  edge pixels before performing the operation so that\n  the output image has the same size as the input.\n\n* Edge pixels in the output image are only\n  approximate.\n\n* The erosion is implemented as a [rank filter](https://www.sciencedirect.com/science/article/abs/pii/S0031320301000474?via%3Dihub).","title":"Notes - Image.erode!/2","ref":"Image.html#erode!/2-notes"},{"type":"function","doc":"Returns the EXIF data for an image as a\nmap.\n\nOnly a subset of EXIF data is returned but\nits a substantial subset.","title":"Image.exif/1","ref":"Image.html#exif/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`","title":"Arguments - Image.exif/1","ref":"Image.html#exif/1-arguments"},{"type":"function","doc":"* `{:ok, exif_map}` where `exif_map` is a map\n  of selected EXIF data.\n\n* `{:error, reason}`","title":"Returns - Image.exif/1","ref":"Image.html#exif/1-returns"},{"type":"function","doc":"Extract each page of a multi-page image into its\nown image.\n\nNot all image types support multi-page images.","title":"Image.extract_pages/1","ref":"Image.html#extract_pages/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` in `.gif`\n   or `.png` multi-page format.","title":"Arguments - Image.extract_pages/1","ref":"Image.html#extract_pages/1-arguments"},{"type":"function","doc":"* `{:ok, list_of_images}` or\n\n* `{:error, reasom}`","title":"Returns - Image.extract_pages/1","ref":"Image.html#extract_pages/1-returns"},{"type":"function","doc":"The `pages: :all` option should be used when opening the\nmulti-page image.","title":"Notes - Image.extract_pages/1","ref":"Image.html#extract_pages/1-notes"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/animated.gif\", pages: :all)\n    iex> {:ok, list_of_images} = Image.extract_pages(image)\n    iex> Enum.count(list_of_images)\n    19","title":"Example - Image.extract_pages/1","ref":"Image.html#extract_pages/1-example"},{"type":"function","doc":"Feather (blur the edges) of an image\nmask.\n\nApplies a gaussian blur to a one-band image\nor the alpha band of a multi-band image\nthat can be used to smooth the blending of\none image into another.","title":"Image.feather/2","ref":"Image.html#feather/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` that is either\n  a single band image or an image with an alpha band.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.feather/2","ref":"Image.html#feather/2-arguments"},{"type":"function","doc":"* `:sigma` is the `float` size of the mask\n  to use. A larger number makes the image more\n  blurry. A range between `1.0` and `10.0`\n  is normally appropriate. The default is\n  `5`.\n\n* `:min_amplitude` is a `float` that determines\n  the accuracy of the mask. The default is `0.2`.\n  A smaller number will generate a larger, more\n  accurate mask,","title":"Options - Image.feather/2","ref":"Image.html#feather/2-options"},{"type":"function","doc":"* `{:ok, blurred_mask_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.feather/2","ref":"Image.html#feather/2-returns"},{"type":"function","doc":"Feather (blur the edges) of an image\nmask returning an image or raising an\nexception.\n\nApplies a gaussian blur to a one-band image\nor the alpha band of a multi-band image\nthat can be used to smooth the blending of\none image into another.","title":"Image.feather!/2","ref":"Image.html#feather!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` that is either\n  a single band image or an image with an alpha band.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.feather!/2","ref":"Image.html#feather!/2-arguments"},{"type":"function","doc":"* `:sigma` is the `float` size of the mask\n  to use. A larger number makes the image more\n  blurry. A range between `1.0` and `10.0`\n  is normally appropriate. The default is\n  `5`.\n\n* `:min_amplitude` is a `float` that determines\n  the accuracy of the mask. The default is `0.2`.\n  A smaller number will generate a larger, more\n  accurate mask,","title":"Options - Image.feather!/2","ref":"Image.html#feather!/2-options"},{"type":"function","doc":"* `blurred_mask_image` or\n\n* raises an exception.","title":"Returns - Image.feather!/2","ref":"Image.html#feather!/2-returns"},{"type":"function","doc":"Returns the filename for an image.","title":"Image.filename/1","ref":"Image.html#filename/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.filename/1","ref":"Image.html#filename/1-arguments"},{"type":"function","doc":"* The pathname from which the image was opened or\n  `nil` if there is no associated path. This can\n  happen in the case of a streamed image or an image\n  created from a memory buffer.","title":"Returns - Image.filename/1","ref":"Image.html#filename/1-returns"},{"type":"function","doc":"Flatten an alpha layer out of an image.","title":"Image.flatten/2","ref":"Image.html#flatten/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.flatten/2","ref":"Image.html#flatten/2-arguments"},{"type":"function","doc":"* `:background_color` is an RGB color which is used\n  to fill the transparent parts of the image.. The color\n  can be an integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:black`.","title":"Options - Image.flatten/2","ref":"Image.html#flatten/2-options"},{"type":"function","doc":"* `{:ok, flattened_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.flatten/2","ref":"Image.html#flatten/2-returns"},{"type":"function","doc":"Flatten an alpha layer out of an image\nor raises an exception.","title":"Image.flatten!/2","ref":"Image.html#flatten!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.flatten!/2","ref":"Image.html#flatten!/2-arguments"},{"type":"function","doc":"* `:background_color` is an RGB color which is used\n  to fill the transparent parts of the image.. The color\n  can be an integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:black`.","title":"Options - Image.flatten!/2","ref":"Image.html#flatten!/2-options"},{"type":"function","doc":"* `flattened_image` or\n\n* raises an exception","title":"Returns - Image.flatten!/2","ref":"Image.html#flatten!/2-returns"},{"type":"function","doc":"Flip an image horizontally or vertically.","title":"Image.flip/2","ref":"Image.html#flip/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `direction` is either `:horizontal` or\n  `:vertical`.","title":"Arguments - Image.flip/2","ref":"Image.html#flip/2-arguments"},{"type":"function","doc":"* `{:ok, flipped_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.flip/2","ref":"Image.html#flip/2-returns"},{"type":"function","doc":"Flip an image horizontally or vertically returning\na flipped image or raising an exception.","title":"Image.flip!/2","ref":"Image.html#flip!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `direction` is either `:horizontal` or\n  `:vertical`.","title":"Arguments - Image.flip!/2","ref":"Image.html#flip!/2-arguments"},{"type":"function","doc":"* `flipped_image` or\n\n* raises an exception.","title":"Returns - Image.flip!/2","ref":"Image.html#flip!/2-returns"},{"type":"function","doc":"Returns an image created from an in-memory binary representation\nof an image.\n\nThe binary must be a complete formatted image such as that\nreturned from `File.read!/1`.","title":"Image.from_binary/2","ref":"Image.html#from_binary/2"},{"type":"function","doc":"* `binary` is a binary representation of a formatted image\n  including `.jpg`, `.png`, `.webp` and `.svg` binary data.\n\n* `options` is a keyword list of options. See `Image.open/2`\n  for the list of applicable options.","title":"Arguments - Image.from_binary/2","ref":"Image.html#from_binary/2-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.from_binary/2","ref":"Image.html#from_binary/2-returns"},{"type":"function","doc":"Returns an image created from an in-memory binary representation\nof an image or raises an exception.\n\n* `binary` is a binary representation of a formatted image\n  including `.jpg`, `.png`, `.webp` and `.svg` binary data.","title":"Image.from_binary!/2","ref":"Image.html#from_binary!/2"},{"type":"function","doc":"* `binary` is a binary representation of a formatted image\n\n* `options` is a keyword list of options. See `Image.open/2`\n  for the list of applicable options.","title":"Arguments - Image.from_binary!/2","ref":"Image.html#from_binary!/2-arguments"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.from_binary!/2","ref":"Image.html#from_binary!/2-returns"},{"type":"function","doc":"Converts to an `Image` image from an `t:Evision.Mat.t/0` image.","title":"Image.from_evision/1","ref":"Image.html#from_evision/1"},{"type":"function","doc":"* `evision_image` is any `t:Evision.Mat.t/0` image.","title":"Arguments - Image.from_evision/1","ref":"Image.html#from_evision/1-arguments"},{"type":"function","doc":"* `{:ok, image}`","title":"Returns - Image.from_evision/1","ref":"Image.html#from_evision/1-returns"},{"type":"function","doc":"* `Image` images have the shape `{width, height, bands}`\n  whereas `Evision` images have the shape `{height, width, bands}`\n  so this function transposes the dimensions to match.\n\n* `Image` data is arranged as `rgb` data elements whereas\n  `Evision` requires the data to be in `bgr` order. This function\n  also reorders the data appropriately.","title":"Notes - Image.from_evision/1","ref":"Image.html#from_evision/1-notes"},{"type":"function","doc":"Returns an image from a [Kino](https://hex.pm/packages/kino) image\ninput.","title":"Image.from_kino/2","ref":"Image.html#from_kino/2"},{"type":"function","doc":"* `image` is a a map returned from `Kino.Input.read(image)`\n  via a `Kino.Input.image/1` input field. The data will have\n  the following fields:\n\n  * `:file_ref` which contains a file reference to the image. It can be extraced\n    into a path with `Kino.Input.file_path/1`\n  * `:width` which is the width of the image in pixels\n  * `:height` which is the height of the image in pixels\n  * `:format` which is the image band format which must be `:rgb`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.from_kino/2","ref":"Image.html#from_kino/2-arguments"},{"type":"function","doc":"* `:bands` indicates the integer number of bands (channels) in\n  the image. The default is `3`.","title":"Options - Image.from_kino/2","ref":"Image.html#from_kino/2-options"},{"type":"function","doc":"* Thus function requries Kino v0.11.0 which in turn requires\n  Livebook v0.11.0.\n\n* The image is assumed to contain pixel data that is in\n  unsigned 8-bit format which is common for most web-oriented\n  images.","title":"Notes - Image.from_kino/2","ref":"Image.html#from_kino/2-notes"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.from_kino/2","ref":"Image.html#from_kino/2-returns"},{"type":"function","doc":"Returns an image from a [Kino](https://hex.pm/packages/kino) image\ninput or raises an exception.","title":"Image.from_kino!/2","ref":"Image.html#from_kino!/2"},{"type":"function","doc":"* `image` is a a map returned from `Kino.Input.read(image)`\n  via a `Kino.Input.image/1` input field. The data will have\n  the following fields:\n  * `:file_ref` which contains a file reference to the image. It can be extraced into a path with `Kino.Input.file_path/1`\n  * `:width` which is the width of the image in pixels\n  * `:height` which is the height of the image in pixels\n  * `:format` which is the image band format which must be `:rgb`\n\n* `options` is a keyword list of options","title":"Arguments - Image.from_kino!/2","ref":"Image.html#from_kino!/2-arguments"},{"type":"function","doc":"* `:bands` indicates the integer number of bands (channels) in\n  the image. The default is `3`.","title":"Options - Image.from_kino!/2","ref":"Image.html#from_kino!/2-options"},{"type":"function","doc":"* Thus function requries Kino v0.11.0 which in turn requires\n  Livebook v0.11.0.\n\n* The image is assumed to contain pixel data that is in\n  unsigned 8-bit format which is common for most web-oriented\n  images.","title":"Notes - Image.from_kino!/2","ref":"Image.html#from_kino!/2-notes"},{"type":"function","doc":"* `{:ok, image}` or\n\n* raises an exception.","title":"Returns - Image.from_kino!/2","ref":"Image.html#from_kino!/2-returns"},{"type":"function","doc":"Converts an [Nx](https://hex.pm/packages/nx) tensor\ninto an image.","title":"Image.from_nx/1","ref":"Image.html#from_nx/1"},{"type":"function","doc":"* `tensor` is any three dimensional `t:Nx.Tensor.t/0`.\n\n* `options` is a keyword list of options. For valid\n  options see `Nx.from_binary/2`.","title":"Arguments - Image.from_nx/1","ref":"Image.html#from_nx/1-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.from_nx/1","ref":"Image.html#from_nx/1-returns"},{"type":"function","doc":"In order to convert a tensor into an image it must\nsatisfy these constraints:\n\n* It must have three dimensions.\n\n* It must have a tensor type that is compatible\n  with `libvips` (most tensors will satisfy this\n  requirement other than tensors whose type is complex).\n\n* The names of the axes must be `[:width, :height, any_other]`\n  or `[:height, :width, any_other]`.","title":"Notes - Image.from_nx/1","ref":"Image.html#from_nx/1-notes"},{"type":"function","doc":"iex> {:ok, image} = Vix.Vips.Operation.black(3, 3)\n    iex> {:ok, tensor} = Image.to_nx(image)\n    iex> {:ok, _image_2} = Image.from_nx(tensor)","title":"Example - Image.from_nx/1","ref":"Image.html#from_nx/1-example"},{"type":"function","doc":"Converts an [Nx](https://hex.pm/packages/nx) tensor\ninto an image or raises an exception.","title":"Image.from_nx!/1","ref":"Image.html#from_nx!/1"},{"type":"function","doc":"* `tensor` is any three dimensional `t:Nx.Tensor.t/0`.\n\n* `options` is a keyword list of options. For valid\n  options see `Nx.from_binary/2`.","title":"Arguments - Image.from_nx!/1","ref":"Image.html#from_nx!/1-arguments"},{"type":"function","doc":"* `image` or\n\n* `{:error, reason}`","title":"Returns - Image.from_nx!/1","ref":"Image.html#from_nx!/1-returns"},{"type":"function","doc":"In order to convert a tensor into an image it must\nsatisfy these constraints:\n\n* It must have three dimensions.\n\n* It must have a tensor type that is compatible\n  with `libvips` (most tensors will satisfy this\n  requirement other than tensors whose type is complex).\n\n* The names of the axes must be `[:width, :height, any_other]`\n  or `[:height, :width, any_other]`.","title":"Notes - Image.from_nx!/1","ref":"Image.html#from_nx!/1-notes"},{"type":"function","doc":"iex> {:ok, image} = Vix.Vips.Operation.black(3, 3)\n    iex> {:ok, tensor} = Image.to_nx(image)\n    iex> _image_2 = Image.from_nx(tensor)","title":"Example - Image.from_nx!/1","ref":"Image.html#from_nx!/1-example"},{"type":"function","doc":"Returns an image created from an SVG string.","title":"Image.from_svg/2","ref":"Image.html#from_svg/2"},{"type":"function","doc":"* `svg` is an SVG string.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.from_svg/2","ref":"Image.html#from_svg/2-arguments"},{"type":"function","doc":"* `:access` is the file access mode, either `:random`\n  or `:sequential`. The default is `:random`.\n  When `:sequential`, `Image` (via `Vix`) is able\n  to support streaming transformations and optimise\n  memory usage more effectively. However `:sequential`\n  also means that some operations cannot be completed\n  because they would require non-sequential access to\n  the image. In these cases, `:random` access is required.\n\n* `:fail_on` sets the error level at which image\n  loading and decoding will stop. The default is `:none`.\n  Each error state implies all the states before it such\n  that `:error` implies also `:truncated`.\n\n* `:scale` will scale the image on load. The value is\n  a number greater than `0` and less than or equal\n  to `1024` with a default of `1.0` meaning no scaling\n  on load. Numbers less than `1.0` scale the image down\n  so that a scale of `0.5` will halve the image size on\n  load.","title":"Options - Image.from_svg/2","ref":"Image.html#from_svg/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.from_svg/2","ref":"Image.html#from_svg/2-returns"},{"type":"function","doc":"Returns an image created from an SVG string or\nraises an exception.","title":"Image.from_svg!/2","ref":"Image.html#from_svg!/2"},{"type":"function","doc":"* `svg` is an SVG string.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.from_svg!/2","ref":"Image.html#from_svg!/2-arguments"},{"type":"function","doc":"* `:access` is the file access mode, either `:random`\n  or `:sequential`. The default is `:random`.\n  When `:sequential`, `Image` (via `Vix`) is able\n  to support streaming transformations and optimise\n  memory usage more effectively. However `:sequential`\n  also means that some operations cannot be completed\n  because they would require non-sequential access to\n  the image. In these cases, `:random` access is required.\n\n* `:fail_on` sets the error level at which image\n  loading and decoding will stop. The default is `:none`.\n  Each error state implies all the states before it such\n  that `:error` implies also `:truncated`.\n\n* `:scale` will scale the image on load. The value is\n  a number greater than `0` and less than or equal\n  to `1024` with a default of `1.0` meaning no scaling\n  on load. Numbers less than `1.0` scale the image down\n  so that a scale of `0.5` will halve the image size on\n  load.","title":"Options - Image.from_svg!/2","ref":"Image.html#from_svg!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.from_svg!/2","ref":"Image.html#from_svg!/2-returns"},{"type":"function","doc":"Returns the number of operating system\nthreads available for use by `libvips`.\n\nBy default the number of threads will be\nthe number of cores in the system.\n\nSince image processing is CPU intensive it\nmay be appropriate to reduce the number of\nthreads to be available to reduce the risk\nof CPU starvation for other workloads.\n\nSee `Image.put_concurrency/1`.","title":"Image.get_concurrency/0","ref":"Image.html#get_concurrency/0"},{"type":"function","doc":"Returns the pixel value at the given image location.\n\nThe returned pixel is a list of numbers where\nthe length of the list is equal to the number\nof bands in the image.","title":"Image.get_pixel/3","ref":"Image.html#get_pixel/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `x` is an integer offset from the top\n  left of the image along the `x` (width) axis.\n  The number must be in the range `0..width - 1`.\n\n* `y` is an integer offset from the top\n  left of the image along the `y` (height) axis.\n  The number must be in the range `0..height - 1`.","title":"Arguments - Image.get_pixel/3","ref":"Image.html#get_pixel/3-arguments"},{"type":"function","doc":"* `{:ok, pixel_value}` or\n\n* `{:error, reason}`","title":"Returns - Image.get_pixel/3","ref":"Image.html#get_pixel/3-returns"},{"type":"function","doc":"Returns the pixel value at the given image location\nor raises an exception.\n\nThe returned pixel is a list of numbers where\nthe length of the list is equal to the number\nof bands in the image.","title":"Image.get_pixel!/3","ref":"Image.html#get_pixel!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `x` is an integer offset from the top\n  left of the image along the `x` (width) axis.\n  The number must be in the range `0..width - 1`.\n\n* `y` is an integer offset from the top\n  left of the image along the `y` (height) axis.\n  The number must be in the range `0..height - 1`.","title":"Arguments - Image.get_pixel!/3","ref":"Image.html#get_pixel!/3-arguments"},{"type":"function","doc":"* `pixel_value` or\n\n* raises an exception","title":"Returns - Image.get_pixel!/3","ref":"Image.html#get_pixel!/3-returns"},{"type":"function","doc":"Returns the hamming distance of two images\nor two image hashes.\n\nA [hamming distance](https://en.wikipedia.org/wiki/Hamming_distance)\ngives an indication of the similarity of two images.\n\nIn general, a hamming distance of less than `10` indicates\nthat the images are very similar.  A distance of\nless than `20` suggests the images are quite similar. Any\nother distance suggests the images have little in common.","title":"Image.hamming_distance/3","ref":"Image.html#hamming_distance/3"},{"type":"function","doc":"* `image_1` is any `t:Vix.Vips.Image.t/0`.\n\n* `image_2` is any `t:Vix.Vips.Image.t/0`.\n\nAlternatively, both arguments may be image hashes\nreturned by `Image.dhash/1`. Both arguments must\nbe of the same type.","title":"Arguments - Image.hamming_distance/3","ref":"Image.html#hamming_distance/3-arguments"},{"type":"function","doc":"* `{:ok, hamming_distance}` where hamming distance is\n  a positive integer or\n\n* `{:error, reason}`.","title":"Returns - Image.hamming_distance/3","ref":"Image.html#hamming_distance/3-returns"},{"type":"function","doc":"Returns a boolean based upon whether a given\nimage has an alpha band.\n\nThe determination is a heuristic so certainty\ncannot be guaranteed.","title":"Image.has_alpha?/1","ref":"Image.html#has_alpha?/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.has_alpha?/1","ref":"Image.html#has_alpha?/1-arguments"},{"type":"function","doc":"* `true` or `false`","title":"Returns - Image.has_alpha?/1","ref":"Image.html#has_alpha?/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/image_with_alpha2.png\")\n    iex> Image.has_alpha?(image)\n    true\n\n    iex> image = Image.open!(\"./test/support/images/Kamchatka-2019-8754.jpg\")\n    iex> Image.has_alpha?(image)\n    false","title":"Examples - Image.has_alpha?/1","ref":"Image.html#has_alpha?/1-examples"},{"type":"function","doc":"Returns the height of an image.","title":"Image.height/1","ref":"Image.html#height/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.height/1","ref":"Image.html#height/1-arguments"},{"type":"function","doc":"* The image height as an integer.","title":"Returns - Image.height/1","ref":"Image.html#height/1-returns"},{"type":"function","doc":"Returns the histogram for an image.\n\nThe histogram is returned as a `t:Vimage.t/0`\nthat is a 255 by 255 image the same numbers of\nbands as the source image.","title":"Image.histogram/1","ref":"Image.html#histogram/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Argument - Image.histogram/1","ref":"Image.html#histogram/1-argument"},{"type":"function","doc":"* `{:ok, histogram_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.histogram/1","ref":"Image.html#histogram/1-returns"},{"type":"function","doc":"The returned image is is organized\nas a 256x256 pixel image with\nthe same number of bands as the original\nimage.\n\nEach pixel on the image returns the count\nof pixels in the original image that are\nin that 1/256th part of the image.","title":"Notes - Image.histogram/1","ref":"Image.html#histogram/1-notes"},{"type":"function","doc":"Scans the `condition_image` cond and uses it to select\npixels from either the `if_image` or the `else_image`.\n\nNon-zero means copy a pixel from `if_image`, `0` means\ncopy a pixel from `else_image`.","title":"Image.if_then_else/4","ref":"Image.html#if_then_else/4"},{"type":"function","doc":"* `condition_image` is any image. Typically it is an image\n  formed by the relation operations such as `Image.Math.greater_than/2`.\n\n* `if_image_or_color` is either an `t:Vimage.t/0` or\n  a `t:Image.Color.t/0`. If a color is provided then\n  an image is constructed with the same shape as `condition_image`\n  filled with the provided color.\n\n* `else_image_or_color` is either an `t:Vimage.t/0` or\n  a `t:Image.Color.t/0`. If a color is provided then\n  an image is constructed with the same shape as `condition_image`\n  filled with the provided color.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.if_then_else/4","ref":"Image.html#if_then_else/4-arguments"},{"type":"function","doc":"* `:blend` is a boolean indicating if a the operation should blend\n  smoothly between `then` and `else` images. The default is `false`.","title":"Options - Image.if_then_else/4","ref":"Image.html#if_then_else/4-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.if_then_else/4","ref":"Image.html#if_then_else/4-returns"},{"type":"function","doc":"Any image can have either 1 band or `n` bands, where `n`\nis the same for all the non-1-band images. Single band\nimages are then effectively copied to make n-band images.\n\nImages `if_image` and `else_image` are cast up to the\nsmallest common format. The `condition_image` is cast to\n`{:u, 8}`.\n\nIf the images differ in size, the smaller images are\nenlarged to match the largest by adding zero pixels along\nthe bottom and right.\n\nThe output image is calculated pixel by pixel as:\n\n    (condition_image / 255) * if_image + (1 - condition_image / 255) * else_image","title":"Notes - Image.if_then_else/4","ref":"Image.html#if_then_else/4-notes"},{"type":"function","doc":"Scans the condition image cond and uses it to select\npixels from either the `if_image` or the `else_image`.\nRaise an exception on error.\n\nNon-zero means copy a pixel from `if_image`, `0` means\ncopy a pixel from `else_image`.","title":"Image.if_then_else!/3","ref":"Image.html#if_then_else!/3"},{"type":"function","doc":"* `condition_image` is any image. Typically it is an image\n  formed by the relation operations such as `Image.Math.greater_than/2`.\n\n* `if_image_or_color` is either an `t:Vimage.t/0` or\n  a `t:Image.Color.t/0`. If a color is provided then\n  an image is constructed with the same shape as `condition_image`\n  filled with the provided color.\n\n* `else_image_or_color` is either an `t:Vimage.t/0` or\n  a `t:Image.Color.t/0`. If a color is provided then\n  an image is constructed with the same shape as `condition_image`\n  filled with the provided color.","title":"Arguments - Image.if_then_else!/3","ref":"Image.html#if_then_else!/3-arguments"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.if_then_else!/3","ref":"Image.html#if_then_else!/3-returns"},{"type":"function","doc":"Any image can have either 1 band or `n` bands, where `n`\nis the same for all the non-1-band images. Single band\nimages are then effectively copied to make n-band images.\n\nImages `if_image` and `else_image` are cast up to the\nsmallest common format. The `condition_image` is cast to\n`{:u, 8}`.\n\nIf the images differ in size, the smaller images are\nenlarged to match the largest by adding zero pixels along\nthe bottom and right.\n\nThe output image is calculated pixel by pixel as:\n\n    (condition_image / 255) * if_image + (1 - condition_image / 255) *`else_image`","title":"Notes - Image.if_then_else!/3","ref":"Image.html#if_then_else!/3-notes"},{"type":"function","doc":"Inverts an image.","title":"Image.invert/1","ref":"Image.html#invert/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.invert/1","ref":"Image.html#invert/1-arguments"},{"type":"function","doc":"* `{:ok, inverted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.invert/1","ref":"Image.html#invert/1-returns"},{"type":"function","doc":"* For unsigned formats, this operation calculates\n  `(max_value - pixel_value)`, eg. `(255 - pixel_value)` for\n  typical 8-bit sRGB images.\n\n* For signed and float formats, this operation calculates\n  `(-1 * pixel_value)`.\n\n* For complex images, only the real part is inverted.","title":"Notes - Image.invert/1","ref":"Image.html#invert/1-notes"},{"type":"function","doc":"Inverts an image or raises an exception.","title":"Image.invert!/1","ref":"Image.html#invert!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.invert!/1","ref":"Image.html#invert!/1-arguments"},{"type":"function","doc":"* `inverted_image` or\n\n* raises an exception.","title":"Returns - Image.invert!/1","ref":"Image.html#invert!/1-returns"},{"type":"function","doc":"* For unsigned formats, this operation calculates\n  `(max_value - pixel_value)`, eg. `(255 - pixel_value)` for\n  typical 8-bit sRGB images.\n\n* For signed and float formats, this operation calculates\n  `(-1 * pixel_value)`.\n\n* For complex images, only the real part is inverted.","title":"Notes - Image.invert!/1","ref":"Image.html#invert!/1-notes"},{"type":"macro","doc":"Guards whether the coordinates can be reasonably\ninterpreted as a bounding box.\n\n`left` and `top` when positive are relative to\nthe left and top of the image respectively. When\nnegative they are relative to the right and bottom\nof the image.","title":"Image.is_box/4","ref":"Image.html#is_box/4"},{"type":"macro","doc":"Guards whether the given struct is an image type\neither `Vix.Vips.Image` or `Vix.Vips.MutableImage`.","title":"Image.is_image/1","ref":"Image.html#is_image/1"},{"type":"macro","doc":"Guards whether a value is a multiplier as representeed\nby a float greater than `0.0`.","title":"Image.is_multiplier/1","ref":"Image.html#is_multiplier/1"},{"type":"macro","doc":"Guards whether a value is a percentage as representeed\nby a float between `-1.0` and `1.0`.","title":"Image.is_percent/1","ref":"Image.html#is_percent/1"},{"type":"macro","doc":"Guards whether a term might be reasonably interpreted\nas an image pixel.","title":"Image.is_pixel/1","ref":"Image.html#is_pixel/1"},{"type":"macro","doc":"Guards whether a value is a positive percentage as representeed\nby a float greater than `0.0` and less than or equal to `1.0`.","title":"Image.is_positive_percent/1","ref":"Image.html#is_positive_percent/1"},{"type":"macro","doc":"Guards whether a parameter is a rectangular bounding box. A\nrectangular bounding box is a list of four 2-tuples that must\nrepresent a rectangle (not an arbitrary quadrilateral),\n\nThe order of points is top_left -> top right -> bottom\nright -> bottm left.","title":"Image.is_rectangle/4","ref":"Image.html#is_rectangle/4"},{"type":"macro","doc":"Guards whether a number can be reasonably interpreted\nas a size (as in size of a crop or mask)","title":"Image.is_size/1","ref":"Image.html#is_size/1"},{"type":"function","doc":"Join a list of images into a single image.","title":"Image.join/2","ref":"Image.html#join/2"},{"type":"function","doc":"* `image_list` is a non-empty list of `t:Vimage.t/0`\n  images.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.join/2","ref":"Image.html#join/2-arguments"},{"type":"function","doc":"* `:across` is an integer number of images in the\n  horizontal direction of the grid. The default is `1`.\n\n* `:vertical_spacing` determines the height in pixels of\n  each image row. The default, `0`, means that the row\n  height is the maximum height of the\n  images in `image_list`.\n\n* `:horizontal_spacing` determines the width in pixels of\n  each image in a row. The default, `0`, means\n  that the width is the maximum width of the\n  images in `image_list`.\n\n* `:vertical_align` is `:bottom`, `:middle` or `:top`.\n  The default is `:bottom`.\n\n* `:horizontal_align` is `:left`, `:center` or `:right`.\n  The default is `:left`.\n\n* `:background_color` is the color of any pixels generated\n  between images. This can be specified as a single integer\n  which will be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `:shim` is the number of pixels of spacing between\n  images in the grid. The default is `0`.","title":"Options - Image.join/2","ref":"Image.html#join/2-options"},{"type":"function","doc":"* `{:ok, joined_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.join/2","ref":"Image.html#join/2-returns"},{"type":"function","doc":"`Image.join/2`Lay out the list of images in a grid.\nThe grid is `:across` images across and however high\nis necessary to use up all of `image_list`.  Images are\nset down left-to-right and top-to-bottom.\n\nEach input image is placed with a box of size `:horizontal_spacing`\nby `:vertical_spacing` pixels and cropped. These default\nto the largest width and largest height of the input images.\n\nSpace between images is filled with `:background_color` .\nThis defaults to black.\n\nImages are positioned within their `:horizontal_spacing` by\n`:vertical_spacing` box at `:vertical_align` of `:bottom`,\n`:middle` or `:top``and by `:horizontal_align` of `:left`,\n`:center` or `:righ`. The defaults are `:bottom`, `:left.","title":"Notes - Image.join/2","ref":"Image.html#join/2-notes"},{"type":"function","doc":"Join a list of images into a single image or raises\nan exception.","title":"Image.join!/2","ref":"Image.html#join!/2"},{"type":"function","doc":"* `image_list` is a non-empty list of `t:Vimage.t/0`\n  images.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.join!/2","ref":"Image.html#join!/2-arguments"},{"type":"function","doc":"* `:across` is an integer number of images in the\n  horizontal direction of the grid. The default is `1`.\n\n* `:vertical_spacing` determines the height in pixels of\n  each image row. The default, `0`, means that the row\n  height is the maximum height of the\n  images in `image_list`.\n\n* `:horizontal_spacing` determines the width in pixels of\n  each image in a row. The default, `0`, means\n  that the width is the maximum width of the\n  images in `image_list`.\n\n* `:vertical_align` is `:bottom`, `:middle` or `:top`.\n  The default is `:bottom`.\n\n* `:horizontal_align` is `:left`, `:center` or `:right`.\n  The default is `:left`.\n\n* `:background_color` is the color of any pixels generated\n  between images. This can be specified as a single integer\n  which will be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `:shim` is the number of pixels of spacing between\n  images in the grid. The default is `0`.","title":"Options - Image.join!/2","ref":"Image.html#join!/2-options"},{"type":"function","doc":"* `{:ok, joined_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.join!/2","ref":"Image.html#join!/2-returns"},{"type":"function","doc":"`Image.join/2`Lay out the list of images in a grid.\nThe grid is `:across` images across and however high\nis necessary to use up all of `image_list`.  Images are\nset down left-to-right and top-to-bottom.\n\nEach input image is placed with a box of size `:horizontal_spacing`\nby `:vertical_spacing` pixels and cropped. These default\nto the largest width and largest height of the input images.\n\nSpace between images is filled with `:background_color` .\nThis defaults to black.\n\nImages are positioned within their `:horizontal_spacing` by\n`:vertical_spacing` box at `:vertical_align` of `:bottom`,\n`:middle` or `:top``and by `:horizontal_align` of `:left`,\n`:center` or `:righ`. The defaults are `:bottom`, `:left.","title":"Notes - Image.join!/2","ref":"Image.html#join!/2-notes"},{"type":"function","doc":"Applies [K-means](https://en.wikipedia.org/wiki/K-means_clustering) clustering\nto an image using the [scholar](https://hex.pm/packages/scholar)\nlibrary. The returned result is a list of colors resulting from\npartioning the colors in an image.\n\nThis function is only available if [Scholar](https://hex.pm/packages/scholar)\nis configured.","title":"Image.k_means/2","ref":"Image.html#k_means/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.k_means/2","ref":"Image.html#k_means/2-arguments"},{"type":"function","doc":"* See `Scholar.Cluster.KMeans.fit/2` for the\n  available options.","title":"Options - Image.k_means/2","ref":"Image.html#k_means/2-options"},{"type":"function","doc":"* `{:ok, list_of_colors}` or\n\n* `{:error, reason}`","title":"Returns - Image.k_means/2","ref":"Image.html#k_means/2-returns"},{"type":"function","doc":"* The current implementation is performed in the\n  sRGB colorspace. This may not produce the most\n  perceptually appropriate clusters. This limitation\n  will be removed in a future release.\n\n* The option `:num_clusters` determines the\n  number of clusters into which image colors are\n  partioned. The default is `num_clusters: 16`.\n\n* The default options mean that the results are\n  not deterministic. Different calls to `Image.k_means/2`\n  can return different - but equally valid - results. Use\n  the `:key` option to return deterministic results.\n\n* Performance is very correlated with image size.\n  Where possible, resize the image to be under a 1_000_000\n  pixels or even less before invoking `Image.k_means/2`.\n\n* Performance is primarily determined by the vector\n  performance of the system and specifically by the\n  GPU configuration and EXLAs support of that GPU.\n  In most cases it is recommended that the following\n  be added to `config.exs`:\n\n```elixir\nconfig :nx,\n  default_backend: EXLA.Backend\n\nconfig :nx, :default_defn_options,\n  compiler: EXLA\n```","title":"Notes - Image.k_means/2","ref":"Image.html#k_means/2-notes"},{"type":"function","doc":"iex> key = Nx.Random.key(40)\n    iex> image = Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n    iex> Image.k_means(image, key: key)\n    {:ok,\n     [\n       [32, 37, 39],\n       [34, 76, 101],\n       [41, 121, 158],\n       [42, 189, 58],\n       [93, 61, 32],\n       [99, 87, 90],\n       [112, 156, 184],\n       [115, 112, 140],\n       [157, 100, 37],\n       [166, 125, 103],\n       [175, 191, 206],\n       [178, 148, 158],\n       [217, 145, 60],\n       [228, 170, 116],\n       [228, 226, 226],\n       [231, 200, 167]\n     ]}","title":"Example - Image.k_means/2","ref":"Image.html#k_means/2-example"},{"type":"function","doc":"Applies [K-means](https://en.wikipedia.org/wiki/K-means_clustering) clustering\nto an image using the [scholar](https://hex.pm/packages/scholar)\nlibrary. The returned result is a list of colors resulting from\npartioning the colors in an image.\n\nThis function is only available if [Scholar](https://hex.pm/packages/scholar)\nis configured.","title":"Image.k_means!/2","ref":"Image.html#k_means!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.k_means!/2","ref":"Image.html#k_means!/2-arguments"},{"type":"function","doc":"* See `Scholar.Cluster.KMeans.fit/2` for the\n  available options.","title":"Options - Image.k_means!/2","ref":"Image.html#k_means!/2-options"},{"type":"function","doc":"* `{:ok, list_of_colors}` or\n\n* `{:error, reason}`","title":"Returns - Image.k_means!/2","ref":"Image.html#k_means!/2-returns"},{"type":"function","doc":"* The current implementation is targetted towards\n  sRGB images Results for images in other colorspaces\n  is undefined. It is planned this limitation be\n  removed in a future release.\n\n* The option `:num_clusters` determines the\n  number of clusters into which image colors are\n  partioned. The default is `num_clusters: 16`.\n\n* The default options mean that the results are\n  not deterministic. Different calls to `Image.k_means/2`\n  can return different - but equally valid - results. Use\n  the `:key` option to return deterministic results.\n\n* Performance is very correlated with image size.\n  Where possible, resize the image to be under a 1_000_000\n  pixels or even less before invoking `Image.k_means/2`.\n\n* Performance is primarily determined by the vector\n  performance of the system and specifically by the\n  GPU configuration and EXLAs support of that GPU.\n  In most cases it is recommended that the following\n  be added to `config.exs`:\n\n```elixir\nconfig :nx,\n  default_backend: EXLA.Backend\n\nconfig :nx, :default_defn_options,\n  compiler: EXLA\n```","title":"Notes - Image.k_means!/2","ref":"Image.html#k_means!/2-notes"},{"type":"function","doc":"iex> key = Nx.Random.key(40)\n    iex> image = Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n    iex> Image.k_means!(image, key: key)\n    [\n      [32, 37, 39],\n      [34, 76, 101],\n      [41, 121, 158],\n      [42, 189, 58],\n      [93, 61, 32],\n      [99, 87, 90],\n      [112, 156, 184],\n      [115, 112, 140],\n      [157, 100, 37],\n      [166, 125, 103],\n      [175, 191, 206],\n      [178, 148, 158],\n      [217, 145, 60],\n      [228, 170, 116],\n      [228, 226, 226],\n      [231, 200, 167]\n    ]","title":"Example - Image.k_means!/2","ref":"Image.html#k_means!/2-example"},{"type":"function","doc":"Create an image gradient the size of a given\nimage, or the size of the given dimenssion.\n\nThe gradient will be interpolated from the `start_color`\nvalue to the `finish_color` value.","title":"Image.linear_gradient/1","ref":"Image.html#linear_gradient/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments using a template image - Image.linear_gradient/1","ref":"Image.html#linear_gradient/1-arguments-using-a-template-image"},{"type":"function","doc":"* `width` is the width in pixels of the gradient image.\n\n* `height` is the height in pixels of the gradient image.\n\n* `options` is a keyword list of options. See\n  `t:Image.Options.LinearGradient.linear_gradient_option/0`.","title":"Arguments supplying a width and height - Image.linear_gradient/1","ref":"Image.html#linear_gradient/1-arguments-supplying-a-width-and-height"},{"type":"function","doc":"* `:start_color` is an sRGB color which represents the starting\n  color of the gradient. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color, or an atom\n  representing a CSS color name. The default is `:black`\n  with 100% transparency.\n\n* `:finish_color` is an sRGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:black` with 100% opacity.\n\n* `:angle` is a float or integer number of degrees of\n  clockwise rotation applied to the gradient. The default\n  is `0.0`. The number is normalized into the range `0..360`.","title":"Options - Image.linear_gradient/1","ref":"Image.html#linear_gradient/1-options"},{"type":"function","doc":"* `{:ok, gradient_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.linear_gradient/1","ref":"Image.html#linear_gradient/1-returns"},{"type":"function","doc":"# transparent_black and opaque_black are the default\n    # start and finish values\n    iex> transparent_black = [0, 0, 0, 0]\n    iex> opaque_black = [0, 0, 0, 255]\n    iex> Image.linear_gradient(100, 100, start_color: transparent_black, finish_color: opaque_black)\n    iex> Image.linear_gradient(100, 100, start_color: :red, finish_color: :blue, angle: 42)","title":"Example - Image.linear_gradient/1","ref":"Image.html#linear_gradient/1-example"},{"type":"function","doc":"","title":"Image.linear_gradient/2","ref":"Image.html#linear_gradient/2"},{"type":"function","doc":"","title":"Image.linear_gradient/3","ref":"Image.html#linear_gradient/3"},{"type":"function","doc":"Create an image gradient the size of a given\nimage, or the size of the given dimenssion or\nraises an exception.\n\nThe gradient will be interpolated from the `start_color`\nvalue to the `finish_color` value.","title":"Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments using a template image - Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1-arguments-using-a-template-image"},{"type":"function","doc":"* `width` is the width in pixels of the gradient image.\n\n* `height` is the height in pixels of the gradient image.\n\n* `options` is a keyword list of options. See\n  `t:Image.Options.LinearGradient.linear_gradient_option/0`.","title":"Arguments supplying a width and height - Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1-arguments-supplying-a-width-and-height"},{"type":"function","doc":"* `:start_color` is an sRGB color which represents the starting\n  color of the gradient. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color, or an atom\n  representing a CSS color name. The default is `:black`\n  with 100% transparency.\n\n* `:finish_color` is an sRGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:black` with 100% opacity.\n\n* `:angle` is a float or integer number of degrees of\n  clockwise rotation applied to the gradient. The default\n  is `0.0`. The number is normalized into the range `0..360`.","title":"Options - Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1-options"},{"type":"function","doc":"* `gradient_image` or\n\n* raises an exception.","title":"Returns - Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1-returns"},{"type":"function","doc":"# transparent_black and opaque_black are the default\n    # start and finish values\n    iex> transparent_black = [0, 0, 0, 0]\n    iex> opaque_black = [0, 0, 0, 255]\n    iex> Image.linear_gradient!(100, 100, start_color: transparent_black, finish_color: opaque_black)","title":"Example - Image.linear_gradient!/1","ref":"Image.html#linear_gradient!/1-example"},{"type":"function","doc":"","title":"Image.linear_gradient!/2","ref":"Image.html#linear_gradient!/2"},{"type":"function","doc":"","title":"Image.linear_gradient!/3","ref":"Image.html#linear_gradient!/3"},{"type":"function","doc":"Apply a local contrast adjustment to an image.\n\nThis function applies a [Constrast Limited Adaptive histogram equalization (AHE)](https://en.wikipedia.org/wiki/Adaptive_histogram_equalization#Contrast_Limited_AHE)\nto improve contrast in images. It differs from ordinary histogram\nequalization in the respect that the adaptive method computes several\nhistograms, each corresponding to a distinct section of the image, and\nuses them to redistribute the lightness values of the image.\n\nIt is therefore suitable for improving the local contrast and\nenhancing the definitions of edges in each region of an image,\nhence the name of the function.","title":"Image.local_contrast/2","ref":"Image.html#local_contrast/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.local_contrast/2","ref":"Image.html#local_contrast/2-arguments"},{"type":"function","doc":"* :`window_size` is an integer indicating the size of\n  the window (in pixels) into the image in which the contrast adjustment\n  is calculated. The default is `3`.\n\n* `:max_slope` is the integral level of brightening, between 0 and\n  100, where 0 (the default) disables contrast limiting.","title":"Options - Image.local_contrast/2","ref":"Image.html#local_contrast/2-options"},{"type":"function","doc":"* `{:ok, adjusted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.local_contrast/2","ref":"Image.html#local_contrast/2-returns"},{"type":"function","doc":"Apply a local contrast adjustment to an image\nor raises an exception.\n\nThis function applies a [Constrast Limited Adaptive histogram equalization (AHE)](https://en.wikipedia.org/wiki/Adaptive_histogram_equalization#Contrast_Limited_AHE)\nto improve contrast in images. It differs from ordinary histogram\nequalization in the respect that the adaptive method computes several\nhistograms, each corresponding to a distinct section of the image, and\nuses them to redistribute the lightness values of the image.\n\nIt is therefore suitable for improving the local contrast and\nenhancing the definitions of edges in each region of an image,\nhence the name of the function.","title":"Image.local_contrast!/2","ref":"Image.html#local_contrast!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.local_contrast!/2","ref":"Image.html#local_contrast!/2-arguments"},{"type":"function","doc":"* :`window_size` is an integer indicating the size of\n  the window (in pixels) into the image in which the contrast adjustment\n  is calculated. The default is `3`.\n\n* `:max_slope` is the integral level of brightening, between 0 and\n  100, where 0 (the default) disables contrast limiting.","title":"Options - Image.local_contrast!/2","ref":"Image.html#local_contrast!/2-options"},{"type":"function","doc":"* `adjusted_image` or\n\n* raises an exception.","title":"Returns - Image.local_contrast!/2","ref":"Image.html#local_contrast!/2-returns"},{"type":"function","doc":"Applies a transformation matrix to an image.\n\nA transformation matrix is returned by\n`Image.transform_matrix/3`.\n\n`Image.warp_perspective/4` uses this function to\napply a perspective transform to an image.","title":"Image.map/3","ref":"Image.html#map/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `transform_matrix` is a matrix returned by\n  `Image.transform_matrix/3`.","title":"Arguments - Image.map/3","ref":"Image.html#map/3-arguments"},{"type":"function","doc":"* `{:ok, mapped_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.map/3","ref":"Image.html#map/3-returns"},{"type":"function","doc":"For each page of an image, execute `fun/1` then\nreassemble the pages.\n\nIf the function is successful for each page,\nassemble the new pages (returned from `fun/1`)\ninto a new image.","title":"Image.map_join_pages/2","ref":"Image.html#map_join_pages/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` in `.gif`\n   or `.png` multi-page format.\n\n* `fun` is any 1-arity function that takes a\n  page as a `t:Vix.Vips.Image.t/0` as its argument\n  and is required to return either `{:ok, new_page_image}`\n  or `{:error, reason}` as its return value.","title":"Arguments - Image.map_join_pages/2","ref":"Image.html#map_join_pages/2-arguments"},{"type":"function","doc":"* `{:ok, mapped_joined_image}` where all the new pages returned\n  from `fun/1` are assembled into `mapped_image` or\n\n* `{:error, reason}`.","title":"Returns - Image.map_join_pages/2","ref":"Image.html#map_join_pages/2-returns"},{"type":"function","doc":"# The option `pages: -1` means load all the pages of a multi-page image.\n    iex> image = Image.open!(\"./test/support/images/animated.webp\", pages: :all)\n    iex> {:ok, _mapped_image} = Image.map_join_pages(image, &Image.equalize/1)\n\n    # Also works for .gif images\n    iex> image = Image.open!(\"./test/support/images/animated.gif\", pages: :all)\n    iex> {:ok, _mapped_image} = Image.map_join_pages(image, &Image.equalize/1)\n\n    # If an image isn't opened with `pages: :all` then only\n    # the first page of an image is loaded.\n    iex> image_2 = Image.open!(\"./test/support/images/animated.webp\")\n    iex> Image.map_join_pages(image_2, &Image.equalize/1)\n    {:error, \"Image does not have a page-height header. \" <>\n      \"Perhaps the image wasn't opened with the `pages: :all` option or \" <>\n      \"libvips wasn't built with libwebp-dev/libgif-dev configured? \" <>\n      \"Run `vips --vips-config` from the command line to check.\"}","title":"Examples - Image.map_join_pages/2","ref":"Image.html#map_join_pages/2-examples"},{"type":"function","doc":"Create a meme image from a base image and\none or two lines of text.\n\nThe size of the text is determined by the size\nof the base image.","title":"Image.meme/3","ref":"Image.html#meme/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` over which\n  the meme text will be composed.\n\n* `headline` is the top line of the meme text.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.meme/3","ref":"Image.html#meme/3-arguments"},{"type":"function","doc":"* `:text` is the second line of text at the bottom of the\n  meme image. The default is `\"\"`.\n\n* `:text_size` is the size of the bottom text in points.\n  The default is calculated proportional to the size of the\n  image.\n\n* `:headline_size` is the size of the headline text in points.\n  The default is calculated proportional to the size of the\n  image.\n\n* `:font` is the name of the font family to be applied.\n  The default is `Impact`.\n\n* `:font_file` is the path name to a font file that will be\n  loaded. The default is `:default` which will load the included\n  `Impact` font if the font family is `Impact`. If the font family\n  is not `Impact` and the `:font_file` is `:default` then the\n  font displayed is resolved by the underlying operating system.\n  If `:font_file` is a string, then it is expected to be a valid\n  font file. If `:font_file` is set to a path then the `:font` option\n  should also be set to the correct font name.\n\n* `:weight` is the font weight to be rendered. The options\n  are `:ultralight`, `:light`, `:normal`, `:bold`, `:ultrabold`,\n  and `:heavy`. The default `:bold`.\n\n* `:transform` determines how the text is presented. The\n  options are `:upcase`, `:downcase`, `:capitalize` and `:none`.\n  The default is `:upcase`.\n\n* `:color` is an RGB color of the text. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:white`.\n\n* `:outline_color` is an RGB color of the text outline. The\n  color can be an integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:black`.\n\n* `:margin` is the width of the margin in pixels. The margin is\n  applied to both the left and right sides of the image. The\n  default is calculated proportional to the size of the\n  image.","title":"Options - Image.meme/3","ref":"Image.html#meme/3-options"},{"type":"function","doc":"Return a meme image from a base image and\none or two lines of text or raise an exception.\n\nThe size of the text is determined by the size\nof the base image.","title":"Image.meme!/3","ref":"Image.html#meme!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` over which\n  the meme text will be composed.\n\n* `headline` is the top line of the meme text.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.meme!/3","ref":"Image.html#meme!/3-arguments"},{"type":"function","doc":"* `:text` is the second line of text at the bottom of the\n  meme image. The default is `\"\"`.\n\n* `:text_size` is the size of the bottom text in points.\n  The default is calculated proportional to the size of the\n  image.\n\n* `:headline_size` is the size of the headline text in points.\n  The default is calculated proportional to the size of the\n  image.\n\n* `:font` is the name of the font family to be applied.\n  The default is `Impact`. If the font family name is `\"Impact\"`\n  then the included `unicode.impact.ttf` font file will also be\n  loaded. This ensures that the `Impact` font is available on all\n  systems.\n\n* `:font_file` is the path name to a font file that will be\n  loaded. The default is `:default` which will load the included\n  `Impact` font if the font family is `Impact`. If the font family\n  is not `Impact` and the `:font_file` is `:default` then the\n  font displayed is resolved by the underlying operating system.\n  If `:font_file` is a string, then it is expected to be a valid\n  font file. If `:font_file` is set to a path then the `:font` option\n  should also be set to the correct font name.\n\n* `:weight` is the font weight to be rendered. The options\n  are `:ultralight`, `:light`, `:normal`, `:bold`, `:ultrabold`,\n  and `:heavy`. The default `:bold`.\n\n* `:justify` is a boolean indicating if the headline and text\n  are to be justified. If `true` then space is added between\n  words so that both edges of each line are aligned with both\n  margins. The default is `false`.\n\n* `:transform` determines how the text is presented. The\n  options are `:upcase`, `:downcase`, `:capitalize` and `:none`.\n  The default is `:upcase`.\n\n* `:color` is an RGB color of the text. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:white`.\n\n* `:outline_color` is an RGB color of the text outline. The\n  color can be an integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is `:black`.\n\n* `:margin` is the width of the margin in pixels. The margin is\n  applied to both the left and right sides of the image. The\n  default is calculated proportional to the size of the\n  image.","title":"Options - Image.meme!/3","ref":"Image.html#meme!/3-options"},{"type":"function","doc":"Minimize metadata by keeping only the artist\nand copyright (if available).\n\nRemoving metadata from an image can greatly reduce\nthe overall size of an image. The proportional\nreduction is most noticeable with smaller images\nwhich are very common in web applications.\n\nRemoving all metadata is a common option however\nwith intellectual property concerns in mind\nthis function will keep the artist and\ncopyright fields if they exist in the original\nimage.\n\nOn a 1000x500px image exported from Adobe Lightroom\nwith metadata intact, removing the metadata\nresults in am approximately 50% saving in file\nsize due to the removal of most EXIF and all\nIPTC and XMP metadata.\n\nNote that the minimized metadata is only materialized when\nthe minimized image is saved to a file.","title":"Image.minimize_metadata/1","ref":"Image.html#minimize_metadata/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`","title":"Arguments - Image.minimize_metadata/1","ref":"Image.html#minimize_metadata/1-arguments"},{"type":"function","doc":"* `{:ok, image_with_minimal_metadata}` or\n\n* `{:error, reason}`","title":"Returns - Image.minimize_metadata/1","ref":"Image.html#minimize_metadata/1-returns"},{"type":"function","doc":"Minimize metadata by keeping only the artist\nand copyright (if available).\n\nSee also `Image.minimize_metadata/1`.","title":"Image.minimize_metadata!/1","ref":"Image.html#minimize_metadata!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`","title":"Arguments - Image.minimize_metadata!/1","ref":"Image.html#minimize_metadata!/1-arguments"},{"type":"function","doc":"* ` image_with_minimal_metadata` or\n\n* raises an exception.","title":"Returns - Image.minimize_metadata!/1","ref":"Image.html#minimize_metadata!/1-returns"},{"type":"function","doc":"Transforms an image using brightness, saturation,\nhue rotation, and lightness.\n\nBrightness and lightness both operate on luminance,\nwith the difference being that brightness is multiplicative\nwhereas lightness is additive.","title":"Image.modulate/2","ref":"Image.html#modulate/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.modulate/2","ref":"Image.html#modulate/2-arguments"},{"type":"function","doc":"* `:brightness` is any float greater than `0.0`. A number less\n  than `1.0` means reduce brightness. A number greater than `1.0`\n  means increas brightness.  The default is `1.0` meaning no\n  brightness adjustment.\n\n* `:lightness` is any float. This value is added to the luminance\n  of an image. This is different to `:brightness` which is *multuplied*\n  by the luminance. The default is `0.0` meaning no lightness\n  adjustment.\n\n* `:saturation` is any float greater than `0.0`. A number less\n  than `1.0` means reduce saturation. A number greater than `1.0`\n  means increas saturation. The default is `1.0` meaning no\n  saturation adjustment.\n\n* `:hue` is an integer angle in degrees added to the hue. This is often\n  referred to as the *hug angle* and the operation as adjusting\n  the *hue rotation*. The value should typically be in the range `0..360`.\n  The default is `0` meaning no hue adjustment.","title":"Options - Image.modulate/2","ref":"Image.html#modulate/2-options"},{"type":"function","doc":"* `{:ok, modulated_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.modulate/2","ref":"Image.html#modulate/2-returns"},{"type":"function","doc":"Transforms an image using brightness, saturation,\nhue rotation, and lightness or raises an exception.\n\nBrightness and lightness both operate on luminance,\nwith the difference being that brightness is multiplicative\nwhereas lightness is additive.","title":"Image.modulate!/2","ref":"Image.html#modulate!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.modulate!/2","ref":"Image.html#modulate!/2-arguments"},{"type":"function","doc":"* `:brightness` is any float greater than `0.0`. A number less\n  than `1.0` means reduce brightness. A number greater than `1.0`\n  means increas brightness.  The default is `1.0` meaning no\n  brightness adjustment.\n\n* `:lightness` is any float. This value is added to the luminance\n  of an image. This is different to `:brightness` which is *multuplied*\n  by the luminance. The default is `0.0` meaning no lightness\n  adjustment.\n\n* `:saturation` is any float greater than `0.0`. A number less\n  than `1.0` means reduce saturation. A number greater than `1.0`\n  means increas saturation. The default is `1.0` meaning no\n  saturation adjustment.\n\n* `:hue` is an integer angle in degrees added to the hue. This is often\n  referred to as the *hug angle* and the operation as adjusting\n  the *hue rotation*. The value should typically be in the range `0..360`.\n  The default is `0` meaning no hue adjustment.","title":"Options - Image.modulate!/2","ref":"Image.html#modulate!/2-options"},{"type":"function","doc":"* `modulated_image` or\n\n* raises an exception.","title":"Returns - Image.modulate!/2","ref":"Image.html#modulate!/2-returns"},{"type":"function","doc":"Mutate an image with through the given\nfunction.\n\nMutations, like those functions in the\n`Image.Draw`, module are operations on\na *copy* of the base image and operations\nare serialized through a genserver in order\nto maintain thread safety.\n\nIn order to perform multiple mutations without\ncoopying for each each mutation,`Image.mutate/2` takes\na function argument `fun` that is passed a\n`t:Vix.Vips.MutableImage.t/0` as a parameter. In that\nway several mutations can be safely applied withouout\ncopying the image prior to each mutation.\n\nAlthough the image is not copied before each mutuation,\neach mutable operation is still serialized behind\na genserver to ensure thread safety.\n\nThe functions in `Image.Draw` all support either\na `t:Vix.Vips.Image.t/0` or a `t:Vix.Vips.MutableImage.t/0`\nas the image parameter.\n\nWhen the parameter `fun` returns, the mutation\nprocess is ended and a normal `t:Vix.Vips.Image.t/0`\nis returned.\n\nThis function is a convenience wrapper\naround `Vix.Vips.Image.mutate/2`.","title":"Image.mutate/2","ref":"Image.html#mutate/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `fun` is any 1-arity function that receives\n  a `t:Vix.Vips.MutableImage.t/0` parameter.","title":"Arguments - Image.mutate/2","ref":"Image.html#mutate/2-arguments"},{"type":"function","doc":"* `{:ok, mutated_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.mutate/2","ref":"Image.html#mutate/2-returns"},{"type":"function","doc":"# The image is copied and operations\n      # are serialized behind a genserver.\n      # Only one copy is made but all operations\n      # will be serialized behind a genserver.\n      # When the function returns the genserver\n      # is broken down and the underlying\n      # mutated `t:Vix.Vips.Image.t/0` is returned.\n\n      Image.mutate image, fn mutable_image ->\n        mutable_image\n        |> Image.Draw.rect!(0, 0, 10, 10, color: :red)\n        |> Image.Draw.rect!(10, 10, 20, 20, color: :green)\n      end","title":"Example - Image.mutate/2","ref":"Image.html#mutate/2-example"},{"type":"function","doc":"Create a new image of the same shape as the\nprovided image.\n\nThe function creates a new image with the same\nwidth, height and bands as the image argument and\na color of `:black`.","title":"Image.new/1","ref":"Image.html#new/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` from\n  which the new images `width` and `height` and\n` bands` will be derived.","title":"Arguments - Image.new/1","ref":"Image.html#new/1-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.new/1","ref":"Image.html#new/1-returns"},{"type":"function","doc":"Create a new image of the given dimensions.","title":"Image.new/2","ref":"Image.html#new/2"},{"type":"function","doc":"Either `width` and `height` OR `image` should be\nprovided.\n\n* `width` is the image width as an integer.\n\n* `height` is the image height as an integer.\n\n* `image` is an image from which the `width`, `height` are\n  derived.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.new/2","ref":"Image.html#new/2-arguments"},{"type":"function","doc":"* `:color` defines the color of the image. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `:bands` defines the number of bands (channels)\n  to be created. The default is the number of bands of\n  `:color` option or if `:color` is an integer then the\n  default value is `3`.\n\n* `:format` defines the format of the image. The\n  default is `{:u, 8}`.\n\n* `:interpretation` defines the interpretation of\n  the image. The default is `:srgb`.","title":"Options - Image.new/2","ref":"Image.html#new/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.new/2","ref":"Image.html#new/2-returns"},{"type":"function","doc":"* Either `width` and `height` OR `image` should\n  be provided as arguments but NOT both.","title":"Notes - Image.new/2","ref":"Image.html#new/2-notes"},{"type":"function","doc":"# 100x100 pixel image of dark blue slate color\n      iex> {:ok, _image} = Image.new(100, 100, color: :dark_slate_blue)\n\n      # 100x100 pixel green image, fully transparent\n      iex> {:ok, _image} = Image.new(100, 100, color: [0, 255, 0, 255], bands: 4)","title":"Examples - Image.new/2","ref":"Image.html#new/2-examples"},{"type":"function","doc":"","title":"Image.new/3","ref":"Image.html#new/3"},{"type":"function","doc":"Return a new image of the same shape as the\nprovided image or raise an exception.\n\nThe function creates a new image with the same\nwidth, height and bands as the image argument.","title":"Image.new!/1","ref":"Image.html#new!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` from\n  which the new images `width` and `height` and\n` bands` will be derived.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.new!/1","ref":"Image.html#new!/1-arguments"},{"type":"function","doc":"* `:bands` defines the number of bands (channels)\n  to be created. The default is the number of bands\n  in `image`.\n\n* `:color` defines the color of the image. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `:format` defines the format of the image. The\n  default is `{:u, 8}`.\n\n* `:interpretation` defines the interpretation of\n  the image. The default is `:srgb`.","title":"Options - Image.new!/1","ref":"Image.html#new!/1-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.new!/1","ref":"Image.html#new!/1-returns"},{"type":"function","doc":"Return a new image of the given dimensions and\nbackground color or raise an exception.","title":"Image.new!/2","ref":"Image.html#new!/2"},{"type":"function","doc":"Either `width` and `height` OR `image` should be\nprovided.\n\n* `width` is the image width as an integer.\n\n* `height` is the image height as an integer.\n\n* `image` is an image from which the `width`, `height` re\n  derived.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.new!/2","ref":"Image.html#new!/2-arguments"},{"type":"function","doc":"* `:bands` defines the number of bands (channels)\n  to be created. The default is `3`.\n\n* `:color` defines the color of the image. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The default is `0`, meaning black. The color\n  can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `:format` defines the format of the image. The\n  default is `{:u, 8}`.\n\n* `:interpretation` defines the interpretation of\n  the image. The default is `:srgb`.","title":"Options - Image.new!/2","ref":"Image.html#new!/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.new!/2","ref":"Image.html#new!/2-returns"},{"type":"function","doc":"* Either `width` and `height` OR `image` should\n  be provided as arguments but NOT both.","title":"Notes - Image.new!/2","ref":"Image.html#new!/2-notes"},{"type":"function","doc":"# 100x100 pixel image of dark blue slate color\n      iex> {:ok, _image} = Image.new(100, 100, color: :dark_slate_blue)\n\n      # 100x100 pixel green image, fully transparent\n      iex> {:ok, _image} = Image.new(100, 100, color: [0, 255, 0, 1], bands: 4)","title":"Examples - Image.new!/2","ref":"Image.html#new!/2-examples"},{"type":"function","doc":"","title":"Image.new!/3","ref":"Image.html#new!/3"},{"type":"function","doc":"Opens an image file or stream for image processing.","title":"Image.open/2","ref":"Image.html#open/2"},{"type":"function","doc":"* `image_path_or_stream_or_binary` is the file system path to an image\n  file or a `t:File.Stream.t/0` or any `t:Enumerable.t/0`. It\n  can also be any binary `.jpg`, `.png`, `.webp` or `.svg` image.\n\n* `options` is a keyword list of options. The default is\n  `[access: :random]` for all images except images\n  derived from binary image data.","title":"Arguments - Image.open/2","ref":"Image.html#open/2-arguments"},{"type":"function","doc":"The available options depend upon the image type.\n\n#### All image types\n\n* `:access` is the file access mode, either `:random`\n  or `:sequential`. The default is `:random`.\n  When `:sequential`, `Image` (via `Vix`) is able\n  to support streaming transformations and optimise\n  memory usage more effectively. However `:sequential`\n  also means that some operations cannot be completed\n  because they would require non-sequential access to\n  the image. In these cases, `:random` access is required.\n\n* `:fail_on` sets the error level at which image\n  loading and decoding will stop. The default is `:none`.\n  Each error state implies all the states before it such\n  that `:error` implies also `:truncated`.\n\n#### JPEG image options\n\n* `:shrink` is an integer factor in the range `1..16` by\n  which the image is reduced upon loading. This is an\n  optimization that can result in improved performance and\n  reduced memory usage if the image is being loaded\n  with the intent to resize it to smaller dimensions. The\n  default value is `1` meaning no shrink-on-load.\n\n#### WEBP options\n\n* `:scale` will scale the image on load. The value is\n  a number greater than `0` and less than or equal\n  to `1024` with a default of `1` meaning no scaling\n  on load. Numbers less than `1.0` scale the image down\n  so that a scale of `0.5` will halve the image size on\n  load.\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### TIFF options\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### GIF options\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### PNG options\n\n* There are no PNG-specific image loading\n  options.","title":"Options - Image.open/2","ref":"Image.html#open/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, message}`","title":"Returns - Image.open/2","ref":"Image.html#open/2-returns"},{"type":"function","doc":"Opens an image file for image processing\nreturning an image or raising an exception.","title":"Image.open!/2","ref":"Image.html#open!/2"},{"type":"function","doc":"* `image_path_or_stream_or_binary` is the file system path to an image\n  file or a `t:File.Stream.t/0` or any `t:Enumerable.t/0`. It\n  can also be any binary `.jpg`, `.png`, `.webp` or `.svg` image.\n\n* `options` is a keyword list of options. The default is\n  `[access: :random]` for all images except images\n  derived from binary image data.","title":"Arguments - Image.open!/2","ref":"Image.html#open!/2-arguments"},{"type":"function","doc":"The available options depend upon the image type.\n\n#### All image types\n\n* `:access` is the file access mode, either `:random`\n  or `:sequential`. The default is `:random`.\n  When `:sequential`, `Image` (via `Vix`) is able\n  to support streaming transformations and optimise\n  memory usage more effectively. However `:sequential`\n  also means that some operations cannot be completed\n  because they would require non-sequential access to\n  the image. In these cases, `:random` access is required.\n\n* `:fail_on` sets the error level at which image\n  loading and decoding will stop. The default is `:none`.\n  Each error state implies all the states before it such\n  that `:error` implies also `:truncated`.\n\n#### JPEG image options\n\n* `:shrink` is an integer factor in the range `1..16` by\n  which the image is reduced upon loading. This is an\n  optimization that can result in improved performance and\n  reduced memory usage if the image is being loaded\n  with the intent to resize it to smaller dimensions. The\n  default value is `1` meaning no shrink-on-load.\n\n* `:autorotate` is a boolean value indicating if\n  the image should be rotated according to the orientation\n  data stored in the image metadata. The default is\n  `false`.\n\n#### WEBP options\n\n* `:scale` will scale the image on load. The value is\n  a number greater than `0` and less than or equal\n  to `1024` with a default of `1` meaning no scaling\n  on load. Numbers less than `1.0` scale the image down\n  so that a scale of `0.5` will halve the image size on\n  load.\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### TIFF options\n\n* `:autorotate` is a boolean value indicating if\n  the image should be rotated according to the orientation\n  data stored in the image metadata. The default is\n  `false`.\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### GIF options\n\n* `:page` indicates the first page to be loaded. The\n  value is in the range `0..100_000` with a default\n  value of `0`. This parameter is useful on animated images.\n\n* `:pages` indicates the number of pages to load.\n  The value must be between `-1` and `100_000`. The default\n  value is `1`.  A value of `-1` would load all the available\n  pages which is useful if you want to keep the animation of\n  the input image. The atom `:all` can be used in place of\n  `-1` to indicate all pages should be loaded.\n\n#### PNG options\n\n* There are no PNG-specific image loading\n  options.","title":"Options - Image.open!/2","ref":"Image.html#open!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.open!/2","ref":"Image.html#open!/2-returns"},{"type":"function","doc":"Outputs an inline preview of an image to\nan iTerm2 terminal.\n\nOnly iTerm2 terminal windows are supported.\n\nDelegates to `Image.preview/1`","title":"Image.p/1","ref":"Image.html#p/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.p/1","ref":"Image.html#p/1-arguments"},{"type":"function","doc":"* The function `Image.p/1` is delegated to\n  this function.\n\n* The maximum width of the preview can be set\n  by the environment variable `IMAGE_PREVIEW_MAX_WIDTH`.\n  The default is `1_000` pixels wide. If the width\n  of the image is greater than the maximum it will be\n  resized to the maximum width for the preview.\n\n* Intended to be used as shortcut in `iex`.\n  It can be included in `.iex.exs` file:\n\n    # .iex.exs\n    import_if_available(Image, only: [p: 1])","title":"Notes - Image.p/1","ref":"Image.html#p/1-notes"},{"type":"function","doc":"Returns the number of pages in an image.\n\nAnimated images will return an integer representing\nthe number of animated frames. Normal images will\nreturn `1`.","title":"Image.pages/1","ref":"Image.html#pages/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.pages/1","ref":"Image.html#pages/1-arguments"},{"type":"function","doc":"* `integer` number of pages in the `image`.","title":"Returns - Image.pages/1","ref":"Image.html#pages/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/animated.webp\")\n    iex> Image.pages(image)\n    12\n\n    iex> image = Image.open!(\"./test/support/images/Kamchatka-2019-8754.jpg\")\n    iex> Image.pages(image)\n    1","title":"Example - Image.pages/1","ref":"Image.html#pages/1-example"},{"type":"function","doc":"Pixelates an image.\n\nPixelation is the process of reducing the image\nresolution while retaining the image dimensions.","title":"Image.pixelate/2","ref":"Image.html#pixelate/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `scale` is the scale factor to apply to\n  the image when it is pixelated. This means that\n  one \"pixel\" is `image width * scale`. The default\n  is `0.05`.","title":"Arguments - Image.pixelate/2","ref":"Image.html#pixelate/2-arguments"},{"type":"function","doc":"* `{:ok, pixelated_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.pixelate/2","ref":"Image.html#pixelate/2-returns"},{"type":"function","doc":"Pixelates an image or raise an exception.\n\nPixelation is the process of reducing the image\nresolution while retaining the image dimensions.","title":"Image.pixelate!/2","ref":"Image.html#pixelate!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `scale` is the scale factor to apply to\n  the image when it is pixelated. This means that\n  one \"pixel\" is `image width * scale`. The default\n  is `0.05`.","title":"Arguments - Image.pixelate!/2","ref":"Image.html#pixelate!/2-arguments"},{"type":"function","doc":"* `{:ok, pixelated_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.pixelate!/2","ref":"Image.html#pixelate!/2-returns"},{"type":"function","doc":"Outputs an inline preview of an image to\nan iTerm2 terminal.\n\nOnly iTerm2 terminal windows are supported.","title":"Image.preview/1","ref":"Image.html#preview/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` or\n  a tuple of the form `{:ok, image}`.","title":"Arguments - Image.preview/1","ref":"Image.html#preview/1-arguments"},{"type":"function","doc":"* The `image` parameter as provided with the\n  side effect of emitting an image preview on\n  an iTerm terminal.","title":"Returns - Image.preview/1","ref":"Image.html#preview/1-returns"},{"type":"function","doc":"* The function `Image.p/1` is delegated to\n  this function.\n\n* The maximum width of the preview can be set\n  by the environment variable `IMAGE_PREVIEW_MAX_WIDTH`.\n  The default is `1_000` pixels wide. If the width\n  of the image is greater than the maximum it will be\n  resized to the maximum width for the preview.\n\n* Intended to be used as shortcut in `iex`.\n  It can be included in an `.iex.exs` file:\n\n    # .iex.exs\n    import_if_available(Image, only: [preview: 1])","title":"Notes - Image.preview/1","ref":"Image.html#preview/1-notes"},{"type":"function","doc":"Sets the number of available threads for use\nby `libvips`.\n\nBy default this is the same as the number of\ncores in the system. Reducing this number may\nprevent CPU starvation for other workloads.","title":"Image.put_concurrency/1","ref":"Image.html#put_concurrency/1"},{"type":"function","doc":"* `concurrency` is a positive integer denoting\n  the maximum number of threads that `libvips` will\n  use for concurrency.","title":"Arguments - Image.put_concurrency/1","ref":"Image.html#put_concurrency/1-arguments"},{"type":"function","doc":"* `{:ok, updated_concurrency}`","title":"Returns - Image.put_concurrency/1","ref":"Image.html#put_concurrency/1-returns"},{"type":"function","doc":"Returns a radial gradient as an image.\n\nThis image might then be composited over\nanother image.","title":"Image.radial_gradient/3","ref":"Image.html#radial_gradient/3"},{"type":"function","doc":"* `width` is the width of the gradient in\n  pixels.\n\n* `height` is the height of the gradient in\n  pixels.\n\n* `options` is a keyword list of options. See\n  `t:Image.Options.RadialrGradient.radial_gradient_option/0`.","title":"Arguments - Image.radial_gradient/3","ref":"Image.html#radial_gradient/3-arguments"},{"type":"function","doc":"* `:start_color` is an sRGB color which represents the starting\n  color of the gradient. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color, or an atom\n  representing a CSS color name. The default is `:black`\n  with 100% transparency.\n\n* `:finish_color` is an sRGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:black` with 100% opacity.\n\n* `:feather` is the slope of the gradient. That is,\n  how quickly the gradient moves from the `:start_color`\n  color to the `:finish_color`. The valid range is\n  `1..10` representing the smallest amount of feather\n  (harshest transition) to the largest amount of\n  feather (smoothest transition). The default is `1`.\n\n* `:radius` is the radius of the gradient in the range `1..5`\n  where `1` fully fills the space and `5` fills a small section\n  of the center of the space.  The default is `2`.","title":"Options - Image.radial_gradient/3","ref":"Image.html#radial_gradient/3-options"},{"type":"function","doc":"* `{:ok, gradient_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.radial_gradient/3","ref":"Image.html#radial_gradient/3-returns"},{"type":"function","doc":"Returns a radial gradient as an image.\n\nThis image might then be composited over\nanother image.","title":"Image.radial_gradient!/3","ref":"Image.html#radial_gradient!/3"},{"type":"function","doc":"* `width` is the width of the gradient in\n  pixels.\n\n* `height` is the height of the gradient in\n  pixels.\n\n* `options` is a keyword list of options. See\n  `t:Image.Options.RadialrGradient.radial_gradient_option/0`.","title":"Arguments - Image.radial_gradient!/3","ref":"Image.html#radial_gradient!/3-arguments"},{"type":"function","doc":"* `:start_color` is an sRGB color which represents the starting\n  color of the gradient. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color, or an atom\n  representing a CSS color name. The default is `:black`\n  with 100% transparency.\n\n* `:finish_color` is an sRGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-or-four-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:black` with 100% opacity.\n\n* `:feather` is the slope of the gradient. That is,\n  how quickly the gradient moves from the `:start_color`\n  color to the `:finish_color`. The valid range is\n  `1..10` representing the smallest amount of feather\n  (harshest transition) to the largest amount of\n  feather (smoothest transition). The default is `1`.\n\n* `:radius` is the radius of the gradient in the range `1..5`\n  where `1` fully fills the space and `5` fills a small section\n  of the center of the space.  The default is `2`.","title":"Options - Image.radial_gradient!/3","ref":"Image.html#radial_gradient!/3-options"},{"type":"function","doc":"* `{:ok, gradient_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.radial_gradient!/3","ref":"Image.html#radial_gradient!/3-returns"},{"type":"function","doc":"Returns the range of permissable values\nas a tuple for each pixel in an image.","title":"Image.range/1","ref":"Image.html#range/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.range/1","ref":"Image.html#range/1-arguments"},{"type":"function","doc":"* `{min_value, max_value}` where `min_value` and\n  `max_value` are integers for unsigned images and\n  floats for signed images.","title":"Returns - Image.range/1","ref":"Image.html#range/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Singapore-2016-09-5887.jpg\")\n      iex> Image.range(image)\n      {0, 255}","title":"Examples - Image.range/1","ref":"Image.html#range/1-examples"},{"type":"function","doc":"Reduces the number of colors in an image.\n\nTakes the `k_means/2` of the image and then\nre-colors the image using the returned cluster\ncolors.","title":"Image.reduce_colors/2","ref":"Image.html#reduce_colors/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.reduce_colors/2","ref":"Image.html#reduce_colors/2-arguments"},{"type":"function","doc":"* `:colors` is the number of distinct colors to be\n  used in the returned image. The default is `16`.\n\n* See also `Scholar.Cluster.KMeans.fit/2` for the\n  available options.","title":"Options - Image.reduce_colors/2","ref":"Image.html#reduce_colors/2-options"},{"type":"function","doc":"* Note the performance considerations described in\n  `Image.k_means/2` since they also apply to this function.\n\n* If the intent is to reduce colors in order to\n  reduce the size of an image file it is strongly advised to\n  use the appropriate arguments when calling `Image.write/2`.","title":"Note - Image.reduce_colors/2","ref":"Image.html#reduce_colors/2-note"},{"type":"function","doc":"* `{:ok, reduced_colors_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.reduce_colors/2","ref":"Image.html#reduce_colors/2-returns"},{"type":"function","doc":"Reduces the number of colors in an image or\nraises an exception.\n\nTakes the `k_means/2` of the image and then\nre-colors the image using the returned cluster\ncolors.","title":"Image.reduce_colors!/2","ref":"Image.html#reduce_colors!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.reduce_colors!/2","ref":"Image.html#reduce_colors!/2-arguments"},{"type":"function","doc":"* `:colors` is the number of distinct colors to be\n  used in the returned image. The default is `16`.\n\n* See also `Scholar.Cluster.KMeans.fit/2` for the\n  available options.","title":"Options - Image.reduce_colors!/2","ref":"Image.html#reduce_colors!/2-options"},{"type":"function","doc":"* Note the performance considerations described in\n  `Image.k_means/2` since they also apply to this function.\n\n* If the intent is to reduce colors in order to\n  reduce the size of an image file it is strongly advised to\n  use the appropriate arguments when calling `Image.write/2`.","title":"Note - Image.reduce_colors!/2","ref":"Image.html#reduce_colors!/2-note"},{"type":"function","doc":"* `reduced_colors_image` or\n\n* raises an exception.","title":"Returns - Image.reduce_colors!/2","ref":"Image.html#reduce_colors!/2-returns"},{"type":"function","doc":"Reduces noise in an image by applying a median\nfilter.\n\nThe implementation uses a [median rank filter](https://en.wikipedia.org/wiki/Median_filter)\nbased on ordering the pixel values under a convolution kernel of a given\nwindow size and extracting the median value.\n\nThe result is appropriate for removing\n[salt and pepper noise](https://en.wikipedia.org/wiki/Salt-and-pepper_noise) and\nmay be useful for smoothing gaussian noise in some cases.","title":"Image.reduce_noise/2","ref":"Image.html#reduce_noise/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `window_size` is the integer size of the convolution kernel use\n  in the median rank filter. The default is `3`.","title":"Arguments - Image.reduce_noise/2","ref":"Image.html#reduce_noise/2-arguments"},{"type":"function","doc":"* `{:ok, reduced_noise_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.reduce_noise/2","ref":"Image.html#reduce_noise/2-returns"},{"type":"function","doc":"Reduces noise in an image by applying a median\nfilter or raises an exception.\n\nThe implementation uses a [median rank filter](https://en.wikipedia.org/wiki/Median_filter)\nbased on ordering the pixel values under a convolution kernel of a given\nwindow size and extracting the median value.\n\nThe result is appropriate for removing\n[salt and pepper noise](https://en.wikipedia.org/wiki/Salt-and-pepper_noise) and\nmay be useful for smoothing gaussian noise in some cases.","title":"Image.reduce_noise!/2","ref":"Image.html#reduce_noise!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `window_size` is the integer size of the convolution kernel use\n  in the median rank filter. The default is `3`.","title":"Arguments - Image.reduce_noise!/2","ref":"Image.html#reduce_noise!/2-arguments"},{"type":"function","doc":"* `reduced_noise_image` or\n\n* raises an exception.","title":"Returns - Image.reduce_noise!/2","ref":"Image.html#reduce_noise!/2-returns"},{"type":"function","doc":"Remove metadata from an image returning\nan updated image or raising an exception.\n\nThis can significantly reduce the size of\nan image file.","title":"Image.remove_metadata/2","ref":"Image.html#remove_metadata/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `fields` is a list of metadata field names\n  as strings. The default is all known\n  field names. There are some special field\n  names interpreted by `Image` to simplify\n  metadata removal these are:\n\n  * `:exif` which means remove all\n    [EXIF](https://en.wikipedia.org/wiki/Exif) metadata\n  * `:iptc` which means remove all\n    [IPTC](https://en.wikipedia.org/wiki/IPTC_Information_Interchange_Model) metadata\n  * `:xmp` which means remove all\n    [xmp](https://en.wikipedia.org/wiki/Extensible_Metadata_Platform) data","title":"Arguments - Image.remove_metadata/2","ref":"Image.html#remove_metadata/2-arguments"},{"type":"function","doc":"* The available field names (ie. metadata fields)\n  in an image can be returned with a call to\n  `Vix.Vips.Image.header_field_names/1`.\n\n* Errors removing metadata fields is not propagated\n  into the return for this function. Errors might occur\n  when attempting to remove metadata fields that\n  do not exist in the image.","title":"Notes - Image.remove_metadata/2","ref":"Image.html#remove_metadata/2-notes"},{"type":"function","doc":"* `{:ok, image_without_metadata_fields}` or\n\n  * `{:error, reason}`","title":"Returns - Image.remove_metadata/2","ref":"Image.html#remove_metadata/2-returns"},{"type":"function","doc":"Remove metadata from an image returning\nan image or raising an exception.\n\nThis can significant;y reduce the size of\nan image file.","title":"Image.remove_metadata!/2","ref":"Image.html#remove_metadata!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `fields` is a list of metadata field names\n  as strings. The default is all known\n  field names. There are some special field\n  names interpreted by `Image` to simplify\n  metadata removal these are:\n\n  * `:exif` which means remove all\n    [EXIF](https://en.wikipedia.org/wiki/Exif) metadata\n  * `:iptc` which means remove all\n    [IPTC](https://en.wikipedia.org/wiki/IPTC_Information_Interchange_Model) metadata\n  * `:xmp` which means remove all\n    [xmp](https://en.wikipedia.org/wiki/Extensible_Metadata_Platform) data","title":"Arguments - Image.remove_metadata!/2","ref":"Image.html#remove_metadata!/2-arguments"},{"type":"function","doc":"* The available field names (ie. metadata fields)\n  in an image can be returned with a call to\n  `Vix.Vips.Image.header_field_names/1`.\n\n* Errors removing metadata fields is not propagated\n  into the return for this function. Errors might occur\n  when attempting to remove metadata fields that\n  do not exist in the image.","title":"Notes - Image.remove_metadata!/2","ref":"Image.html#remove_metadata!/2-notes"},{"type":"function","doc":"* `image_without_metadata_fields` or\n\n  * raises an exception.","title":"Returns - Image.remove_metadata!/2","ref":"Image.html#remove_metadata!/2-returns"},{"type":"function","doc":"Replace one color in an image with another.","title":"Image.replace_color/2","ref":"Image.html#replace_color/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.replace_color/2","ref":"Image.html#replace_color/2-arguments"},{"type":"function","doc":"With the exception of the option `:replace_with`, the\noptions for specifying the color or color range\nto be replaced are passed to `Image.chroma_mask/2`.\n\n* `:blend` is a boolean indicating if a the replacement\n  should blend at the border of the color replacement.\n  The default is `false`.\n\n* `:replace_with` is the replacement color.  This can be specified as\n  a single integer which wil be applied to all bands, or a\n  list of integers representing the color for each band. The\n  color can also be supplied as a CSS color name as a string or\n  atom. For example: `:misty_rose`. It can also be supplied as a\n  hex string of the form `#rrggbb`. The default is `:black`.\n  See also `Image.Color.color_map/0` and `Image.Color.validate_color/1`.\n\nThere are two strategies available for selecting the\ncolor or color range to be replaced: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold`is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be selected. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n* `:less_than` is an RGB color which represents the lower\n   end of the color range to be selected. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.replace_color/2","ref":"Image.html#replace_color/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.replace_color/2","ref":"Image.html#replace_color/2-returns"},{"type":"function","doc":"Replace one color in an image with another or\nraises an exception.","title":"Image.replace_color!/2","ref":"Image.html#replace_color!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.replace_color!/2","ref":"Image.html#replace_color!/2-arguments"},{"type":"function","doc":"With the exception of the option `:replace_with`, the\noptions for specifying the color or color range\nto be replaced are passed to `Image.chroma_mask/2`.\n\n* `:replace_with` is the replacement color.  This can be specified as\n  a single integer which wil be applied to all bands, or a\n  list of integers representing the color for each band. The\n  color can also be supplied as a CSS color name as a string or\n  atom. For example: `:misty_rose`. It can also be supplied as a\n  hex string of the form `#rrggbb`. The default is `:black`.\n  See also `Image.Color.color_map/0` and `Image.Color.validate_color/1`.\n\nThere are two strategies available for selecting the\ncolor or color range to be replaced: the\nthresholding strategy (default) and the color\nrange strategy.\n\n#### Threshold strategy\n\n* `:color` is an RGB color which represents the the\n  chroma key to be selected. The color can be an\n  integer between `0..255`, a three-element list of\n  integers representing an RGB color or an atom\n  representing a CSS color name. The default is\n  `:auto` in which the average of the top left `10x10`\n  pixels of the image is used.\n\n* `:threshold`is a positive integer to indicate the\n  threshold around `:color` when calculating the mask.\n  The default is `20`.\n\n#### Color range strategy\n\n* `:greater_than` is an RGB color which represents the upper\n   end of the color range to be selected. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.\n\n* `:less_than` is an RGB color which represents the lower\n   end of the color range to be selected. The color can be an\n   integer between `0..255`, a three-element list of\n   integers representing an RGB color or an atom\n   representing a CSS color name.","title":"Options - Image.replace_color!/2","ref":"Image.html#replace_color!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.replace_color!/2","ref":"Image.html#replace_color!/2-returns"},{"type":"function","doc":"Resize an image.\n\nIf the intent is to thumbnail an image then `Image.thumbnail/3`\nis recommended since it applies a very efficient downsizing\nalgorithm for that use case.","title":"Image.resize/3","ref":"Image.html#resize/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `scale` is a float scale factor.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.resize/3","ref":"Image.html#resize/3-arguments"},{"type":"function","doc":"* `:centre` is a boolean indicating whether to use\n  the centre downsampling convention. The default is\n  `false`.\n\n* `:interpolate` defines which resampling kernel to apply.\n  The options are `:nearest`, `:linear`, `:cubic`,\n  `:mitchell`, `:lanczos2` or `:lanczos3` (the default).\n\n* `:vertical_scale` is a float indicating the scaling\n  factor of the vertical axis. In specified, then `scale`\n  is applied only to the horizontal axis.","title":"Options - Image.resize/3","ref":"Image.html#resize/3-options"},{"type":"function","doc":"* `{:ok, resized_image}` or\n\n* raises an exception","title":"Returns - Image.resize/3","ref":"Image.html#resize/3-returns"},{"type":"function","doc":"Resize an image or raise an exception.\n\nIf the intent is to thumbnail an image then `Image.thumbnail/3`\nis recommended since it applies a very efficient downsizing\nalgorithm for that use case.","title":"Image.resize!/3","ref":"Image.html#resize!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `scale` is a float scale factor.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.resize!/3","ref":"Image.html#resize!/3-arguments"},{"type":"function","doc":"* `:centre` is a boolean indicating whether to use\n  the centre downsampling convention. The default is\n  `false`.\n\n* `:interpolate` defines which resampling kernel to apply.\n  The options are `:nearest`, `:linear`, `:cubic`,\n  `:mitchell`, `:lanczos2` or `:lanczos3` (the default).\n\n* `:vertical_scale` is a float indicating the scaling\n  factor of the vertical axis. In specified, then `scale`\n  is applied only to the horizontal axis.","title":"Options - Image.resize!/3","ref":"Image.html#resize!/3-options"},{"type":"function","doc":"* `resized_image` or\n\n* raises an exception","title":"Returns - Image.resize!/3","ref":"Image.html#resize!/3-returns"},{"type":"function","doc":"Adds a concentric ripple effect to an image.","title":"Image.ripple/1","ref":"Image.html#ripple/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.ripple/1","ref":"Image.html#ripple/1-arguments"},{"type":"function","doc":"* `{:ok, image_with_ripple}` or\n\n* `{:error, reason}`","title":"Returns - Image.ripple/1","ref":"Image.html#ripple/1-returns"},{"type":"function","doc":"Adds a concentric ripple effect to an image\nreturning an image or raising an exception.","title":"Image.ripple!/1","ref":"Image.html#ripple!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.ripple!/1","ref":"Image.html#ripple!/1-arguments"},{"type":"function","doc":"* `image_with_ripple` or\n\n* raises an exception.","title":"Returns - Image.ripple!/1","ref":"Image.html#ripple!/1-returns"},{"type":"function","doc":"Rotate an image clockwise (to the\nright) by a number of degrees.","title":"Image.rotate/3","ref":"Image.html#rotate/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `angle` is a `float` number of degrees\n  to rotate in a clockwise direction.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.rotate/3","ref":"Image.html#rotate/3-arguments"},{"type":"function","doc":"* `:idy` is the vertical input displacement which\n  defaults to `0.0`\n\n* `:idx` is the horizontal input displacement which\n  defaults to `0.0`\n\n* `:ody` is the vertical output displacement\n  which defaults to `0.0`\n\n* `:odx` is the horizontal output displacement\n  which defaults to `0.0`\n\n* `:background` is the background color to be used for filling\n  the blank areas of the image. The background is specified as\n  a list of 3 or 4 float values depending on the image\n  color space.","title":"Options - Image.rotate/3","ref":"Image.html#rotate/3-options"},{"type":"function","doc":"The displacement parameters cause the image canvas to be\nexpanded and the image displaced, relative to the top left\ncorner of the image, by the amount specified.\n\nThe rules defining how the image canvas is expanded\nis not known to the author of `Image`. Experimentation will\nbe required if you explore these options.","title":"Notes - Image.rotate/3","ref":"Image.html#rotate/3-notes"},{"type":"function","doc":"* `{:ok, rotated_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.rotate/3","ref":"Image.html#rotate/3-returns"},{"type":"function","doc":"Rotate an image clockwise (to the\nright) by a number of degrees.","title":"Image.rotate!/3","ref":"Image.html#rotate!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `angle` is a `float` number of degrees\n  to rotate in a clockwise direction.\n\n* `options` is a keyword list of options.\n  See `Image.rotate/3`.","title":"Arguments - Image.rotate!/3","ref":"Image.html#rotate!/3-arguments"},{"type":"function","doc":"The displacement parameters cause the image canvas to be\nexpanded and the image displaced, relative to the top left\ncorner of the image, by the amount specified.\n\nThe rules defining how the image canvas is expanded\nis not known to the author of `Image`. Experimentation will\nbe required if you explore these options.","title":"Notes - Image.rotate!/3","ref":"Image.html#rotate!/3-notes"},{"type":"function","doc":"* `rotated_image` or\n\n* raises an exception.","title":"Returns - Image.rotate!/3","ref":"Image.html#rotate!/3-returns"},{"type":"function","doc":"Apply rounded corners to an image.","title":"Image.rounded/2","ref":"Image.html#rounded/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.rounded/2","ref":"Image.html#rounded/2-arguments"},{"type":"function","doc":"* `:radius` is the desired corner radius.\n  The default is 50.","title":"Options - Image.rounded/2","ref":"Image.html#rounded/2-options"},{"type":"function","doc":"* `{:ok, rounded_corner_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.rounded/2","ref":"Image.html#rounded/2-returns"},{"type":"function","doc":"Apply rounded corners to an image. Returns\nan image or raises an exception.","title":"Image.rounded!/2","ref":"Image.html#rounded!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.rounded!/2","ref":"Image.html#rounded!/2-arguments"},{"type":"function","doc":"* `:radius` is the desired corner radius.\n  The default is 50.","title":"Options - Image.rounded!/2","ref":"Image.html#rounded!/2-options"},{"type":"function","doc":"* `rounded_corner_image` or\n\n* raises an exception.","title":"Returns - Image.rounded!/2","ref":"Image.html#rounded!/2-returns"},{"type":"function","doc":"Apply an adjustment to an image's saturation\n(chroma).\n\nThe image is converted to the `lch` color space, multiplies the\nchroma band by the provided float and converts\nthe image back to its original color space.","title":"Image.saturation/2","ref":"Image.html#saturation/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `saturation` is any float greater than `0.0`. A number less\n  than `1.0` means reduce saturation. A number greater than `1.0`\n  means increas saturation.","title":"Arguments - Image.saturation/2","ref":"Image.html#saturation/2-arguments"},{"type":"function","doc":"* `{:ok, adjusted_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.saturation/2","ref":"Image.html#saturation/2-returns"},{"type":"function","doc":"Apply an adjustment to an image's saturation\n(chroma) or raises an exception.\n\nThe image is converted to the `lch` color space, multiplies the\nchroma band by the provided float and converts\nthe image back to its original color space.","title":"Image.saturation!/2","ref":"Image.html#saturation!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `saturation` is any float greater than `0.0`. A number less\n  than `1.0` means reduce saturation. A number greater than `1.0`\n  means increas saturation.","title":"Arguments - Image.saturation!/2","ref":"Image.html#saturation!/2-arguments"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `saturation` is any float greater than `0.0`. A number less\n  than `1.0` means reduce saturation. A number greater than `1.0`\n  means increas saturation.","title":"Arguments - Image.saturation!/2","ref":"Image.html#saturation!/2-arguments"},{"type":"function","doc":"* `adjusted_image` or\n\n* raises an exception.","title":"Returns - Image.saturation!/2","ref":"Image.html#saturation!/2-returns"},{"type":"function","doc":"Returns the shape of an image.","title":"Image.shape/1","ref":"Image.html#shape/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.shape/1","ref":"Image.html#shape/1-arguments"},{"type":"function","doc":"* The image shape as a tuple of\n  `{width, height, bands}`.","title":"Returns - Image.shape/1","ref":"Image.html#shape/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Kamchatka-2019-8754.jpg\")\n    iex> Image.shape(image)\n    {1000,542, 3}","title":"Example - Image.shape/1","ref":"Image.html#shape/1-example"},{"type":"function","doc":"Sharpens an image.\n\nSelectively sharpens the `L` channel of a LAB image. `image`\nis converted to `:labs` for sharpening and the converted back\nto its original interpretation.\n\nThe operation performs a gaussian blur and subtracts from `image` to generate a\nhigh-frequency signal. This signal is passed through a lookup table formed\nfrom the five parameters and then added back to `image`.\n\nThe lookup table is formed like this:\n\n```\n                    ^\n                 y2 |          -----------\n                    |         /\n                    |        / slope m2\n                    |    .../\n            -x1     | ...   |\n-------------------...---------------------->\n            |   ... |      x1\n            |... slope m1\n            /       |\n           / m2     |\n          /         |\n         /          |\n        /           |\n       /            |\n______/             | -y3\n                    |\n```\n\nWhere:\n\n* `m1` is `:flat_amount`\n* `m2` is `:jagged_amount`\n* `x1` is `:threshold`\n* `y2` is `:max_brightening`\n* `y3` is `:max_darkening`","title":"Image.sharpen/2","ref":"Image.html#sharpen/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.sharpen/2","ref":"Image.html#sharpen/2-arguments"},{"type":"function","doc":"* `:jagged_amount` is the primary means of specifing how much\n  sharpening to apply. Shaprening is applied to the jagged areas\n  of the image. It is a float greater or equal to `0.0`\n  with a default of `3.0`.\n\n* `:flat_amount` is the specifies how much\n  sharpening to apply to flat areas of the image. It is a float\n  greater or equal to `0.0` with a default of `0.0`.\n\n* `:threshold` indicates where the transition from the flat\n  part of the image to the jaggy part of the image is to be\n  considered on the curve. It is a float amount greater than\n  or equal to `0.0` with a default of `2.0`.\n\n* `:max_brightening` specifies how much the image may be\n  brightened as part of the sharpening process. It is a positive\n  integer greater than or equal to `0`. The default is `10`.\n\n* `:max_darkening` specifies how much the image may be\n  darkened as part of the sharpening process. It is a positive\n  integer greater than or equal to `0`. The default is `20`.\n\n* `:sigma` changes the width of the sharpening fringe and can be\n  adjusted according to the output printing resolution. As an approximate\n  guideline, use `0.5` for 4 pixels/mm (display resolution),\n  `1.0` for 12 pixels/mm and `1.5` for 16 pixels/mm (300 dpi == 12\n  pixels/mm). These figures refer to the image raster, not the half-tone\n  resolution. The default is `0.5`.","title":"Options - Image.sharpen/2","ref":"Image.html#sharpen/2-options"},{"type":"function","doc":"* `{:ok, sharpened_image}` or\n\n* `{:error reason}`","title":"Returns - Image.sharpen/2","ref":"Image.html#sharpen/2-returns"},{"type":"function","doc":"For screen output sharpening the default options are recommended.\nAdjust `:sigma` for other output devices as required.","title":"Output sharpening - Image.sharpen/2","ref":"Image.html#sharpen/2-output-sharpening"},{"type":"function","doc":"Sharpens an image or raises an exception.\n\nSelectively sharpens the `L` channel of a LAB image. `image`\nis converted to `:labs` for sharpening and the converted back\nto its original interpretation.\n\nThe operation performs a gaussian blur and subtracts from `image` to generate a\nhigh-frequency signal. This signal is passed through a lookup table formed\nfrom the five parameters and then added back to `image`.\n\nThe lookup table is formed like this:\n\n```\n                    ^\n                 y2 |          -----------\n                    |         /\n                    |        / slope m2\n                    |    .../\n            -x1     | ...   |\n-------------------...---------------------->\n            |   ... |      x1\n            |... slope m1\n            /       |\n           / m2     |\n          /         |\n         /          |\n        /           |\n       /            |\n______/             | -y3\n                    |\n```\n\nWhere:\n\n* `m1` is `:flat_amount`\n* `m2` is `:jagged_amount`\n* `x1` is `:threshold`\n* `y2` is `:max_brightening`\n* `y3` is `:max_darkening`","title":"Image.sharpen!/2","ref":"Image.html#sharpen!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.sharpen!/2","ref":"Image.html#sharpen!/2-arguments"},{"type":"function","doc":"* `:jagged_amount` is the primary means of specifing how much\n  sharpening to apply. Shaprening is applied to the jagged areas\n  of the image. It is a float greater or equal to `0.0`\n  with a default of `3.0`.\n\n* `:flat_amount` is the specifies how much\n  sharpening to apply to flat areas of the image. It is a float\n  greater or equal to `0.0` with a default of `0.0`.\n\n* `:threshold` indicates where the transition from the flat\n  part of the image to the jaggy part of the image is to be\n  considered on the curve. It is a float amount greater than\n  or equal to `0.0` with a default of `2.0`.\n\n* `:max_brightening` specifies how much the image may be\n  brightened as part of the sharpening process. It is a positive\n  integer greater than or equal to `0`. The default is `10`.\n\n* `:max_darkening` specifies how much the image may be\n  darkened as part of the sharpening process. It is a positive\n  integer greater than or equal to `0`. The default is `20`.\n\n* `:sigma` changes the width of the sharpening fringe and can be\n  adjusted according to the output printing resolution. As an approximate\n  guideline, use `0.5` for 4 pixels/mm (display resolution),\n  `1.0` for 12 pixels/mm and `1.5` for 16 pixels/mm (300 dpi == 12\n  pixels/mm). These figures refer to the image raster, not the half-tone\n  resolution. The default is `0.5`.","title":"Options - Image.sharpen!/2","ref":"Image.html#sharpen!/2-options"},{"type":"function","doc":"* `sharpened_image` or\n\n* raises an exception.","title":"Returns - Image.sharpen!/2","ref":"Image.html#sharpen!/2-returns"},{"type":"function","doc":"For screen output sharpening the default options are recommended.\nAdjust `:sigma` for other output devices as required.","title":"Output sharpening - Image.sharpen!/2","ref":"Image.html#sharpen!/2-output-sharpening"},{"type":"function","doc":"Split an image to separate the alpha band\nfrom the other image bands.","title":"Image.split_alpha/1","ref":"Image.html#split_alpha/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.split_alpha/1","ref":"Image.html#split_alpha/1-arguments"},{"type":"function","doc":"* `{image_without_alpha, alpha_band}` or\n\n* `{image, nil}` if there is no\n  alpha band detected.","title":"Returns - Image.split_alpha/1","ref":"Image.html#split_alpha/1-returns"},{"type":"function","doc":"Split the image into a list of its component\nbands.","title":"Image.split_bands/1","ref":"Image.html#split_bands/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.split_bands/1","ref":"Image.html#split_bands/1-arguments"},{"type":"function","doc":"* a list of single band images extracted\n  from `image`.","title":"Returns - Image.split_bands/1","ref":"Image.html#split_bands/1-returns"},{"type":"function","doc":"Apply squircle mask to an image.","title":"Image.squircle/2","ref":"Image.html#squircle/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.squircle/2","ref":"Image.html#squircle/2-arguments"},{"type":"function","doc":"* `:radius` is the desired squircle radius.\n  The default is 20.","title":"Options - Image.squircle/2","ref":"Image.html#squircle/2-options"},{"type":"function","doc":"* `{:ok, squircle_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.squircle/2","ref":"Image.html#squircle/2-returns"},{"type":"function","doc":"Apply a squircle mask to an image. Returns\nan image or raises an exception.","title":"Image.squircle!/2","ref":"Image.html#squircle!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.squircle!/2","ref":"Image.html#squircle!/2-arguments"},{"type":"function","doc":"* `:radius` is the desired squircle radius.\n  The default is 20.","title":"Options - Image.squircle!/2","ref":"Image.html#squircle!/2-options"},{"type":"function","doc":"* `squircle_image` or\n\n* raises an exception.","title":"Returns - Image.squircle!/2","ref":"Image.html#squircle!/2-returns"},{"type":"function","doc":"Performs a warp perspective transformation on an\nimage to straighten its perspective.\n\nRequires `Nx` to be configured as a dependency.","title":"Image.straighten_perspective/3","ref":"Image.html#straighten_perspective/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `source` is a list of four 2-tuples representing the\n  four corners of the subject-of-interest in `image`.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.straighten_perspective/3","ref":"Image.html#straighten_perspective/3-arguments"},{"type":"function","doc":"* `:background` defines the color of any generated background\n  pixels. This can be specified as a single integer which will\n  be applied to all bands, or a list of integers representing\n  the color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of\n  the form `#rrggbb`. The default is `:black`. `:background` can\n  also be set to `:average` in which case the background will be\n  the average color of the base image. See also `Image.Color.color_map/0`\n  and `Image.Color.rgb_color/1`.\n\n* `:extend_mode` determines how any additional pixels\n  are generated. The values are:\n\n  * `:black` (the default) meaning the generated pixels are\n    black.\n  * `:white` meaning the generated pixels are white.\n  * `:copy` means the generated pixels take the value of the\n    nearest edge pixel of the base image.\n  * `:repeat` means the generated pixels are tiles from the\n    base image.\n  * `:mirror` means the generated pixels are a reflected tiles of\n    the base image.\n  * `:background` means the generated pixels are the background\n    color setin `options`.","title":"Options - Image.straighten_perspective/3","ref":"Image.html#straighten_perspective/3-options"},{"type":"function","doc":"* `{:ok, destination, straightened_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.straighten_perspective/3","ref":"Image.html#straighten_perspective/3-returns"},{"type":"function","doc":"* The image is flattened before warping and therefore any\n  alpha band will be multiplied into to the image data and\n  removed.\n\n* The returned `destination` is a four element list of\n  2-tuples representing the four points to which the `source`\n  points were transformed. `destination` can be passed as\n  a parameter to `Image.crop/2` to crop the transformed image\n  to the subject-of-interest that was warped.","title":"Notes - Image.straighten_perspective/3","ref":"Image.html#straighten_perspective/3-notes"},{"type":"function","doc":"Performs a warp perspective transformation on an\nimage to straighten its perspective or raises an\nexception.\n\nRequires `Nx` to be configured as a dependency.","title":"Image.straighten_perspective!/3","ref":"Image.html#straighten_perspective!/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `source` is a list of four 2-tuples representing the\n  four corners of the subject-of-interest in `image`.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.straighten_perspective!/3","ref":"Image.html#straighten_perspective!/3-arguments"},{"type":"function","doc":"* `:background` defines the color of any generated background\n  pixels. This can be specified as a single integer which will\n  be applied to all bands, or a list of integers representing\n  the color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of\n  the form `#rrggbb`. The default is `:black`. `:background` can\n  also be set to `:average` in which case the background will be\n  the average color of the base image. See also `Image.Color.color_map/0`\n  and `Image.Color.rgb_color/1`.\n\n* `:extend_mode` determines how any additional pixels\n  are generated. The values are:\n\n  * `:black` (the default) meaning the generated pixels are\n    black.\n  * `:white` meaning the generated pixels are white.\n  * `:copy` means the generated pixels take the value of the\n    nearest edge pixel of the base image.\n  * `:repeat` means the generated pixels are tiles from the\n    base image.\n  * `:mirror` means the generated pixels are a reflected tiles of\n    the base image.\n  * `:background` means the generated pixels are the background\n    color setin `options`.","title":"Options - Image.straighten_perspective!/3","ref":"Image.html#straighten_perspective!/3-options"},{"type":"function","doc":"* `straightened_image` or\n\n* `{:error, reason}`","title":"Returns - Image.straighten_perspective!/3","ref":"Image.html#straighten_perspective!/3-returns"},{"type":"function","doc":"* The image is flattened before warping and therefore any\n  alpha band will be multiplied into to the image data and\n  removed.\n\n* The returned `destination` is a four element list of\n  2-tuples representing the four points to which the `source`\n  points were transformed. `destination` can be passed as\n  a parameter to `Image.crop/2` to crop the transformed image\n  to the subject-of-interest that was warped.","title":"Notes - Image.straighten_perspective!/3","ref":"Image.html#straighten_perspective!/3-notes"},{"type":"function","doc":"Convert an image into an enumerable\nstream.","title":"Image.stream!/2","ref":"Image.html#stream!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.stream!/2","ref":"Image.html#stream!/2-arguments"},{"type":"function","doc":"* `:buffer_size` is the size in bytes for\n  each chunk in the stream being written.\n  Some services, like AWS S3, require a minimum\n  5 MiB per chunk to be delivered and this option\n  can be used to satisfy that requirement.\n\nFor additional options see `Image.write/3`.","title":"Options - Image.stream!/2","ref":"Image.html#stream!/2-options"},{"type":"function","doc":"* An `t:Enumerable.t/0` suitable for\n  streaming to an external service such as\n  S3, Minio or any other enumerable consumer.\n\n> #### S3 and Buffer Size {: .info}\n> You may get an error from S3 if you do not specify a buffer size.\n>\n> ```text\n> EntityTooSmall: Your proposed upload is smaller than the minimum allowed object size.\n> ```\n>\n> Since AWS S3 requires multipart uploads to be 5MiB per chunk, we specify\n> the `:buffer_size` option to `Image.stream!/2`.","title":"Returns - Image.stream!/2","ref":"Image.html#stream!/2-returns"},{"type":"function","doc":"In this example an image is resized\nand then streamed into AWS S3:\n\n    \"some/image.jpg\"\n    |> Image.thumbnail!(200)\n    |> Image.stream!(suffix: \".jpg\", buffer_size: 5_242_880)\n    |> ExAws.S3.upload(\"images\", \"some_object_name.jpg\")\n    |> ExAws.request()","title":"Example - Image.stream!/2","ref":"Image.html#stream!/2-example"},{"type":"function","doc":"Thumbnail an image to fit or fill a bounding box.","title":"Image.thumbnail/3","ref":"Image.html#thumbnail/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` or a\n  pathname to an image file.\n\n* `length` is the integer length of the longest\n  side of the resulting image after resizing. It can\n  also be of the form \" x \". That\n  is, a string with the width and height separated\n  by an `x`. The ` ` may be omitted in which\n  case it is the same as providing an integer length.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.thumbnail/3","ref":"Image.html#thumbnail/3-arguments"},{"type":"function","doc":"* `:crop` determines if the strategy is \"resize to fit\"\n  (crop is `:none`) or \"resize to fill\" (when the crop\n  option is not `:none`). The value may be one of\n  `:none`, `:center`, `:entropy`, `:attention`, `:low`\n  or `:high`. The default is `:none`. See also `t:Image.Options.Crop.crop_focus/0`.\n\n* `:height` - Size to this height. Default is to maintain\n  the image aspect ratio unless `resize: :force` is set. If\n  `resize; :force` is set then the default `:height` is the\n  height of `image`.\n\n* `:fit` sets the `:crop` and `:resize` options to align\n  with the CSS [object-fit](https://www.w3schools.com/css/css3_object-fit.asp)\n  property. Note that using the `:fit` option overwrites the\n  options `:crop` and `:resize`. Since options are processed in\n  the order in which they are presented, `:crop` and `:resize`\n  may still be force set if they are after the `:fit` option.\n  `:fit` takes one of the following values:\n\n  * `:fill` - the image is resized to fill the given dimension.\n    If necessary, the image will be stretched or squished to fit.\n    This is the same as setting `resize: :force`. Note that is\n    `:height` is not specified it will be the same height as `image`.\n\n  * `:contain` - the image keeps its aspect ratio, but is resized\n    to fit within the given dimension. This is the same as\n    setting `crop: :none` and `resize: :both`.\n\n  * `:cover` - the image keeps its aspect ratio and fills the given\n    dimensions. The image will be clipped to fit. Clipping will default to\n    `:center` unless `:crop` is already set to a value other\n    than `:none`. This is the same as setting `crop: :center`\n    (if `:crop` is not already set) and `resize: :both`.\n\n* `:autorotate` is a boolean indicating if the image should\n  be autorotated based upon the image metadata. The default\n  is `true`.\n\n* `:intent` indicates the rendering intent. The default\n  is `:relative`. See also `t:Image.render_intent/0`.\n\n* `:export_icc_profile` indicates the icc profile to be attached\n  to the resized image. The value may be an inbuilt profile (`:srgb`,\n  `:p3` or `:cmyk`), the name of an icc profile in the systems\n  profile directory or a full path to an icc profile file. The\n  default is to export the icc profile of the resized image if\n  there is one.\n\n* `:import_icc_profile` indicates the icc profile to be attached\n  to the input image. The value may be an inbuilt profile (`:srgb`,\n  `:p3` or `:cmyk`), the name of an icc profile in the systems\n  profile directory or a full path to an icc profile file. The\n  default is to use the icc profile of the input image if\n  there is one.\n\n* `:linear` is a boolean indicating of the image should\n  be resized in linear space. The default `false`. Shrinking is\n  normally done in sRGB colourspace. Set linear to shrink in\n  linear light colourspace instead. This can give better results,\n  but can also be far slower, since tricks like JPEG shrink-on-load\n  cannot be used in linear space.\n\n* `:resize` determines if an image may be only upsized, only\n  downsized, both or a forced aspect ratio is applied. The value\n  may be one of `:up`, `:down`, `:both` or `:force`. The default\n  is `:both`.","title":"Options - Image.thumbnail/3","ref":"Image.html#thumbnail/3-options"},{"type":"function","doc":"* `{:ok, thumbnailed_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.thumbnail/3","ref":"Image.html#thumbnail/3-returns"},{"type":"function","doc":"Thumbnail an image to fit or fill a bounding box\nreturning an image or raising an exception.","title":"Image.thumbnail!/3","ref":"Image.html#thumbnail!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` or a\n  pathname to an image file.\n\n* `length` is the integer length of the longest\n  side of the resulting image after resizing. It c\n  an also be of the form \" x \". That\n  is, a string with the width and height separated\n  by an `x`. The ` ` may be omitted in which\n  case it is the same as providing an integer length.\n\n* `options` is a keyword list of options.\n  See `Image.thumbnail/3`.","title":"Arguments - Image.thumbnail!/3","ref":"Image.html#thumbnail!/3-arguments"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.thumbnail!/3","ref":"Image.html#thumbnail!/3-returns"},{"type":"function","doc":"Converts an image to the given colorspace.\n\nAvailable colorspaces are returned from\n`Image.Interpretation.known_interpretations/0`.","title":"Image.to_colorspace/2","ref":"Image.html#to_colorspace/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `colorspace` is any known colorspace. See\n  `Image.Interpretation.known_interpretations/0`\n  for a list of the known colorspaces.","title":"Arguments - Image.to_colorspace/2","ref":"Image.html#to_colorspace/2-arguments"},{"type":"function","doc":"* `{;ok, image_in_new_colorspace}` or\n\n* `{:error, reason}`","title":"Returns - Image.to_colorspace/2","ref":"Image.html#to_colorspace/2-returns"},{"type":"function","doc":"Image.to_colorspace(image, :bw)","title":"Example - Image.to_colorspace/2","ref":"Image.html#to_colorspace/2-example"},{"type":"function","doc":"Converts an image to the given colorspace returning\nan image or raising an exception.\n\nAvailable colorspaces are returned from\n`Image.Interpretation.known_interpretations/0`.","title":"Image.to_colorspace!/2","ref":"Image.html#to_colorspace!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `colorspace` is any known colorspace. See\n  `Image.Interpretation.known_interpretations/0`\n  for a list of the known colorspaces.","title":"Arguments - Image.to_colorspace!/2","ref":"Image.html#to_colorspace!/2-arguments"},{"type":"function","doc":"* `image_in_new_colorspace` or\n\n* raises an exception","title":"Returns - Image.to_colorspace!/2","ref":"Image.html#to_colorspace!/2-returns"},{"type":"function","doc":"Image.to_colorspace!(image, :bw)","title":"Example - Image.to_colorspace!/2","ref":"Image.html#to_colorspace!/2-example"},{"type":"function","doc":"Converts an `Image` image to an `t:Evision.Mat.t/0` image.\n\nNote that only images with 3 bands can be transferred\nto `eVision`.","title":"Image.to_evision/2","ref":"Image.html#to_evision/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`.\n\n* `convert_to_bgr` is a boolean indicating if the\n  color order should be converted from `RGB` to `BGR`\n  which is the normal channel layout for OpenCV. The\n  default is `true`.","title":"Arguments - Image.to_evision/2","ref":"Image.html#to_evision/2-arguments"},{"type":"function","doc":"* `{:ok, evision_image}`\n\n* `{:error, reason}`","title":"Returns - Image.to_evision/2","ref":"Image.html#to_evision/2-returns"},{"type":"function","doc":"* `Image` images have the shape `{width, height, bands}`\n  whereas `Evision` images have the shape `{height, width, bands}`\n  so this function transposes the dimensions to match.\n\n* `Image` data is arranged as `rgb` data elements whereas\n  `Evision` requires the data to be in `bgr` order. This function\n  also reorders the data appropriately.","title":"Notes - Image.to_evision/2","ref":"Image.html#to_evision/2-notes"},{"type":"function","doc":"Transfers an image to Kino for display\nin a livebook.","title":"Image.to_kino/1","ref":"Image.html#to_kino/1"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`.","title":"Arguments - Image.to_kino/1","ref":"Image.html#to_kino/1-arguments"},{"type":"function","doc":"* a Kino image struct.","title":"Returns - Image.to_kino/1","ref":"Image.html#to_kino/1-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Hong-Kong-2015-07-1998.jpg\")\n    iex> %Kino.Image{} = Image.to_kino(image)\n    iex> match?(%Kino.Image{}, Image.to_kino(image))\n    true","title":"Example - Image.to_kino/1","ref":"Image.html#to_kino/1-example"},{"type":"function","doc":"Converts an image into an [Nx](https://hex.pm/packages/nx)\ntensor.","title":"Image.to_nx/2","ref":"Image.html#to_nx/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `options` is a keyword list of options","title":"Arguments - Image.to_nx/2","ref":"Image.html#to_nx/2-arguments"},{"type":"function","doc":"* `:shape` determines how the tensor is shaped. The valid\n  values are:\n\n  * `:hwb` or `:hwc` which leaves the tensor unchanged with\n    the underlying data in `{height, width, bands}` shape.\n    This is the default action.\n\n  * `:whc` or `:whb` which reshapes the tensor to\n    `width, height, bands`.","title":"Options - Image.to_nx/2","ref":"Image.html#to_nx/2-options"},{"type":"function","doc":"* `{:ok, tensor)` where tensor is an `t:Nx.Tensor.t/0` tensor\n  suitable for use in the `Nx` library or\n\n* `{:error, reason}`.","title":"Returns - Image.to_nx/2","ref":"Image.html#to_nx/2-returns"},{"type":"function","doc":"* The image type, `t:Vix.Vips.Image.t/0` stores data in\n  `{width, height, band}` format. However when the data is conerted\n  into an `t:Nx.Tensor.t/0` the data is written in `{height, width, band}`\n  format.","title":"Note - Image.to_nx/2","ref":"Image.html#to_nx/2-note"},{"type":"function","doc":"iex> {:ok, image} = Vix.Vips.Operation.black(3, 3)\n    iex> Image.to_nx(image, backend: Nx.BinaryBackend)\n    {:ok,\n      Nx.tensor([[[0], [0], [0]], [[0], [0], [0]], [[0], [0], [0]]],\n        type: {:u, 8}, names: [:height, :width, :bands], backend: Nx.BinaryBackend)}","title":"Example - Image.to_nx/2","ref":"Image.html#to_nx/2-example"},{"type":"function","doc":"Converts an image into an [Nx](https://hex.pm/packages/nx)\ntensor.","title":"Image.to_nx!/2","ref":"Image.html#to_nx!/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `options` is a keyword list of options","title":"Arguments - Image.to_nx!/2","ref":"Image.html#to_nx!/2-arguments"},{"type":"function","doc":"* `:shape` determines how the tensor is shaped. The valid\n  values are:\n\n  * `:hwb` or `:hwc` which leaves the tensor unchanged with\n    the underlying data in `{height, width, bands}` shape.\n    This is the default action.\n\n  * `:whc` or `:whb` which reshapes the tensor to\n    `width, height, bands`.","title":"Options - Image.to_nx!/2","ref":"Image.html#to_nx!/2-options"},{"type":"function","doc":"* `tensor` where tensor is an `t:Nx.Tensor.t/0` tensor\n  suitable for use in the `Nx` library or\n\n* raises an exception.","title":"Returns - Image.to_nx!/2","ref":"Image.html#to_nx!/2-returns"},{"type":"function","doc":"* The image type, `t:Vix.Vips.Image.t/0` stores data in\n  `{width, height, band}` format. However when the data is conerted\n  into an `t:Nx.Tensor.t/0` the data is written in `{height, width, band}`\n  format.","title":"Note - Image.to_nx!/2","ref":"Image.html#to_nx!/2-note"},{"type":"function","doc":"iex> {:ok, image} = Vix.Vips.Operation.black(3, 3)\n    iex> Image.to_nx!(image, backend: Nx.BinaryBackend)\n    Nx.tensor([[[0], [0], [0]], [[0], [0], [0]], [[0], [0], [0]]],\n      type: {:u, 8}, names: [:height, :width, :bands], backend: Nx.BinaryBackend)","title":"Example - Image.to_nx!/2","ref":"Image.html#to_nx!/2-example"},{"type":"function","doc":"Convert image to polar coordinates.","title":"Image.to_polar_coordinates/1","ref":"Image.html#to_polar_coordinates/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.to_polar_coordinates/1","ref":"Image.html#to_polar_coordinates/1-arguments"},{"type":"function","doc":"* `{:ok, image_in_polar_coordinates}` or\n\n* `{:error, reason}`","title":"Returns - Image.to_polar_coordinates/1","ref":"Image.html#to_polar_coordinates/1-returns"},{"type":"function","doc":"Convert image to polar coordinates returning\nan image or raising an exception.","title":"Image.to_polar_coordinates!/1","ref":"Image.html#to_polar_coordinates!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.to_polar_coordinates!/1","ref":"Image.html#to_polar_coordinates!/1-arguments"},{"type":"function","doc":"* `image_in_polar_coordinates` or\n\n* raises an exception.","title":"Returns - Image.to_polar_coordinates!/1","ref":"Image.html#to_polar_coordinates!/1-returns"},{"type":"function","doc":"Convert image to rectangular coordinates.","title":"Image.to_rectangular_coordinates/1","ref":"Image.html#to_rectangular_coordinates/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.to_rectangular_coordinates/1","ref":"Image.html#to_rectangular_coordinates/1-arguments"},{"type":"function","doc":"Roundtrip to polar and back to rectangular\ncoordinates displays some image distortion,\nlikely due to rounding errors in float\narithmetic. Further study is required.","title":"Notes - Image.to_rectangular_coordinates/1","ref":"Image.html#to_rectangular_coordinates/1-notes"},{"type":"function","doc":"* `{:ok, image_in_rectangular_coordinates}` or\n\n* `{:error, reason}`","title":"Returns - Image.to_rectangular_coordinates/1","ref":"Image.html#to_rectangular_coordinates/1-returns"},{"type":"function","doc":"Convert image to rectangular coordinates\nreturning an image or raising an exception.","title":"Image.to_rectangular_coordinates!/1","ref":"Image.html#to_rectangular_coordinates!/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.to_rectangular_coordinates!/1","ref":"Image.html#to_rectangular_coordinates!/1-arguments"},{"type":"function","doc":"Roundtrip to polar and back to rectangular\ncoordinates displays some image distortion,\nlikely due to rounding errors in float\narithmetic. Further study is required.","title":"Notes - Image.to_rectangular_coordinates!/1","ref":"Image.html#to_rectangular_coordinates!/1-notes"},{"type":"function","doc":"* `image_in_rectangular_coordinates` or\n\n* raises an exception.","title":"Returns - Image.to_rectangular_coordinates!/1","ref":"Image.html#to_rectangular_coordinates!/1-returns"},{"type":"function","doc":"Returns a transformation matrix for a given\nimage, source quadrilateral and desintation quadrilateral.\n\nA transformation matrix when applied to an image\n(using, for example, `Image.map/2`) maps pixels from\nthe source persecptive to the destination perspective.\n\nRequires `Nx` to be configured as a dependency.","title":"Image.transform_matrix/3","ref":"Image.html#transform_matrix/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `source` is a list of four 2-tuples representing the\n  four corners of the subject-of-interest in `image`.\n\n* `destination` is a list of four 2-tuples representing the\n  four corners of the destination image into which the\n  subject-of-interest is transformed.","title":"Arguments - Image.transform_matrix/3","ref":"Image.html#transform_matrix/3-arguments"},{"type":"function","doc":"* `{:ok, transform_matrix}` or\n\n* `{:error, reason}`.","title":"Returns - Image.transform_matrix/3","ref":"Image.html#transform_matrix/3-returns"},{"type":"function","doc":"Trims an image to the bounding box of the non-background\narea.\n\nThe image is median-filtered, all the row and column sums\nof the absolute difference from background are calculated\nin a single pass.\n\nThen the first row or column in each of the four directions\nwhere the sum is greater than threshold gives the bounding\nbox that is used to define the crop area.","title":"Image.trim/2","ref":"Image.html#trim/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.trim/2","ref":"Image.html#trim/2-arguments"},{"type":"function","doc":"* `:background` is the color to be considered\n  the background color. The default is automatically\n  detected by averaging the pixels at the top\n  left of the image. If background is set to\n  `:alpha` then the image is trimmed to the size\n  of the alpha mask.\n\n* `:threshold` is the integer threshold (or color\n  similarity) that is applied when determining the\n  bounds of the non-background area. The default is\n  `10`. The default value means only a small color\n  background color range is considered.  Increasing\n  the threshold value maybe required.","title":"Options - Image.trim/2","ref":"Image.html#trim/2-options"},{"type":"function","doc":"* `{:ok, cropped_image}` which is the image\n  cropped to the bounding box of the non-background\n  area.\n\n* `{:error, reason}`.  Reason may be\n  `:uncropped` which means the image was\n  considered to be only the background color.","title":"Returns - Image.trim/2","ref":"Image.html#trim/2-returns"},{"type":"function","doc":"Trims an image to the bounding box of the non-background\narea or raises an exception.\n\nThe image is median-filtered, all the row and column sums\nof the absolute difference from background are calculated\nin a single pass.\n\nThen the first row or column in each of the four directions\nwhere the sum is greater than threshold gives the bounding\nbox that is used to define the crop area.","title":"Image.trim!/2","ref":"Image.html#trim!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.trim!/2","ref":"Image.html#trim!/2-arguments"},{"type":"function","doc":"* `:background` is the color to be considered\n  the background color. The default is automatically\n  detected by averaging the pixels at the top\n  left of the image. If background is set to\n  `:alpha` then the image is trimmed to the size\n  of the alpha mask.\n\n* `:threshold` is the integer threshold (or color\n  similarity) that is applied when determining the\n  bounds of the non-background area. The default is\n  `10`. The default value means only a small color\n  background color range is considered.  Increasing\n  the threshold value maybe required.","title":"Options - Image.trim!/2","ref":"Image.html#trim!/2-options"},{"type":"function","doc":"* `cropped_image` which is the image\n  cropped to the bounding box of the non-background\n  area or\n\n* raises an exception.","title":"Returns - Image.trim!/2","ref":"Image.html#trim!/2-returns"},{"type":"function","doc":"Returns the version of `libvips` in\noperation.","title":"Image.vips_version/0","ref":"Image.html#vips_version/0"},{"type":"function","doc":"Performs a warp perspective transformation on an\nimage.\n\nRequires `Nx` to be configured as a dependency.","title":"Image.warp_perspective/4","ref":"Image.html#warp_perspective/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `source` is a list of four 2-tuples representing the\n  four corners of the subject-of-interest in `image`.\n\n* `destination` is a list of four 2-tuples representing the\n  four corners of the destination image into which the\n  subject-of-interest is transformed.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.warp_perspective/4","ref":"Image.html#warp_perspective/4-arguments"},{"type":"function","doc":"* `:background` defines the color of any generated background\n  pixels. This can be specified as a single integer which will\n  be applied to all bands, or a list of integers representing\n  the color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of\n  the form `#rrggbb`. The default is `:black`. `:background` can\n  also be set to `:average` in which case the background will be\n  the average color of the base image. See also `Image.Color.color_map/0`\n  and `Image.Color.rgb_color/1`.\n\n* `:extend_mode` determines how any additional pixels\n  are generated. The values are:\n\n  * `:black` (the default) meaning the generated pixels are\n    black.\n  * `:white` meaning the generated pixels are white.\n  * `:copy` means the generated pixels take the value of the\n    nearest edge pixel of the base image.\n  * `:repeat` means the generated pixels are tiles from the\n    base image.\n  * `:mirror` means the generated pixels are a reflected tiles of\n    the base image.\n  * `:background` means the generated pixels are the background\n    color setin `options`.","title":"Options - Image.warp_perspective/4","ref":"Image.html#warp_perspective/4-options"},{"type":"function","doc":"* The image is flattened before warping and therefore any\n  alpha band will be multiplied into to the image data and\n  removed.","title":"Notes - Image.warp_perspective/4","ref":"Image.html#warp_perspective/4-notes"},{"type":"function","doc":"* `{:ok, warped_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.warp_perspective/4","ref":"Image.html#warp_perspective/4-returns"},{"type":"function","doc":"Performs a warp perspective transformation on an\nimage or raises an exception.\n\nRequires `Nx` to be configured as a dependency.","title":"Image.warp_perspective!/4","ref":"Image.html#warp_perspective!/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `source` is a list of four 2-tuples representing the\n  four corners of the subject-of-interest in `image`.\n\n* `destination` is a list of four 2-tuples representing the\n  four corners of the destination image into which the\n  subject-of-interest is transformed.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.warp_perspective!/4","ref":"Image.html#warp_perspective!/4-arguments"},{"type":"function","doc":"* `:background` defines the color of any generated background\n  pixels. This can be specified as a single integer which will\n  be applied to all bands, or a list of integers representing\n  the color for each band. The color can also be supplied as a\n  CSS color name as a string or atom. For example: `:misty_rose`.\n  It can also be supplied as a hex string of\n  the form `#rrggbb`. The default is `:black`. `:background` can\n  also be set to `:average` in which case the background will be\n  the average color of the base image. See also `Image.Color.color_map/0`\n  and `Image.Color.rgb_color/1`.\n\n* `:extend_mode` determines how any additional pixels\n  are generated. The values are:\n\n  * `:black` (the default) meaning the generated pixels are\n    black.\n  * `:white` meaning the generated pixels are white.\n  * `:copy` means the generated pixels take the value of the\n    nearest edge pixel of the base image.\n  * `:repeat` means the generated pixels are tiles from the\n    base image.\n  * `:mirror` means the generated pixels are a reflected tiles of\n    the base image.\n  * `:background` means the generated pixels are the background\n    color setin `options`.","title":"Options - Image.warp_perspective!/4","ref":"Image.html#warp_perspective!/4-options"},{"type":"function","doc":"* `warped_image` or\n\n* raises an exception.","title":"Returns - Image.warp_perspective!/4","ref":"Image.html#warp_perspective!/4-returns"},{"type":"function","doc":"* The image is flattened before warping and therefore any\n  alpha band will be multiplied into to the image data and\n  removed.","title":"Notes - Image.warp_perspective!/4","ref":"Image.html#warp_perspective!/4-notes"},{"type":"function","doc":"Returns the width of an image.","title":"Image.width/1","ref":"Image.html#width/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.","title":"Arguments - Image.width/1","ref":"Image.html#width/1-arguments"},{"type":"function","doc":"* The image width as an integer.","title":"Returns - Image.width/1","ref":"Image.html#width/1-returns"},{"type":"function","doc":"Execute a function over the image casting it\nfirst to a different band format and ensuring the band\nformat reverted when the function returns.","title":"Image.with_band_format/3","ref":"Image.html#with_band_format/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `band_format` is any valid band format.\n  See `Image.BandFormat.known_band_formats/0`.\n\n* `fun` is any 1-arity function that is\n  required to return `{:ok, image}` or\n  `{:error, reason}`.","title":"Arguments - Image.with_band_format/3","ref":"Image.html#with_band_format/3-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.with_band_format/3","ref":"Image.html#with_band_format/3-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Singapore-2016-09-5887.jpg\")\n    iex> {:ok, updated_image} = Image.with_band_format(image, {:s, 16}, fn i -> {:ok, i} end)\n    iex> Image.band_format(updated_image)\n    {:u, 8}","title":"Example - Image.with_band_format/3","ref":"Image.html#with_band_format/3-example"},{"type":"function","doc":"Execute a function over the image casting it\nfirst to a color space and ensuring the color\nspace conversion is reverted when the function\nreturns.","title":"Image.with_colorspace/3","ref":"Image.html#with_colorspace/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `colorspace` is any valid color space.\n  See `Image.Interpretation.known_interpretations/0`.\n\n* `fun` is any 1-arity function that is\n  required to return `{:ok, image}` or\n  `{:error, reason}`.","title":"Arguments - Image.with_colorspace/3","ref":"Image.html#with_colorspace/3-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.with_colorspace/3","ref":"Image.html#with_colorspace/3-returns"},{"type":"function","doc":"Execute a function over the image without\nits alpha band (if any) ensuring the alpha\nband is replaced when the function returns.","title":"Image.without_alpha_band/2","ref":"Image.html#without_alpha_band/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `fun` is any 1-arity function that is\n  required to return `{:ok, image}` or\n  `{:error, reason}`.","title":"Arguments - Image.without_alpha_band/2","ref":"Image.html#without_alpha_band/2-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.without_alpha_band/2","ref":"Image.html#without_alpha_band/2-returns"},{"type":"function","doc":"Write an image to a file, a stream, an enumerable or\nto memory.","title":"Image.write/3","ref":"Image.html#write/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `image_path` is the file system path to an image\n  file. It may also be a stream created with\n  `File.stream!/3` or with `Stream.resource/3`, a\n  `t:Plug.Conn.t/0` if `Plug` is configured or lastly,\n  it can also be `:memory` in which case the image is\n  written to a binary.\n\n* `options` is a keyword list of options. The default is\n  `[]`.","title":"Arguments - Image.write/3","ref":"Image.html#write/3-arguments"},{"type":"function","doc":"The available options depends on the type of image\nfile being opened.\n\n#### All image types\n\n* `:strip_metadata` is a boolean indicating if all metadata\n  is to be stripped from the image. The default is `false`.\n\n* `:background` is the background value to be used\n  for any transparent areas of the image. Jpeg does\n  not support alpha bands so a color value must be\n  assigned.\n\n* `:quality` which influences image compression and\n  is a integer in the range `1..100`. The default for\n  most image formats is `75`. For HEIF files the default\n  is `50`.For PNG files the `:quality` option is ignored.","title":"Options - Image.write/3","ref":"Image.html#write/3-options"},{"type":"function","doc":"* `:suffix` must be specified so that the image is written\n  in the correct format. For example: `suffix: \".jpg\"`.\n\n#### JPEG images\n\n* `:progressive` is a boolean indicating if the image\n  should be interleaved rather than baseline. Progressive\n  has the advantage of perceived time for the initial\n  image load and the cost of multiple decoding passes on\n  the client. For many applications `:progressive` is\n  to be preferred but validation of this assumption for\n  specific use cases is required.\n\n* `:minimize_file_size` is a boolean indicating whether\n  to apply a number of techniques to minimise the file\n  size of the jpeg file at the cost of additional time to\n  save the image. All metadata will also be removed.\n\n* `:icc_profile` indicates the icc profile to be attached\n  to the output image. The value may be an inbuilt profile\n  (`:none`, `:srgb`, `:cmyk`, `:p3`), the name of an icc\n  profile in the systems profile directory or a full path\n  to an icc profile file. The default is to use the icc\n  profile of the input image if there is one.\n\n#### PNG images\n\n* `:progressive` which has the same meaning and values\n    as for JPEG images.\n\n* `:minimize_file_size` is a boolean indicating whether\n  to apply a number of techniques to minimise the file\n  size of the `png` file at the cost of additional time to\n  save the image. All metadata will also be removed.\n\n* `:compression`  is the compression factor which is an\n  integer in the range `1..9`. The default is `6`.\n\n* `:effort` is an integer to adjust the level of CPU\n  effort to reduce the file size. The value must be in the\n  range `1..10`, the default is `7`.\n\n* `:icc_profile` indicates the icc profile to be attached\n  to the output image. The value may be an inbuilt profile\n  (`:none`, `:srgb`, `:cmyk`, `:p3`), the name of an icc\n  profile in the systems profile directory or a full path\n  to an icc profile file. The default is to use the icc\n  profile of the input image if there is one.\n\n#### WEBP images\n\n* `:minimize_file_size` is a boolean which is most useful\n  on animated `WebP`. It enables mixed encoding and optimise\n  the file for minimum size at the cost of additional time\n  to save the image. All metadata will also be removed.\n  Using this parameter on a non-animated `webp` file will\n  only remove the metadata as `:strip_metadata` would do.\n\n* `:effort` is an integer to adjust the level of CPU\n  effort to reduce the file size.\n  The value must be in the range `1..10`, the default\n  is `7`.\n\n* `:icc_profile` indicates the icc profile to be attached\n  to the output image. The value may be an inbuilt profile\n  (`:none`, `:srgb`, `:cmyk`, `:p3`), the name of an icc\n  profile in the systems profile directory or a full path\n  to an icc profile file. The default is to use the icc\n  profile of the input image if there is one.\n\n#### GIF options\n\n* `:interframe_maxerror` Maximum inter-frame error for transparency.\n  The value must be in the range `0..32`.\n  The default is `0`.\n  By increasing this value, the encoder will try to take advantage\n  from temporal redundancy between neighboring frames by enabling\n  higher compression rates.\n\n* `:effort` is an integer to adjust the level of CPU\n  effort to reduce the file size.\n  The value must be in the range `1..10`, the default\n  is `7`.\n\n#### HEIF images\n\n* `:compression` is the compression strategy to\n  be applied. The allowable values are `:hevc`,\n  `:avc`, `:jpeg` and `:av1`. The default is `:hevc`.\n\n* `:effort` is an integer to adjust the level of CPU\n  effort to reduce the file size.\n  The value can be in the range `1..10`, the default is\n  `5`.\n\n* `:minimize_file_size` is a boolean indicating whether\n  to apply a number of techniques to minimise the file\n  size of the `heif` file at the cost of additional time to\n  save the image. All metadata will also be removed.","title":"Streaming images and :memory images - Image.write/3","ref":"Image.html#write/3-streaming-images-and-memory-images"},{"type":"function","doc":"Options can also be grouped under an option key\nfor each known image type. For example:\n\n    Image.write(image, image_path, minimize_file_size: true,\n      png: [compress: 60, lossy: true],\n      jpg: [quality: 70],\n      webp: [quality: 5])\n\nWhen validating options, the options applicable to the\nimage type of `image_path` are merged into the rest of\nthe supplied options.\n\nThe valid image type option keys are `:jpg`, `.png`,\n`:gif`, `:tif`, `:webp` and `:heif`.\n\nThis makes it easier to define a general purpose image\nprocessing pipeline that can still apply specific\noptions when writing the image file.","title":"Merging image type options - Image.write/3","ref":"Image.html#write/3-merging-image-type-options"},{"type":"function","doc":"* `{:ok, image}` (or `{:ok, binary}` if the destination is\n  `:memory`) or\n\n* `{:error, reason}`","title":"Returns - Image.write/3","ref":"Image.html#write/3-returns"},{"type":"function","doc":"Write an image to a file, a stream, an enumerable or\nto memory returning the image or raising an exception.","title":"Image.write!/3","ref":"Image.html#write!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `image_path` is the file system path to an image\n  file. It may also be a stream created with\n  `File.stream!/3` or with `Stream.resource/3`. Lastly,\n  it can also be `:memory` in which case the image is\n  written to a memory buffer.\n\n* `options` is a keyword list of options.\n  See `Image.write/2`.","title":"Arguments - Image.write!/3","ref":"Image.html#write!/3-arguments"},{"type":"function","doc":"* `image` (or a binary if the destination is `:memory`) or\n\n* raises an exception.","title":"Returns - Image.write!/3","ref":"Image.html#write!/3-returns"},{"type":"function","doc":"Returns the XMP data for an image as a\nkeyword list.\n\nOnly a selected set of XMP data is returned.","title":"Image.xmp/1","ref":"Image.html#xmp/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`","title":"Arguments - Image.xmp/1","ref":"Image.html#xmp/1-arguments"},{"type":"function","doc":"* `{:ok, xmp_map}` where `xmp_map` is a map\n  of selected XMP data.","title":"Returns - Image.xmp/1","ref":"Image.html#xmp/1-returns"},{"type":"type","doc":"Image orientation.","title":"Image.aspect/0","ref":"Image.html#t:aspect/0"},{"type":"type","doc":"A composition can be a simple image, or an image with\nassociated composition options.","title":"Image.composition/0","ref":"Image.html#t:composition/0"},{"type":"type","doc":"A list of images or images with placement options used in\nImage.compose/2.","title":"Image.composition_list/0","ref":"Image.html#t:composition_list/0"},{"type":"type","doc":"Error messages returned by `libvips`\n\nTypically a string.","title":"Image.error_message/0","ref":"Image.html#t:error_message/0"},{"type":"type","doc":"The data type of the image, using the same\ntype definitions as `t:Nx.Type.t/0`.","title":"Image.format/0","ref":"Image.html#t:format/0"},{"type":"type","doc":"The valid sources of image data when opening an\nimage.","title":"Image.image_data/0","ref":"Image.html#t:image_data/0"},{"type":"type","doc":"A 512 bit binary hash of an image.\n\nUseful for comparing the similarity of\ntwo images. See `Image.dhash/1` and\n`Image.hamming_distance/2`.","title":"Image.image_hash/0","ref":"Image.html#t:image_hash/0"},{"type":"type","doc":"Represents either in image, or a color\nthat is used to fill a new image","title":"Image.image_or_color/0","ref":"Image.html#t:image_or_color/0"},{"type":"type","doc":"THe structure of an image returned from `Kino.Input.read/1`\nwhen the input field is a `Kino.Input.image/1` type.","title":"Image.kino_image/0","ref":"Image.html#t:kino_image/0"},{"type":"type","doc":"A pixel is represented as a list of number values or\na single number (which is then assumed to be the value\nfor all bands).\n\nThe number of list elements is determined by\nthe colorspace interpretations. For example:\n\n* `RGB` colorspace would be represented by\n  a list of three floats like `[0.0, 0,0, 0.0]` for black.\n\n* `CMYK` colorspace would be represented by a\n  list of four floats.\n\n* A `PNG` image can be in any appropriate\n  colorspace but may also have an `alpha` band\n  and therefore have three, four or five floats\n  in a list to represent the pixel.","title":"Image.pixel/0","ref":"Image.html#t:pixel/0"},{"type":"type","doc":"An image bounding box being a four element list\nof 2-tuples representing the points of a rectangle\nin the order top left -> top right -> bottom right ->\nbottom left.","title":"Image.quadrilateral/0","ref":"Image.html#t:quadrilateral/0"},{"type":"type","doc":"The valid rendering intent values. For all\nfunctions that take an optional intent\nparameter the default is `:perceptual`.","title":"Image.render_intent/0","ref":"Image.html#t:render_intent/0"},{"type":"type","doc":"Perceptual rendering is used to process photographic\ntype images. This intent processes the colors so that\nthe output reproduction is pleasing. This process\ntends to change the color from the original, so no\nguarantee the reproduction will be accurate against\nthe original.","title":"Perceptual Intent - Image.render_intent/0","ref":"Image.html#t:render_intent/0-perceptual-intent"},{"type":"type","doc":"Relative colorimetric changes all the colours out\nof gamut to the nearest colour in gamut, so many\ncolours change to the same one. It DOES NOT change\ncolours in gamut. Perceptual changes ALL the colours\nin the image in a proportional way so that they lie\nin the output device gamut.","title":"Relative Intent - Image.render_intent/0","ref":"Image.html#t:render_intent/0-relative-intent"},{"type":"type","doc":"Saturation moves in-gamut colors toward the edge of the\ndestination gamut for maximum saturation and impact.\nThis intent will make an image more colorful by using\nthe full gamut of the destination device. This intent\ncares not for the genuine representation of color.","title":"Saturation Intent - Image.render_intent/0","ref":"Image.html#t:render_intent/0-saturation-intent"},{"type":"type","doc":"Absolute rendering attempts to reproduce all\ncolors numerically (destination = source). This\ncan cause unexpected results if the source gamut is\nlarger than the destination.","title":"Absolute Intent - Image.render_intent/0","ref":"Image.html#t:render_intent/0-absolute-intent"},{"type":"type","doc":"The level of transparency for an alpha band\nwhere `0` means fully opaque and `255` means\nfully transparent.","title":"Image.transparency/0","ref":"Image.html#t:transparency/0"},{"type":"type","doc":"The x location on an image which is either a\nnon_negative 0-based integer relative to the image left or\na negative -1-based integer relative to the image right or\nthe symbolic references `:left`, `:center` and\n`:right`.","title":"Image.x_location/0","ref":"Image.html#t:x_location/0"},{"type":"type","doc":"The y location on an image which is either a\nnon_negative 0-based integer relative to the image top or\na negative -1-based integer relative to the image right or\nthe symbolic references `:top`, `:middle` and\n`:bottom`.","title":"Image.y_location/0","ref":"Image.html#t:y_location/0"},{"type":"module","doc":"BlurHash is an algorithm developed by [Wolt](https://github.com/woltapp)\nthat allows encoding of an image into a compact string representation\ncalled a blurhash. This string can then be decoded back into\nan image, providing a low-resolution placeholder that can be\ndisplayed quickly while the actual image is being loaded.\n\nIt combines the benefits of data compression and perceptual\nhashing to create visually pleasing representations of images.\n\nThe blurhash string consists of a short sequence of characters\nthat represents the image's colors and their distribution. By\n adjusting the length of the blurhash, you can control the level\nof detail and the amount of data required to represent the image.\n\nThe encode and decoder in this implementation are a fork of\nthe [rinpatch_blurhash](https://github.com/rinpatch/blurhash) library\nby @rinpatch.","title":"Image.Blurhash","ref":"Image.Blurhash.html"},{"type":"function","doc":"Decodes an blurhash to an image.","title":"Image.Blurhash.decode/3","ref":"Image.Blurhash.html#decode/3"},{"type":"function","doc":"* `blurhash` is a blurhash returned by `Image.Blurhash.encode/2`.\n\n* `width` is the required width of the returned image.\n\n* `height` is the required height of the returned image.","title":"Arguments - Image.Blurhash.decode/3","ref":"Image.Blurhash.html#decode/3-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Blurhash.decode/3","ref":"Image.Blurhash.html#decode/3-returns"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Kip_small.jpg\")\n    iex> {:ok, blurhash} = Image.Blurhash.encode(image)\n    iex> {:ok, _image} = Image.Blurhash.decode(blurhash, 400, 200)\n\n    iex> Image.Blurhash.decode(\"nonsense\", 400, 200)\n    {:error, \"Invalid blurhash\"}","title":"Examples - Image.Blurhash.decode/3","ref":"Image.Blurhash.html#decode/3-examples"},{"type":"function","doc":"Encodes an image as a [blurhash](https://blurha.sh).\n\n`Image.Blurhash.encode/2` takes an image and returns a short string\n(only 20-30 characters) that represents the placeholder\nfor this image.\n\nIt is intended that calculating a blurhash is performed\nin a background process and stored for retrieval on demand\nwhen rendering a page.","title":"Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options. The default is\n  `[x_components: 4, y_components: 3]`.","title":"Arguments - Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2-arguments"},{"type":"function","doc":"* `:x_components` represents the number of horizontal blocks used\n  to calculate the blurhash.\n\n* `:y_components` represents the number of vertical blocks used\n  to calculate the blurhash.","title":"Options - Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2-options"},{"type":"function","doc":"* `{:ok, blurhash}` or\n\n* `{:error, reason}`","title":"Returns - Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2-returns"},{"type":"function","doc":"A higher `:x_components` and `:y_components` value will result in\nmore details in the blurhash in the X and Y direction respectively.\nA lower value will create a more abstract representation.\n\nBy adjusting the X and Y components, you can control the level of\ngranularity and complexity in the generated blurhash. However, it's\nimportant to note that increasing the X and Y values also increases\nthe size of the blurhash string, which may impact performance and\nbandwidth usage.\n\nThe default of `[x_components: 4, y_components: 3]` is a good starting\npoints but if the the image aspect ratio is portrait, a higher\n`:y_compnents` value may be appropriate.","title":"Selecting the number of X and Y components - Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2-selecting-the-number-of-x-and-y-components"},{"type":"function","doc":"iex> image = Image.open!(\"./test/support/images/Kip_small.jpg\")\n    iex> Image.Blurhash.encode(image)\n    {:ok, \"LBA,zk9F00~qofWBt7t700%M?bD%\"}","title":"Example - Image.Blurhash.encode/2","ref":"Image.Blurhash.html#encode/2-example"},{"type":"module","doc":"Implements image classification functions using [Axon](https://hex.pm/packages/axon)\nmachine learning models managed by [Bumblebee](https://hex.pm/packages/bumblebee).\n\nImage classification refers to the task of extracting information from an image.\nIn this module, the information extracted is one or more labels desribing the\nimage. Typically something like \"sports car\" or \"Blenheim spaniel\". The labels\nreturns depend on the machine learning model used.","title":"Image.Classification","ref":"Image.Classification.html"},{"type":"module","doc":"The machine learning model to be used is configurable.\nThe `:model` and `:featurizer` may be any model supported by Bumblebee. Any\nadditional options can be supplied as keyword lists under the `:model_options`\nand `:featureizer_options` keys. The `:name` is the name given to the classification\nservice process.\n\nThe default configuration is:\n\n    # runtime.exs\n    config :image, :classifier,\n      model: {:hf, \"microsoft/resnet-50\"},\n      featurizer:  {:hf, \"microsoft/resnet-50\"},\n      model_options: [],\n      featurizer_options: [],\n      batch_size: 10,\n      name: Image.Classification.Server,\n      autostart: true","title":"Configuration - Image.Classification","ref":"Image.Classification.html#module-configuration"},{"type":"module","doc":"If `autostart: true` is configured (the default) then a process\nis started under a supervisor to execute the classification\nrequests.  If running the process under an application\nsupervision tree is desired, set `autostart: false`. In that\ncase the function `classifer/1` can be\nused to return a `t:Supervisor.child_spec/0`.","title":"Autostart - Image.Classification","ref":"Image.Classification.html#module-autostart"},{"type":"module","doc":"To add image classification to an application supervision tree,\nuse `Image.Classification.classifier/1` to return a child spec:\nFor example:\n\n    # Application.ex\n    def start(_type, _args) do\n      children = [\n        # default classifier configuration\n        Image.Classification.classifier()\n\n        # custom classifier configuration\n        Image.Classification.classifier(model: {:hf, \"google/vit-base-patch16-224\"},\n          featurizer: {:hf, \"google/vit-base-patch16-224\"})\n      ]\n\n      Supervisor.start_link(\n        children,\n        strategy: :one_for_one\n      )\n    end","title":"Adding a classification server to an application supervision tree - Image.Classification","ref":"Image.Classification.html#module-adding-a-classification-server-to-an-application-supervision-tree"},{"type":"module","doc":"This module is provided as a convenience to make it easy\nand idiomatic to perform simple classification tasks\nwhile still managing CPU capacity.\n\nFor more complex classification requirements it is recommended\nto use [Bumblebee](https://hex.pm/packages/bumblebee) directly.","title":"Limitations - Image.Classification","ref":"Image.Classification.html#module-limitations"},{"type":"module","doc":"This module is only available if the optional dependency\n[Bumblebee](https://hex.pm/packages/bumblebee) is configured in\n`mix.exs`.","title":"Note - Image.Classification","ref":"Image.Classification.html#module-note"},{"type":"function","doc":"Returns a child spec suitable for starting an image classification\nprocess as part of a supervision tree.","title":"Image.Classification.classifier/1","ref":"Image.Classification.html#classifier/1"},{"type":"function","doc":"* `configuration` is a keyword list of options which\n  are merged over the default configuration.","title":"Arguments - Image.Classification.classifier/1","ref":"Image.Classification.html#classifier/1-arguments"},{"type":"function","doc":"* `:model` is any supported machine learning model for image\n  classification supported by Bumblebee.\n\n* `:featurizer` is any supported machine learning model for image\n  featurization supported by Bumblebee.\n\n* `:model_options` is a keyword list of options that\n  are passed to `Bumblebee.load_model/2`.\n\n* `:featurizer_options` is a keyword list of options that\n  are passed to `Bumblebee.load_featurizer/2`.\n\n* `:name` is the name given to the classification process when\n  it is started.\n\n* `:batch_size` is the batch size passed to\n  `Bumblebee.Vision.image_classification/3`,","title":"Configuration keys - Image.Classification.classifier/1","ref":"Image.Classification.html#classifier/1-configuration-keys"},{"type":"function","doc":"The default configuration is:\n\n```elixir\nconfig :image, :classifier,\n  model: {:hf, \"microsoft/resnet-50\"},\n  featurizer:  {:hf, \"microsoft/resnet-50\"},\n  model_options: [],\n  featurizer_options: [],\n  batch_size: 10,\n  name: Image.Classification.Server,\n  autostart: true\n```","title":"Default configuration - Image.Classification.classifier/1","ref":"Image.Classification.html#classifier/1-default-configuration"},{"type":"function","doc":"Classify an image using a machine learning\nmodel.","title":"Image.Classification.classify/2","ref":"Image.Classification.html#classify/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options","title":"Arguments - Image.Classification.classify/2","ref":"Image.Classification.html#classify/2-arguments"},{"type":"function","doc":"* `:backend` is any valid `Nx` backend. The default is\n  `Nx.default_backend/0`.\n\n* `:server` is the name of the process performing the\n  classification service. The default is `Image.Classification.Server`.","title":"Options - Image.Classification.classify/2","ref":"Image.Classification.html#classify/2-options"},{"type":"function","doc":"* A map containing the predictions of the image\n  classification.","title":"Returns - Image.Classification.classify/2","ref":"Image.Classification.html#classify/2-returns"},{"type":"function","doc":"iex> puppy = Image.open!(\"./test/support/images/puppy.webp\")\n    iex> %{predictions: [%{label: \"Blenheim spaniel\", score: _} | _rest]} =\n    ...>   Image.Classification.classify(puppy)","title":"Example - Image.Classification.classify/2","ref":"Image.Classification.html#classify/2-example"},{"type":"function","doc":"Classify an image using a machine learning\nmodel and return the labels that meet a minimum\nscore.","title":"Image.Classification.labels/2","ref":"Image.Classification.html#labels/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Classification.labels/2","ref":"Image.Classification.html#labels/2-arguments"},{"type":"function","doc":"* `:backend` is any valid `Nx` backend. The default is\n  `Nx.default_backend/0`.\n\n* `:min_score` is the minimum score, a float between `0.0`\n  and `1.0`, which a label must match in order to be\n  returned.","title":"Options - Image.Classification.labels/2","ref":"Image.Classification.html#labels/2-options"},{"type":"function","doc":"* A list of labels. The list may be empty if there\n  are no predictions that exceed the `:min_score`.\n\n* `{:error, reason}`","title":"Returns - Image.Classification.labels/2","ref":"Image.Classification.html#labels/2-returns"},{"type":"function","doc":"iex> {:ok, image} = Image.open (\"./test/support/images/lamborghini-forsennato-concept.jpg\")\n    iex> Image.Classification.labels(image)\n    [\"sports car\", \"sport car\"]","title":"Example - Image.Classification.labels/2","ref":"Image.Classification.html#labels/2-example"},{"type":"module","doc":"Functions to manage image color and color conversion.","title":"Image.Color","ref":"Image.Color.html"},{"type":"function","doc":"Returns a mapping from CSS color names to CSS hex values\nand RGB triplets as a list.","title":"Image.Color.color_map/0","ref":"Image.Color.html#color_map/0"},{"type":"function","doc":"Converts a color from one color space to another.","title":"Image.Color.convert/4","ref":"Image.Color.html#convert/4"},{"type":"function","doc":"* `color` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. Lastly, the\n  color can be supplied as a hex string like `\"#ffe4e1\"`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `from` is the colorspace from which `color` is converted.\n\n* `to` is the colorspace into which the `color` is converted.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Color.convert/4","ref":"Image.Color.html#convert/4-arguments"},{"type":"function","doc":"There are currently no defined options.","title":"Options - Image.Color.convert/4","ref":"Image.Color.html#convert/4-options"},{"type":"function","doc":"* `{:ok, color}` or\n\n* `{:error, reason}`","title":"Returns - Image.Color.convert/4","ref":"Image.Color.html#convert/4-returns"},{"type":"function","doc":"iex> Image.Color.convert(:misty_rose, :srgb, :hsv)\n    {:ok, [4, 30, 255]}\n\n    iex> Image.Color.convert([255, 255, 255], :srgb, :lab)\n    {:ok, [100.0, 0.005245208740234375, -0.010609626770019531]}","title":"Example - Image.Color.convert/4","ref":"Image.Color.html#convert/4-example"},{"type":"function","doc":"Converts an color from one color space to another or\nraises an exception.","title":"Image.Color.convert!/4","ref":"Image.Color.html#convert!/4"},{"type":"function","doc":"* `color` which can be specified as a single integer\n  which or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `from` is the colorspace from which `color` is converted.\n\n* `to` is the colorspace into which the `color` is converted.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Color.convert!/4","ref":"Image.Color.html#convert!/4-arguments"},{"type":"function","doc":"There are currently no defined options.","title":"Options - Image.Color.convert!/4","ref":"Image.Color.html#convert!/4-options"},{"type":"function","doc":"* `converted_color` or\n\n* raises an exception.","title":"Returns - Image.Color.convert!/4","ref":"Image.Color.html#convert!/4-returns"},{"type":"function","doc":"iex> Image.Color.convert!(:misty_rose, :srgb, :hsv)\n    [4, 30, 255]\n\n    iex> Image.Color.convert!([255, 255, 255], :srgb, :lab)\n    [100.0, 0.005245208740234375, -0.010609626770019531]","title":"Example - Image.Color.convert!/4","ref":"Image.Color.html#convert!/4-example"},{"type":"function","doc":"Returns a mapping from CSS color names to CSS hex values\nand RGB triplets as a list - but only for greyscal colors.","title":"Image.Color.greyscale_color_map/0","ref":"Image.Color.html#greyscale_color_map/0"},{"type":"function","doc":"Converts a hex color string to an RGB\nlist.","title":"Image.Color.hex_to_rgb/1","ref":"Image.Color.html#hex_to_rgb/1"},{"type":"function","doc":"`color` is a hex string representing an RGB color. It has\nthe form `#RRGGBB`.","title":"Arguments - Image.Color.hex_to_rgb/1","ref":"Image.Color.html#hex_to_rgb/1-arguments"},{"type":"function","doc":"* `{:ok, [r, g, b]}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Color.hex_to_rgb/1","ref":"Image.Color.html#hex_to_rgb/1-returns"},{"type":"function","doc":"iex> Image.Color.validate_color \"#0000FF\"\n    {:ok, [0, 0, 255]}","title":"Examples - Image.Color.hex_to_rgb/1","ref":"Image.Color.html#hex_to_rgb/1-examples"},{"type":"function","doc":"Returns the list of color profiles built into\n`libvips`.","title":"Image.Color.inbuilt_profiles/0","ref":"Image.Color.html#inbuilt_profiles/0"},{"type":"macro","doc":"Guards whether a given value can be interpreted\nas a color value.","title":"Image.Color.is_color/1","ref":"Image.Color.html#is_color/1"},{"type":"macro","doc":"Guards whether a given profile is one of the inbuilt\nprofiles.","title":"Image.Color.is_inbuilt_profile/1","ref":"Image.Color.html#is_inbuilt_profile/1"},{"type":"function","doc":"Returns a boolean indicating if the given\nprofile is known and can be used for image\noperations.","title":"Image.Color.known_icc_profile?/1","ref":"Image.Color.html#known_icc_profile?/1"},{"type":"function","doc":"","title":"Image.Color.rgb_color/1","ref":"Image.Color.html#rgb_color/1"},{"type":"function","doc":"","title":"Image.Color.rgb_color!/1","ref":"Image.Color.html#rgb_color!/1"},{"type":"function","doc":"Converts a color name or RGB value\nto a hex string.","title":"Image.Color.rgb_to_hex/1","ref":"Image.Color.html#rgb_to_hex/1"},{"type":"function","doc":"* `color` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.","title":"Arguments - Image.Color.rgb_to_hex/1","ref":"Image.Color.html#rgb_to_hex/1-arguments"},{"type":"function","doc":"* `{:ok, #RRGGBB}` string or\n\n* `{:error, reason}`.","title":"Returns - Image.Color.rgb_to_hex/1","ref":"Image.Color.html#rgb_to_hex/1-returns"},{"type":"function","doc":"iex> Image.Color.rgb_to_hex(:green)\n    {:ok, \"#008000\"}\n\n    iex> Image.Color.rgb_to_hex([10,20,30])\n    {:ok, \"#A141E\"}","title":"Examples - Image.Color.rgb_to_hex/1","ref":"Image.Color.html#rgb_to_hex/1-examples"},{"type":"function","doc":"Sorts a list of colors.\n\nThe color sorting is based upon https://www.alanzucconi.com/2015/09/30/colour-sorting/","title":"Image.Color.sort/2","ref":"Image.Color.html#sort/2"},{"type":"function","doc":"* `color` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. Lastly, the\n  color can be supplied as a hex string like `#ffe4e1`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Color.sort/2","ref":"Image.Color.html#sort/2-arguments"},{"type":"function","doc":"There are currently no defined options.","title":"Options - Image.Color.sort/2","ref":"Image.Color.html#sort/2-options"},{"type":"function","doc":"* A sorted list of colors.","title":"Returns - Image.Color.sort/2","ref":"Image.Color.html#sort/2-returns"},{"type":"function","doc":"Validates a color returning an\n`[r, g, b]` triplet or error.","title":"Image.Color.validate_color/1","ref":"Image.Color.html#validate_color/1"},{"type":"function","doc":"* `color` which can be specified as a single integer\n  or a list of integers representing the color.\n  The color can also be supplied as a CSS color name as a\n  string or atom. For example: `:misty_rose`. Lastly, the\n  color can be supplied as a hex string like `\"#ffe4e1\"`. See\n  `Image.Color.color_map/0` and `Image.Color.rgb_color/1`.","title":"Arguments - Image.Color.validate_color/1","ref":"Image.Color.html#validate_color/1-arguments"},{"type":"function","doc":"* `{:ok, [r, g, b]}` or\n\n* `{:error, reason}`","title":"Returns - Image.Color.validate_color/1","ref":"Image.Color.html#validate_color/1-returns"},{"type":"function","doc":"Returns a transparency value in the range 0 to 255\nwhere 0 means transparent and 255 means opqque.","title":"Image.Color.validate_transparency/1","ref":"Image.Color.html#validate_transparency/1"},{"type":"type","doc":"Reference to an ICC color profile\n\n* `:none` means no profile\n* `:cmyk`, `:srgb` and `:p3` refer to the built-in color profiles\n* `Path.t()` means any file system path. If the path is a relative\n  path then is will be loaded from the systems profile directory.","title":"Image.Color.icc_profile/0","ref":"Image.Color.html#t:icc_profile/0"},{"type":"type","doc":"An rbg color expressed as a list of numbers.\n\nThe number of list elements and the type\nvaries depending on the image format, colorspace\nand dimensions.\n\nFor a common `sRGB` image it will be a list of\nthree of four images. If the fourth number is provided\nit will be considered as an alpha transparency band.","title":"Image.Color.rgb_color/0","ref":"Image.Color.html#t:rgb_color/0"},{"type":"type","doc":"A color can be expressed as a list of numbers or\nas a CSS color name in atom or string format.","title":"Image.Color.t/0","ref":"Image.Color.html#t:t/0"},{"type":"type","doc":"A transparency value which is one of the atoms `:none`,\n`:transparent` or `:opaque`. Or an integer between `0` and\n`255` where 0 is transparent and 255 is opaque. Or a float\nin the range `0.0` to `1.0` that is converted to the range\n`0` to `255`.","title":"Image.Color.transparency/0","ref":"Image.Color.html#t:transparency/0"},{"type":"module","doc":"Functions to draw directly on a mutable image.\n\n**Note** that while the functions in this module\nmutate an image, the mutations are performed on\na copy of the image so no harm will come to other\nfunctions maintaining a reference to the original\nimage.","title":"Image.Draw","ref":"Image.Draw.html"},{"type":"function","doc":"Draw a circle on a mutable image.","title":"Image.Draw.circle/5","ref":"Image.Draw.html#circle/5"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `cx` is the 0-based offset from the\n  left edge of the image indicating where\n  the center of the circle will be localed.\n\n* `cy` is the 0-based offset from the\n  top edge of the image indicating where\n  the center of the circle will be localed.\n\n* `radius` is the radius of the drawn circle.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.circle/5","ref":"Image.Draw.html#circle/5-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.\n\n* `:fill` is a boolean indicating whether the\n  rectangle is to be filled with `:color`. The\n  default is `true`.\n\n* `:stroke_width` indicates the width in pixels\n  of the stroke that forms the rectangle. The\n  default is `1`. Values greater than `1` will\n  have a negative performance impact since the\n  rectangle will be draw as 4 filled rectangles\n  forming each of the four sides. If `fill: true`\n  is set then this options is ignored.","title":"Options - Image.Draw.circle/5","ref":"Image.Draw.html#circle/5-options"},{"type":"function","doc":"* `{:ok, image}` where `image` is the same\n  type as that passed as an argument to the\n  function.\n\n* or `{:error, reason}`","title":"Returns - Image.Draw.circle/5","ref":"Image.Draw.html#circle/5-returns"},{"type":"function","doc":"Draw a circle on a mutable image returning\nthe mutated image or raises an exception.","title":"Image.Draw.circle!/5","ref":"Image.Draw.html#circle!/5"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `cx` is the 0-based offset from the\n  left edge of the image indicating where\n  the center of the circle will be localed.\n\n* `cy` is the 0-based offset from the\n  top edge of the image indicating where\n  the center of the circle will be localed.\n\n* `radius` is the radius of the drawn circle.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.circle!/5","ref":"Image.Draw.html#circle!/5-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.\n\n* `:fill` is a boolean indicating whether the\n  rectangle is to be filled with `:color`. The\n  default is `true`.","title":"Options - Image.Draw.circle!/5","ref":"Image.Draw.html#circle!/5-options"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* raises an exception.","title":"Returns - Image.Draw.circle!/5","ref":"Image.Draw.html#circle!/5-returns"},{"type":"function","doc":"Flood-fill image with color, starting at position\n`top`, `left`.\n\nThe filled area is bounded by pixels that are equal to\nthe `:colour`. That is, it searches for pixels enclosed\nby an edge of `:color`.\n\nIf `:equal` is `true`, it instead searches for pixels\nwhich are equal to the start point and fills them with\n`:color`.","title":"Image.Draw.flood/4","ref":"Image.Draw.html#flood/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the flood\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the flood will\n  drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.flood/4","ref":"Image.Draw.html#flood/4-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.flood/4","ref":"Image.Draw.html#flood/4-options"},{"type":"function","doc":"* `{:ok, {image, height, width, top, left}` where `image`\n  is the same type as that passed as an argument to the\n  function. `height` and `width` represent the dimensions\n  of the flood fill in pixels. `top` and `left` are the\n  0-based offsets from the top and left location respectively\n  of the flood area.\n\n* or `{:error, reason}`","title":"Returns - Image.Draw.flood/4","ref":"Image.Draw.html#flood/4-returns"},{"type":"function","doc":"Flood-fill image with color, starting at position\n`top`, `left` or raise an exception.\n\nThe filled area is bounded by pixels that are equal to\nthe `:colour`. That is, it searches for pixels enclosed\nby an edge of `:color`.\n\nIf `:equal` is `true`, it instead searches for pixels\nwhich are equal to the start point and fills them with\n`:color`.","title":"Image.Draw.flood!/4","ref":"Image.Draw.html#flood!/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the flood\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the flood will\n  drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.flood!/4","ref":"Image.Draw.html#flood!/4-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.flood!/4","ref":"Image.Draw.html#flood!/4-options"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* raises an exception.","title":"Returns - Image.Draw.flood!/4","ref":"Image.Draw.html#flood!/4-returns"},{"type":"function","doc":"Draw one image over the top of a mutable\nimage.","title":"Image.Draw.image/5","ref":"Image.Draw.html#image/5"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `sub_image` is any `t:Vimage.t/0` that\n  is drawn on top of `image`.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the sub-image\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the sub-image\n  will be drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.image/5","ref":"Image.Draw.html#image/5-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.image/5","ref":"Image.Draw.html#image/5-options"},{"type":"function","doc":"* `{:ok, image}` where `image` is the same\n  type as that passed as an argument to the\n  function.\n\n* or `{:error, reason}`","title":"Returns - Image.Draw.image/5","ref":"Image.Draw.html#image/5-returns"},{"type":"function","doc":"Draw one image over the top of a mutable\nimage or raises an exception.","title":"Image.Draw.image!/5","ref":"Image.Draw.html#image!/5"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `sub_image` is any `t:Vimage.t/0` that\n  is drawn on top of `image`.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the sub-image\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the sub-image\n  will be drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.image!/5","ref":"Image.Draw.html#image!/5-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.image!/5","ref":"Image.Draw.html#image!/5-options"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function.\n\n* raises an exception.","title":"Returns - Image.Draw.image!/5","ref":"Image.Draw.html#image!/5-returns"},{"type":"macro","doc":"Validates acceptable circle dimensions","title":"Image.Draw.is_circle/3","ref":"Image.Draw.html#is_circle/3"},{"type":"macro","doc":"Validate a point location on an image","title":"Image.Draw.is_point/2","ref":"Image.Draw.html#is_point/2"},{"type":"function","doc":"Draw a line on a mutable image.","title":"Image.Draw.line/6","ref":"Image.Draw.html#line/6"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `x1`, `y1` are the 0-based offsets from the `left`\n  and `top` accordingly indicating the point\n  at the start of the line.\n\n* `x2`, `y2` are the 0-based offsets from the `left`\n  and `top` accordingly indicating the point\n  at the end of the line.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.line/6","ref":"Image.Draw.html#line/6-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.line/6","ref":"Image.Draw.html#line/6-options"},{"type":"function","doc":"* `{:ok, image}` where `image` is the same\n  type as that passed as an argument to the\n  function.\n\n* or `{:error, reason}`","title":"Returns - Image.Draw.line/6","ref":"Image.Draw.html#line/6-returns"},{"type":"function","doc":"Draw a line on a mutable image returning\nthe mutated image or raising an exception.","title":"Image.Draw.line!/6","ref":"Image.Draw.html#line!/6"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `x1`, `y1` are the 0-based offsets from the `left`\n  and `top` accordingly indicating the point\n  at the start of the line.\n\n* `x2`, `y2` are the 0-based offsets from the `left`\n  and `top` accordingly indicating the point\n  at the end of the line.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.line!/6","ref":"Image.Draw.html#line!/6-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.line!/6","ref":"Image.Draw.html#line!/6-options"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* raises an exception.","title":"Returns - Image.Draw.line!/6","ref":"Image.Draw.html#line!/6-returns"},{"type":"function","doc":"Draw mask on the image.\n\nMask is a monochrome 8-bit image with the values of `0` or `255` for transparent\nand any other value as a color to be blended into the base image.","title":"Image.Draw.mask/5","ref":"Image.Draw.html#mask/5"},{"type":"function","doc":"Draw a point on a mutable image.","title":"Image.Draw.point/4","ref":"Image.Draw.html#point/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the point\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the point\n  will be drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.point/4","ref":"Image.Draw.html#point/4-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.","title":"Options - Image.Draw.point/4","ref":"Image.Draw.html#point/4-options"},{"type":"function","doc":"* `{:ok, image}` where `image` is the same\n  type as that passed as an argument to the\n  function.\n\n* or `{:error, reason}`","title":"Returns - Image.Draw.point/4","ref":"Image.Draw.html#point/4-returns"},{"type":"function","doc":"Draw a point on a mutable image returning\nthe mutated image or raising an exception.","title":"Image.Draw.point!/4","ref":"Image.Draw.html#point!/4"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the point\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the point\n  will be drawn.\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.  See\n  the options for `Image.Draw.point/4`.","title":"Arguments - Image.Draw.point!/4","ref":"Image.Draw.html#point!/4-arguments"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* raises an exception.","title":"Returns - Image.Draw.point!/4","ref":"Image.Draw.html#point!/4-returns"},{"type":"function","doc":"Draw a rectangle on a mutable image.","title":"Image.Draw.rect/6","ref":"Image.Draw.html#rect/6"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the rectangle\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the rectangle\n  will be drawn.\n\n* `width` is the width of the rectangle\n\n* `height` is the height of the rectangle\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.rect/6","ref":"Image.Draw.html#rect/6-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.\n\n* `:fill` is a boolean indicating whether the\n  rectangle is to be filled with `:color`. The\n  default is `true`.\n\n* `:stroke_width` indicates the width in pixels\n  of the stroke that forms the rectangle. The\n  default is `1`. Values greater than `1` will\n  have a negative performance impact since the\n  rectangle will be draw as 4 filled rectangles\n  forming each of the four sides. If `fill: true`\n  is set then this options is ignored.","title":"Options - Image.Draw.rect/6","ref":"Image.Draw.html#rect/6-options"},{"type":"function","doc":"* `{:ok, image}` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* `{:error, reason}`.","title":"Returns - Image.Draw.rect/6","ref":"Image.Draw.html#rect/6-returns"},{"type":"function","doc":"Draw a rectangle on a mutable image and\nreturns the mutated image or raises an\nexception.","title":"Image.Draw.rect!/6","ref":"Image.Draw.html#rect!/6"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` or a\n  `t:MutableImage.t/0` upon which the rectangle\n  will be drawn. If `image` is a `t:MutableImage.t/0`\n  it will be mutated directly. If `image` is a\n  `t:Vimage.t/0` it will be copied to a `t:MutableImage.t/0`\n  and then mutated.\n\n* `left` is the 0-based offset from the\n  left edge of the image where the rectangle\n  will be drawn.\n\n* `top` is the 0-based offset from the\n  top edge of the image where the rectangle\n  will be drawn.\n\n* `width` is the width of the rectangle\n\n* `height` is the height of the rectangle\n\n* `options` is a keyword list of options.\n  The default is `color: :black`.","title":"Arguments - Image.Draw.rect!/6","ref":"Image.Draw.html#rect!/6-arguments"},{"type":"function","doc":"* `:color` defines the color of the point. This\n  can be specified as a single integer which will\n  be applied to all bands, or a list of\n  integers representing the color for each\n  band. The color can also be supplied as a CSS color\n  name as a string or atom. For example: `:misty_rose`.\n  Lastly, it can also be supplied as a hex string of\n  the form `#rrggbb`. See `Image.Color.color_map/0` and\n  `Image.Color.rgb_color/1`.\n\n* `:fill` is a boolean indicating whether the\n  rectangle is to be filled with `:color`. The\n  default is `true`.\n\n* `:stroke_width` indicates the width in pixels\n  of the stroke that forms the rectangle. The\n  default is `1`. Values greater than `1` will\n  have a negative performance impact since the\n  rectangle will be draw as 4 filled rectangles\n  forming each of the four sides. If `fill: true`\n  is set then this options is ignored.","title":"Options - Image.Draw.rect!/6","ref":"Image.Draw.html#rect!/6-options"},{"type":"function","doc":"* `image` where `image` is the same\n  type as that passed as an argument to the\n  function or\n\n* raises an exception.","title":"Returns - Image.Draw.rect!/6","ref":"Image.Draw.html#rect!/6-returns"},{"type":"function","doc":"Smudge a section of image .\n\nEach pixel in the area left , top , width , height is\nreplaced by the average of the surrounding 3x3 pixels.","title":"Image.Draw.smudge/6","ref":"Image.Draw.html#smudge/6"},{"type":"module","doc":"Implements image generation functions using [Axon](https://hex.pm/packages/axon)\nmachine learning models managed by [Bumblebee](https://hex.pm/packages/bumblebee).","title":"Image.Generation","ref":"Image.Generation.html"},{"type":"module","doc":"The machine learning model to be used is configurable however\nonly Stable Diffusion is currently supported.\n\nThe default configuration is:\n\n    # runtime.exs\n    config :image, :generator,\n      repository_id: \"CompVis/stable-diffusion-v1-4\",\n      scheduler: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"scheduler\"},\n      featurizer: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"feature_extractor\"},\n      safety_checker: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"safety_checker\"},\n      autostart: false","title":"Configuration - Image.Generation","ref":"Image.Generation.html#module-configuration"},{"type":"module","doc":"If `autostart: true` is configured (the default is `false`) then\na process is started under a supervisor to execute the generation\nrequests.  If running the process under an application\nsupervision tree is desired, set `autostart: false`. In that\ncase the function `Image.Generation.generator/2` can be\nused to return a `t:Supervisor.child_spec/0`.","title":"Autostart - Image.Generation","ref":"Image.Generation.html#module-autostart"},{"type":"module","doc":"To add image generation to an application supervision tree,\nuse `Image.Generation.generator/2` to return a child spec:\nFor example:\n\n    # Application.ex\n    def start(_type, _args) do\n      children = [\n        # default classifier configuration\n        Image.Generation.generator()\n      ]\n\n      Supervisor.start_link(\n        children,\n        strategy: :one_for_one\n      )\n    end","title":"Adding a image generation server to an application supervision tree - Image.Generation","ref":"Image.Generation.html#module-adding-a-image-generation-server-to-an-application-supervision-tree"},{"type":"module","doc":"If a dynamically started image generation process is\nrequired one can be started under a supervisor with:\n\n    iex> Supervisor.start_link([Image.Generation.generator()], strategy: :one_for_one)","title":"Starting a supervised image generation process - Image.Generation","ref":"Image.Generation.html#module-starting-a-supervised-image-generation-process"},{"type":"function","doc":"Returns a child spec for service that generates images from text\nusing Stable Diffusion implemented in Bumblebee.","title":"Image.Generation.generator/2","ref":"Image.Generation.html#generator/2"},{"type":"function","doc":"* `generator` is a keyword list of configuration\n  options for an image generator or `:default`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Generation.generator/2","ref":"Image.Generation.html#generator/2-arguments"},{"type":"function","doc":"* `:num_steps` determines the number of steps\n  to execute in the generation model. The default\n  is `20`. Changing this to `40` may increase image\n  quality.\n\n* `:num_images_per_prompt` determines how many image\n  alternatives are returned. The default is `1`.\n\n* `:name` is the name given to the child process. THe\n  default is `Image.Generation.Server`.","title":"Options - Image.Generation.generator/2","ref":"Image.Generation.html#generator/2-options"},{"type":"function","doc":"If `generator` is set to `:default` the following configuration\nis used:\n\n```elixir\n[\n  repository_id: \"CompVis/stable-diffusion-v1-4\",\n  scheduler: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"scheduler\"},\n  featurizer: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"feature_extractor\"},\n  safety_checker: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"safety_checker\"},\n  autostart: false\n]\n```\n\nIf no generator is specified (or it is set to `:default`\nthen the configuration is derived from `runtime.exs` which\nis then merged into the default configuration. In\n`runtime.exs` the configuration would be specified as follows:\n\n```elixir\nconfig :image, :generator,\n  repository_id: \"CompVis/stable-diffusion-v1-4\",\n  scheduler: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"scheduler\"},\n  featurizer: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"feature_extractor\"},\n  safety_checker: {:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"safety_checker\"},\n  autostart: false\n```","title":"Default configuration - Image.Generation.generator/2","ref":"Image.Generation.html#generator/2-default-configuration"},{"type":"function","doc":"The `:autostart` configuration option determines if the\nimage generation service is started when the `:image` application\nis started.  The default is `false`. To cause the service to\nbe started at application start, add the following to your\n`runtime.exs`:\n\n```elixir\nconfig :image, :generator,\n  autostart: true\n```","title":"Automatically starting the service - Image.Generation.generator/2","ref":"Image.Generation.html#generator/2-automatically-starting-the-service"},{"type":"function","doc":"Generates an image from a textual description using [Bumblebee's](https://hex.pm/packages/bumblebee)\nsuport of the [Stable Diffusion](https://github.com/CompVis/stable-diffusion) model.","title":"Image.Generation.text_to_image/2","ref":"Image.Generation.html#text_to_image/2"},{"type":"function","doc":"* `prompt` is a `t:String.t/0` description of the scene to\n  be generated.\n\n* `options` is a keyword list of options. The default is\n  `negative_prompt: \"\"`.","title":"Arguments - Image.Generation.text_to_image/2","ref":"Image.Generation.html#text_to_image/2-arguments"},{"type":"function","doc":"* `:negative_prompt` is a `t:String.t/0` that tells Stable Diffusion what you\n  don't want to see in the generated images. When specified, it guides\n  the generation process not to include things in the image according\n  to a given text.","title":"Options - Image.Generation.text_to_image/2","ref":"Image.Generation.html#text_to_image/2-options"},{"type":"function","doc":"iex> Image.Generation.text_to_image \"impressionist purple numbat in the style of monet\"\n    [%Vix.Vips.Image{ref: #Reference<0.1281915998.296878104.76045>}]","title":"Example - Image.Generation.text_to_image/2","ref":"Image.Generation.html#text_to_image/2-example"},{"type":"module","doc":"A histogram is a graphical representation of the tonal\ndistribution in a digital image. It plots the number\nof pixels for each tonal value. By looking at the histogram\nfor a specific image a viewer will be able to judge the\nentire tonal distribution at a glance.\n\nThe horizontal axis of the graph represents the tonal variations,\nwhile the vertical axis represents the total number of pixels in\nthat particular tone.\n\nThe left side of the horizontal axis represents the dark areas,\nthe middle represents mid-tone values and the right hand side\nrepresents light areas. The vertical axis represents the size\nof the area (total number of pixels) that is captured in each\none of these zones.\n\nThus, the histogram for a very dark image will have most of\nits data points on the left side and center of the graph.\n\nConversely, the histogram for a very bright image with few\ndark areas and/or shadows will have most of its data points\non the right side and center of the graph.\n\nThe histograms generated in this module have red, green,\nblue and luminance layers and can be returned as either an\n[svg](https://en.wikipedia.org/wiki/SVG) string or as an\n`t:Vimage.t/0`.\n\nThe current implementation does not applying any scale\ncompression or expansion and therefore where the image\nhas very wide tonality differences the differences may\nbe difficult to distinguish if `:height` is small.","title":"Image.Histogram","ref":"Image.Histogram.html"},{"type":"function","doc":"Returns an image representing a red, green, blue and\nluminance histogram for an image.","title":"Image.Histogram.as_image/2","ref":"Image.Histogram.html#as_image/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Histogram.as_image/2","ref":"Image.Histogram.html#as_image/2-arguments"},{"type":"function","doc":"* `:width` is the integer width of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.\n\n* `:height` is the integer height of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.","title":"Options - Image.Histogram.as_image/2","ref":"Image.Histogram.html#as_image/2-options"},{"type":"function","doc":"* `{:ok, histogram_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Histogram.as_image/2","ref":"Image.Histogram.html#as_image/2-returns"},{"type":"function","doc":"With `Image.Histogram.as_image/2` it is recommended that\nthe `:width` and/or `:height` options be provided (in pixels)\nto ensure the image is generated at the desired size.\n\nThe default of `:auto` will generate an image the size\nof the underlying SVG viewbox which is `255` pixels\nwide and `255` pixels high.","title":"Histogram image sizing - Image.Histogram.as_image/2","ref":"Image.Histogram.html#as_image/2-histogram-image-sizing"},{"type":"function","doc":"Returns an image representing a red, green, blue and\nluminance histogram for an image or raises an exception.","title":"Image.Histogram.as_image!/2","ref":"Image.Histogram.html#as_image!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Histogram.as_image!/2","ref":"Image.Histogram.html#as_image!/2-arguments"},{"type":"function","doc":"* `:width` is the integer width of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.\n\n* `:height` is the integer height of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.","title":"Options - Image.Histogram.as_image!/2","ref":"Image.Histogram.html#as_image!/2-options"},{"type":"function","doc":"* `histogram_image` or\n\n* raises an exception.","title":"Returns - Image.Histogram.as_image!/2","ref":"Image.Histogram.html#as_image!/2-returns"},{"type":"function","doc":"With `Image.Histogram.as_image/2` it is recommended that\nthe `:width` and/or `:height` options be provided (in pixels)\nto ensure the image is generated at the desired size.\n\nThe default of `:auto` will generate an image the size\nof the underlying SVG viewbox which is `255` pixels\nwide and `255` pixels high.","title":"Histogram image sizing - Image.Histogram.as_image!/2","ref":"Image.Histogram.html#as_image!/2-histogram-image-sizing"},{"type":"function","doc":"Returns an [svg](https://en.wikipedia.org/wiki/SVG) string\nrepresenting a red, green, blue and luminance histogram\nfor an image.","title":"Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2-arguments"},{"type":"function","doc":"* `:width` is the integer width of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.\n\n* `:height` is the integer height of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.","title":"Options - Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2-options"},{"type":"function","doc":"* `{:ok, svg_string}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2-returns"},{"type":"function","doc":"SVG will, by default, resize to fit its parent container\nin an HTMl page. `Image.Histogram.as_svg/2` will\ngenerate SVG with a default width and height of `auto`\nthe reflects this intent.\n\nIn some cases, such as generating images with\n`Image.Histogram.as_image/2`, `:width` and `:height` options\nshould be provided (in pixels) to ensure the image is generated\nat the desired size.","title":"Histogram image sizing - Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2-histogram-image-sizing"},{"type":"function","doc":"Thanks to [Alex Plescan](https://alexplescan.com/posts/2023/07/08/easy-svg-sparklines/)\nfor the inspiration for the SVG design.","title":"Attribution - Image.Histogram.as_svg/2","ref":"Image.Histogram.html#as_svg/2-attribution"},{"type":"function","doc":"Returns an [svg](https://en.wikipedia.org/wiki/SVG) string\nrepresenting a red, green, blue and luminance histogram for\nan image or raises an exception.","title":"Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2-arguments"},{"type":"function","doc":"* `:width` is the integer width of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.\n\n* `:height` is the integer height of the SVG image.\n  The default is `:auto` which means the image is\n  sized to its parent container.","title":"Options - Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2-options"},{"type":"function","doc":"* `svg_string` or\n\n* raises an exception.","title":"Returns - Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2-returns"},{"type":"function","doc":"SVG will, by default, resize to fit its parent container\nin an HTMl page. `Image.Histogram.as_svg/2` will\ngenerate SVG with a default width and height of `auto`\nthe reflects this intent.\n\nIn some cases, such as generating images with\n`Image.Histogram.as_image/2`, `:width` and `:height` options\nshould be provided (in pixels) to ensure the image is generated\nat the desired size.","title":"Histogram image sizing - Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2-histogram-image-sizing"},{"type":"function","doc":"Thanks to [Alex Plescan](https://alexplescan.com/posts/2023/07/08/easy-svg-sparklines/)\nfor the inspiration for the SVG design.","title":"Attribution - Image.Histogram.as_svg!/2","ref":"Image.Histogram.html#as_svg!/2-attribution"},{"type":"module","doc":"Implements math operators for images,\ndelegating to the `Kernel` functions in the\ncases where the parameters do not include\n`t:Vix.Vips.Image.t/0`.\n\nTo override the standard operations in a\nfunction or module, add `use Image.Math`.\n\nTo maximise readability and clarity it\nis recommended that `use Image.Math` be added\nto only those functions that require it.","title":"Image.Math","ref":"Image.Math.html"},{"type":"module","doc":"defmodule MyModule do\n      # Not recommended\n      use Image.Math\n\n      def my_function(%Vix.Vips.Image{} = image) do\n        # Recommended\n        use Image.Math\n\n        # Increase the all bands by 20%\n        brigher = image * 1.2\n\n        # Or adjust only green by 20%\n        bright_green = image * [1, 1.2, 1]\n      end\n    end","title":"Example - Image.Math","ref":"Image.Math.html#module-example"},{"type":"function","doc":"Matrix bitwise 'and' of\ntwo images.","title":"Image.Math.&&&/2","ref":"Image.Math.html#&&&/2"},{"type":"function","doc":"Matrix exponent of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.**/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.**/2","ref":"Image.Math.html#**/2"},{"type":"function","doc":"Matrix multiplation of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.*/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.*/2","ref":"Image.Math.html#*/2"},{"type":"function","doc":"Matrix addition of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.+/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.+/2","ref":"Image.Math.html#+/2"},{"type":"function","doc":"Matrix subtraction of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.-/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.-/2","ref":"Image.Math.html#-/2"},{"type":"function","doc":"Matrix division of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.//2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.//2","ref":"Image.Math.html#//2"},{"type":"function","doc":"Matrix inequality of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.!=/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.!=/2","ref":"Image.Math.html#!=/2"},{"type":"function","doc":"Matrix less than of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.</2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.</2","ref":"Image.Math.html#%3C/2"},{"type":"function","doc":"Matrix bitwise 'left shift' of\ntwo images.","title":"Image.Math.<<</2","ref":"Image.Math.html#%3C%3C%3C/2"},{"type":"function","doc":"Matrix less than or equal of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.<=/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.<=/2","ref":"Image.Math.html#%3C=/2"},{"type":"function","doc":"Matrix equality of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.==/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.==/2","ref":"Image.Math.html#==/2"},{"type":"function","doc":"Matrix greater than of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.>/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.>/2","ref":"Image.Math.html#%3E/2"},{"type":"function","doc":"Matrix greater than or equal of two images or\none image and a constant or vector.\n\nDelegates to `Kernel.>=/2` if none of\nthe parameters is a `t:Vix.Vips.Image.t/0`.","title":"Image.Math.>=/2","ref":"Image.Math.html#%3E=/2"},{"type":"function","doc":"Matrix bitwise 'right shift' of\ntwo images.","title":"Image.Math.>>>/2","ref":"Image.Math.html#%3E%3E%3E/2"},{"type":"function","doc":"","title":"Image.Math.add/2","ref":"Image.Math.html#add/2"},{"type":"function","doc":"","title":"Image.Math.add!/2","ref":"Image.Math.html#add!/2"},{"type":"function","doc":"","title":"Image.Math.boolean_and/2","ref":"Image.Math.html#boolean_and/2"},{"type":"function","doc":"","title":"Image.Math.boolean_and!/2","ref":"Image.Math.html#boolean_and!/2"},{"type":"function","doc":"","title":"Image.Math.boolean_lshift/2","ref":"Image.Math.html#boolean_lshift/2"},{"type":"function","doc":"","title":"Image.Math.boolean_lshift!/2","ref":"Image.Math.html#boolean_lshift!/2"},{"type":"function","doc":"","title":"Image.Math.boolean_or/2","ref":"Image.Math.html#boolean_or/2"},{"type":"function","doc":"","title":"Image.Math.boolean_or!/2","ref":"Image.Math.html#boolean_or!/2"},{"type":"function","doc":"","title":"Image.Math.boolean_rshift/2","ref":"Image.Math.html#boolean_rshift/2"},{"type":"function","doc":"","title":"Image.Math.boolean_rshift!/2","ref":"Image.Math.html#boolean_rshift!/2"},{"type":"function","doc":"","title":"Image.Math.boolean_xor/2","ref":"Image.Math.html#boolean_xor/2"},{"type":"function","doc":"","title":"Image.Math.boolean_xor!/2","ref":"Image.Math.html#boolean_xor!/2"},{"type":"function","doc":"","title":"Image.Math.cos/1","ref":"Image.Math.html#cos/1"},{"type":"function","doc":"","title":"Image.Math.cos!/1","ref":"Image.Math.html#cos!/1"},{"type":"function","doc":"","title":"Image.Math.divide/2","ref":"Image.Math.html#divide/2"},{"type":"function","doc":"","title":"Image.Math.divide!/2","ref":"Image.Math.html#divide!/2"},{"type":"function","doc":"","title":"Image.Math.equal/2","ref":"Image.Math.html#equal/2"},{"type":"function","doc":"","title":"Image.Math.equal!/2","ref":"Image.Math.html#equal!/2"},{"type":"function","doc":"","title":"Image.Math.greater_than/2","ref":"Image.Math.html#greater_than/2"},{"type":"function","doc":"","title":"Image.Math.greater_than!/2","ref":"Image.Math.html#greater_than!/2"},{"type":"function","doc":"","title":"Image.Math.greater_than_or_equal/2","ref":"Image.Math.html#greater_than_or_equal/2"},{"type":"function","doc":"","title":"Image.Math.greater_than_or_equal!/2","ref":"Image.Math.html#greater_than_or_equal!/2"},{"type":"macro","doc":"Guards if a given value might be reasonably interpreted\nas a pixel.","title":"Image.Math.is_pixel/1","ref":"Image.Math.html#is_pixel/1"},{"type":"function","doc":"","title":"Image.Math.less_than/2","ref":"Image.Math.html#less_than/2"},{"type":"function","doc":"","title":"Image.Math.less_than!/2","ref":"Image.Math.html#less_than!/2"},{"type":"function","doc":"","title":"Image.Math.less_than_or_equal/2","ref":"Image.Math.html#less_than_or_equal/2"},{"type":"function","doc":"","title":"Image.Math.less_than_or_equal!/2","ref":"Image.Math.html#less_than_or_equal!/2"},{"type":"function","doc":"Return the image maximum.","title":"Image.Math.maxpos/2","ref":"Image.Math.html#maxpos/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Math.maxpos/2","ref":"Image.Math.html#maxpos/2-arguments"},{"type":"function","doc":"* `:size` is the number of maximums to find. The\n  default is `10`.","title":"Options - Image.Math.maxpos/2","ref":"Image.Math.html#maxpos/2-options"},{"type":"function","doc":"* `{:ok, maximum, x_position, y_position}`","title":"Returns - Image.Math.maxpos/2","ref":"Image.Math.html#maxpos/2-returns"},{"type":"function","doc":"Return the image minimum.","title":"Image.Math.minpos/2","ref":"Image.Math.html#minpos/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Math.minpos/2","ref":"Image.Math.html#minpos/2-arguments"},{"type":"function","doc":"* `:size` is the number of minimums to find. The\n  default is `10`.","title":"Options - Image.Math.minpos/2","ref":"Image.Math.html#minpos/2-options"},{"type":"function","doc":"* `{:ok, minimum, x_position, y_position}`","title":"Returns - Image.Math.minpos/2","ref":"Image.Math.html#minpos/2-returns"},{"type":"function","doc":"","title":"Image.Math.multiply/2","ref":"Image.Math.html#multiply/2"},{"type":"function","doc":"","title":"Image.Math.multiply!/2","ref":"Image.Math.html#multiply!/2"},{"type":"function","doc":"","title":"Image.Math.not_equal/2","ref":"Image.Math.html#not_equal/2"},{"type":"function","doc":"","title":"Image.Math.not_equal!/2","ref":"Image.Math.html#not_equal!/2"},{"type":"function","doc":"","title":"Image.Math.pow/2","ref":"Image.Math.html#pow/2"},{"type":"function","doc":"","title":"Image.Math.pow!/2","ref":"Image.Math.html#pow!/2"},{"type":"function","doc":"","title":"Image.Math.sin/1","ref":"Image.Math.html#sin/1"},{"type":"function","doc":"","title":"Image.Math.sin!/1","ref":"Image.Math.html#sin!/1"},{"type":"function","doc":"","title":"Image.Math.subtract/2","ref":"Image.Math.html#subtract/2"},{"type":"function","doc":"","title":"Image.Math.subtract!/2","ref":"Image.Math.html#subtract!/2"},{"type":"function","doc":"Matrix bitwise 'or' of\ntwo images.","title":"Image.Math.|||/2","ref":"Image.Math.html#%7C%7C%7C/2"},{"type":"module","doc":"Detects and decodes QRcodes.\n\nNote that the implementation, which is based upon\n[eVision](https://github.com/cocoa-xu/evision) requires that\nthe image be a 3-channel image in order to support\ndetection.\n\nImages that are in different formats must be converted\nfirst.","title":"Image.QRcode","ref":"Image.QRcode.html"},{"type":"module","doc":"This module is only available if the optional dependency\n[eVision](https://hex.pm/packages/evision) is configured in\n`mix.exs`.","title":"Note - Image.QRcode","ref":"Image.QRcode.html#module-note"},{"type":"function","doc":"Detects and decodes a QR code in an image.","title":"Image.QRcode.decode/1","ref":"Image.QRcode.html#decode/1"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0` that\n  has three bands (for example, a typical srgb\n  image).","title":"Arguments - Image.QRcode.decode/1","ref":"Image.QRcode.html#decode/1-arguments"},{"type":"function","doc":"* `{:ok, string}` or\n\n* `{:error, reason}`","title":"Returns - Image.QRcode.decode/1","ref":"Image.QRcode.html#decode/1-returns"},{"type":"function","doc":"Only images with three bands (channels) are\nsupported. This restriction may be lifted in\na future release.","title":"Note - Image.QRcode.decode/1","ref":"Image.QRcode.html#decode/1-note"},{"type":"function","doc":"Encodes a string as a QRCode.","title":"Image.QRcode.encode/2","ref":"Image.QRcode.html#encode/2"},{"type":"function","doc":"* `string` is any string to be encoded,\n\n* `options` is a keyword list of options. The\n  default is `size: :auto`.","title":"Arguments - Image.QRcode.encode/2","ref":"Image.QRcode.html#encode/2-arguments"},{"type":"function","doc":"* `:size` is the size in pixels of the QRcode\n  dimensions. The default is `:auto` in which\n  the generated QRcode will be the minimum dimensions\n  necessary to encode the `string`.","title":"Options - Image.QRcode.encode/2","ref":"Image.QRcode.html#encode/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.QRcode.encode/2","ref":"Image.QRcode.html#encode/2-returns"},{"type":"module","doc":"","title":"Image.Scholar","ref":"Image.Scholar.html"},{"type":"function","doc":"","title":"Image.Scholar.k_means/2","ref":"Image.Scholar.html#k_means/2"},{"type":"function","doc":"","title":"Image.Scholar.unique_colors/1","ref":"Image.Scholar.html#unique_colors/1"},{"type":"module","doc":"Functions to render a shape as an image.\n\nThe supported shapes match those defined in\n[Scalable Vector Graphics](https://developer.mozilla.org/en-US/docs/Web/SVG)\nincluding:\n\n* Rectangle\n* Polygon\n* Circle\n* Ellipse\n* Line","title":"Image.Shape","ref":"Image.Shape.html"},{"type":"function","doc":"Creates an image of a circle.\n\n* `radius` is the radius of the circle in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.circle/2","ref":"Image.Shape.html#circle/2"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  circle. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the circle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the circle. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.circle/2","ref":"Image.Shape.html#circle/2-options"},{"type":"function","doc":"* `{:ok, circle_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.circle/2","ref":"Image.Shape.html#circle/2-returns"},{"type":"function","doc":"iex> {:ok, circle} = Image.Shape.circle(50, fill_color: :green, stroke_color: :blue)","title":"Example - Image.Shape.circle/2","ref":"Image.Shape.html#circle/2-example"},{"type":"function","doc":"Creates an image of a circle or raises an exception.\n\n* `radius` is the radius of the circle in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.circle!/2","ref":"Image.Shape.html#circle!/2"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  circle. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the circle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the circle. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.circle!/2","ref":"Image.Shape.html#circle!/2-options"},{"type":"function","doc":"* `circle_image` or\n\n* raises an exception.","title":"Returns - Image.Shape.circle!/2","ref":"Image.Shape.html#circle!/2-returns"},{"type":"function","doc":"iex> circle = Image.Shape.circle!(50, fill_color: :green, stroke_color: :blue)","title":"Example - Image.Shape.circle!/2","ref":"Image.Shape.html#circle!/2-example"},{"type":"function","doc":"Creates an image of a ellipse.\n\n* `x_radius` is the radius of the x-aixs of the\n  ellipse in pixels.\n\n* `y_radius` is the radius of the y-aixs of the\n  ellipse in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.ellipse/3","ref":"Image.Shape.html#ellipse/3"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  ellipse. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the ellipse. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the ellipse. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.ellipse/3","ref":"Image.Shape.html#ellipse/3-options"},{"type":"function","doc":"* `{:ok, ellipse_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.ellipse/3","ref":"Image.Shape.html#ellipse/3-returns"},{"type":"function","doc":"iex> {:ok, ellipse} = Image.Shape.ellipse(50, 100, fill_color: :green, stroke_color: :none)","title":"Examples - Image.Shape.ellipse/3","ref":"Image.Shape.html#ellipse/3-examples"},{"type":"function","doc":"Creates an image of a ellipse or raises an exception.\n\n* `x_radius` is the radius of the x-aixs of the\n  ellipse in pixels.\n\n* `y_radius` is the radius of the y-aixs of the\n  ellipse in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.ellipse!/3","ref":"Image.Shape.html#ellipse!/3"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  ellipse. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the rectangle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the polygon. The default is `:black`\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.ellipse!/3","ref":"Image.Shape.html#ellipse!/3-options"},{"type":"function","doc":"* `ellipse_image` or\n\n* raises an exception.","title":"Returns - Image.Shape.ellipse!/3","ref":"Image.Shape.html#ellipse!/3-returns"},{"type":"function","doc":"iex> ellipse = Image.Shape.ellipse!(50, 100, fill_color: :green, stroke_color: :none)","title":"Example - Image.Shape.ellipse!/3","ref":"Image.Shape.html#ellipse!/3-example"},{"type":"function","doc":"Creates an image of a line.\n\n* `x1` Defines the x-axis coordinate of the line\n  starting point in pixels.\n\n* `y1` Defines the y-axis coordinate of the line\n  starting point in pixels.\n\n* `x2` Defines the x-axis coordinate of the line\n  ending point in pixels.\n\n* `y2` Defines the y-axis coordinate of the line\n  ending point in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.line/5","ref":"Image.Shape.html#line/5"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  line. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the line. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the line. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.line/5","ref":"Image.Shape.html#line/5-options"},{"type":"function","doc":"* `{:ok, line_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.line/5","ref":"Image.Shape.html#line/5-returns"},{"type":"function","doc":"iex> {:ok, line} = Image.Shape.line(5, 5, 50, 50, stroke_width: 10, stroke_color: :white)","title":"Examples - Image.Shape.line/5","ref":"Image.Shape.html#line/5-examples"},{"type":"function","doc":"Creates a image of a line or raises an exception.\n\n* `x1` Defines the x-axis coordinate of the line\n  starting point in pixels.\n\n* `y1` Defines the y-axis coordinate of the line\n  starting point in pixels.\n\n* `x2` Defines the x-axis coordinate of the line\n  ending point in pixels.\n\n* `y2` Defines the y-axis coordinate of the line\n  ending point in pixels.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.line!/5","ref":"Image.Shape.html#line!/5"},{"type":"function","doc":"* `:stroke_width` is the width of the line used\n  to draw the rectangle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the polygon. The default is `:black`\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.line!/5","ref":"Image.Shape.html#line!/5-options"},{"type":"function","doc":"* `line_image` or\n\n* raises an exception.","title":"Returns - Image.Shape.line!/5","ref":"Image.Shape.html#line!/5-returns"},{"type":"function","doc":"iex> line = Image.Shape.line!(5, 5, 50, 50, stroke_width: 10, stroke_color: :white)","title":"Example - Image.Shape.line!/5","ref":"Image.Shape.html#line!/5-example"},{"type":"function","doc":"Creates an image of a polygon.","title":"Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2"},{"type":"function","doc":"* `points` defines the points of the polygon. The\n  origin is the top left of the image with a positive\n  `x` value moving from right to left and a positive\n  `y` value moving from top to bottom.  The points can\n  be an [SVG point string](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/points)\n  or a \"list of lists\" of the form\n  `[[x1, y1], [x2, y2], ...]` where `x1` and `y1`\n  are integers.  `points` can also be a positive\n  integer >= 3 which indicates that an `n` sided\n  polygon will be generated. In this case the options\n  `:rotation` and `:radius` are also applicable.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Arguments - Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2-arguments"},{"type":"function","doc":"* `:width` is the width of the canvas onto which the\n  polygon is drawn. The default is `500` pixels.\n\n* `:height` is the height of the canvas onto which the\n  polygon is drawn. The default is `500` pixels.\n\n* `:fill_color` is the color used to fill in the\n  polygon. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the polygon. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the polygon. The default is `:black`\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.\n\n* `:rotation` is the number of degrees to rotate the\n  axis of a generated n-sided polygon. This option is\n  only valid if `points` is an integer >= 3.\n  The default is `180`.\n\n* `:radius` indicates the radius in pixels of a generated\n  n-sided polygon. The default is `100`.","title":"Options - Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2-options"},{"type":"function","doc":"* The polygon points are scaled to fit the canvas size\n  defined by `:width` and `:height` This means that the\n  resulting image will fill the canvas. This is useful\n  for composing images. Define the canvas to be the size\n  intended to be composed into a base image and the\n  polygon will be scaled to fit.\n\n* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2-notes"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2-returns"},{"type":"function","doc":"","title":"Examples - Image.Shape.polygon/2","ref":"Image.Shape.html#polygon/2-examples"},{"type":"function","doc":"Creates an image of a polygon as a single\nband image on a transparent background.","title":"Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2"},{"type":"function","doc":"* `points` defines the points of the polygon. The\n  origin is the top left of the image with a positive\n  `x` value moving from right to left and a positive\n  `y` value moving from top to bottom.  The points can\n  be an [SVG point string](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/points)\n  or a \"list of lists\" of the form\n  `[[x1, y1], [x2, y2], ...]` where `x1` and `y1`\n  are integers.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Arguments - Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2-arguments"},{"type":"function","doc":"* `:width` is the width of the canvas onto which the\n  polygon is drawn. The default is `500` pixels.\n\n* `:height` is the width of the canvas onto which the\n  polygon is drawn. The default is `500` pixels.\n\n* `:fill_color` is the color used to fill in the\n  polygon. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the polygon. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the polygon. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.","title":"Options - Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2-options"},{"type":"function","doc":"* The polygon points are scaled to fit the canvas size\n  defined by `:width` and `:height` This means that the\n  resulting image will fill the canvas. This is useful\n  for composing images. Define the canvas to be the size\n  intended to be composed into a base image and the\n  polygon will be scaled to fit.\n\n* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2-notes"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2-returns"},{"type":"function","doc":"","title":"Examples - Image.Shape.polygon!/2","ref":"Image.Shape.html#polygon!/2-examples"},{"type":"function","doc":"Creates a image of a rectangle.\n\n* `width` is the number of pixels wide.\n\n* `height` is the number of pixels high.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.rect/3","ref":"Image.Shape.html#rect/3"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  rectangle. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the rectangle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the rectangle. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.\n\n* `:rotation` is the number of degrees to rotate the\n  axis of a generated rectangle.","title":"Options - Image.Shape.rect/3","ref":"Image.Shape.html#rect/3-options"},{"type":"function","doc":"* `{:ok, rectangle_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.rect/3","ref":"Image.Shape.html#rect/3-returns"},{"type":"function","doc":"iex> {:ok, rectangle} = Image.Shape.rect(50, 100, fill_color: :red, stroke_color: :yellow)","title":"Example - Image.Shape.rect/3","ref":"Image.Shape.html#rect/3-example"},{"type":"function","doc":"Creates a image of a rectangle or raises\nand exception.\n\n* `width` is the number of pixels wide.\n\n* `height` is the number of pixels high.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Image.Shape.rect!/3","ref":"Image.Shape.html#rect!/3"},{"type":"function","doc":"* `:fill_color` is the color used to fill in the\n  rectangle. The default is `:none`.\n\n* `:stroke_width` is the width of the line used\n  to draw the rectangle. The default is `1px`.\n\n* `:stroke_color` is the color used for the outline\n  of the rectangle. The default is `:black`.\n\n* `:opacity` is the opacity as a float between\n  `0.0` and `1.0` where `0.0` is completely transparent\n  and `1.0` is completely opaque. The default is `0.7`.\n\n* `:rotation` is the number of degrees to rotate the\n  axis of a generated rectangle.","title":"Options - Image.Shape.rect!/3","ref":"Image.Shape.html#rect!/3-options"},{"type":"function","doc":"* `rectangle_image` or\n\n* raises an exception.","title":"Returns - Image.Shape.rect!/3","ref":"Image.Shape.html#rect!/3-returns"},{"type":"function","doc":"iex> rectangle = Image.Shape.rect!(50, 100, fill_color: :red, stroke_color: :yellow)","title":"Examples - Image.Shape.rect!/3","ref":"Image.Shape.html#rect!/3-examples"},{"type":"function","doc":"Returns an image of an n-pointed star that\ncan be composed over other images.","title":"Image.Shape.star/2","ref":"Image.Shape.html#star/2"},{"type":"function","doc":"* `points` is an integer number of points\n  on the star. `points` must be >= 3. The default\n  is `5`.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Arguments - Image.Shape.star/2","ref":"Image.Shape.html#star/2-arguments"},{"type":"function","doc":"* `:inner_radius` is the size of the inner\n  radius. The default is `60`.\n\n* `:outer_radius` is the size of the outer\n  radius. The default is `150`.\n\n* `:rotation` is the angle in degrees of rotation\n  applied to the points. The default is `0`.\n\n* Any remaining options are passed to `Image.Shape.polygon/2`.","title":"Options - Image.Shape.star/2","ref":"Image.Shape.html#star/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Shape.star/2","ref":"Image.Shape.html#star/2-returns"},{"type":"function","doc":"iex> {:ok, star} = Image.Shape.star\n    iex> {:ok, star} = Image.Shape.star(5, rotation: 90, fill_color: :red, stroke_color: :green)","title":"Examples - Image.Shape.star/2","ref":"Image.Shape.html#star/2-examples"},{"type":"function","doc":"Returns an image of an n-pointed star that\ncan be composed over other images.","title":"Image.Shape.star!/2","ref":"Image.Shape.html#star!/2"},{"type":"function","doc":"* `points` is an integer number of points\n  on the star. `points` must be >= 3. The default\n  is `5`.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Arguments - Image.Shape.star!/2","ref":"Image.Shape.html#star!/2-arguments"},{"type":"function","doc":"* `:inner_radius` is the size of the inner\n  radius. The default is `60`.\n\n* `:outer_radius` is the size of the outer\n  radius. The default is `150`.\n\n* `:rotation` is the angle in degrees of rotation\n  applied to the points. The default is `0`.\n\n* Any remaining options are passed to `Image.Shape.polygon/2`.","title":"Options - Image.Shape.star!/2","ref":"Image.Shape.html#star!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.Shape.star!/2","ref":"Image.Shape.html#star!/2-returns"},{"type":"function","doc":"iex> star = Image.Shape.star!\n    iex> star = Image.Shape.star!(5, rotation: 90, fill_color: :red, stroke_color: :green)","title":"Examples - Image.Shape.star!/2","ref":"Image.Shape.html#star!/2-examples"},{"type":"type","doc":"A path is a list of points representing\na path, open polygon or closed polygon.","title":"Image.Shape.path/0","ref":"Image.Shape.html#t:path/0"},{"type":"type","doc":"A point is a list of two integers\nrepresenting the `x` and `y` coordinates","title":"Image.Shape.point/0","ref":"Image.Shape.html#t:point/0"},{"type":"module","doc":"Functions to introspect standard image sizes for\nvarious social media platforms.","title":"Image.Social","ref":"Image.Social.html"},{"type":"function","doc":"Returns the default image type that an\nimage is resized to for a given platform\nis no `:type` parameter is provided.","title":"Image.Social.default_image_usage/1","ref":"Image.Social.html#default_image_usage/1"},{"type":"function","doc":"* `platform` is any known social platform.\n  See `Image.Social.known_platforms/0`.","title":"Arguments - Image.Social.default_image_usage/1","ref":"Image.Social.html#default_image_usage/1-arguments"},{"type":"function","doc":"* The default image type for the platform.","title":"Returns - Image.Social.default_image_usage/1","ref":"Image.Social.html#default_image_usage/1-returns"},{"type":"function","doc":"","title":"Example - Image.Social.default_image_usage/1","ref":"Image.Social.html#default_image_usage/1-example"},{"type":"function","doc":"Returns the image types for the given\nsocial platform.","title":"Image.Social.image_usages/1","ref":"Image.Social.html#image_usages/1"},{"type":"function","doc":"* `platform` is any known social platform.\n  See `Image.Social.known_platforms/0`.","title":"Arguments - Image.Social.image_usages/1","ref":"Image.Social.html#image_usages/1-arguments"},{"type":"function","doc":"* A list of images uses available for the\n  platform.","title":"Returns - Image.Social.image_usages/1","ref":"Image.Social.html#image_usages/1-returns"},{"type":"function","doc":"","title":"Example - Image.Social.image_usages/1","ref":"Image.Social.html#image_usages/1-example"},{"type":"function","doc":"Returns a list of known social\nplatforms.","title":"Image.Social.known_platforms/0","ref":"Image.Social.html#known_platforms/0"},{"type":"function","doc":"","title":"Example - Image.Social.known_platforms/0","ref":"Image.Social.html#known_platforms/0-example"},{"type":"function","doc":"Return the map of social media image\nsizes.\n\nThe returned map of maps is of a standard form:\n\n* The first key is the platform name (ie `:twitter`)\n* The second key is the image type for the platform (ie `:profile`)\n* The third level is optional. But if it exists it must\n  have three keys: `:landscape`, `:portrait` and `:square`\n\nThe values are all of the form \"WxH\" where `W` is the\nwidth in pixels and `H` is the height in pixels.","title":"Image.Social.media_sizes/0","ref":"Image.Social.html#media_sizes/0"},{"type":"function","doc":"Resize an image for a particular social\nplatform and usage.\n\nThis function:\n\n* Resizes an image to the correct dimensions, including being\n  image aspect aware\n* Converts to the sRGB color space\n* Minimises metadata (retains only Artist and Copyright)","title":"Image.Social.resize/3","ref":"Image.Social.html#resize/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `platform` is the name of a known social\n  media platform. See `Image.Social.known_platforms/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Social.resize/3","ref":"Image.Social.html#resize/3-arguments"},{"type":"function","doc":"* `:type` is the image type within the social\n  platform for which the image should be resized. See\n  `Image.Social.image_usages/1`\n\n* All other options are passed to `Image.thumbnail!/3`.","title":"Options - Image.Social.resize/3","ref":"Image.Social.html#resize/3-options"},{"type":"function","doc":"* `{:ok, resized_image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Social.resize/3","ref":"Image.Social.html#resize/3-returns"},{"type":"function","doc":"Resize an image for a particular social\nplatform and usage.\n\nThis function:\n\n* Resizes an image to the correct dimensions, including being\n  image orientation aware\n* Converts to the sRGB color space\n* Minimises metadata (retains only Artist and Copyright)","title":"Image.Social.resize!/3","ref":"Image.Social.html#resize!/3"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`\n\n* `platform` is the name of a known social\n  media platform. See `Image.Social.known_platforms/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Social.resize!/3","ref":"Image.Social.html#resize!/3-arguments"},{"type":"function","doc":"* `:type` is the image type within the social\n  platform for which the image should be resized. See\n  `Image.Social.image_usages/1`\n\n* All other options are passed to `Image.thumbnail!/3`.","title":"Options - Image.Social.resize!/3","ref":"Image.Social.html#resize!/3-options"},{"type":"function","doc":"* `resized_image` or\n\n* Raises an exception.","title":"Returns - Image.Social.resize!/3","ref":"Image.Social.html#resize!/3-returns"},{"type":"type","doc":"The social media platform image usage.","title":"Image.Social.image_usage/0","ref":"Image.Social.html#t:image_usage/0"},{"type":"type","doc":"The known social media platforms.","title":"Image.Social.platform/0","ref":"Image.Social.html#t:platform/0"},{"type":"module","doc":"Functions for the creation of images from text.","title":"Image.Text","ref":"Image.Text.html"},{"type":"function","doc":"Adds a background to an image generated from\ntext.","title":"Image.Text.add_background/2","ref":"Image.Text.html#add_background/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` but is expected\n  to be an image generated by `Image.Text.text/2`.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background/2","ref":"Image.Text.html#add_background/2-arguments"},{"type":"function","doc":"* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_fill_opacity` is the opacity of the background. It is a\n  float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.","title":"Options - Image.Text.add_background/2","ref":"Image.Text.html#add_background/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Text.add_background/2","ref":"Image.Text.html#add_background/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background/2","ref":"Image.Text.html#add_background/2-notes"},{"type":"function","doc":"Adds a background to an image generated from\ntext returning and image or raising an exception.","title":"Image.Text.add_background!/2","ref":"Image.Text.html#add_background!/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` but is expected\n  to be an image generated by `Image.Text.text/2`.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background!/2","ref":"Image.Text.html#add_background!/2-arguments"},{"type":"function","doc":"* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_fill_opacity` is the opacity of the background. It is a\n  float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.","title":"Options - Image.Text.add_background!/2","ref":"Image.Text.html#add_background!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Text.add_background!/2","ref":"Image.Text.html#add_background!/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background!/2","ref":"Image.Text.html#add_background!/2-notes"},{"type":"function","doc":"Adds a border on an image, typically an\nimage generated from a string.","title":"Image.Text.add_background_border/2","ref":"Image.Text.html#add_background_border/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background_border/2","ref":"Image.Text.html#add_background_border/2-arguments"},{"type":"function","doc":"* `:background_stroke_color` is the colour of the outline\n  of the background. The default is \"none\",\n\n* `:background_stroke_width` is the integer size in pixels\n  of the background border. The default is `1`.\n\n* `:background_stroke_opacity` is the opacity of the background\n  string. It is a float between `0.0` and `1.0` where `0.0` means\n  transparent and `1.0` means opaque. The default is `0.7`.","title":"Options - Image.Text.add_background_border/2","ref":"Image.Text.html#add_background_border/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Text.add_background_border/2","ref":"Image.Text.html#add_background_border/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background_border/2","ref":"Image.Text.html#add_background_border/2-notes"},{"type":"function","doc":"Adds a border on an image, typically an\nimage generated from a string. Returns an\nimage or raises an exception.","title":"Image.Text.add_background_border!/2","ref":"Image.Text.html#add_background_border!/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background_border!/2","ref":"Image.Text.html#add_background_border!/2-arguments"},{"type":"function","doc":"* `:background_stroke_color` is the colour of the outline\n  of the background. The default is \"none\",\n\n* `:background_stroke_width` is the integer size in pixels\n  of the background border. The default is `1`.\n\n* `:background_stroke_opacity` is the opacity of the background\n  string. It is a float between `0.0` and `1.0` where `0.0` means\n  transparent and `1.0` means opaque. The default is `0.7`.","title":"Options - Image.Text.add_background_border!/2","ref":"Image.Text.html#add_background_border!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Text.add_background_border!/2","ref":"Image.Text.html#add_background_border!/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background_border!/2","ref":"Image.Text.html#add_background_border!/2-notes"},{"type":"function","doc":"Adds padding to a background to an image generated from\ntext.","title":"Image.Text.add_background_padding/2","ref":"Image.Text.html#add_background_padding/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` but is expected\n  to be an image generated by `Image.Text.add_background/2`.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background_padding/2","ref":"Image.Text.html#add_background_padding/2-arguments"},{"type":"function","doc":"* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_fill_opacity` is the opacity of the background. It is a\n  float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.\n\n* `:padding` is the padding in pixels between the\n  text and the edge of the background.  It can be expressed\n  as a single integer integer in which case the same padding\n  is applied to all four sides of the image.  It can also\n  be expressed as a list of two integers like `[0, 0]`.\n  The first integer will be used as the padding for the\n  left and right of the image. The second integer will be used\n  for the top and bottom of the image.  Another alternative is\n  to pass a `t:Vimage.t/0` in which case the padding will be derived\n  from the image dimensions such that the background covers the\n  whole of the image.  The default is `[0, 0]`.","title":"Options - Image.Text.add_background_padding/2","ref":"Image.Text.html#add_background_padding/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Text.add_background_padding/2","ref":"Image.Text.html#add_background_padding/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background_padding/2","ref":"Image.Text.html#add_background_padding/2-notes"},{"type":"function","doc":"Adds padding to a background to an image generated from\ntext returning an image or raising an exception.","title":"Image.Text.add_background_padding!/2","ref":"Image.Text.html#add_background_padding!/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` but is expected\n  to be an image generated by `Image.Text.add_background/2`.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.add_background_padding!/2","ref":"Image.Text.html#add_background_padding!/2-arguments"},{"type":"function","doc":"* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_fill_opacity` is the opacity of the background. It is a\n  float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.\n\n* `:padding` is the padding in pixels between the\n  text and the edge of the background.  It can be expressed\n  as a single integer integer in which case the same padding\n  is applied to all four sides of the image.  It can also\n  be expressed as a list of two integers like `[0, 0]`.\n  The first integer will be used as the padding for the\n  left and right of the image. The second integer will be used\n  for the top and bottom of the image.  Another alternative is\n  to pass a `t:Vimage.t/0` in which case the padding will be derived\n  from the image dimensions such that the background covers the\n  whole of the image.  The default is `[0, 0]`.","title":"Options - Image.Text.add_background_padding!/2","ref":"Image.Text.html#add_background_padding!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Text.add_background_padding!/2","ref":"Image.Text.html#add_background_padding!/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.add_background_padding!/2","ref":"Image.Text.html#add_background_padding!/2-notes"},{"type":"function","doc":"Creates an image from the provided text.\n\nThis function creates an image from the text\nbut does not apply a background or padding.","title":"Image.Text.simple_text/2","ref":"Image.Text.html#simple_text/2"},{"type":"function","doc":"* `string` is any string. The string will be\n  HTML-escaped to avoid malicious code injection. If you\n  are completely confident that the text is safe then\n  you can pass it by calling with `Phoenix.HTML.raw/1`\n  on the string first.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.simple_text/2","ref":"Image.Text.html#simple_text/2-arguments"},{"type":"function","doc":"* `:text_fill_color` is the fill color of the text.\n  The default is \"white\". If set to `:transparent` then\n  the text will be rendered transparently against\n  a background. A black background will be forced if a\n  `:background_fill_color` is not provided\n\n* `:dpi` sets the resolution of the text generation. The\n  default `72` which is suitable for screen output. `300`\n  may be more appropriate for printed output.\n\n* `:width` is the width of the generated text image.\n\n* `:height` is the height of the generated text image.\n\n* `:font_size` is an integer font size in pixels. The\n  default is `50`. If set to `0`, the font size will\n  be calculated to fit the text within the specified `:width`\n  and `:height`.\n\n* `:justify` is a boolean indicating whether to justify text.\n  The default is `false`.\n\n* `:letter_spacing` is the amount of space in pixels between each letter.\n  Default is `:normal`.\n\n* `:font` is any font recognised on the host system.\n  The default is \"Helvetica\". The system command `fc-list`\n  can be used to see what fonts are available.\n\n* `:font_weight` is the [font weight](https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight).\n  The alternatives are `:normal`, `:bold`, `:lighter`, `:bolder`,\n  or an integer between `1` and `1_000`. The default is `:normal`\n  which is equivalent to `400`.","title":"Options - Image.Text.simple_text/2","ref":"Image.Text.html#simple_text/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Text.simple_text/2","ref":"Image.Text.html#simple_text/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.simple_text/2","ref":"Image.Text.html#simple_text/2-notes"},{"type":"function","doc":"Creates an image from the provided text and\nreturns an image or raises an exception.\n\nThis function creates an image from the text\nbut does not apply a background or padding.","title":"Image.Text.simple_text!/2","ref":"Image.Text.html#simple_text!/2"},{"type":"function","doc":"* `string` is any string. The string will be\n  HTML-escaped to avoid malicious code injection. If you\n  are completely confident that the text is safe then\n  you can pass it by calling with `Phoenix.HTML.raw/1`\n  on the string first.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.simple_text!/2","ref":"Image.Text.html#simple_text!/2-arguments"},{"type":"function","doc":"* `:text_fill_color` is the fill color of the text.\n  The default is \"white\". If set to `:transparent` then\n  the text will be rendered transparently against\n  a background. A black background will be forced if a\n  `:background_fill_color` is not provided\n\n* `:font_size` is an integer font size in pixels. The\n  default is `50`.\n\n* `:dpi` sets the resolution of the text generation. The\n  default `72` which is suitable for screen output. `300`\n  may be more appropriate for printed output.\n\n* `:width` is the width of the generated text image.\n\n* `:height` is the height of the generated text image.\n\n* `:font_size` is an integer font size in pixels. The\n  default is `50`. If set to `0`, the font size will\n  be calculated to fit the text within the specified `:width`\n  and `:height`.\n\n* `:justify` is a boolean indicating whether to justify text.\n  The default is `false`.\n\n* `:letter_spacing` is the amount of space in pixels between each letter.\n  Default is `:normal`.\n\n* `:font` is any font recognised on the host system.\n  The default is \"Helvetica\". The system command `fc-list`\n  can be used to see what fonts are available.\n\n* `:font_weight` is the [font weight](https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight).\n  The alternatives are `:normal`, `:bold`, `:lighter`, `:bolder`,\n  or an integer between `1` and `1_000`. The default is `:normal`\n  which is equivalent to `400`.","title":"Options - Image.Text.simple_text!/2","ref":"Image.Text.html#simple_text!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Text.simple_text!/2","ref":"Image.Text.html#simple_text!/2-returns"},{"type":"function","doc":"* There is no text wrapping, justification or kerning\n  applied. This means this function is not a general\n  purpose text layout function and is suitable mostly\n  for overlaying text for emphasis over another image.\n\n* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.simple_text!/2","ref":"Image.Text.html#simple_text!/2-notes"},{"type":"function","doc":"Create a new image from the provided string and\nformatting options.\n\n`text/2` creates an image with the\nfollowing steps:\n\n* Render the text\n* Add an optional background color\n* Expand the background according to the required padding\n\nThe text can be rendered as a positive (the default)\nin which an image of the provided string is rendered\nin the provided font, weight, size, fill color and\nstroke color.\n\nIt can also be rendered transparently in which case\na background color is required against which the\ntransparent text can be composed. If not provided,\nthe background color will be black.\n\nAfter rendering the text and composing it against\nthe (optional) background, the background can\nbe expanded to provide some padding between the\ntext and any base image onto which it is later\ncomposed.  The default no padding.","title":"Image.Text.text/2","ref":"Image.Text.html#text/2"},{"type":"function","doc":"The text string can take advantage of\n[Pango markup language](https://docs.gtk.org/Pango/pango_markup.html) that\nprovides some simple HTML-like text transformation\ncapabilities. Note that some of the options to `Image.Text.text/2`,\nsuch as `:font_weight` and `:letter_spacing` operate by adding markup\nto the provided string.","title":"The Pango markup language - Image.Text.text/2","ref":"Image.Text.html#text/2-the-pango-markup-language"},{"type":"function","doc":"* `string` is any string. The string will be\n  HTML-escaped to avoid malicious code injection. If you\n  are completely confident that the text is safe then\n  you can pass it by calling with `Phoenix.HTML.raw/1`\n  on the string first.\n\n* `options` is a `t:Keyword.t/0` list of options.","title":"Arguments - Image.Text.text/2","ref":"Image.Text.html#text/2-arguments"},{"type":"function","doc":"See also the options for `Image.Text.simple_text/2` which\nis ultimately called by this function.\n\n* `:font` is any font recognised on the host system.\n  The default is\"Helvetica\".\n\n* `:font_size` is an integer font size in pixels. The\n  default is `50`.\n\n* `:dpi` sets the resolution of the text generation. The\n  default `72` which is suitable for screen output. `300`\n  may be more appropriate for printed output.\n\n* `:font_weight` is the [font weight](https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight).\n  The alternatives `:normal`, `:bold`, `:lighter`, `:bolder`,\n  or an integer between `1` and `1_000`. The default is `:normal`\n  which is equivalent to `400`.\n\n* `:text_fill_color` is the fill color of the text.\n  The default is \"white\". If set to `:transparent` then\n  the text will be rendered transparently against\n  a background. A black background will be forced if a\n  `:background_fill_color` is not provided\n\n* `:background_fill_opacity` is the opacity of the background fill.\n  It is a float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.\n\n* `:padding` is the padding in pixels between the\n  text and the edge of the background.  It can be expressed\n  as a single integer integer in which case the same padding\n  is applied to all four sides of the image.  It can also\n  be expressed as a list of two integers like `[0, 0]`.\n  The first integer will be used as the padding for the\n  left and right of the image. The second integer will be used\n  for the top and bottom of the image.  Another alternative is\n  to pass a `t:Vimage.t/0` in which case the padding will be derived\n  from the image dimensions such that the background covers the\n  whole of the image.  The default is `[0, 0]`.\n\n* `:align` indicates how multiple lines of text are aligned.\n  The options are `:left`, `:right` and `:center`. The default\n  is `:left`.\n\n* `:letter_spacing` is the amount of space in pixels between each letter.\n  Default is `:normal`.\n\n* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_stroke_color` is the colour of the outline\n  of the background. The default is \"none\",\n\n* `:background_stroke_width` is the integer size in pixels\n  of the background border. The default is `1`.\n\n* `:background_stroke_opacity` is the opacity of the background\n  string. It is a float between `0.0` and `1.0` where `0.0` means\n  transparent and `1.0` means opaque. The default is `0.7`.\n\n* `:width` is the maximum width of the generated text image in pixels. The\n  default is calculated by the rendering engine based upon the font\n  and other options.\n\n* `:height` is the maximum height of the generated text image in pixels. The\n  default is calculated by the rendering engine based upon the font\n  and other options.\n\n* `:x` is the horizontal location of the text on its background.\n  The value is either a non-negative integer or one of `:left`,\n  `:right` or `:center`. The default is `:center` if `:width` is\n  specified and `:left` if it is not.\n\n* `:y` is the vertical location of the text on its background.\n  The value is either a non-negative integer or one of `:top`,\n  `:middle` or `:bottom`. The default is `:middle` if `:height`\n  is specified and `:top` if it is not.","title":"Options - Image.Text.text/2","ref":"Image.Text.html#text/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`","title":"Returns - Image.Text.text/2","ref":"Image.Text.html#text/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.text/2","ref":"Image.Text.html#text/2-notes"},{"type":"function","doc":"Create a new image from the provided string and\nformatting options returning an image or raising\nan exception.\n\n`text!/2` creates an image with the\nfollowing steps:\n\n* Render the text\n* Add an optional background color\n* Expand the background according to the required padding\n\nThe text can be rendered as a positive (the default)\nin which an image of the provided string is rendered\nin the provided font, weight, size, fill color and\nstroke color.\n\nIt can also be rendered transparently in which case\na background color is required against which the\ntransparent text can be composed. If not provided,\nthe background color will be black.\n\nAfter rendering the text and composing it against\nthe (optional) background, the background can\nbe expanded to provide some padding between the\ntext and any base image onto which it is later\ncomposed.  The default no padding.","title":"Image.Text.text!/2","ref":"Image.Text.html#text!/2"},{"type":"function","doc":"The text string can take advantage of\n[Pango markup language](https://docs.gtk.org/Pango/pango_markup.html) that\nprovides some simple HTML-like text transformation\ncapabilities. Note that some of the options to `Image.Text.text/2`,\nsuch as `:font_weight` and `:letter_spacing` operate by adding markup\nto the provided string.","title":"The Pango markup language - Image.Text.text!/2","ref":"Image.Text.html#text!/2-the-pango-markup-language"},{"type":"function","doc":"* `string` is any string. The string will be\n  HTML-escaped to avoid malicious code injection. If you\n  are completely confident that the text is safe then\n  you can pass it by calling with `Phoenix.HTML.raw/1`\n  on the string first.\n\n* `options` is a `t:Keyword.t/0` list of options","title":"Arguments - Image.Text.text!/2","ref":"Image.Text.html#text!/2-arguments"},{"type":"function","doc":"See also the options for `Image.Text.simple_text/2` which\nis ultimately called by this function.\n\n* `:font` is any font recognised on the host system.\n  The default is\"Helvetica\".\n\n* `:font_size` is an integer font size in pixels. The\n  default is `50`.\n\n* `:dpi` sets the resolution of the text generation. The\n  default `72` which is suitable for screen output. `300`\n  may be more appropriate for printed output.\n\n* `:font_weight` is the [font weight](https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight).\n  The alternatives `:normal`, `:bold`, `:lighter`, `:bolder`,\n  or an integer between `1` and `1_000`. The default is `:normal`\n  which is equivalent to `400`.\n\n* `:text_fill_color` is the fill color of the text.\n  The default is \"white\". If set to `:transparent` then\n  the text will be rendered transparently against\n  a background. A black background will be forced if a\n  `:background_fill_color` is not provided\n\n* `:background_fill_opacity` is the opacity of the background fill.\n  It is a float between `0.0` and `1.0` where `0.0` means transparent\n  and `1.0` means opaque. The default is `0.7`.\n\n* `:padding` is the padding in pixels between the\n  text and the edge of the background.  It can be expressed\n  as a single integer integer in which case the same padding\n  is applied to all four sides of the image.  It can also\n  be expressed as a list of two integers like `[0, 0]`.\n  The first integer will be used as the padding for the\n  left and right of the image. The second integer will be used\n  for the top and bottom of the image.  Another alternative is\n  to pass a `t:Vimage.t/0` in which case the padding will be derived\n  from the image dimensions such that the background covers the\n  whole of the image.  The default is `[0, 0]`.\n\n* `:align` indicates how multiple lines of text are aligned.\n  The options are `:left`, `:right` and `:center`. The default\n  is `:left`.\n\n* `:letter_spacing` is the amount of space in pixels between each letter.\n  Default is `:normal`.\n\n* `:background_fill_color` is the background fill color behind\n  the text. The default is `:none` which indicates no\n  background. Note that if\n\n* `:background_stroke_color` is the colour of the outline\n  of the background. The default is \"none\",\n\n* `:background_stroke_width` is the integer size in pixels\n  of the background border. The default is `1`.\n\n* `:background_stroke_opacity` is the opacity of the background\n  string. It is a float between `0.0` and `1.0` where `0.0` means\n  transparent and `1.0` means opaque. The default is `0.7`.\n\n* `:width` is the maximum width of the generated text image in pixels. The\n  default is calculated by the rendering engine based upon the font\n  and other options.\n\n* `:height` is the maximum height of the generated text image in pixels. The\n  default is calculated by the rendering engine based upon the font\n  and other options.\n\n* `:x` is the horizontal location of the text on its background.\n  The value is either a non-negative integer or one of `:left`,\n  `:right` or `:center`. The default is `:center` if `:width` is\n  specified and `:left` if it is not.\n\n* `:y` is the vertical location of the text on its background.\n  The value is either a non-negative integer or one of `:top`,\n  `:middle` or `:bottom`. The default is `:middle` if `:height`\n  is specified and `:top` if it is not.","title":"Options - Image.Text.text!/2","ref":"Image.Text.html#text!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception","title":"Returns - Image.Text.text!/2","ref":"Image.Text.html#text!/2-returns"},{"type":"function","doc":"* Colors may be any valid\n  [CSS color name](https://www.w3.org/wiki/CSS/Properties/color/keywords) or\n  a six hexadecimal digit string prefixed with `#`. For example\n  `#FF00FF` for the color \"Fuchsia\".","title":"Notes - Image.Text.text!/2","ref":"Image.Text.html#text!/2-notes"},{"type":"module","doc":"Implements functions to extract frames froma video file\nas images using [eVision](https://hex.pm/packages/evision). The\nimplementation is based upon\n[OpenCV Video Capture](https://docs.opencv.org/3.4/d0/da7/videoio_overview.html).\n\nImages can be extracted by frame number of number of milliseconds with\n`Image.Video.image_from_video/2`.\n\nIn order to extract images the video file must first be\nopened with `Image.Video.open/1`. At the end of processing the video\nfile should be closed with `Image.Video.close/1`.\n\nThis process can be wrapped by `Image.Video.with_video/2` which will\nopen a video file, execute a function (passing it the video reference) and\nclosing the video file at the end of the function.","title":"Image.Video","ref":"Image.Video.html"},{"type":"module","doc":"This module is only available if the optional dependency\n[eVision](https://hex.pm/packages/evision) is configured in\n`mix.exs`.","title":"Note - Image.Video","ref":"Image.Video.html#module-note"},{"type":"function","doc":"Returns a boolean indicating if the specified\nbackend is available (configured and\navailable for use).","title":"Image.Video.available_backend?/1","ref":"Image.Video.html#available_backend?/1"},{"type":"function","doc":"Returns a list of available (configured and\navailable for use) backend video processors.\n\nSee the [OpenCV documentation](https://docs.opencv.org/4.x/d4/d15/group__videoio__flags__base.html#ga023786be1ee68a9105bf2e48c700294d)\nfor more information on video processor backends.","title":"Image.Video.available_backends/0","ref":"Image.Video.html#available_backends/0"},{"type":"function","doc":"Closes a video.","title":"Image.Video.close/1","ref":"Image.Video.html#close/1"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.","title":"Arguments - Image.Video.close/1","ref":"Image.Video.html#close/1-arguments"},{"type":"function","doc":"* `{:ok, closed_video}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Video.close/1","ref":"Image.Video.html#close/1-returns"},{"type":"function","doc":"iex> {:ok, video} = Image.Video.open \"./test/support/video/video_sample.mp4\"\n    iex> Image.Video.close(video)","title":"Example - Image.Video.close/1","ref":"Image.Video.html#close/1-example"},{"type":"function","doc":"Closes a video or raises an exception.","title":"Image.Video.close!/1","ref":"Image.Video.html#close!/1"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.","title":"Arguments - Image.Video.close!/1","ref":"Image.Video.html#close!/1-arguments"},{"type":"function","doc":"* `closed_video` or\n\n* raises an exception.","title":"Returns - Image.Video.close!/1","ref":"Image.Video.html#close!/1-returns"},{"type":"function","doc":"iex> {:ok, video} = Image.Video.open \"./test/support/video/video_sample.mp4\"\n    iex> Image.Video.close!(video)","title":"Example - Image.Video.close!/1","ref":"Image.Video.html#close!/1-example"},{"type":"function","doc":"Extracts a frame from a video and returns\nan image.\n\nAfter the image is extracted the play head\nin the video file is advanced one frame. That is,\nsuccessive calls to `Image.Video.image_from_video/2`\nwill return successive frames - not the same frame.","title":"Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`\n\n* `options` is a keyword list of options. The defalt","title":"Arguments - Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2-arguments"},{"type":"function","doc":"* `unit` is either `:frame` or `:millisecond` with a\n  non-negative integer offset. For example `frame: 3`.\n  The default is `[]` which means that no seek is performed\n  and the extracted image is taken from the current\n  position in the file or video stream. Note that seeking\n  is not guaranteed to be accurate. If frame accuracy is\n  required the recommended process is:\n\n  * Open the video file with `Image.Video.open/1`\n  * Scrub forward to the required freame with `Image.Video.scrub/2`\n  * Then capture the frame with `Image.Video.image_from_video/1`","title":"Options - Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2-options"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2-returns"},{"type":"function","doc":"Seeking cannot be performed on image streams such as\nwebcams.  Therefore no options may be provided when\nextracting images from an image stream.","title":"Notes - Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2-notes"},{"type":"function","doc":"iex> {:ok, video} = Image.Video.open(\"./test/support/video/video_sample.mp4\")\n    iex> {:ok, _image} = Image.Video.image_from_video(video)\n    iex> {:ok, _image} = Image.Video.image_from_video(video, frame: 0)\n    iex> {:ok, _image} = Image.Video.image_from_video(video, millisecond: 1_000)\n    iex> Image.Video.image_from_video(video, frame: -1)\n    {:error, \"Offset for :frame must be a non-negative integer. Found -1\"}\n    iex> Image.Video.image_from_video(video, frame: 500)\n    {:error, \"Offset for :frame is too large\"}","title":"Examples - Image.Video.image_from_video/2","ref":"Image.Video.html#image_from_video/2-examples"},{"type":"function","doc":"Extracts a frame from a video and returns\nan image or raises an exception.\n\nAfter the image is extracted the play head\nin the video file is advanced one frame. That is,\nsuccessive calls to `Image.Video.image_from_video/2`\nwill return successive frames - not the same frame.","title":"Image.Video.image_from_video!/2","ref":"Image.Video.html#image_from_video!/2"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Video.image_from_video!/2","ref":"Image.Video.html#image_from_video!/2-arguments"},{"type":"function","doc":"* `unit` is either `:frame` or `:millisecond` with a\n  non-negative integer offset. For example `frame: 3`.\n  The default is `[]` which means that no seek is performed\n  and the extracted image is taken from the current\n  position in the file or video stream. Note that seeking\n  is not guaranteed to be accurate. If frame accuracy is\n  required the recommended process is:\n\n  * Open the video file with `Image.Video.open/1`\n  * Scrub forward to the required freame with `Image.Video.scrub/2`\n  * Then capture the frame with `Image.Video.image_from_video/1`","title":"Options - Image.Video.image_from_video!/2","ref":"Image.Video.html#image_from_video!/2-options"},{"type":"function","doc":"* `image` or\n\n* raises an exception.","title":"Returns - Image.Video.image_from_video!/2","ref":"Image.Video.html#image_from_video!/2-returns"},{"type":"function","doc":"Seeking cannot be performed on image streams such as\nwebcams.  Therefore no options may be provided when\nextracting images from an image stream.","title":"Notes - Image.Video.image_from_video!/2","ref":"Image.Video.html#image_from_video!/2-notes"},{"type":"macro","doc":"Guards that a frame offset is valid for a video","title":"Image.Video.is_frame/2","ref":"Image.Video.html#is_frame/2"},{"type":"macro","doc":"Guards that a stream id is valid for a video stream","title":"Image.Video.is_stream/1","ref":"Image.Video.html#is_stream/1"},{"type":"macro","doc":"Guards that a millisecond count is valid for a video","title":"Image.Video.is_valid_millis/3","ref":"Image.Video.html#is_valid_millis/3"},{"type":"function","doc":"Returns a boolean indicating if the specified\nbackend is known (valid but not necessarily\navailable for use in the current OpenCV configuration).","title":"Image.Video.known_backend?/1","ref":"Image.Video.html#known_backend?/1"},{"type":"function","doc":"iex> Image.Video.known_backend?(:avfoundation)\n    true\n    iex> Image.Video.known_backend?(:invalid)\n    false\n    iex> Image.Video.known_backend?(1200)\n    true\n    iex> Image.Video.known_backend?(-1)\n    false","title":"Examples - Image.Video.known_backend?/1","ref":"Image.Video.html#known_backend?/1-examples"},{"type":"function","doc":"Returns a list of known (valid but not necessarily\navailable for use in the current OpenCV configuration)\nbackend video processors.\n\nSee the [OpenCV documentation](https://docs.opencv.org/4.x/d4/d15/group__videoio__flags__base.html#ga023786be1ee68a9105bf2e48c700294d)\nfor more information on video processor backends.","title":"Image.Video.known_backends/0","ref":"Image.Video.html#known_backends/0"},{"type":"function","doc":"iex> Image.Video.known_backends() |> Enum.sort()\n    [:android, :any, :aravis, :avfoundation, :cmu1394, :dc1394, :dshow, :ffmpeg,\n     :fireware, :firewire, :giganetix, :gphoto2, :gstreamer, :ieee1394, :images,\n     :intel_mfx, :intelperc, :msmf, :obsensor, :opencv_mjpeg, :openni, :openni2,\n     :openni2_astra, :openni2_asus, :openni_asus, :pvapi, :qt, :realsense, :ueye,\n     :unicap, :v4l, :v4l2, :vfw, :winrt, :xiapi, :xine]","title":"Example - Image.Video.known_backends/0","ref":"Image.Video.html#known_backends/0-example"},{"type":"function","doc":"Opens a video file or video stream for\nframe extraction.","title":"Image.Video.open/2","ref":"Image.Video.html#open/2"},{"type":"function","doc":"* `filename_or_stream` is the filename of a video file\n  or the OpenCV representation of a video stream as\n  an integer.  It may also be `:default_camera` to open\n  the default camera if there is one.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.Video.open/2","ref":"Image.Video.html#open/2-arguments"},{"type":"function","doc":"* `:backend` specifies the backend video processing\n  system to be used. The default is `:any` which means\n  that the first available backend in the current OpenCV\n  configuration will be used.  The available backends\n  can be returned by `Image.Video.available_backends/0`.","title":"Options - Image.Video.open/2","ref":"Image.Video.html#open/2-options"},{"type":"function","doc":"* `{:ok, video}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Video.open/2","ref":"Image.Video.html#open/2-returns"},{"type":"function","doc":"* The video `t:VideoCapture.t/0` struct that is returned\n  includes metadata fields for frame rate (:fps), frame width\n  (:frame_width), frame height (:frame_height) and frame count\n  (:frame_count). *Note that frame count is an approximation due to\n  issues in the underlying OpenCV*.","title":"Note - Image.Video.open/2","ref":"Image.Video.html#open/2-note"},{"type":"function","doc":"iex> Image.Video.open \"./test/support/video/video_sample.mp4\"\n    iex> {:ok, camera_video} = Image.Video.open(:default_camera)\n    iex> Image.Video.close(camera_video)","title":"Example - Image.Video.open/2","ref":"Image.Video.html#open/2-example"},{"type":"function","doc":"Opens a video file for frame extraction or\nraises an exception.","title":"Image.Video.open!/1","ref":"Image.Video.html#open!/1"},{"type":"function","doc":"* `filename` is the filename of a video file.\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Image.Video.open!/1","ref":"Image.Video.html#open!/1-arguments"},{"type":"function","doc":"* `:backend` specifies the backend video processing\n  system to be used. The default is `:any` which means\n  that the first available backend in the current OpenCV\n  configuration will be used.  The available backends\n  can be returned by `Image.Video.available_backends/0`.","title":"Options - Image.Video.open!/1","ref":"Image.Video.html#open!/1-options"},{"type":"function","doc":"* `video` or\n\n* raises an exception.","title":"Returns - Image.Video.open!/1","ref":"Image.Video.html#open!/1-returns"},{"type":"function","doc":"iex> Image.Video.open! \"./test/support/video/video_sample.mp4\"","title":"Example - Image.Video.open!/1","ref":"Image.Video.html#open!/1-example"},{"type":"function","doc":"Scrubs a video forward by a number of frames.\n\nIn OpenCV (the underlying video library used by\n`Image.Video`), seeking to a specified frame is not\nframe accurate.  This function moves the video\nplay head forward frame by frame and is therefore\na frame accurate way of moving the the video head\nforward.","title":"Image.Video.scrub/2","ref":"Image.Video.html#scrub/2"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.\n\n* `frames` is a positive integer number of frames\n  to scrub forward.","title":"Arguements - Image.Video.scrub/2","ref":"Image.Video.html#scrub/2-arguements"},{"type":"function","doc":"* `{:ok, frames_scrubbed}`. `frames_scrubbed` may\n  be less than the number of requested frames. This may\n  happen of the end of the video stream is reached, or\n\n* `{:error, reason}`.","title":"Returns - Image.Video.scrub/2","ref":"Image.Video.html#scrub/2-returns"},{"type":"function","doc":"iex> {:ok, video} = Image.Video.open \"./test/support/video/video_sample.mp4\"\n    iex> {:ok, 10} = Image.Video.scrub(video, 10)\n    iex>  Image.Video.scrub(video, 100_000_000)\n    {:ok, 161}","title":"Examples - Image.Video.scrub/2","ref":"Image.Video.html#scrub/2-examples"},{"type":"function","doc":"Seeks the video head to a specified frame offset\nor millisecond offset.\n\nNote that seeking a video format is supported,\nseeking a live video stream (such as from a\nwebcam) is not supported and will return an\nerror.","title":"Image.Video.seek/2","ref":"Image.Video.html#seek/2"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Video.seek/2","ref":"Image.Video.html#seek/2-arguments"},{"type":"function","doc":"* `unit` is either `:frame` or `:millisecond` with a\n  non-negative integer offset. For example `frame: 3`.","title":"Options - Image.Video.seek/2","ref":"Image.Video.html#seek/2-options"},{"type":"function","doc":"* `{:ok, video}` or\n\n* `{:error, reason}`","title":"Returns - Image.Video.seek/2","ref":"Image.Video.html#seek/2-returns"},{"type":"function","doc":"Seeking cannot be performed on image streams such as\nwebcams.  Therefore no options may be provided when\nextracting images from an image stream.","title":"Notes - Image.Video.seek/2","ref":"Image.Video.html#seek/2-notes"},{"type":"function","doc":"Seeking is not [frame accurate](https://github.com/opencv/opencv/issues/9053)!","title":"Warning - Image.Video.seek/2","ref":"Image.Video.html#seek/2-warning"},{"type":"function","doc":"iex> {:ok, video} = Image.Video.open(\"./test/support/video/video_sample.mp4\")\n    iex> {:ok, _image} = Image.Video.seek(video, frame: 0)\n    iex> {:ok, _image} = Image.Video.seek(video, millisecond: 1_000)\n    iex> Image.Video.seek(video, frame: -1)\n    {:error, \"Offset for :frame must be a non-negative integer. Found -1\"}","title":"Examples - Image.Video.seek/2","ref":"Image.Video.html#seek/2-examples"},{"type":"function","doc":"Seeks the video head to a specified frame offset\nor millisecond offset.\n\nNote that seeking a video format is supported,\nseeking a live video stream (such as from a\nwebcam) is not supported and will return an\nerror.","title":"Image.Video.seek!/2","ref":"Image.Video.html#seek!/2"},{"type":"function","doc":"* `video` is any `t:VideoCapture.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Video.seek!/2","ref":"Image.Video.html#seek!/2-arguments"},{"type":"function","doc":"* `unit` is either `:frame` or `:millisecond` with a\n  non-negative integer offset. For example `frame: 3`.","title":"Options - Image.Video.seek!/2","ref":"Image.Video.html#seek!/2-options"},{"type":"function","doc":"* `{:ok, video}` or\n\n* `{:error, reason}`.","title":"Returns - Image.Video.seek!/2","ref":"Image.Video.html#seek!/2-returns"},{"type":"function","doc":"Seeking cannot be performed on image streams such as\nwebcams.  Therefore no options may be provided when\nextracting images from an image stream.","title":"Notes - Image.Video.seek!/2","ref":"Image.Video.html#seek!/2-notes"},{"type":"function","doc":"Returns video file or live video as a `t:Enumerable.t/0`\nstream.\n\nThis allows a video file or live video to be streamed\nfor processing like any other enumerable.","title":"Image.Video.stream!/2","ref":"Image.Video.html#stream!/2"},{"type":"function","doc":"* `filename_or_stream` is either a pathname on the\n  current system, a non-negative integer representing a\n  video stream or `:default_camera` representing the\n  stream for the default system camera. It can also\n  be a `t:VideoCapture.t/0` representing a\n  video file or stream that is already opened (this is the\n  preferred approach).\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Video.stream!/2","ref":"Image.Video.html#stream!/2-arguments"},{"type":"function","doc":"Only one of the following options can be provided. No\noptions means the entire video will be streamed frame\nby frame.\n\n* `:frame` is a `t:Range.t/0` representing the range\n  of frames to be extracted. `:frames` can only be specified\n  for video files, not for video streams. For example,\n  `frames: 10..100/2` will produce a stream of images that\n  are every second image between the frame offsets `10` and `100`.\n\n* `:millisecond` is a `t:Range.t/0` representing the range\n  of milliseconds to be extracted. `:millisecond` can only\n  be specified for video files, not for video streams. For example,\n  `millisecond: 1000..100000/2` will produce a stream of images\n  that are every second image between the millisecond offsets of `1_000`\n  and `100_000`.","title":"Options - Image.Video.stream!/2","ref":"Image.Video.html#stream!/2-options"},{"type":"function","doc":"* A `t:Enumerable.t/0` that can be used with functions in\n  the `Stream` and `Enum` modules to lazily enumerate images\n  extracted from a video stream.","title":"Returns - Image.Video.stream!/2","ref":"Image.Video.html#stream!/2-returns"},{"type":"function","doc":"# Extract every second frame starting at the\n    # first frame and ending at the last frame.\n    iex> \"./test/support/video/video_sample.mp4\"\n    ...> |> Image.Video.stream!(frame: 0..-1//2)\n    ...> |> Enum.to_list()\n    ...> |> Enum.count()\n    86","title":"Example - Image.Video.stream!/2","ref":"Image.Video.html#stream!/2-example"},{"type":"function","doc":"Opens a video file, calls the given function with the video\nreference and closes the video after the function returns.","title":"Image.Video.with_video/2","ref":"Image.Video.html#with_video/2"},{"type":"function","doc":"* `filename` is the filename of a video file","title":"Arguments - Image.Video.with_video/2","ref":"Image.Video.html#with_video/2-arguments"},{"type":"function","doc":"* `{:ok, video}` or\n\n* `{:error, reason}`","title":"Returns - Image.Video.with_video/2","ref":"Image.Video.html#with_video/2-returns"},{"type":"function","doc":"iex> Image.Video.with_video \"./test/support/video/video_sample.mp4\", fn video ->\n    ...>  Image.Video.image_from_video(video, 1)\n    ...> end","title":"Example - Image.Video.with_video/2","ref":"Image.Video.html#with_video/2-example"},{"type":"type","doc":"The valid options for Image.Video.seek/2, Image.Video.image_from_video/2","title":"Image.Video.seek_options/0","ref":"Image.Video.html#t:seek_options/0"},{"type":"type","doc":"The representation of a video stream","title":"Image.Video.stream_id/0","ref":"Image.Video.html#t:stream_id/0"},{"type":"module","doc":"Functions to convert from/to YUV (YCbCr) encoding and BT.601/BT.709\ncolorspaces and sRGB images.\n\nThe following YUV ([YCbCr](https://en.wikipedia.org/wiki/YCbCr)) binary\nformats are supported:\n\n* Planar frame types only (not packed frames).\n\n* `4:4:4`, `4:2:2` and `4:2:0` encodings.\n\n* [BT.601](https://en.wikipedia.org/wiki/Rec._601) and\n  [BT.709](https://en.wikipedia.org/wiki/Rec._709) colorspaces.\n\nPerformance profiling indicates this implementation is not suitable\nfor real time frame processing of YUV images.","title":"Image.YUV","ref":"Image.YUV.html"},{"type":"function","doc":"Deocdes a raw YUV binary into `[y, u, v]` planes\nwhere each plane is a binary.","title":"Image.YUV.decode/4","ref":"Image.YUV.html#decode/4"},{"type":"function","doc":"* `binary` is a binary representation of a YUV image.\n\n* `width` is the width of the image encoded in `yuv`.\n\n* `height` is the height of the image encoded in `yuv`.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420` representing how `yuv` is encoded.","title":"Arguments - Image.YUV.decode/4","ref":"Image.YUV.html#decode/4-arguments"},{"type":"function","doc":"* `{:ok, [y, u, v]}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.decode/4","ref":"Image.YUV.html#decode/4-returns"},{"type":"function","doc":"Encodes an image that is in a YUV colorspace to\nraw YUV data that is a list of the three planes, each a\nbinary.\n\nThe data is always written in a planar format.","title":"Image.YUV.encode/2","ref":"Image.YUV.html#encode/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` that is in a YUV\n  colorspace such as that returned from `Image.YUV.new_from_file/5`\n  or `Image.YUV.new_from_binary/5`.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420` representing how `yuv` is to be encoded.","title":"Arguments - Image.YUV.encode/2","ref":"Image.YUV.html#encode/2-arguments"},{"type":"function","doc":"* `{:ok, [y, u, v]}` or\n\n* `{:error, Image.error_message()}`.","title":"Returns - Image.YUV.encode/2","ref":"Image.YUV.html#encode/2-returns"},{"type":"function","doc":"Converts raw YUV data into an RGB image.\n\nThe data is assumed, and required to be in:\n\n* Planar format\n* 8-bit color depth","title":"Image.YUV.new_from_binary/5","ref":"Image.YUV.html#new_from_binary/5"},{"type":"function","doc":"* `binary` is raw YUV data as a binary.\n\n* `width` is the width of the image encoded in\n  the YUV data.\n\n* `height` is the height of the image encoded in\n  the YUV data.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709`.","title":"Arguments - Image.YUV.new_from_binary/5","ref":"Image.YUV.html#new_from_binary/5-arguments"},{"type":"function","doc":"* `{:ok, rgb_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.new_from_binary/5","ref":"Image.YUV.html#new_from_binary/5-returns"},{"type":"function","doc":"Converts the raw YUV data in a `.yuv` file\ninto an RGB image.\n\nThe data is assumed, and required to be in:\n\n* Planar format\n* 8-bit color depth","title":"Image.YUV.new_from_file/5","ref":"Image.YUV.html#new_from_file/5"},{"type":"function","doc":"* `path` is any accessible file system path.\n\n* `width` is the width of the image encoded in\n  the YUV data.\n\n* `height` is the height of the image encoded in\n  the YUV data.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709`.","title":"Arguments - Image.YUV.new_from_file/5","ref":"Image.YUV.html#new_from_file/5-arguments"},{"type":"function","doc":"* `{:ok, rgb_image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.new_from_file/5","ref":"Image.YUV.html#new_from_file/5-returns"},{"type":"function","doc":"Convert an image in an YUV colorspace and convert it to RGB\ncolorspace.","title":"Image.YUV.to_rgb/2","ref":"Image.YUV.html#to_rgb/2"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0` that is in a YUV\n  colorspace such as that returned from `Image.YUV.new_from_file/5`\n  or `Image.YUV.new_from_binary/5`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709` that represents the colorspace of `image` before\n  conversion.","title":"Arguments - Image.YUV.to_rgb/2","ref":"Image.YUV.html#to_rgb/2-arguments"},{"type":"function","doc":"Takes the `[y, u, v]` planes and converts them to\nan RGB image.","title":"Image.YUV.to_rgb/5","ref":"Image.YUV.html#to_rgb/5"},{"type":"function","doc":"* `yuv` is a list of three binaries representing the `Y`,\n  `U` and `V` planes. Such a list is returned from\n  `Image.YUV.to_yuv/3` and from `Image.YUV.encode/2`.\n\n* `width` is the width of the image encoded in `yuv`.\n\n* `height` is the height of the image encoded in `yuv`.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420` representing how `yuv` is encoded.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709` that represents the colorspace of `image` before\n  conversion.","title":"Arguments - Image.YUV.to_rgb/5","ref":"Image.YUV.html#to_rgb/5-arguments"},{"type":"function","doc":"* `{:ok, image}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.to_rgb/5","ref":"Image.YUV.html#to_rgb/5-returns"},{"type":"function","doc":"Converts an image to raw YUV data as\na binary.","title":"Image.YUV.to_yuv/3","ref":"Image.YUV.html#to_yuv/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709`.","title":"Arguments - Image.YUV.to_yuv/3","ref":"Image.YUV.html#to_yuv/3-arguments"},{"type":"function","doc":"* `{:ok, [y, u, v]}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.to_yuv/3","ref":"Image.YUV.html#to_yuv/3-returns"},{"type":"function","doc":"Writes an image to a YUV raw binary.","title":"Image.YUV.write_to_binary/3","ref":"Image.YUV.html#write_to_binary/3"},{"type":"function","doc":"* `image` is any `t:Vimage.t/0`.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709`.","title":"Arguments - Image.YUV.write_to_binary/3","ref":"Image.YUV.html#write_to_binary/3-arguments"},{"type":"function","doc":"* `{:ok, yuv_binary}` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.write_to_binary/3","ref":"Image.YUV.html#write_to_binary/3-returns"},{"type":"function","doc":"Writes an image to a YUV file as raw YUV data.\n\nIt is recommeneded, but not required, that the path\nname use a `.yuv` suffix.","title":"Image.YUV.write_to_file/4","ref":"Image.YUV.html#write_to_file/4"},{"type":"function","doc":"* `path` is any accessible file system path.\n\n* `encoding` is one of `:C444`, `:C422` or\n  `:C420`.\n\n* `colorspace` is one of `:bt601` (the default) or\n  `:bt709`.","title":"Arguments - Image.YUV.write_to_file/4","ref":"Image.YUV.html#write_to_file/4-arguments"},{"type":"function","doc":"* `:ok` or\n\n* `{:error, reason}`.","title":"Returns - Image.YUV.write_to_file/4","ref":"Image.YUV.html#write_to_file/4-returns"},{"type":"type","doc":"YUV colorspace","title":"Image.YUV.yuv_colorspace/0","ref":"Image.YUV.html#t:yuv_colorspace/0"},{"type":"type","doc":"YUV encoding","title":"Image.YUV.yuv_encoding/0","ref":"Image.YUV.html#t:yuv_encoding/0"},{"type":"type","doc":"YUV data as a three-element list of binaries","title":"Image.YUV.yuv_list/0","ref":"Image.YUV.html#t:yuv_list/0"},{"type":"module","doc":"Functions to extract and interpret image EXIF\ndata.","title":"Image.Exif","ref":"Image.Exif.html"},{"type":"function","doc":"Extract EXIF data from a binary blob.","title":"Image.Exif.extract_exif/1","ref":"Image.Exif.html#extract_exif/1"},{"type":"function","doc":"","title":"Image.Exif.field/1","ref":"Image.Exif.html#field/1"},{"type":"function","doc":"","title":"Image.Exif.read_exif/2","ref":"Image.Exif.html#read_exif/2"},{"type":"type","doc":"","title":"Image.Exif.context/0","ref":"Image.Exif.html#t:context/0"},{"type":"type","doc":"","title":"Image.Exif.t/0","ref":"Image.Exif.html#t:t/0"},{"type":"type","doc":"","title":"Image.Exif.value/0","ref":"Image.Exif.html#t:value/0"},{"type":"module","doc":"Functions to extract and interpret image XMP\ndata.","title":"Image.Xmp","ref":"Image.Xmp.html"},{"type":"function","doc":"","title":"Image.Xmp.extract_xmp/1","ref":"Image.Xmp.html#extract_xmp/1"},{"type":"module","doc":"Helper functions to simplify rendering images in Kino.","title":"Image.Kino","ref":"Image.Kino.html"},{"type":"function","doc":"Renders an image in [Kino](https://hex.pm/packages/kino),","title":"Image.Kino.show/2","ref":"Image.Kino.html#show/2"},{"type":"function","doc":"* `image` is any `t:Vix.Vips.Image.t/0`.\n\n* `options` is a keyword list of options.","title":"Arguments - Image.Kino.show/2","ref":"Image.Kino.html#show/2-arguments"},{"type":"function","doc":"* `:max_height` determines the maximum height for the\n  rendered image. The aspect ratio of the rendered\n  image is unchanged.  The default is `200`.","title":"Options - Image.Kino.show/2","ref":"Image.Kino.html#show/2-options"},{"type":"function","doc":"* `maybe_resized_image` of type `t:Kino.Image.t/0`.","title":"Returns - Image.Kino.show/2","ref":"Image.Kino.html#show/2-returns"},{"type":"module","doc":"Options and option validation for `Image.avatar/2`.","title":"Image.Options.Avatar","ref":"Image.Options.Avatar.html"},{"type":"function","doc":"","title":"Image.Options.Avatar.validate_options/1","ref":"Image.Options.Avatar.html#validate_options/1"},{"type":"type","doc":"","title":"Image.Options.Avatar.avatar_option/0","ref":"Image.Options.Avatar.html#t:avatar_option/0"},{"type":"type","doc":"","title":"Image.Options.Avatar.avatar_options/0","ref":"Image.Options.Avatar.html#t:avatar_options/0"},{"type":"module","doc":"Options and option validation for `Image.blur/2`.","title":"Image.Options.Blur","ref":"Image.Options.Blur.html"},{"type":"function","doc":"Validate the options for `Image.blur/2`.\n\nSee `t:Image.Options.Blur.blur_options/0`.","title":"Image.Options.Blur.validate_options/1","ref":"Image.Options.Blur.html#validate_options/1"},{"type":"type","doc":"Options applicable to Image.blur/2","title":"Image.Options.Blur.blur_option/0","ref":"Image.Options.Blur.html#t:blur_option/0"},{"type":"type","doc":"Options list for Image.blur/2","title":"Image.Options.Blur.blur_options/0","ref":"Image.Options.Blur.html#t:blur_options/0"},{"type":"module","doc":"Options and option validation for `Image.Blurhash.encode/2`.","title":"Image.Options.Blurhash","ref":"Image.Options.Blurhash.html"},{"type":"function","doc":"Validate the options for `Image.Blurhash.encode/2`.\n\nSee `t:Image.Options.Blurhash.blurhash_options/0`.","title":"Image.Options.Blurhash.validate_options/2","ref":"Image.Options.Blurhash.html#validate_options/2"},{"type":"type","doc":"Options applicable to `Image.Blurhash.encode/2`","title":"Image.Options.Blurhash.blurhash_option/0","ref":"Image.Options.Blurhash.html#t:blurhash_option/0"},{"type":"type","doc":"Options list for Image.Blurhash.encode/2","title":"Image.Options.Blurhash.blurhash_options/0","ref":"Image.Options.Blurhash.html#t:blurhash_options/0"},{"type":"module","doc":"Options and option validation for `Image.chroma_key/2`.","title":"Image.Options.ChromaKey","ref":"Image.Options.ChromaKey.html"},{"type":"function","doc":"Validate the options for `Image.chroma_key/2`.","title":"Image.Options.ChromaKey.validate_options/1","ref":"Image.Options.ChromaKey.html#validate_options/1"},{"type":"type","doc":"Options applicable to Image.chroma_key/2","title":"Image.Options.ChromaKey.chroma_key_options/0","ref":"Image.Options.ChromaKey.html#t:chroma_key_options/0"},{"type":"module","doc":"Options and option validation for `Image.compare/3`.","title":"Image.Options.Compare","ref":"Image.Options.Compare.html"},{"type":"function","doc":"Validate the options for `Image.compare/3`.","title":"Image.Options.Compare.validate_options/1","ref":"Image.Options.Compare.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.compare/3`.","title":"Image.Options.Compare.compare_option/0","ref":"Image.Options.Compare.html#t:compare_option/0"},{"type":"type","doc":"","title":"Image.Options.Compare.compare_options/0","ref":"Image.Options.Compare.html#t:compare_options/0"},{"type":"module","doc":"This module processes the options for\n`Image.compose/3`.\n\nSince x,y can be relative or absolution, can be symbolic\nor numeric and can even by a function this becomes more\ncomplex that it might initially seem","title":"Image.Options.Compose","ref":"Image.Options.Compose.html"},{"type":"function","doc":"","title":"Image.Options.Compose.default_composit_options/0","ref":"Image.Options.Compose.html#default_composit_options/0"},{"type":"type","doc":"When composing an image on a base image, these\noptions drive how the composition proceeds.\n\n* `:x` describes the absolute `x` offset on the\n  base image where this image will be placed. If\n  this option is set to `:left`, `:center` or\n  `:right` then the `x` position will be calculated\n  relative to the base image. If `:x` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dx`.\n\n* `:y` describes the absolute `y` offset on the\n  base image where this image will be placed. If\n  this option is set to `:top`, `:middle` or\n  `:bottom` then the `y` position will be calculated\n  relative to the base image. If `:y` is nil\n  (the default) then the image will be placed according\n  to the relative offset of the previously composed\n  image using `:dy`.\n\n* `:dx` describes the relative offset used to calculate\n  the `x` value. `:dx` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:x_baseline` option. If `:x` is also\n  specified then `:x` is first calculated, then `:dx` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:dy` describes the relative offset used to calculate\n  the `y` value. `:dy` is an integer offset from the\n  edge of the previously composed image. Which edge is\n  determined by the `:y_baseline` option. If `:y` is also\n  specified then `:y` is first calculated, then `:dy` is\n  added to it. In this case, `:x_baseline` is ignored.\n\n* `:blend_mode` is the `t:Image.BlendMode.t/0` used when\n  composing this image over its base image. The default\n  is `:over` which is appropriate for most use cases.\n\n* `:x_baseline` establishes the baseline on the\n  previously composed image from which `:dx` is\n  calculated. The default is `:right`.\n\n* `:y_baseline` establishes the baseline on the\n  previously composed image from which `:dy` is\n  calculated. The default is `:bottom`.","title":"Image.Options.Compose.composition_option/0","ref":"Image.Options.Compose.html#t:composition_option/0"},{"type":"type","doc":"Image compoositions options","title":"Image.Options.Compose.t/0","ref":"Image.Options.Compose.html#t:t/0"},{"type":"module","doc":"Options and option validation for `Image.crop/5`.","title":"Image.Options.Crop","ref":"Image.Options.Crop.html"},{"type":"function","doc":"Validates options to `Iamge.crop/5`.","title":"Image.Options.Crop.validate_options/1","ref":"Image.Options.Crop.html#validate_options/1"},{"type":"type","doc":"Indicates how to determine where to crop\nan image to fill a target area.\n\n* `:none` means the image will be reduced\n  to fit the required bounding box and\n  no cropping will occur.\n\n* `:center` means crop from the center of\n  the image. The central part of the image\n  will be returned, cropped to fill the\n  bounding box.\n\n* `:entropy` uses an entropy measure.\n\n* `:attention` means crop the image by looking\n  for features likely to draw human attention.\n\n* `:low` means position the crop towards the\n  low coordinate. This means the bottom part\n  of the image remains after the crop.\n\n* `:high` means position the crop towards the\n  high coordinate. This means the top part\n  of the image remains after the crop.","title":"Image.Options.Crop.crop_focus/0","ref":"Image.Options.Crop.html#t:crop_focus/0"},{"type":"type","doc":"Options applicable to cropping an\nimage.\n\nCurrently there are no options.","title":"Image.Options.Crop.crop_options/0","ref":"Image.Options.Crop.html#t:crop_options/0"},{"type":"module","doc":"Options and options validation for the\ndrawing functionss.","title":"Image.Options.Draw","ref":"Image.Options.Draw.html"},{"type":"function","doc":"Validate the options for `Image.Draw`.","title":"Image.Options.Draw.validate_options/2","ref":"Image.Options.Draw.html#validate_options/2"},{"type":"type","doc":"","title":"Image.Options.Draw.circle/0","ref":"Image.Options.Draw.html#t:circle/0"},{"type":"type","doc":"","title":"Image.Options.Draw.flood/0","ref":"Image.Options.Draw.html#t:flood/0"},{"type":"type","doc":"","title":"Image.Options.Draw.image/0","ref":"Image.Options.Draw.html#t:image/0"},{"type":"type","doc":"","title":"Image.Options.Draw.line/0","ref":"Image.Options.Draw.html#t:line/0"},{"type":"type","doc":"","title":"Image.Options.Draw.mask/0","ref":"Image.Options.Draw.html#t:mask/0"},{"type":"type","doc":"","title":"Image.Options.Draw.point/0","ref":"Image.Options.Draw.html#t:point/0"},{"type":"type","doc":"","title":"Image.Options.Draw.rect/0","ref":"Image.Options.Draw.html#t:rect/0"},{"type":"type","doc":"","title":"Image.Options.Draw.smudge/0","ref":"Image.Options.Draw.html#t:smudge/0"},{"type":"module","doc":"Options and option validation for `Image.embed/4`.","title":"Image.Options.Embed","ref":"Image.Options.Embed.html"},{"type":"function","doc":"Validate the options for `Image.embed/4`.","title":"Image.Options.Embed.validate_options/4","ref":"Image.Options.Embed.html#validate_options/4"},{"type":"type","doc":"Options applicable to `Image.embed/4`.","title":"Image.Options.Embed.embed_option/0","ref":"Image.Options.Embed.html#t:embed_option/0"},{"type":"type","doc":"Options list for `Image.embed/4`.","title":"Image.Options.Embed.embed_options/0","ref":"Image.Options.Embed.html#t:embed_options/0"},{"type":"type","doc":"When extending the canvas the generated\npixels are determined by this option.","title":"Image.Options.Embed.extend_mode/0","ref":"Image.Options.Embed.html#t:extend_mode/0"},{"type":"module","doc":"Options and option validation for `Image.equalize/2`.","title":"Image.Options.Equalize","ref":"Image.Options.Equalize.html"},{"type":"function","doc":"Validate the options for `Image.equalize/2`.","title":"Image.Options.Equalize.validate_options/1","ref":"Image.Options.Equalize.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.equalize/2`.","title":"Image.Options.Equalize.equalize_option/0","ref":"Image.Options.Equalize.html#t:equalize_option/0"},{"type":"module","doc":"Options and option validation for `Image.Histogram.as_svg/2`.","title":"Image.Options.Histogram","ref":"Image.Options.Histogram.html"},{"type":"function","doc":"Validate the options for `Image.Histogram.as_svg/2`.","title":"Image.Options.Histogram.validate_options/1","ref":"Image.Options.Histogram.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.Histogram.as_svg/2`.","title":"Image.Options.Histogram.histogram_option/0","ref":"Image.Options.Histogram.html#t:histogram_option/0"},{"type":"type","doc":"Options list or map for `Image.Histogram.as_svg/2`.","title":"Image.Options.Histogram.histogram_options/0","ref":"Image.Options.Histogram.html#t:histogram_options/0"},{"type":"module","doc":"Options and option validation for `Image.join/2`.","title":"Image.Options.Join","ref":"Image.Options.Join.html"},{"type":"function","doc":"Validate the options for `Image.join/2`.","title":"Image.Options.Join.validate_options/1","ref":"Image.Options.Join.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.join/2`.","title":"Image.Options.Join.join_option/0","ref":"Image.Options.Join.html#t:join_option/0"},{"type":"type","doc":"Image.join/2 options list.","title":"Image.Options.Join.join_options/0","ref":"Image.Options.Join.html#t:join_options/0"},{"type":"module","doc":"Options and option validation for `Image.linear_gradient/2`.","title":"Image.Options.LinearGradient","ref":"Image.Options.LinearGradient.html"},{"type":"function","doc":"Validate the options for `Image.linear_gradient/2`.","title":"Image.Options.LinearGradient.validate_options/1","ref":"Image.Options.LinearGradient.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.linear_gradient/2`.","title":"Image.Options.LinearGradient.linear_gradient_option/0","ref":"Image.Options.LinearGradient.html#t:linear_gradient_option/0"},{"type":"type","doc":"Options list or map for `Image.linear_gradient/2`.","title":"Image.Options.LinearGradient.linear_gradient_options/0","ref":"Image.Options.LinearGradient.html#t:linear_gradient_options/0"},{"type":"module","doc":"Options and option validation for `Image.local_contrast/2`.","title":"Image.Options.LocalContrast","ref":"Image.Options.LocalContrast.html"},{"type":"function","doc":"Validate the options for `Image.local_contrast/2`.","title":"Image.Options.LocalContrast.validate_options/1","ref":"Image.Options.LocalContrast.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.local_contrast/2`.","title":"Image.Options.LocalContrast.local_contrast_option/0","ref":"Image.Options.LocalContrast.html#t:local_contrast_option/0"},{"type":"type","doc":"Options list or map for `Image.local_contrast/2`.","title":"Image.Options.LocalContrast.local_contrast_options/0","ref":"Image.Options.LocalContrast.html#t:local_contrast_options/0"},{"type":"module","doc":"Options and option validation for `Image.meme/2`.","title":"Image.Options.Meme","ref":"Image.Options.Meme.html"},{"type":"function","doc":"","title":"Image.Options.Meme.default_margin/1","ref":"Image.Options.Meme.html#default_margin/1"},{"type":"function","doc":"","title":"Image.Options.Meme.no_such_font_file/1","ref":"Image.Options.Meme.html#no_such_font_file/1"},{"type":"function","doc":"","title":"Image.Options.Meme.validate_options/1","ref":"Image.Options.Meme.html#validate_options/1"},{"type":"function","doc":"Validate the options for `Image.meme/3`.\n\nSee `t:Image.Options.Meme.meme_options/0`.","title":"Image.Options.Meme.validate_options/2","ref":"Image.Options.Meme.html#validate_options/2"},{"type":"type","doc":"Valid font weights","title":"Image.Options.Meme.font_weight/0","ref":"Image.Options.Meme.html#t:font_weight/0"},{"type":"type","doc":"Options applicable to Image.meme/3","title":"Image.Options.Meme.meme_options/0","ref":"Image.Options.Meme.html#t:meme_options/0"},{"type":"type","doc":"Valid type transforms","title":"Image.Options.Meme.text_transform/0","ref":"Image.Options.Meme.html#t:text_transform/0"},{"type":"module","doc":"Options and option validation for `Image.modulate/2`.","title":"Image.Options.Modulate","ref":"Image.Options.Modulate.html"},{"type":"function","doc":"Validate the options for `Image.modulate/2`.\n\nSee `t:Image.Options.Modulate.modulate_options/0`.","title":"Image.Options.Modulate.validate_options/1","ref":"Image.Options.Modulate.html#validate_options/1"},{"type":"type","doc":"Valid options for `Image.modulate/2`.","title":"Image.Options.Modulate.modulate_option/0","ref":"Image.Options.Modulate.html#t:modulate_option/0"},{"type":"type","doc":"Options applicable to Image.modulate/2","title":"Image.Options.Modulate.modulate_options/0","ref":"Image.Options.Modulate.html#t:modulate_options/0"},{"type":"module","doc":"Options for new images.","title":"Image.Options.New","ref":"Image.Options.New.html"},{"type":"function","doc":"","title":"Image.Options.New.default_options/0","ref":"Image.Options.New.html#default_options/0"},{"type":"function","doc":"","title":"Image.Options.New.set_default_bands/1","ref":"Image.Options.New.html#set_default_bands/1"},{"type":"function","doc":"Validate the options for `Image.new/2`.","title":"Image.Options.New.validate_options/1","ref":"Image.Options.New.html#validate_options/1"},{"type":"type","doc":"","title":"Image.Options.New.t/0","ref":"Image.Options.New.html#t:t/0"},{"type":"module","doc":"Options and option validation for `Image.open/2`.","title":"Image.Options.Open","ref":"Image.Options.Open.html"},{"type":"function","doc":"","title":"Image.Options.Open.validate_option/2","ref":"Image.Options.Open.html#validate_option/2"},{"type":"function","doc":"","title":"Image.Options.Open.validate_options/1","ref":"Image.Options.Open.html#validate_options/1"},{"type":"type","doc":"Stop attempting to load an image file\nwhen a level of error is detected.\nThe default is `:none`.\n\nEach error state implies all the states\nbefore it such that `:error` implies\nalso `:truncated`.","title":"Image.Options.Open.fail_on/0","ref":"Image.Options.Open.html#t:fail_on/0"},{"type":"type","doc":"The file access mode when opening\nimage files. The default in `:sequential`.","title":"Image.Options.Open.file_access/0","ref":"Image.Options.Open.html#t:file_access/0"},{"type":"type","doc":"","title":"Image.Options.Open.gif_open_options/0","ref":"Image.Options.Open.html#t:gif_open_options/0"},{"type":"type","doc":"The options applicable to opening an\nimage.","title":"Image.Options.Open.image_open_options/0","ref":"Image.Options.Open.html#t:image_open_options/0"},{"type":"type","doc":"","title":"Image.Options.Open.jpeg_open_options/0","ref":"Image.Options.Open.html#t:jpeg_open_options/0"},{"type":"type","doc":"","title":"Image.Options.Open.other_open_options/0","ref":"Image.Options.Open.html#t:other_open_options/0"},{"type":"type","doc":"The number of pages to open. Either\na positive integer or one of `-1` or `:all`\nmeaning all pages.","title":"Image.Options.Open.pages/0","ref":"Image.Options.Open.html#t:pages/0"},{"type":"type","doc":"","title":"Image.Options.Open.png_open_options/0","ref":"Image.Options.Open.html#t:png_open_options/0"},{"type":"type","doc":"","title":"Image.Options.Open.tiff_open_options/0","ref":"Image.Options.Open.html#t:tiff_open_options/0"},{"type":"type","doc":"","title":"Image.Options.Open.webp_open_options/0","ref":"Image.Options.Open.html#t:webp_open_options/0"},{"type":"module","doc":"Options and option validation for `Image.radial_gradient/3`.","title":"Image.Options.RadialGradient","ref":"Image.Options.RadialGradient.html"},{"type":"function","doc":"Validate the options for `Image.radial_gradient/3`.","title":"Image.Options.RadialGradient.validate_options/1","ref":"Image.Options.RadialGradient.html#validate_options/1"},{"type":"type","doc":"Options applicable to `Image.radial_gradient/3`.","title":"Image.Options.RadialGradient.radial_gradient_option/0","ref":"Image.Options.RadialGradient.html#t:radial_gradient_option/0"},{"type":"type","doc":"Options list or map for `Image.radial_gradient/3`.","title":"Image.Options.RadialGradient.radial_gradient_options/0","ref":"Image.Options.RadialGradient.html#t:radial_gradient_options/0"},{"type":"module","doc":"Options and option validation for `Image.resize/3`.","title":"Image.Options.Resize","ref":"Image.Options.Resize.html"},{"type":"function","doc":"Validate the options for `Image.resize/2`.\n\nSee `t:Image.Options.Resize.resize_options/0`.","title":"Image.Options.Resize.validate_options/1","ref":"Image.Options.Resize.html#validate_options/1"},{"type":"type","doc":"Options applicable to Image.resize/3","title":"Image.Options.Resize.resize_options/0","ref":"Image.Options.Resize.html#t:resize_options/0"},{"type":"module","doc":"Options and option validation for `Image.rotate/3`.","title":"Image.Options.Rotate","ref":"Image.Options.Rotate.html"},{"type":"function","doc":"Validate the options for `Image.rotate/3`.\n\nSee `t:Image.Options.Rotate.rotation_options/0`.","title":"Image.Options.Rotate.validate_options/1","ref":"Image.Options.Rotate.html#validate_options/1"},{"type":"type","doc":"The options applicable to rotating an\nimage.","title":"Image.Options.Rotate.rotation_options/0","ref":"Image.Options.Rotate.html#t:rotation_options/0"},{"type":"module","doc":"Options and option validation for `Image.sharpen/2`.","title":"Image.Options.Sharpen","ref":"Image.Options.Sharpen.html"},{"type":"function","doc":"Validate the options for `Image.sharpen/2`.\n\nSee `t:Image.Options.Sharpen.sharpen_options/0`.","title":"Image.Options.Sharpen.validate_options/1","ref":"Image.Options.Sharpen.html#validate_options/1"},{"type":"type","doc":"Valid options for `Image.sharpen/2`.","title":"Image.Options.Sharpen.sharpen_option/0","ref":"Image.Options.Sharpen.html#t:sharpen_option/0"},{"type":"type","doc":"Options applicable to Image.sharpen/2","title":"Image.Options.Sharpen.sharpen_options/0","ref":"Image.Options.Sharpen.html#t:sharpen_options/0"},{"type":"module","doc":"Options for text drawing.","title":"Image.Options.Text","ref":"Image.Options.Text.html"},{"type":"function","doc":"","title":"Image.Options.Text.default_options/0","ref":"Image.Options.Text.html#default_options/0"},{"type":"function","doc":"Validate the options for `Image.Text.text/2`.","title":"Image.Options.Text.validate_options/1","ref":"Image.Options.Text.html#validate_options/1"},{"type":"type","doc":"","title":"Image.Options.Text.t/0","ref":"Image.Options.Text.html#t:t/0"},{"type":"module","doc":"Options and option validation for `Image.thumbnail/3`.","title":"Image.Options.Thumbnail","ref":"Image.Options.Thumbnail.html"},{"type":"function","doc":"Validate the options for `Image.resize/2`.\n\nSee `t:Image.Options.Resize.resize_options/0`.","title":"Image.Options.Thumbnail.validate_options/1","ref":"Image.Options.Thumbnail.html#validate_options/1"},{"type":"type","doc":"","title":"Image.Options.Thumbnail.resize_dimension/0","ref":"Image.Options.Thumbnail.html#t:resize_dimension/0"},{"type":"type","doc":"Options applicable to Image.thumbnail/3","title":"Image.Options.Thumbnail.thumbnail_options/0","ref":"Image.Options.Thumbnail.html#t:thumbnail_options/0"},{"type":"module","doc":"Options and option validation for `Image.apply_tone_curve/2`.","title":"Image.Options.ToneCurve","ref":"Image.Options.ToneCurve.html"},{"type":"macro","doc":"Valid range for setting the black point and\nwhite point.","title":"Image.Options.ToneCurve.is_set_point/1","ref":"Image.Options.ToneCurve.html#is_set_point/1"},{"type":"macro","doc":"The range in which the shadows, mids and highlights\ncan be adjusted.","title":"Image.Options.ToneCurve.is_tone_adjustment/1","ref":"Image.Options.ToneCurve.html#is_tone_adjustment/1"},{"type":"function","doc":"Validate the options for `Image.apply_tone_curve/2`.","title":"Image.Options.ToneCurve.validate_options/1","ref":"Image.Options.ToneCurve.html#validate_options/1"},{"type":"type","doc":"A percent expressed as a float in the range\n[0.0..1.0]","title":"Image.Options.ToneCurve.positive_percent/0","ref":"Image.Options.ToneCurve.html#t:positive_percent/0"},{"type":"type","doc":"Range for setting the black point and\nwhite point. The range is 0..100 reflecting\nthe values of L* in the `Lab` colorspace.","title":"Image.Options.ToneCurve.set_point/0","ref":"Image.Options.ToneCurve.html#t:set_point/0"},{"type":"type","doc":"The adjustment range for the shadow,\nmidpoint and highlights.","title":"Image.Options.ToneCurve.tone_adjustment/0","ref":"Image.Options.ToneCurve.html#t:tone_adjustment/0"},{"type":"type","doc":"Options applicable to `Image.apply_tone_curve/2`.","title":"Image.Options.ToneCurve.tone_curve_option/0","ref":"Image.Options.ToneCurve.html#t:tone_curve_option/0"},{"type":"type","doc":"","title":"Image.Options.ToneCurve.tone_curve_options/0","ref":"Image.Options.ToneCurve.html#t:tone_curve_options/0"},{"type":"module","doc":"Options and option validation for `Image.trim/2`.","title":"Image.Options.Trim","ref":"Image.Options.Trim.html"},{"type":"function","doc":"Validate the options for `Image.trim/2`.","title":"Image.Options.Trim.validate_options/1","ref":"Image.Options.Trim.html#validate_options/1"},{"type":"type","doc":"Options applicable to Image.trim/2","title":"Image.Options.Trim.trim_options/0","ref":"Image.Options.Trim.html#t:trim_options/0"},{"type":"module","doc":"Options and option validation for `Image.Video.stream!/2`.","title":"Image.Options.Video","ref":"Image.Options.Video.html"},{"type":"function","doc":"","title":"Image.Options.Video.known_backends/0","ref":"Image.Options.Video.html#known_backends/0"},{"type":"function","doc":"","title":"Image.Options.Video.validate_open_options/1","ref":"Image.Options.Video.html#validate_open_options/1"},{"type":"function","doc":"","title":"Image.Options.Video.validate_stream_options/2","ref":"Image.Options.Video.html#validate_stream_options/2"},{"type":"function","doc":"","title":"Image.Options.Video.validate_stream_options!/2","ref":"Image.Options.Video.html#validate_stream_options!/2"},{"type":"type","doc":"","title":"Image.Options.Video.backend/0","ref":"Image.Options.Video.html#t:backend/0"},{"type":"type","doc":"","title":"Image.Options.Video.open_options/0","ref":"Image.Options.Video.html#t:open_options/0"},{"type":"module","doc":"Options and option validation for `Image.warp_perspective/4`.","title":"Image.Options.WarpPerspective","ref":"Image.Options.WarpPerspective.html"},{"type":"function","doc":"Validate the options for `Image.warp_perspective/4`.","title":"Image.Options.WarpPerspective.validate_options/2","ref":"Image.Options.WarpPerspective.html#validate_options/2"},{"type":"type","doc":"When extending the canvas the generated\npixels are determined by this option.","title":"Image.Options.WarpPerspective.extend_mode/0","ref":"Image.Options.WarpPerspective.html#t:extend_mode/0"},{"type":"type","doc":"Options for Image.warp_perspective/4.","title":"Image.Options.WarpPerspective.t/0","ref":"Image.Options.WarpPerspective.html#t:t/0"},{"type":"type","doc":"Options applicable to `Image.embed/4`.","title":"Image.Options.WarpPerspective.warp_perspective_option/0","ref":"Image.Options.WarpPerspective.html#t:warp_perspective_option/0"},{"type":"module","doc":"Options and option validation for `Image.write/3`.","title":"Image.Options.Write","ref":"Image.Options.Write.html"},{"type":"function","doc":"","title":"Image.Options.Write.validate_options/2","ref":"Image.Options.Write.html#validate_options/2"},{"type":"type","doc":"Options for writing a gif file with `Image.write/2`.","title":"Image.Options.Write.gif_write_option/0","ref":"Image.Options.Write.html#t:gif_write_option/0"},{"type":"type","doc":"Allowable compression types for heif images.","title":"Image.Options.Write.heif_compression/0","ref":"Image.Options.Write.html#t:heif_compression/0"},{"type":"type","doc":"Options for writing a heif file with `Image.write/2`.","title":"Image.Options.Write.heif_write_option/0","ref":"Image.Options.Write.html#t:heif_write_option/0"},{"type":"type","doc":"Options for writing an image to a file with `Image.write/2`.","title":"Image.Options.Write.image_write_options/0","ref":"Image.Options.Write.html#t:image_write_options/0"},{"type":"type","doc":"Options for writing a jpeg file with `Image.write/2`.","title":"Image.Options.Write.jpeg_write_option/0","ref":"Image.Options.Write.html#t:jpeg_write_option/0"},{"type":"type","doc":"Options for writing a png file with `Image.write/2`.","title":"Image.Options.Write.png_write_option/0","ref":"Image.Options.Write.html#t:png_write_option/0"},{"type":"type","doc":"Options for writing an image stream","title":"Image.Options.Write.stream_write_option/0","ref":"Image.Options.Write.html#t:stream_write_option/0"},{"type":"type","doc":"Options for writing a tiff file with `Image.write/2`.","title":"Image.Options.Write.tiff_write_option/0","ref":"Image.Options.Write.html#t:tiff_write_option/0"},{"type":"type","doc":"Options for writing a webp file with `Image.write/2`.","title":"Image.Options.Write.webp_write_option/0","ref":"Image.Options.Write.html#t:webp_write_option/0"},{"type":"module","doc":"Functions to define and validate the band\nformats of an image.","title":"Image.BandFormat","ref":"Image.BandFormat.html"},{"type":"function","doc":"Returns the `Image` format type for an\n`Nx` format type.\n\n`Image` uses the same type formats as `Nx` so\nthis function is more a validation than a\nconversion.","title":"Image.BandFormat.image_format_from_nx/1","ref":"Image.BandFormat.html#image_format_from_nx/1"},{"type":"function","doc":"* Any `Nx` type like `{:u, 8}`.","title":"Arguments - Image.BandFormat.image_format_from_nx/1","ref":"Image.BandFormat.html#image_format_from_nx/1-arguments"},{"type":"function","doc":"* `{:ok, band_format}` or\n\n* `{:error, reason}`","title":"Returns - Image.BandFormat.image_format_from_nx/1","ref":"Image.BandFormat.html#image_format_from_nx/1-returns"},{"type":"function","doc":"Returns a list of the known band formats.","title":"Image.BandFormat.known_band_formats/0","ref":"Image.BandFormat.html#known_band_formats/0"},{"type":"function","doc":"Returns the `Nx` format type for an\n`Image` or image format type.\n\n`Image` uses the same type formats as `Nx` so\nthis function is more a validation than a\nconversion.","title":"Image.BandFormat.nx_format/1","ref":"Image.BandFormat.html#nx_format/1"},{"type":"function","doc":"* Any `t:Vimage.t/0` of format in the list\n  returned by `Image.BandFormat.known_band_formats/0`.","title":"Arguments - Image.BandFormat.nx_format/1","ref":"Image.BandFormat.html#nx_format/1-arguments"},{"type":"function","doc":"* `{:ok, band_format}` or\n\n* `{:error, reason}`","title":"Returns - Image.BandFormat.nx_format/1","ref":"Image.BandFormat.html#nx_format/1-returns"},{"type":"function","doc":"Returns the `Nx` format type for an\n`Image` or image format type or raises\nan exception.\n\n`Image` uses the same type formats as `Nx` so\nthis function is more a validation than a\nconversion.","title":"Image.BandFormat.nx_format!/1","ref":"Image.BandFormat.html#nx_format!/1"},{"type":"function","doc":"* Any `t:Vimage.t/0` of format in the list\n  returned by `Image.BandFormat.known_band_formats/0`.","title":"Arguments - Image.BandFormat.nx_format!/1","ref":"Image.BandFormat.html#nx_format!/1-arguments"},{"type":"function","doc":"* `band_format` or\n\n* raises an exception.","title":"Returns - Image.BandFormat.nx_format!/1","ref":"Image.BandFormat.html#nx_format!/1-returns"},{"type":"function","doc":"Validates a band format returning the band\nformat value required in the underlying\n`Vix` code.","title":"Image.BandFormat.validate/1","ref":"Image.BandFormat.html#validate/1"},{"type":"function","doc":"* `format` is any format returned by\n  `Image.BandFormat.known_band_formats/0`.","title":"Arguments - Image.BandFormat.validate/1","ref":"Image.BandFormat.html#validate/1-arguments"},{"type":"function","doc":"* `{:ok, validated_foramt}` or\n\n* `{:error, reason}`","title":"Returns - Image.BandFormat.validate/1","ref":"Image.BandFormat.html#validate/1-returns"},{"type":"function","doc":"iex> Image.BandFormat.validate({:u, 8})\n      {:ok, :VIPS_FORMAT_UCHAR}\n\n      iex> Image.BandFormat.validate(:u8)\n      {:ok, :VIPS_FORMAT_UCHAR}\n\n      iex> Image.BandFormat.validate(:VIPS_FORMAT_UCHAR)\n      {:ok, :VIPS_FORMAT_UCHAR}","title":"Examples - Image.BandFormat.validate/1","ref":"Image.BandFormat.html#validate/1-examples"},{"type":"type","doc":"","title":"Image.BandFormat.t/0","ref":"Image.BandFormat.html#t:t/0"},{"type":"module","doc":"Functions to define and validate the blending\nmodes that can be applied when composing images.","title":"Image.BlendMode","ref":"Image.BlendMode.html"},{"type":"function","doc":"Returns the default blend mode","title":"Image.BlendMode.default_blend_mode/0","ref":"Image.BlendMode.html#default_blend_mode/0"},{"type":"function","doc":"iex> Image.BlendMode.default_blend_mode\n    :VIPS_BLEND_MODE_OVER","title":"Example - Image.BlendMode.default_blend_mode/0","ref":"Image.BlendMode.html#default_blend_mode/0-example"},{"type":"function","doc":"Returns the known blending modes.\n\nSee `t:Image.BlendMode.t/0` for a description\nof each mode.","title":"Image.BlendMode.known_blend_modes/0","ref":"Image.BlendMode.html#known_blend_modes/0"},{"type":"function","doc":"Normalizes and validates a blend mode.","title":"Image.BlendMode.validate_blend_mode/1","ref":"Image.BlendMode.html#validate_blend_mode/1"},{"type":"function","doc":"* `blend_mode` is one of `Image.BlendMode.known_blend_modes/0`\n  as either a `t:String.t/0` or an `atom`.","title":"Argument - Image.BlendMode.validate_blend_mode/1","ref":"Image.BlendMode.html#validate_blend_mode/1-argument"},{"type":"function","doc":"* `{:ok, atom_blend_mode}` where `atom_blend_mode` is\n  a valid blend mode for `libvips`\n\n* `{:error, reason}`","title":"Returns - Image.BlendMode.validate_blend_mode/1","ref":"Image.BlendMode.html#validate_blend_mode/1-returns"},{"type":"function","doc":"iex> Image.BlendMode.validate_blend_mode :clear\n    {:ok, :VIPS_BLEND_MODE_CLEAR}\n\n    iex> Image.BlendMode.validate_blend_mode \"Over\"\n    {:ok, :VIPS_BLEND_MODE_OVER}\n\n    iex> Image.BlendMode.validate_blend_mode :VIPS_BLEND_MODE_XOR\n    {:ok, :VIPS_BLEND_MODE_XOR}\n\n    iex> Image.BlendMode.validate_blend_mode :woops\n    {:error, {:error, \"Unknown blend mode. Found :woops\"}}","title":"Examples - Image.BlendMode.validate_blend_mode/1","ref":"Image.BlendMode.html#validate_blend_mode/1-examples"},{"type":"type","doc":"Blend mode to use when compositing images. See `Image.compose/3`.\n\n* `:over` the image shows what you would expect if you held two\n  semi-transparent slides on top of each other. This is the default\n  when composing images\n* `:clear` where the second image is drawn, the first is removed\n* `:source` the second image is drawn as if nothing were below\n* `:in` the first image is removed completely, the second is only\n  drawn where the first was\n* `:out` the second is drawn only where the first isn't\n* `:atop` this leaves the first image mostly intact, but mixes\n  both images in the overlapping area\n* `:dest` leaves the first image untouched, the second is discarded\n  completely\n* `:dest_over` like `:over`, but swaps the arguments\n* `:dest_in` like `:in`, but swaps the arguments\n* `:dest_out` like `:out`, but swaps the arguments\n* `:dest_atop` like `:atop`, but swaps the arguments\n* `:xor` something like a difference operator\n* `:add` a bit like adding the two images\n* `:saturate` a bit like the darker of the two\n* `:multiply` at least as dark as the darker of the two inputs\n* `:screen` at least as light as the lighter of the inputs\n* `:overlay` multiplies or screens colors, depending on the lightness\n* `:darken` the darker of each component\n* `:lighten` the lighter of each component\n* `:colour_dodge` brighten first by a factor second\n* `:colour_burn` darken first by a factor of second\n* `:hard_light` multiply or screen, depending on lightness\n* `:soft_light` darken or lighten, depending on lightness\n* `:difference` difference of the two\n* `:exclusion` somewhat like :difference, but lower-contrast","title":"Image.BlendMode.t/0","ref":"Image.BlendMode.html#t:t/0"},{"type":"module","doc":"Functions to define and validate the combine\nmodes that can be applied when composing images.","title":"Image.CombineMode","ref":"Image.CombineMode.html"},{"type":"function","doc":"","title":"Image.CombineMode.validate/1","ref":"Image.CombineMode.html#validate/1"},{"type":"type","doc":"","title":"Image.CombineMode.t/0","ref":"Image.CombineMode.html#t:t/0"},{"type":"module","doc":"Defines the known modes by which an image\ncan be extended.","title":"Image.ExtendMode","ref":"Image.ExtendMode.html"},{"type":"function","doc":"Returns the known extend modes.","title":"Image.ExtendMode.known_extend_modes/0","ref":"Image.ExtendMode.html#known_extend_modes/0"},{"type":"function","doc":"Normalizes and validates an extend mode.","title":"Image.ExtendMode.validate_extend/1","ref":"Image.ExtendMode.html#validate_extend/1"},{"type":"function","doc":"* `extend` is any atom or string value\n  in `Image.ExtendMode.known_extend_modes/0`.","title":"Arguments - Image.ExtendMode.validate_extend/1","ref":"Image.ExtendMode.html#validate_extend/1-arguments"},{"type":"function","doc":"* `{:error, normalized_extend_mode}` or\n\n* `{:error, reason}`.","title":"Returns - Image.ExtendMode.validate_extend/1","ref":"Image.ExtendMode.html#validate_extend/1-returns"},{"type":"function","doc":"iex> Image.Kernel.validate_extend(:black)\n    {:ok, :VIPS_EXTEND_BLACK}\n\n    iex> Image.Kernel.validate_extend(:VIPS_EXTEND_REPEAT)\n    {:ok, :VIPS_EXTEND_REPEAT}\n\n    iex> Image.Kernel.validate_extend(:unknown)\n    {:error, \"Unknown extend mode. Found :unknown\"}","title":"Examples - Image.ExtendMode.validate_extend/1","ref":"Image.ExtendMode.html#validate_extend/1-examples"},{"type":"type","doc":"Defines the known extend strategies.","title":"Image.ExtendMode.t/0","ref":"Image.ExtendMode.html#t:t/0"},{"type":"module","doc":"Defines the known color interpretations to which\nan image can be converted to and from.","title":"Image.Interpretation","ref":"Image.Interpretation.html"},{"type":"function","doc":"Returns the known colorspace interpretations","title":"Image.Interpretation.known_interpretations/0","ref":"Image.Interpretation.html#known_interpretations/0"},{"type":"function","doc":"Normalizes and validates a color interpretation.","title":"Image.Interpretation.validate_interpretation/1","ref":"Image.Interpretation.html#validate_interpretation/1"},{"type":"function","doc":"* `interpretation` is any atom or string value\n  in `Image.Interpretation.known_interpretations/0`.","title":"Arguments - Image.Interpretation.validate_interpretation/1","ref":"Image.Interpretation.html#validate_interpretation/1-arguments"},{"type":"function","doc":"* `{:error, normalized_interpretation}` or\n\n* `{:error, reason}`","title":"Returns - Image.Interpretation.validate_interpretation/1","ref":"Image.Interpretation.html#validate_interpretation/1-returns"},{"type":"function","doc":"iex> Image.Interpretation.validate_interpretation(:bw)\n    {:ok, :VIPS_INTERPRETATION_B_W}\n\n    iex> Image.Interpretation.validate_interpretation(:VIPS_INTERPRETATION_sRGB)\n    {:ok, :VIPS_INTERPRETATION_sRGB}\n\n    iex> Image.Interpretation.validate_interpretation(:unknown)\n    {:error, \"Unknown interpretation. Found :unknown\"}","title":"Examples - Image.Interpretation.validate_interpretation/1","ref":"Image.Interpretation.html#validate_interpretation/1-examples"},{"type":"type","doc":"Defines the known colorspace interpretations.","title":"Image.Interpretation.t/0","ref":"Image.Interpretation.html#t:t/0"},{"type":"module","doc":"Defines the known resampling kernels to which\nan image can be converted to and from.","title":"Image.Kernel","ref":"Image.Kernel.html"},{"type":"function","doc":"Returns the known colorspace interpretations","title":"Image.Kernel.known_kernel/0","ref":"Image.Kernel.html#known_kernel/0"},{"type":"function","doc":"Normalizes and validates a resampling kernel.","title":"Image.Kernel.validate_kernel/1","ref":"Image.Kernel.html#validate_kernel/1"},{"type":"function","doc":"* `kernel` is any atom or string value\n  in `Image.Kernel.known_kernel/0`.","title":"Arguments - Image.Kernel.validate_kernel/1","ref":"Image.Kernel.html#validate_kernel/1-arguments"},{"type":"function","doc":"* `{:error, normalized_kernel}` or\n\n* `{:error, reason}`","title":"Returns - Image.Kernel.validate_kernel/1","ref":"Image.Kernel.html#validate_kernel/1-returns"},{"type":"function","doc":"iex> Image.Kernel.validate_kernel(:linear)\n    {:ok, :VIPS_KERNEL_LINEAR}\n\n    iex> Image.Kernel.validate_kernel(:VIPS_KERNEL_CUBIC)\n    {:ok, :VIPS_KERNEL_CUBIC}\n\n    iex> Image.Kernel.validate_kernel(:unknown)\n    {:error, \"Unknown kernel. Found :unknown\"}","title":"Examples - Image.Kernel.validate_kernel/1","ref":"Image.Kernel.html#validate_kernel/1-examples"},{"type":"type","doc":"Defines the known kernel resampling methods.","title":"Image.Kernel.t/0","ref":"Image.Kernel.html#t:t/0"},{"type":"extras","doc":"# Image Install & Configure\n\n`Image` is an image processing library for Elixir. It is based upon the fabulous [vix](https://hex.pm/packages/vix) library that provides a [libvips](https://www.libvips.org) wrapper for Elixir.\n\n`Image` is intended to provide well-documented common image processing functions in an idiomatic Elixir functional style as a layer above the very comprehensive set of functions in `Vix` and `libvips`.\n\nAs of version 0.18.0, `Image` provides optional integration with [Bumblebee](https://hex.pm/packages/bumblebee) allowing machine learning models to be deployed as part of an image processing pipeline.\n\n`Image` is also intended to be an idiomatic API layer over [eVision (OpenCV)](https://github.com/cocoa-xu/evision). As of `Image verison 0.9.0`, the `Image.QRcode.decode/1` function is provided to decode QRcodes with the functionality to do so provided by `eVision`. The `eVision` integration is optional and currently considered experimental.\n\nIn a very simple image resizing [benchmark](https://github.com/elixir-image/image/blob/main/bench/vips_v_mogrify.exs), `Image` is approximately 2 to 3 times faster than `Mogrify` and uses about 5 times less memory.\n\nThe documentation can be found at [https://hexdocs.pm/image](https://hexdocs.pm/image).","title":"Image Install & Configure","ref":"readme.html"},{"type":"extras","doc":"`Image` can be installed by adding `image` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # ...\n    {:image, \"~> 0.37\"}\n  ]\nend\n```","title":"Installation - Image Install & Configure","ref":"readme.html#installation"},{"type":"extras","doc":"Starting from v0.16.0 [Vix](https://hex.pm/packages/vix) which underpins `Image` can use either pre-built binaries or platform provided binaries.\n\nBy default `Vix` provides pre-built NIF and `libvips` and uses them for operation. This makes deployment and release of your application a breeze. With this you don't have to install any compiler tools or `libvips` to use `Vix`. This is especially useful when using `Image` with [Livebook](https://livebook.dev).\n\nHowever the pre-built NIF and pre-built libvips do not include dependencies that support all image formats and operations. If you require those formats or operations then you can bring your own `libvips` by installing it manually and configure `Vix` to use that instead. `Vix` makes sure to generate relevant functions and documentation based on the dependencies you bring. For example, if you install libvips with `tiff` support, vix will generate `tiff` related bindings for you.\n\nYou can choose this using `VIX_COMPILATION_MODE` environment variable. This variable must be set both during compilation and runtime. Possible values are:\n\n* `PRECOMPILED_NIF_AND_LIBVIPS` (Default): Uses vix provided NIF and libvips. No need to install any additional dependencies. Big thanks to sharp library maintainers, pre-compiled libvips is based on: https://github.com/lovell/sharp-libvips/.\n\n* `PLATFORM_PROVIDED_LIBVIPS`: Uses platform provided libvips and NIF will be compiled during compilation phase. The following build tools are required generate the `Vix` NIF:\n  * Install a platform specific `libvips`. This can be compiled from source (see https://www.libvips.org/install.html) or via a platform package manager. For example:\n    * macOS: brew brew install libvips\n    * Linux: apt install libvips-dev For more details see\n  * Install `pkg-config`\n  * Ensure a supported C compiler is installed","title":"Installing Libvips - Image Install & Configure","ref":"readme.html#installing-libvips"},{"type":"extras","doc":"[Nx](https://hex.pm/packages/nx) provides multi-dimensional arrays (tensors) and numerical definitions for Elixir. These tensors can also be used as an interchange format for binary image data. When `Nx` is installed and `Image` is compiled, the functions `Image.to_nx/2` and `Image.from_nx/1` are defined.\n\n`Nx` is required in order to support the functions in `Image.Classification`. It is also required to support [eVision](https://hex.pm/packages/evision) and [Bumblebee](https://hex.pm/packages/bumblebee) integrations.\n\n1. Add `Nx` to your `mix.exs`:\n\n    ```elixir\n    def deps do\n      [\n        # ...\n        {:nx, \"~> 0.4\"}\n      ]\n    end\n    ```\n\n2. Add a default `Nx` backend to `config.exs`.\n\n    `Nx` supports a variety of backends that provide CPU and GPU acceleration. The CPU backend that provides the widest platform compatibility is `EXLA.Backend`.\n\n    ```elixir\n    config :nx, default_backend: EXLA.Backend\n    ```\n\n3. Get dependencies:\n\n    ```elixir\n    mix deps.get\n    ```","title":"Installing Nx - Image Install & Configure","ref":"readme.html#installing-nx"},{"type":"extras","doc":"[Bumblebee](https://hex.pm/packages/bumblebee) provides pre-trained and transformer Neural Network models in Axon that can be used for a variety of image classification, segmentation and detection operations. When `Bumblebee` is configured, the functions in `Image.Classification` become available.\n\n1. Add `Bumblebee` and `exla` to your `mix.exs`.\n\n    `exla` is required in order to provide CPU or GPU acceleration for the models so as to deliver acceptable performance. `Nx` will be installed as a transitory dependency.\n\n    ```elixir\n    def deps do\n      [\n        # ...\n        {:bumblebee, \"~> 0.1\"},\n        {:exla, \"~> 0.4\"}\n      ]\n    end\n    ```\n\n2. Add a default Nx backend to `config.exs`.\n\n    `Nx` supports a variety of backends that provide CPU and GPU acceleration. The CPU backend that provides the widest platform compatibility is `EXLA.Backend`.\n\n    ```elixir\n    config :nx, default_backend: EXLA.Backend\n    ```\n\n3. Get dependencies:\n\n    ```elixir\n    mix deps.get\n    ```","title":"Installing Bumblebee - Image Install & Configure","ref":"readme.html#installing-bumblebee"},{"type":"extras","doc":"[eVision (OpenCV)](https://github.com/cocoa-xu/evision) provides Elixir bindings to [OpenCV](https://opencv.org), the most well-known computer vision library.\n\nAs of [Image version 0.9.0](https://hex,pm/packages/image/0.9.0), experimental support for [eVision (OpenCV)](https://github.com/cocoa-xu/evision) is provided. There is extensive documentation on how to install `eVision` and the required [OpenCV](https://opencv.org). However to most cases the following should be enough:\n\n1. Add `eVision` to your `mix.exs`. [exla](https://hex.pm/packages/exla) may be optionally configured too, see the `Nx` installation section above.\n\n    ```elixir\n    def deps do\n      [\n        # ...\n        {:evision, \"~> 0.1\"}\n      ]\n    end\n    ```\n\n2. Get dependencies:\n\n    ```elixir\n    mix deps.get\n    ```\n\nThen proceed as normal. `eVision` will download a precompiled `OpenCV` for the appropriate system architecture and compile both the NIF and Elixir code.","title":"Installing eVision - Image Install & Configure","ref":"readme.html#installing-evision"},{"type":"extras","doc":"`Vix` and `libvips` offer various configuration parameters that affect debug output, image caching, concurrency of imaging operations and memory leak detection. Each of these options has reasonable defaults so no action is required in order to start using the library.","title":"Configuring Libvips - Image Install & Configure","ref":"readme.html#configuring-libvips"},{"type":"extras","doc":"`Vix` NIF code writes logs to stderr on certain errors. This is disabled by default. To enable logging set the `VIX_LOG_ERROR` environment variable to `true`.","title":"Vix NIF Error Logging - Image Install & Configure","ref":"readme.html#vix-nif-error-logging"},{"type":"extras","doc":"The platform upon which `Image` and `Vix` stand is [libvips](https://www.libvips.org), a `C` library that performs the image manipulation. It's `libvips` that delivers the speed, memory efficiency and functionality.\n\n`libvips` uses the [GLib](https://docs.gtk.org/glib/) library which has configurable debug output. This output depends on the setting of the environment variable `G_DEBUG`.  The initial value will depend on the installation method of `libvips` for a given system. It can be changed by setting the `G_DEBUG` environment variable to one of the following:\n\n* **fatal-warnings** which causes GLib to abort the operation at the first call to g_warning() or g_critical().\n\n* **fatal-criticals** causes GLib to abort the operation at the first call to g_critical().\n\n* **gc-friendly** causes newly allocated memory that isn't directly initialized, as well as memory being freed to be reset to 0. The point here is to allow memory checkers and similar programs that use Boehm GC alike algorithms to produce more accurate results.\n\n* **resident-modules** causes all modules loaded by GModule will be made resident. This can be useful for tracking memory leaks in modules which are later unloaded; but it can also hide bugs where code is accessed after the module would have normally been unloaded.\n\n* **bind-now-modules** causes all modules loaded by GModule to bind their symbols at load time, even when the code uses %G_MODULE_BIND_LAZY.\n\nTo produce debug output for only the most critical issues, set `G_DEBUG` as follows (in bash and compatible shells):\n\n```bash\nexport G_DEBUG=fatal-criticals\n```","title":"GLib Debug Output - Image Install & Configure","ref":"readme.html#glib-debug-output"},{"type":"extras","doc":"The environment variable `VIPS_LEAK` determines whether `libvips` reports possible memory leaks. To enable leak detection (on `bash` compatible systems):\n```bash\nexport VIPS_LEAK=true\n```\n\nTo stop leak detection:\n```bash\nunset VIPS_LEAK\n```","title":"Memory Leak Detection - Image Install & Configure","ref":"readme.html#memory-leak-detection"},{"type":"extras","doc":"`Image` (because of `Vix` and `libvips`) will execute concurrent image operations using a number of system native threads (not BEAM processes). The number of threads available for concurrent image operations is configurable by either setting the environment variable `VIPS_CONCURRENCY` or through a call to `Image.put_concurrency/1`.  The current number of configured threads is returned from `Image.get_concurrency/0`.\n\nThe default number of threads is equal to the number of cores detected on the running system. This may create CPU contention with other workloads given that image processing is CPU intensive.  Therefore it may be prudent to reduce the number of threads if overall system throughput is being affected.","title":"Concurrency - Image Install & Configure","ref":"readme.html#concurrency"},{"type":"extras","doc":"Text image generation uses fonts installed and managed by [fontconfig](https://www.freedesktop.org/wiki/Software/fontconfig/). Debug information output is controlled by the [FC_DEBUG](https://www.freedesktop.org/software/fontconfig/fontconfig-user.html) environment variable.","title":"Fontconfig Debug Output - Image Install & Configure","ref":"readme.html#fontconfig-debug-output"},{"type":"extras","doc":"In a future release, `:image` will be split into several packages\n\n* `:image` which will retain all the core components of image transformation based upon `vix` and `libvips`.\n* `:image_nx` which will provide `:nx` interoperability (and will depend on `:image`)\n* `:image_exif` which will provide metadata support (and will depend on `:image`)\n* `:image_classification` which will provide image classification (and will depend on `:image` and `:bumblebee`)\n* `:image_generation` which will provide image generation (and will depend on `:image` and `:bumblebee`)\n* `:image_detection` which will provide object detection (and will depend on `:image`, `:axon`, `:axon_onnx`)\n* `:image_qrcode` which will provide QRcode scanning and production (and will depend on`:image` and `:evision`)\n* `:image_video` which will provide video frame extraction (and will depend on`:image` and `:evision`)","title":"Library packaging future - Image Install & Configure","ref":"readme.html#library-packaging-future"},{"type":"extras","doc":"There are several considerations in the use of any image processing library and any NIF-based library:\n\n1. If a NIF crashes it will likely bring down the BEAM virtual machine. `libvips` is a robust, time-tested library however this risk cannot be eliminated.\n\n2. Image processing is CPU intensive with its concurrent pipelining model and default concurrency level equal to the number of cores in the host machine, CPU starvation for other parts of the application is a possibility. In such cases, reducing the `libvips` concurrency is recommended.\n\n3. Image processing by its nature operates on external data and there have been exploits based upon maliciously crafted images. The two primary vectors are:\n    * An invalid image format that causes the image parser to crash and therefore crash the NIF and the BEAM\n    * Executable code embedded in image metadata (such as EXIF data) that if passed un-escaped to a web browser may result in arbitrary code execution.\n\nIn comparison to `Imagemagick` that has a reported [638](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=imagemagick) CVEs, there have been only  [8](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=libvips) CVE's reported for `libvips`, each resolved in a very timely manner.","title":"Security Considerations - Image Install & Configure","ref":"readme.html#security-considerations"},{"type":"extras","doc":"# Thumbnailing\n\n \n  .column {\n    float: left;\n    width: 33.33%;\n    padding: 5px;\n  }\n\n  /* Clear floats after image containers */\n  .row::after {\n    content: \"\";\n    clear: both;\n    display: table;\n  }\n\n  figure {\n      border: 3px solid #FF1493;\n      display: flex;\n      flex-flow: column;\n      padding: 0;\n      width: 200px;\n      height: 200px;\n      margin: auto;\n      width: 200px;\n      height: 200px;\n  }\n\n  img {\n      max-width: 200px;\n      max-height: 200px;\n      padding: 0;\n      margin: 0\n  }\n\n  figcaption {\n      background-color: #222;\n      color: #fff;\n      font: smaller sans-serif;\n      margin-top: 10px;\n      padding: 3px;\n      text-align: center;\n  }\n \n\nBasic code:\n\n```elixir\niex> original_raw = File.read!(\"/path/to_original.jpg\"); nil\nnil\niex> {:ok, original} = Image.from_binary(original_raw)\n{:ok, %Vix.Vips.Image{ref: #Reference<0.4099923103.164495390.164069>}}\niex> {:ok, thumbnail} = Image.thumbnail(original, 200)\n{:ok, %Vix.Vips.Image{ref: #Reference<0.4099923103.164495390.164078>}}\niex> Image.write(thumbnail, \"/tmp/thumbnail.png\")\n{:ok, %Vix.Vips.Image{ref: #Reference<0.4099923103.164495390.164078>}}\niex> Image.write(thumbnail, \"/path/to_thumbnail.png\")\n{:ok, %Vix.Vips.Image{ref: #Reference<0.4099923103.164495390.164078>}}\n```\n\nExamples:\n\n \n \n   \n       \n   \n   Image.thumbnail(image, 200, crop: :none) \n \n \n   \n       \n   \n   Image.thumbnail(image, 200, crop: :attention) \n \n \n   \n       \n   \n   Image.crop!(image, 550, 320, 200, 200) \n \n \n\n \n \n   \n       \n   \n   image |> Image.thumbnail!(200, crop: :attention) |> Image.rounded!() \n \n \n   \n       \n   \n   image |> Image.thumbnail!(200, crop: :attention) |> Image.squircle!() \n \n \n   \n       \n   \n   Image.avatar(image, 200)","title":"Thumbnailing","ref":"thumbnailing.html"},{"type":"extras","doc":"<!-- livebook:{\"persist_outputs\":true} -->\n\n# Edge Masking\n\n```elixir\nMix.install([\n  {:image, \"~> 0.42\"},\n  {:req, \"> 0.0.0\"},\n  {:kino, \"> 0.0.0\"}\n])\n```","title":"Edge Masking","ref":"image_edge_masking.html"},{"type":"extras","doc":"Image edge masking is used to create an alpha mask from the edges of an image. The mask can then be used to add transparency to a base image or to perform transformations to a region of an image.","title":"Introduction - Edge Masking","ref":"image_edge_masking.html#introduction"},{"type":"extras","doc":"Our base image is a jigsaw piece. It has a dark border around an orange fill on a white background. We'll source it from github.\n\n```elixir\n{:ok, response} =\n  Req.get(\n    \"https://raw.githubusercontent.com/elixir-image/image/main/test/support/images/jigsaw.png\"\n  )\n\njigsaw = Image.open!(response.body)\n```","title":"Open the base image - Edge Masking","ref":"image_edge_masking.html#open-the-base-image"},{"type":"extras","doc":"There are several ways to do edge detection. [Vix](https://hex.pm/packages/vix), which powers the `Image` library and which is itself based upon the amazing [libvips](https://libvips.org), provides both [canny](https://en.wikipedia.org/wiki/Canny_edge_detector) and [sobel](https://en.wikipedia.org/wiki/Sobel_operator) edge detection functions.\nFor this example, we can use the uniformity of the image colors to simplify the edge detection by converting the image to greyscale and multipling all the pixels in the image by 3.  This will result in all but the dark edge pixels becoming white. Why 3?  Its just a number found by empirical means to deliver the required result.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n`Image` provides several basic math functions in the `Image.Math` module. For clarity and in alignment with the goals of Elixir to be explicit, those functions are to be preferred. However there are cases where being explicit also introduces confusion. In these cases we can `use Image.Math` to override the basic arithmetic operators. We'll `use Image.Math` for some of this tutorial.\n\n```elixir\n# `using` Image.Math means the `*` operator is overriden and will call \n# `Image.Math.multiply(jigsaw, 3)`.\nuse Image.Math\n{ok, grey_jigsaw} = Image.to_colorspace(jigsaw, :bw)\nedges = grey_jigsaw * 3\n```","title":"Edge Detection - Edge Masking","ref":"image_edge_masking.html#edge-detection"},{"type":"extras","doc":"Now we have the edge (that was easy!) on a white background. But the edge is quite faint, in the final image, a slightly thicker edge would be easier to visualise. We use the concept of [dilation and erosion](https://www.scaler.com/topics/erosion-and-dilation-in-image-processing/) to increase the thickness of the edge.  `Image.dilate/2` and `Image.erode/2` support those functions.\n\nNote that dilation is the process of increasing the volume of light areas and erosion is the idea of increasing the volume of dark areas. Therefore `Image.erode/2` is the tool we want.\n\n```elixir\nthick_edges = Image.erode!(edges, 3)[0]\n```\n\nNotice that we used `Image.erode!(edges, 3)[0]`. The `[0]` uses the [Access Behaviour](https://hexdocs.pm/elixir/1.16.0/Access.html) to return just the 0th band of the image (band is the term used in `libvips`, you might know it as a channel in `OpenCV`).\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nNow we have strong edges, but we can now see there are varying greyscale values and we would much prefer uniform black for the edge mask. Here we can use the handy `Image.if_then_else/3` function. In this example, if the pixel value is > 200 in the `thick_edges` image, then set the corresponding pixel to `255` (white) and if not, set it to `0` (black).\n\n```elixir\nmask = Image.if_then_else!(thick_edges > 200, 255, 0)\n```\n\nThats it for creating our mask. We'll use this image as the alpha mask on our final image to define transparency.","title":"Refining the selection - Edge Masking","ref":"image_edge_masking.html#refining-the-selection"},{"type":"extras","doc":"In our example we want to produce a coloured outline of the jigsaw set on a transparent background. We've now created the mask that will manage the transparency part. How do we create the green outline?\n\nWe can use our old friend `Image.if_then_else/3` for that.\n\n```elixir\ngreen_outline = Image.if_then_else!(mask < 100, :green, :white)\n```","title":"Creating an image outline - Edge Masking","ref":"image_edge_masking.html#creating-an-image-outline"},{"type":"extras","doc":"Now we have our mask image in `mask` and our green outline in `green_outline`. How do we apply the mask to the green outline?  We can use the `Image.add_alpha/2` function to use `mask` as our alpha layer for the `green_outline` image.\n\nYou'll see that we are using only the 0th band of the mask image since the we just need one band for the alpha - and in our mask image all three bands are the same since its a black and white image.\n\n```elixir\nImage.add_alpha!(green_outline, mask[0])\n```\n\nOh no - what happened! The image has become all white!  That because our mask image is actually the inverse of how masking works. For an alpha mask, black is transparent and white is opaque. We can invert the mask with `Image.invert!/1`.\n\n```elixir\ninverted_mask = Image.invert!(mask[0])\nfinal_image = Image.add_alpha!(green_outline, inverted_mask)\n```\n\nAnd there we have it. A green outline on a transparent background.  Liveview and Kino don't yet have a way to show the transparency for visual checking but you can use the code block below to same the image somewhere and check in your favourite imaging app. The file preview function on MacOS works well for that.\n\nMake sure you save the image to a `.png` file, or other image format that supports transparency. Note that JPEG does not support transparency.\n\n```elixir\n# Image.write(final_image, \"some/path/to/final_image.png\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:ok, %Vix.Vips.Image{ref: #Reference<0.4180048996.1535508509.233750>}}\n```","title":"Compositing the outline and the mask - Edge Masking","ref":"image_edge_masking.html#compositing-the-outline-and-the-mask"},{"type":"extras","doc":"If you got this far then well done and congratulations on your patience. You'll have worked out that most of the process described here can be collapsed into a couple of short pipelines - thats certainly what I would do.","title":"Summary - Edge Masking","ref":"image_edge_masking.html#summary"},{"type":"extras","doc":"# Color Clustering and Dominant Colors\n\n```elixir\nMix.install([\n  {:nx, \"~> 0.7\"},\n  {:nx_image, \"~> 0.1\"},\n  {:scholar, \"~> 0.3\"},\n  {:exla, \"~> 0.7\"},\n  {:kino, \"~> 0.13\"},\n  {:image, \"~> 0.51\"}\n],\n config: [\n    nx: [\n      default_backend: EXLA.Backend,\n      default_defn_options: [compiler: EXLA]\n    ]\n  ]\n)\n\nprevious_inspect = Inspect.Opts.default_inspect_fun()\n\nInspect.Opts.default_inspect_fun(fn term, opts ->\n  previous_inspect.(term, %Inspect.Opts{opts | charlists: :as_lists})\nend)\n```","title":"Color Clustering and Dominant Colors","ref":"color_clustering.html"},{"type":"extras","doc":"```elixir\nimage_input = Kino.Input.image(\"An image to be uploaded\")\n```\n\n`Image.from_kino/1` knows how to take a kino input and open it. We'll resize the image since the k-means algorithm is slow if there isn't a GPU available for Nx (which underpins `Scholar.Cluster.KMeans.fit/2`). The number of colors in the image isn't significantly reduced so the results will be good enough. `Image.shape/1` returns the width, height and number of bands (channels) in the image.\n\n```elixir\n{:ok, image} = \n  image_input\n  |> Kino.Input.read()\n  |> Image.from_kino!()\n  |> Image.resize(0.5)\n\nImage.shape(image)\n```","title":"Choose an image - Color Clustering and Dominant Colors","ref":"color_clustering.html#choose-an-image"},{"type":"extras","doc":"Dominant colors are those colors that appear with the highest frequency in an image. The distribution of color in an image can be seen with an [image histogram](https://en.wikipedia.org/wiki/Image_histogram#:~:text=An%20image%20histogram%20is%20a,tonal%20distribution%20at%20a%20glance.). We can use `Image.Histogram.as_image/1` to see that distribution in an image.\n\n```elixir\nimage\n|> Image.Histogram.as_image!()\n|> Image.to_kino()\n\n```\n\nThe histogram image shows the distribution of the three color primaries that are the consituents of an [sRGB](https://en.wikipedia.org/wiki/SRGB#:~:text=sRGB%20is%20a%20standard%20RGB,and%20the%20World%20Wide%20Web.) image and a white line that shows the luminance distribution.\n\nNow lets get the 32 most dominant colors in the image. Dominant colors is simply those colors that appear most often in the image.\n\n```elixir\ndominant_colors = Image.dominant_color!(image, top_n: 32)\n```\n\nOK, great, but thats not a very friendly way to visualize the colors. Lets do something about that.\n\n```elixir\ndominant_colors\n|> Enum.map(fn color -> \n  Image.new!(50, 50, color: color) \n  |> Image.to_kino()\nend)\n|> Kino.Layout.grid(columns: 10)\n```","title":"Dominant Colors - Color Clustering and Dominant Colors","ref":"color_clustering.html#dominant-colors"},{"type":"extras","doc":"Well now we can see the dominant colors, in descending frequency order. Can we see the colors in sorted order? Yes, thats possible. But what does sorting colors even mean? In `Image.Color.sort/2` we use the approach documented [here](https://www.alanzucconi.com/2015/09/30/colour-sorting/). Colors are converted to a weighted [[hue](https://en.wikipedia.org/wiki/Hue), [luminance](https://en.wikipedia.org/wiki/Luminance), value] color space which is one way to perceptually sort colors.\n\n```elixir\nsorted_dominant_colors = Image.Color.sort(dominant_colors)\n\nsorted_dominant_colors  \n|> Enum.map(fn color -> \n  Image.new!(50, 50, color: color) \n  |> Image.to_kino()\nend)\n|> Kino.Layout.grid(columns: 10)\n```","title":"Color Sorting - Color Clustering and Dominant Colors","ref":"color_clustering.html#color-sorting"},{"type":"extras","doc":"Depending on your image, its quite likely the most dominant colors are probably quite similar. In many cases they may well look the same.  Can we describe how close the colors are to each other?\n\nYes, we can! The approach to [color difference](https://en.wikipedia.org/wiki/Color_difference) is called [ΔE*](https://en.wikipedia.org/wiki/Color_difference#CIELAB_ΔE*), commonly referred to as Delta E. In `Image` the function is `Image.delta_e/2`.\n\nLets take the colors in sorted order and see the distance (color difference) between adjacent colors.\n\n```elixir\ndefmodule ColorDiff do\n  def difference([c1, c2 | rest]), do: [elem(Image.delta_e(c1, c2), 1) | difference([c2 | rest])]\n  def difference([_c1]), do: []\nend\n\nColorDiff.difference(sorted_dominant_colors)\n```\n\nDepending on the image, some of the differences are likely to be quite small. In fact it is quite possible the differences are below the [just noticeable difference (JND)](https://en.wikipedia.org/wiki/Just-noticeable_difference) threshold. Any number below 2.3 means the two colors are probably indistinguishable to the human eye.","title":"Color Difference - Color Clustering and Dominant Colors","ref":"color_clustering.html#color-difference"},{"type":"extras","doc":"While dominant colors are interesting, they don't fully represent the range of colors in an image. In order to do that we need some means of describing a color palette. To do that we use the [K Means](https://stanford.edu/~cpiech/cs221/handouts/kmeans.html#:~:text=K%2DMeans%20is%20one%20of,centroid%20than%20any%20other%20centroid.) clustering algorithm which is implemented in the [scholar](https://hex.pm/packages/scholar) library. When `scholar` is configured, the `Image.k_means/2` function is made available.\n\nSince `scholar` depends on `nx` we know that performance is proportional to image size - and more particularly on whether a GPU is available and supported.\n\nFor this section its recommended the image size be under 1_000_000 pixels or even smaller in order to provide reasonable performance without a GPU.\n\n```elixir\n# Reduce the size of the image to a maximum number of 100_000 pixels\nmax_pixels = 100_000\n{width, height, _bands} = Image.shape(image)\npixels = width * height\nsmall_image = if pixels <= max_pixels, do: image, else: Image.resize!(image, max_pixels / pixels)\n```\n\nNow let call the K-means function to return the clusters into which all the colors of the image are assigned. We can set the number of clusters with the `:num_clusters` option which defaults to `16`.\n\n```elixir\nk_means = Image.k_means!(small_image, num_clusters: 32)\n```\n\nAs with our dominant colors example, lets take a look at the centroids as color swatches.\n\n```elixir\nk_means\n|> Image.Color.sort()\n|> Enum.map(fn color -> \n  Image.new!(50, 50, color: color) \n  |> Image.to_kino()\nend)\n|> Kino.Layout.grid(columns: 10)\n```\n\nWe can see that this set of colors covers the full range of colors in the image, not just the dominant colors. Let's see how different these colors are from each other. We should expect a much wider color difference between adjacent colors.\n\n```elixir\nk_means\n|> Image.Color.sort()\n|> ColorDiff.difference()\n```","title":"Color Clustering (K-Means) - Color Clustering and Dominant Colors","ref":"color_clustering.html#color-clustering-k-means"},{"type":"extras","doc":"You might be wondering at this point, what would the image look like if it only used the colors returned from `Image.k_means/2`. Well we can do that too by using the `Image.reduce_colors/2` function. This function calls `Image.k_means/2` under the hood, then replaces each pixel in the image with the cluster color that is closest to it.\n\nIn this example we'll see what the base image looks like using 2, 4, 8, 16, 32 and 64 colors.\n\n```elixir\nEnum.map([2, 4, 8, 16, 32, 64], fn colors ->\n  small_image\n  |> Image.reduce_colors!(colors: colors)\n  |> Image.to_kino()\nend)\n|> Kino.Layout.grid(columns: 3)\n\n```\n\nDepending on the image, you may well find that the perceived difference of the last 2 or 3 images is quite small. That is why one of the techniques used by different image formats to reduce file sizes is to reduce the number of bits used to represent colors. They may not use K-means but they do color clustering to derive a reduced color palette.","title":"Color Reduction - Color Clustering and Dominant Colors","ref":"color_clustering.html#color-reduction"},{"type":"extras","doc":"<!-- livebook:{\"app_settings\":{\"show_source\":true,\"slug\":\"test\"},\"file_entries\":[{\"file\":{\"file_system_id\":\"local\",\"file_system_type\":\"local\",\"path\":\"/Users/erisson/Documents/DEV/LEARNING/IA/SamOrtex/chair.jpg\"},\"name\":\"chair.jpg\",\"type\":\"file\"},{\"file\":{\"file_system_id\":\"local\",\"file_system_type\":\"local\",\"path\":\"/Users/erisson/Documents/hhh.png\"},\"name\":\"hhh.png\",\"type\":\"file\"},{\"file\":{\"file_system_id\":\"local\",\"file_system_type\":\"local\",\"path\":\"/Users/erisson/Downloads/poulet.jpeg\"},\"name\":\"poulet.jpeg\",\"type\":\"file\"},{\"name\":\"prompt_encoder_mask_decoder.onnx\",\"type\":\"attachment\"},{\"file\":{\"file_system_id\":\"local\",\"file_system_type\":\"local\",\"path\":\"/Users/erisson/Downloads/tinymodel.onnx\"},\"name\":\"tinymodel.onnx\",\"type\":\"file\"},{\"name\":\"vision_encoder.onnx\",\"type\":\"attachment\"},{\"name\":\"vision_encoder_quantized.onnx\",\"type\":\"attachment\"}]} -->\n\n# Segment Anything Model (SAM) using Ortex\n\n```elixir\nMix.install([\n  {:ortex, \"~> 0.1.9\"},\n  {:image, \"~> 0.47\"},\n  {:nx_image, \"~> 0.1.2\"},\n  {:exla, \"~> 0.7.2\"},\n  {:kino, \"~> 0.12.3\"},\n  {:req, \"~> 0.4\"}\n])\n```","title":"Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html"},{"type":"extras","doc":"This is an implementation by @herisson of the [Segment Anything Model](https://github.com/facebookresearch/segment-anything) (SAM) from facebook research using the [Ortex](https://github.com/elixir-nx/ortex) library to run ONNX models.\n\nIt is approximately a port this jupyter notebook example to livebook: https://colab.research.google.com/drive/1wmjHHcrZ_s8iFuVFh9iHo6GbUS_xH5xq\n\nIt uses the onnx \"mobile\" models found [here](https://huggingface.co/vietanhdev/segment-anything-onnx-models/tree/main).\n\n```elixir\nNx.global_default_backend(EXLA.Backend)\nNx.default_backend()\n```","title":"Recap - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#recap"},{"type":"extras","doc":"```elixir\nencoder_url =\n  \"https://huggingface.co/ginkgoo/SegmentAnythingModel-Elixir-Ortex/resolve/main/vision_encoder_quantized.onnx\"\n\nencoder_path = \"/tmp/vision_encoder_quantized.onnx\"\n\n%{body: body} = Req.get!(encoder_url)\nFile.write!(encoder_path, body)\n\nmodel = Ortex.load(encoder_path)\n```\n\n```elixir\ndecoder_url =\n  \"https://huggingface.co/ginkgoo/SegmentAnythingModel-Elixir-Ortex/resolve/main/vit_b_decoder.onnx\"\n\ndecoder_path = \"/tmp/vit_b_decoder.onnx\"\n\n%{body: body} = Req.get!(decoder_url)\nFile.write!(decoder_path, body)\n\ndecoder = Ortex.load(decoder_path)\n```","title":"Loading the models - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#loading-the-models"},{"type":"extras","doc":"```elixir\nimage_input = Kino.Input.image(\"Uploaded Image\")\n# https://ibb.co/Hr8588Y the image I'm using\n```\n\n```elixir\nimage =\n  Kino.Input.read(image_input)\n  |> Image.from_kino!()\n\n# The demo image is already these dimensions\n# but other images may not be.\nresized =\n  Image.thumbnail!(image, \"1024x1024\")\n\noriginal_label = Kino.Markdown.new(\"**Original image**\")\nresized_label = Kino.Markdown.new(\"**Resized image**\")\n\nKino.Layout.grid(\n  [\n    Kino.Layout.grid([image, original_label], boxed: true),\n    Kino.Layout.grid([resized, resized_label], boxed: true)\n  ],\n  columns: 2\n)\n```\n\n```elixir\n# Send the image to Nx. This is a zero-copy\n# operation - basically just give the pointer\n# to a memory area to Nx.\ntensor =\n  resized\n  |> Image.to_nx!()\n  |> Nx.as_type(:f32)\n\n# Mean and std values copied from transformer.js\nmean = Nx.tensor([123.675, 116.28, 103.53])\nstd = Nx.tensor([58.395, 57.12, 57.375])\n\nnormalized_tensor =\n  tensor\n  |> NxImage.normalize(mean, std)\n  |> Nx.tensor(names: [:height, :width, :bands])\n  |> Nx.transpose(axes: [:bands, :height, :width])\n\n# Running image encoder / outputs depends on the onnx model\n{image_embeddings, _} = Ortex.run(model, Nx.broadcast(normalized_tensor, {1, 3, 1024, 1024}))\n# {image_embeddings} = Ortex.run(model, Nx.broadcast(normalized_tensor, {1024, 1024, 3}))\n```","title":"Getting the image - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#getting-the-image"},{"type":"extras","doc":"```elixir\n# prepare inputs\n# xy box coordinates in our image of the object we want to detour\n# input_point = Nx.tensor([[345, 272], [640, 760]]) |> Nx.as_type(:f32) |> Nx.reshape({1, 2, 2})\n# 2, 3 is for box startig / end points\n# input_label = Nx.tensor([2, 3]) |> Nx.reshape({1, 2}) |> Nx.as_type(:f32)\n# single point\ninput_point = Nx.tensor([[514, 514], [0, 0]]) |> Nx.as_type(:f32) |> Nx.reshape({1, 2, 2})\ninput_label = Nx.tensor([1, -1]) |> Nx.reshape({1, 2}) |> Nx.as_type(:f32)\n# Filled with 0, not used here\nmask_input = Nx.broadcast(0, {1, 1, 256, 256}) |> Nx.as_type(:f32)\n# not using mask_input\nhas_mask = Nx.broadcast(0, 1) |> Nx.as_type(:f32)\noriginal_image_dim = Nx.tensor([1024, 1024]) |> Nx.as_type(:f32)\n\n{mask, scores, low_res} =\n  Ortex.run(decoder, {\n    Nx.broadcast(image_embeddings, {1, 256, 64, 64}),\n    Nx.broadcast(input_point, {1, 2, 2}),\n    Nx.broadcast(input_label, {1, 2}),\n    Nx.broadcast(mask_input, {1, 1, 256, 256}),\n    Nx.broadcast(has_mask, {1}),\n    Nx.broadcast(original_image_dim, {2})\n  })\n```","title":"Prompt encoding & mask generation - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#prompt-encoding-mask-generation"},{"type":"extras","doc":"```elixir\nuse Image.Math\n\nmask =\n  mask[0][2]\n  |> Nx.reshape({1024, 1024, 1})\n  |> Image.from_nx!()\n\nlow_res =\n  low_res[0][2]\n  |> Nx.reshape({256, 256, 1})\n  |> Image.from_nx!()\n\n# Threshold the masks to produce black and white\n# This is one NIF call only. Then then take only the\n# first band which we'll use as the alpha band.\nmask = Image.if_then_else!(mask > 0, 255, 0)[0]\nlow_res_mask = Image.if_then_else!(mask > 0, 255, 0)[0]\n\nmask_label = Kino.Markdown.new(\"**Mask**\")\nlow_res_label = Kino.Markdown.new(\"**Low Res**\")\n\nKino.Layout.grid(\n  [\n    Kino.Layout.grid([mask, mask_label], boxed: true),\n    Kino.Layout.grid([low_res_mask, low_res_label], boxed: true)\n  ],\n  columns: 2\n)\n```","title":"Transform output to a black an white image - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#transform-output-to-a-black-an-white-image"},{"type":"extras","doc":"As you can see the high res mask is distorted / badly placed. However, the low res mask fits corectly ??\n\n```elixir\nnew_image = Image.add_alpha!(image, mask)\nmask_label = Kino.Markdown.new(\"**Image mask**\")\nnew_image_label = Kino.Markdown.new(\"**new image**\")\n\nKino.Layout.grid(\n  [\n    Kino.Layout.grid([image, original_label], boxed: true),\n    Kino.Layout.grid([mask, mask_label], boxed: true),\n    Kino.Layout.grid([new_image, new_image_label], boxed: true)\n  ],\n  columns: 3\n)\n```\n\n<!-- livebook:{\"offset\":5945,\"stamp\":{\"token\":\"XCP.gTD1Ek0FTMYRBAVlGrzKnqpjwGMRtcel41K4P2h_iObPzyJErUfmScHej1HFwZz-sbUZhbT2uv7_QmT7jjwdQlFfIp2O9k4Nw0sKTtSGF0gpbRwFIGtLhKOalaDwEmzriMfPwY5cTs1hrOAoHC8_01RfsEcUg0e8E0xQp_JKKSkcLuAsbQD5GutNupFqmA\",\"version\":2}} -->","title":"Showing the masks - Segment Anything Model (SAM) using Ortex","ref":"segment_anything.html#showing-the-masks"},{"type":"extras","doc":"# License\n\nCopyright 2022-2024 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","title":"License","ref":"license.html"},{"type":"extras","doc":"# Changelog","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"This is the changelog for Image version 0.52.2 released on July 9th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.52.2 - Changelog","ref":"changelog.html#image-0-52-2"},{"type":"extras","doc":"* Fix the return from `Image.contrast/2`. Thanks to @RyoWakabayashi for the report and the PR. Closes #144.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.52.1 released on July 3rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.52.1 - Changelog","ref":"changelog.html#image-0-52-1"},{"type":"extras","doc":"* Fix including `Image.Nx` only if `Nx` is configured.  Closes #143.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.52.0 released on July 3rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.52.0 - Changelog","ref":"changelog.html#image-0-52-0"},{"type":"extras","doc":"* Adds `:background_color` option to `Image.flatten/2`.\n\n* Add `Image.Nx` to host some `Nx` convenience functions.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Fix `Image.delta_e/2` to return a float (not an integer)\n\n* Fix `Image.k_means/2` to work with images in color spaces other than sRGB.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.51.0 released on June 29th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.51.0 - Changelog","ref":"changelog.html#image-0-51-0"},{"type":"extras","doc":"* Adds Image.to_kino/1 to convert an image to a Kino image struct. Only available if [Kino](https://hex.pm/packages/kino) is configured.\n\n* Adds `Image.delta_e!/2`\n\n* Adds `Image.reduce_colors!/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.50.0 released on June 28th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.50.0 - Changelog","ref":"changelog.html#image-0-50-0"},{"type":"extras","doc":"* Adds `Image.reduce_colors/2` to reduce the number of colors in an image. `Scholar.Cluster.KMeans.fit/2` is used to cluster the colors. The clusters are then used to recolor the image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.49.0 released on June 28th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.49.0 - Changelog","ref":"changelog.html#image-0-49-0"},{"type":"extras","doc":"* Updates `Image.dominant_color/2` to take an optional `:top_n` which indicates how many of the most dominant colors to return. The default is `1`. In addition, the implementation of `Image.dominant_color/2` has been simplified following the advice at https://github.com/libvips/libvips/discussions/4016\n\n* Adds `Image.delta_e/3` to calculate a difference between two colors using one of the CIE color difference algorithms.\n\n* Adds `Image.k_means/2` to cluster image colors into a color palette. This function is only available if [scholar](https://hex.pm/packages/scholar) is configured. As for any [Nx](https://hex.pm/packages/nx) installation, performance is affected by configuration options. It is likely that setting the following in `config.exs` will be a good idea:\n\n```elixir\nconfig :nx,\n  default_backend: EXLA.Backend\n\nconfig :nx, :default_defn_options,\n  compiler: EXLA\n```\n\n* Adds `Image.Color.sort/2` to sort colors perceptually.\n\n* Adds `Image.Color.convert/3` to convert a color from one color space to another. Currently only supports `srgb_to_hsv`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.48.1 released on June 6th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.48.1 - Changelog","ref":"changelog.html#image-0-48-1"},{"type":"extras","doc":"* Relax `evision` dependency to allow the `0.2` chain as well as the `0.1` chain. Thanks to @davydog187 for the report. Closes #140.\n\n* Fix `Evision.resize/3` parameter to be `:interpolation` rather than `:interpolate`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.48.0 released on May 30th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.48.0 - Changelog","ref":"changelog.html#image-0-48-0"},{"type":"extras","doc":"* Add `:model_options` and `:featurizer_options` configuration keys for `Image.Classifier`. These options are expected to be the options passed to `Bumblebee.load_model/2` and `Bumblebee.load_featurizer/2` respectively.\n\n* Add `:batch_size` as a configuration option. The value is passed to `Bumblebee.Vision.image_classification/4`. The default value is `10`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.47.0 released on May 14th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.47.0 - Changelog","ref":"changelog.html#image-0-47-0"},{"type":"extras","doc":"* Fix warnings for Elixir 1.17","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `Image.from_nx!/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.46.0 released on May 11th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.46.0 - Changelog","ref":"changelog.html#image-0-46-0"},{"type":"extras","doc":"* Adds `:dpi` as an option to `Image.Text.text/2` and `Image.Text.simple_text/2`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.45.0 released on May 6th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.45.0 - Changelog","ref":"changelog.html#image-0-45-0"},{"type":"extras","doc":"The implementations of `Image.text/2` and `Image.simple_text/2` have been simplified to use only the built-in Pango renderer. A bug in font sizing using the Pango renderer has also been fixed. As a result, there may be some small visual differences between text images generated by Image 0.45.0 compared to previous releases.\n\n* `Image.text/2` now uses only the built-in [Pango](https://docs.gtk.org/Pango/pango_markup.html) renderer for all use cases. SVG is not nhow used for any rendering in `Image.text/2` or `Image.simple_text/2`. This gives a more consistent output and less ambiguity. However as a result, a small number of options are no longer available since they cannot be honoured by Pango:\n\n  * `:text_stroke_color`\n\n  * `:text_stroke_width`\n\n* The `:autofit` option to `Image.text/2` is also removed. The autofit capability is now controlled by whether the `:width` and/or `:height` options are provided.\n\n* Some other options are now treated differently in `Image.text/2`:\n\n  * `:width` and `:height` are now truly optional. If ommitted, the renderer will calculate the required image size based upon the other options. It is acceptable to specify `:width` and omit `:height` in which case the maximum width is fixed and the height is variable.","title":"Breaking changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"* Fix warnings on upcoming Elixir 1.17.\n\n* A bug resulting in incorrect font sizing with using the Pango renderer has been fixed. Font sizing is now very similar to the sizing of the previously used SVG renderer.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.44.0 released on April 9th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.44.0 - Changelog","ref":"changelog.html#image-0-44-0"},{"type":"extras","doc":"* Adds `Image.Blurhash.encode/2` and `Image.Blurhash.decode/1` to encode and decode [blurhashes](https://blurha.sh). Based upon a fork of [rinpatch_blurhash](https://github.com/rinpatch/blurhash). Thanks to @stiang for the suggestion. Thanks very much to @rinpatch for the implementation.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.43.2 released on April 2nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.43.2 - Changelog","ref":"changelog.html#image-0-43-2"},{"type":"extras","doc":"* Fix typo in exif `:subsec_time_original`.\n\n* Remove spurious leading space from exif tag description \" Standard Output Sensitivity and Recommended Exposure Index\"\n\n* Fix decoding exif tags that have an empty string as a value.\n\nThanks to Cam Cook for the issues.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.43.1 released on March 22nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.43.1 - Changelog","ref":"changelog.html#image-0-43-1"},{"type":"extras","doc":"* `Image.from_kino/2` and `Image.from_kino!/2` now use the `:file_ref` field in the Kino input structure to identify the required image. This changed was added in [Kino 0.11](https://github.com/livebook-dev/kino/blob/main/CHANGELOG.md#v0110-2023-10-06) which is therefore now a minimum version requirement. Thanks to @kevinschweikert for the PR. Closes #133.\n\n* Improve the thumbnailing guide. Thanks to @nathanl for the PR. Closes #132.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.43.0 released on February 27th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.43.0 - Changelog","ref":"changelog.html#image-0-43-0"},{"type":"extras","doc":"* `Image.erode/2` and `Image.dilate/2` now take a `radius` parameter rather than a `pixels` parameter. Both functions have been refactored to allow a radius in the range `1..5` with a default of `1`. The radius represents the dimension of the matrix used in the `Vix.Vips.Operations.range/4` function that underpins dilation and erosion. As such they represent the *approximate* number of pixels eroded or dilated.  In addition, this function now results in a single `libvips` operation. The previous implementation created `n` operations (where `n` was the value of the `pixels` param) that could result in a slow imaging pipeline and in some cases a [segfault of the entire VM due to stack space exhaustion in libvips](https://github.com/elixir-image/image/issues/125).\n\n* The signature for `Image.linear_gradient/{1..3}` has changed.  The function now takes:\n  * An image and an optional keyword list of options\n  * A width and height as numbers and a keyword list of options\n\n* `Image.dominant_color/2` now returns an `{:ok, rgb_color}` tuple rather than a `[r, g, b]` list. Use `Image.dominant_color!/2` if only the color value return is required.\n\n* `Image.map_pages/2` is deprecated in favour of `Image.map_join_pages/2` to better reflect the intent of the function.","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"* `Image.linear_gradient/{1..3}` now takes an `:angle` option which determines the angle of the gradient in degrees. Thanks to @severian1778 for considerable patience. Closes #67.\n\n* Improve options handling and documentation for `Image.radial_gradient/3`.\n\n* Add `Image.radial_gradient!/3` to mirror `Image.radial_gradient/3`.\n\n* Add `Image.dominant_color!/2` to mirror `Image.dominant_color/2`.\n\n* Add `Image.extract_pages/1` which will extract the pages of a multi-page into a list of separate images.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.42.0 released on January 23rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.42.0 - Changelog","ref":"changelog.html#image-0-42-0"},{"type":"extras","doc":"* `Image.interpretation/0` deprecated in favour of `Image.colorspace/0`. This is more orthogonal to the `Image.to_colorspace/2` call and more in line with common image lexicons.\n\n* `Image.convert_to_mask/1` is deprecated in favour of `Image.covert_alpha_to_mask/1` which is more descriptive of the functions purpose.\n\n* `Image.type/1` is deprecated in favour of `Image.band_format/1`. This function name expresses clearer intent.","title":"Deprecations - Changelog","ref":"changelog.html#deprecations"},{"type":"extras","doc":"* Fix `:rbg` colorspace to be the correct name of `:rgb`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Documentation updates for `Image.dilate/2` and `Image.erode/2`.\n\n* Add `Image.cast!/2` to mirror `Image.cast/2`.\n\n* Add `Image.invert/1` and `Image.invert!/2` to invert an image.\n\n* Add livebook tutorial for edge masking. [![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2Felixir-image%2Fimage%2Fmain%2Flivebook%2Fimage_edge_masking.livemd)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.41.0 released on January 18th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.41.0 - Changelog","ref":"changelog.html#image-0-41-0"},{"type":"extras","doc":"* Adds `Image.YUV` module that provides functions to convert between YUV and RGB image data. Thanks very much to @mat-hek for the collaboration. This module makes it easier to work with video image data which is typically in YUV encoded. The module supports [4:4:4, 4:2:2 and 4:2:0](https://en.wikipedia.org/wiki/Chroma_subsampling) encoding in either of the [BT601](https://en.wikipedia.org/wiki/Rec._601) or [BT709](https://en.wikipedia.org/wiki/Rec._709) colorspaces.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.40.0 released on January 6th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.40.0 - Changelog","ref":"changelog.html#image-0-40-0"},{"type":"extras","doc":"* Fix docs for `Image.new/1` (the docs for `Image.new/{2, 3}` are correct).","title":"Bug Fix - Changelog","ref":"changelog.html#bug-fix"},{"type":"extras","doc":"* Adds `Image.join/2` which takes a list of images and joins them into a grid.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.39.3 released on January 4th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.39.3 - Changelog","ref":"changelog.html#image-0-39-3"},{"type":"extras","doc":"* Fix typespec of `Image.write!/3` to include `:memory` as a valid destination.  Thanks to @LostKobrakai for the PR. Closes #124.","title":"Bug Fix - Changelog","ref":"changelog.html#bug-fix"},{"type":"extras","doc":"This is the changelog for Image version 0.39.2 released on January 2nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.39.2 - Changelog","ref":"changelog.html#image-0-39-2"},{"type":"extras","doc":"* Fix `Image.avatar/2` to correctly resize and maintain aspect ratio. Thanks to @samullen for the report and patience. Closes #123.","title":"Bug Fix - Changelog","ref":"changelog.html#bug-fix"},{"type":"extras","doc":"This is the changelog for Image version 0.39.1 released on December 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.39.1 - Changelog","ref":"changelog.html#image-0-39-1"},{"type":"extras","doc":"* Adds support for `phoenix_html` ~4.0 in addition to ~3.2 and ~2.1. Thanks to @tapickell for the PR.\n\n* Don't include `priv/models` in the hex package.","title":"Bug Fix - Changelog","ref":"changelog.html#bug-fix"},{"type":"extras","doc":"This is the changelog for Image version 0.39.0 released on December 15th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.39.0 - Changelog","ref":"changelog.html#image-0-39-0"},{"type":"extras","doc":"* `Image.open/2` no longer supports the `:autorotate` option. Instead, call `Image.autorotate/1` after opening the image. There reasons are:\n  * `:autorotate` is only supported by `libvips` for a few image types, *not* including `png` images. Hence the option cannot be used in a generalised way.\n  * No signalling is done to indicate whether the image was actually rotated whereas `Image.autorotate/1` does return this information.\n  * Using `autorotate: true` does not appear to remove the `orientation` EXIF tag and therefore calling `Image.autorotate/1` would result in a second rotation.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Fix finding the dominant color for images with an alpha band. Thansk to @mayel for the report. Closes #114.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.5 released on December 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.5 - Changelog","ref":"changelog.html#image-0-38-5"},{"type":"extras","doc":"* The `Image.embed/4` option `:background` is renamed to `:background_color` to better align with other functions.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Fix `Image.Text.add_background_padding/2` when the base image doesn't already have an alpha band. Thanks to @tielur for the report. Closes #120.\n\n* Fix `Image.embed/4` to default to `x: :center, y: :center` as stated in the documentation.\n\n* Fix `Image.embed/4` to set `extend_mode: :background` if `:background_color` is specified.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.4 released on November 9th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.4 - Changelog","ref":"changelog.html#image-0-38-4"},{"type":"extras","doc":"* Fixes `Image.dhash/2`. Thanks to @jhonathas for the report. Closes #118.\n\n* Fixes compiler warnings for Elixir 1.16.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.3 released on October 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.3 - Changelog","ref":"changelog.html#image-0-38-3"},{"type":"extras","doc":"* Due to [the fix](https://github.com/akash-akya/vix/pull/129) for [this issue](https://github.com/akash-akya/vix/issues/126) in [vix](https://github.com/akash-akya/vix), a fix is applied in `Image.nx/2` to ensure correct operation. There should be no change to user code other than the requirement for the versions of `image` and `vix` to correctly match.  This release of `image` requires `vix` version `0.23` to ensure compatibility.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.2 released on September 27th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.2 - Changelog","ref":"changelog.html#image-0-38-2"},{"type":"extras","doc":"* Fix `Image.dominant_color/2` for images with an alpha band.  Thanks to @mayel for the report. Closes #114.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.1 released on September 23rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.1 - Changelog","ref":"changelog.html#image-0-38-1"},{"type":"extras","doc":"* Fix `t:Image.Options.Avatar.avatar_options/0`. Thanks to @jarrodmoldrich. Closes #113.\n\n* Improves `Image.avatar/2` documentation and brings the docs into line with the implementation.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.38.0 released on September 11th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.38.0 - Changelog","ref":"changelog.html#image-0-38-0"},{"type":"extras","doc":"* Fix `extend_mode: :black` color handling for images with an alpha band. Also fixes when the image is a single band image.  Thanks to @icefoxen for reporting the issue. Closes #108.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds a [squircle](https://en.wikipedia.org/wiki/Squircle) mask function and a squircle avatar shape option. Thanks to @gf3 for the PR.\n\n* Adds `Image.map_pages/2` to execute a function for each page in a `.webp` or `.gif` image then reassemble the pages into a new image. This can be used to crop all the frames of an animated image.  Thanks to @Mefgalm for the prompt to get this done. Eventually this function will be used by default for `Image.crop/5` and `Image.thumnail/3`.\n\n* Adds `Image.pages/1` to return the number of pages in an image. For normal images the result will be `1`. For animated images it will be the number of frames in the animation.\n\n* Adds support for cropping multi-page images (like animated `.webp` and `.gif` images) in `Image.crop/5`.\n\n* Adds `Image.Shape.circle/2`, `Image.Shape.ellipse/3` and `Image.Shape.line/5` as well as their `!` counterparts.\n\n* Allow `pages: :all` as a synonym for `pages: -1` when opening an image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.37.0 released on August 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.37.0 - Changelog","ref":"changelog.html#image-0-37-0"},{"type":"extras","doc":"* Adds `background: :alpha` as an option to `Image.trim/2`. When set, the image is trimmed to the bounds of the mask in the alpha band of an image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.36.2 released on July 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.36.2 - Changelog","ref":"changelog.html#image-0-36-2"},{"type":"extras","doc":"* Fix `Image.from_nx/1` by respecting the axis name order in the tensor. Thanks to @gBillal for the PR. Closes #101.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.36.1 released on July 23rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.36.1 - Changelog","ref":"changelog.html#image-0-36-1"},{"type":"extras","doc":"* Support negative offsets `:x` and `:y` for `Image.compose/3`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.36.0 released on July 16th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.36.0 - Changelog","ref":"changelog.html#image-0-36-0"},{"type":"extras","doc":"* Adds `Image.Histogram.as_svg/2` and `Image.Histogram.as_image/2` to return the histogram of an image as either an SVG format suitable to adding to an HTML page or as an `t:Vix.Vips.Image.t/0`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.35.0 released on July 4th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.35.0 - Changelog","ref":"changelog.html#image-0-35-0"},{"type":"extras","doc":"* Removes `Image.autolevel/1` which is replaced by `Image.equalize(image, :each)`.\n\n* Removes `Image.normalize/1` which is replaced by `Image.equalize(image, :luminance)`.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Adds `Image.equalize/2` which expands an image to fill the tone range. Equalization can be performed on all bands, on each band or only on the luminance band. This function replaces `Image.normalize/1` and `Image.autolevel/1`.\n\n* Adds `Image.contrast/2` to apply simple contrast adjustments to an image. The contrast parameter is provided as a float >= 0.0 with contrast less than 1.0 meaning reduce contrast and greater than 1.0 meaning increase contrast.\n\n* Adds `Image.apply_tone_curve/2` which applies a [tone curve](https://en.wikipedia.org/wiki/Curve_(tonality)) to an image. This is typically used to affect overall image contrast.\n\n* Adds `Image.local_contrast/2` which applies a [Constrast Limited Adaptive histogram equalization (CLAHE)](https://en.wikipedia.org/wiki/Adaptive_histogram_equalization#Contrast_Limited_AHE) to improve local contrast in images.\n\n* Adds `Image.sharpen/2` to apply sharpening to an image.\n\n* Adds `Image.modulate/2` to adjust an image using brightness, saturation, hue rotation and lightness in a single call.\n\n* Adds `Image.band_format/1` to return the band format of an image in `Nx` notation.\n\n* Adds `Image.with_band_format/3` to cast an image to a new band format, execute a function on the cast image and then re-cast the image back to its original band format if the function returns successfully.\n\n* Adds `Image.range/1` that returns the possible range of values for a pixel as a tuple in the form `{min_value, max_value}`.\n\n* Adds `Image.reduce_noise/2` and `Image.reduce_noise!/2` that applies a median filter to reduce salt and pepper noise in an image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.34.0 released on June 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.34.0 - Changelog","ref":"changelog.html#image-0-34-0"},{"type":"extras","doc":"* Corrects generating text images with `Image.Text.text/2` whent the `text_stroke_color` and `text_fill_color` are black. Closes #87 (again).\n\n* Fixes using a combination of atom and numeric arguments to `Image.compose/3`. Thanks to @sodapopcan for the PR. Closes #97.\n\n* Removes a warning when testing without minio being installed. Thanks to @sodapopcan for the PR. Closes #95.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.compare/3` to compare two images for similarity using a given metric (default is `:ae` or absolute error). The three metrics implemented in this release are `:ae` (absolute error which returns a value between 0.0 and 1.0), `:mse` (mean squared error) and `:rmse` (root mean squared error which returns a value between 0.0 and 1.0).\n\n* Adds `Image.brightness/2` and `Image.saturation/2` to adjust the image brightness and saturation by a percentage amount between `0.0` and `1.0`. Also adds `Image.brightness!/2` and `Image.saturation!/2`.\n\n* Adds `hash_size` as an argument to `Image.hamming_distance/3`. This is the size in bits of the returned hash. The default is 64. The size of the returned hash is only guaranteed to be this size if the `:math.sqrt(hash_size)` is an integer.\n\n* Adds `:letter_spacing` as an option to `Image.Text.text/2`. Thanks to @sodapopcan for the PR. Closes #97.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.33.0 released on June 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.33.0 - Changelog","ref":"changelog.html#image-0-33-0"},{"type":"extras","doc":"* `Image.dhash/1` now returns a 64-bit hash (by default) rather than a 512-bit hash. The original algorithm is intended to return a 64-bit hash so this is both a breaking change and bug fix.\n\n* Fix generation of images from text when `autofit: false` (the default). In these cases the text image is generated from SVG. The original implementation operated on the basis that the image would be generated with a height and width necessary to contain the text of a given font size. The result is not consistent and is influenced by whether the text has ascenders or desenders.  The new implementation creates an SVG container of a size large enough to contain the text at the given font-size and then trims away the background to produce the final result. Thanks to @ilesar for the report. Closes #86. **As a result of this fix, existing text-generated images may not now be the same as previous releases.**","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"This is the changelog for Image version 0.32.0 released on May 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.32.0 - Changelog","ref":"changelog.html#image-0-32-0"},{"type":"extras","doc":"* Fix `Image.Text.text/2` when the text fill color is black (within a tolerance). When the text image is created, `Vix.Vips.Operation.find_trim/2` is called to trim the image assuming a black background. Since the fill color is also black, the resulting trim is 0 pixels wide and 0 pixels high. When then cropping the image, the crop fails because the crop size is invalid.  The fix is to not crop if there is no trim detected. Thanks to @tielur for the report. Closes #84.\n\n* Fix specification for `Image.compose/3` to remove dialyzer error (and include test case). Thanks to @tielur for the report. Closes #85.\n\n* Fix `Image.add_alpha/2` when providing a \"color\". In fact the value should be an integer in the range 0..255 representing the level of transparency of the alpha band. The function spec, documentation and implementation are now changed to accept only an integer (or the atoms :opaque and :transparent).","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.from_svg/2` and `Image.from_svg!/2` to provide a more discoverable means of creating an image from an SVG string.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.31.1 released on May 10th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.31.1 - Changelog","ref":"changelog.html#image-0-31-1"},{"type":"extras","doc":"* Fix spec for `Image.replace_color/2` and `Image.replace_color!/2`. Thanks to @tielur. Closes #79.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.31.0 released on May 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.31.0 - Changelog","ref":"changelog.html#image-0-31-0"},{"type":"extras","doc":"* Fix resolution of the image returned from `Image.replace_color/2`. Thanks to @tielur for the report. Closes #78.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `:blend` option to `Image.if_then_else/4`. When set to true with smoothly blend between the `then` and `else`  images. The default is `false`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.30.0 released on April 20th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.30.0 - Changelog","ref":"changelog.html#image-0-30-0"},{"type":"extras","doc":"* Add documentation for `Image.with_colorspace/3`.\n\n* Fix `Image.trim/2` reflecting the updated `vix` return data structure.\n\n* Fix `Image.if_then_else/3` to validate color options correctly.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.cast/2` to convert the band format of an image to a different numeric type.\n\n* Adds `Image.replace_color/2` and `Image.replace_color!/2`.\n\n* Adds `Image.if_then_else!/3`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.29.0 released on April 14th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.29.0 - Changelog","ref":"changelog.html#image-0-29-0"},{"type":"extras","doc":"* Supports [vix version 0.17.0](https://hex.pm/packages.vix/0.17.0).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.28.2 released on April 13th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.28.2 - Changelog","ref":"changelog.html#image-0-28-2"},{"type":"extras","doc":"* `Image.Classification.serving/2` was applying the option `top_k: 1` which means not all predictions were being returned. This option is now removed. Thanks to @tmariaz for raising the issue.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.28.1 released on April 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.28.1 - Changelog","ref":"changelog.html#image-0-28-1"},{"type":"extras","doc":"* Fixes `Image.add_alpha/2`. Thanks to @kwando for the PR. Closes #71.\n\n* Fixes `:threshold` option in `Image.Options.ChromaKey` to allow a value of `0`.\n\n* Fixes `Image.warp_perspective/4` to correctly flatten an image with an alpha band before the transform. Closes #70.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.28.0 released on April 6th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.28.0 - Changelog","ref":"changelog.html#image-0-28-0"},{"type":"extras","doc":"* Fixes resizing images with alpha bands. Resizing images with alpha bands requires premultiplying the alpha band into the image and reversing that after resizing.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.warp_perspective/4` to apply a warp transformation to an image. Thanks very much to @sodapopcan for the PR and collaboration.\n\n* Adds `Image.straighten_perspective/3` to apply a warp perspective that straighens the image. It is basically `Image.warp_perspective/4` with algorithmically derived `destination` parameter.\n\n* Adds `Image.map/2` which applies a transformation matrix (not a convolution kernel) to an image. A transformation matrix can be returned from `Image.transform_matrix/3`. These two functions underpin `Image.warp_perspective/4`.\n\n* Adds `Image.crop/2` which is a variation of `Image.crop/5` that takes the same format of bounding box as that applied to `Image.warp_perspective/4` making it easy to apply a warp transform and then crop to the transformed area. Note that cropping requires that the bounding box be a rectangle, not an arbitrary quadrilateral.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.27.1 released on March 20th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.27.1 - Changelog","ref":"changelog.html#image-0-27-1"},{"type":"extras","doc":"* Changes the default position for an image embedded via `Image.embed/2` to be `[0, 0]` not `[:center, :center]`.","title":"Behaviour Change - Changelog","ref":"changelog.html#behaviour-change"},{"type":"extras","doc":"This is the changelog for Image version 0.27.0 released on March 20th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.27.0 - Changelog","ref":"changelog.html#image-0-27-0"},{"type":"extras","doc":"In a future release, Image will be split into several packages\n\n* `:image` which will retain all the core components of image transformation based upon `vix` and `libvips`.\n* `:image_nx` which will provide `:nx` interoperability (and will depend on `:image`)\n* `:image_exif` which will provide metadata support (and will depend on `:image`)\n* `:image_classification` which will provide image classification (and will depend on `:image` and `:bumblebee`)\n* `:image_generation` which will provide image generation (and will depend on `:image` and `:bumblebee`)\n* `:image_detection` which will provide object detection (and will depend on `:image`, `:axon`, `:axon_onnx`)\n* `:image_qrcode` which will provide QRcode scanning and production (and will depend on`:image` and `:evision`)\n* `:image_video` which will provide video frame extraction (and will depend on`:image` and `:evision`)","title":"Image packaging future - Changelog","ref":"changelog.html#image-packaging-future"},{"type":"extras","doc":"* Add `Image.from_kino/2` and `Image.from_kino!/2` to simplify create an image from a [Kino](https://hex.pm/packages/kino) image in [Livebook](https://livebook.dev).\n\n* Add `Image.average/1` and `Image.average!/1` to calulate the average color of an image.\n\n* Add `Image.center_crop/3` and `Image.center_crop!/3`\n\n* Add `Image.embed/4` and `Image.embed!/4` to embed an image in a larger canvas, generating additional border pixels as required.\n\n* Add `Image.Shape.rect/3` to draw a rectangle image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.26.0 released on March 12th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.26.0 - Changelog","ref":"changelog.html#image-0-26-0"},{"type":"extras","doc":"* `Image.avatar/3` is now `Image.avatar/2`. The `size` parameter is now the `:size` option. The default value of 180 pixels remains.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* `Image.avatar/2` takes a `:shape` option that is either `:circle` (the default) or `:square`. This allows the generation of either circular or square avatars.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Fix `Image.open/2` for SVG binaries and add note to show that SVG images can be opened.\n\n* Fix `Image.avatar/2` to square the image after thumbnailing but before applying any mask. This ensures a circular mask is centred on the thumbnailed image.\n\n* Fix `Image.avatar/2` for image path parameters which no correctly flattens the image.\n\n* Fix `Image.avatar!/2` to accept either an image or an image path.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.25.1 released on March 1st, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.25.1 - Changelog","ref":"changelog.html#image-0-25-1"},{"type":"extras","doc":"* Fix `is_webp/1` guard and downcase all suffixes before validation. Thanks to @quentin-bettoum for the report and fix. Closes #64.\n\n* Fix `Image.avatar/3` to flatten the source image before compositing with the mask. Thanks to @jarrodmoldrich for the report. Closes #63.\n\n* Fix `Image.flatten/1` to only flatten if there is an alpha band.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.25.0 released on February March 1st, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.25.0 - Changelog","ref":"changelog.html#image-0-25-0"},{"type":"extras","doc":"* The default access mode for `Image.open/2` is now `access: :random` in line with `libvips` native default. Although `access: :sequential` optimizes for many cases (especially with regard to memory) it resulted in poor developer experience since the error messages when trying to re-use a `access: :sequential` image are difficult to understand and very difficult to re-interpret in `image`.","title":"Behavior Change - Changelog","ref":"changelog.html#behavior-change"},{"type":"extras","doc":"* Adds `:heic` and `:avif` suffixes to the list of valid suffixes for `heif` file formats.  Thanks to @quentin-bettoum for the PR. Closes #50.\n\n* Allows specifying the option `padding: 0` for `Image.Text.text/2`. Previously this only supported positive integers.\n\n* Fix `Image.write/3` documentation. Thanks to @jeregrine for the PR. Closes #62.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Update `README.md` to include updated documentation for installing `libvips` with `Vix`.\n\n* Adds `:x` and `:y` options to `Image.Text.text/2` which allows placing the text on its background in the specified location.  `:x` can be specified as a non-negative integer or one of `:left`, `:right` or `:center` with the default being `:center`. `:y` can be specified as a non-negative integer or one of `:top`, `:bottom` or `:middle` with the default being `:middle`. Thanks to @severian1778 for the issue and collaboration. Closes #44.\n\n* Adds an option `:effort` to `Image.write/3` for `:png`, `:heif`, `:heic`, `:avif` and `:webp` images that determines the amount of CPU effort permitted when compressing the image data.  Thanks to @quentin-bettoum for the PR. Closes #45.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.24.1 released on February 14th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.24.1 - Changelog","ref":"changelog.html#image-0-24-1"},{"type":"extras","doc":"* Fixes `:weight` option handling in `Image.meme/3` to include `:ultralight`. Thanks to @quentin-bettoum. Closes #42.\n\n* Fixes `:intent` option handling in `Image.thumbnail/3`. Thanks to @quentin-bettoum. Closes #43.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.24.0 released on February 6th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.24.0 - Changelog","ref":"changelog.html#image-0-24-0"},{"type":"extras","doc":"* Adds `Image.Draw.flood!/4` to align with `Image.Draw.flood/4`.\n\n* Adds `Image.add_alpha/2` and `Image.add_alpha!/2`.\n\n* Adds `:stroke_width` to `Image.Draw.rect/6` and `Image.Draw.circle/5`. Thanks to @RyoWakabayashi for the suggestion and sample code.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.23.2 released on January 31st, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.23.2 - Changelog","ref":"changelog.html#image-0-23-2"},{"type":"extras","doc":"* `Image.Kino.show/2` returns the type `t:Kino.Image.t/0` which as a side effect does not show a duplicate image and plays nicely with `Kino.Layout.grid/2`.  Thanks to @RyoWakabayashi. Closes #37.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.23.1 released on January 30th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.23.1 - Changelog","ref":"changelog.html#image-0-23-1"},{"type":"extras","doc":"* `Kino.show/2` returns the image instead of `:ok` so that it works correctly in a grid. Thanks to @RyoWakabayashi for the [suggestion](https://github.com/elixir-image/image/discussions/1#discussioncomment-4826961).","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.23.0 released on January 29th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.23.0 - Changelog","ref":"changelog.html#image-0-23-0"},{"type":"extras","doc":"* Fix specs for `Image.Options.Write`. Thanks to @jarrodmoldrich. Closes #36.\n\n* Fix spec for `Image.exif/1`. Thanks to @ntodd for the PR. Closes #35.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.normalize/1` which normalizes an image by expanding the luminance of an image to cover the full dynamic range.\n\n* Adds `Image.autolevel/1` which scales each band of an image to fit the full dynamic range. Unlike `Image.normalize/1`, each band is scaled separately.\n\n* Adds `Image.erode/2` which erodes pixels from the edge of an image mask. This can be useful to remove a small amount of colour fringing around the edge of an image.\n\n* Adds `Image.dilate/2` which dilates pixels from the edge of an image mask.\n\n* Adds `Image.trim/2` which trims an image to the bounding box of the non-background area.\n\n* Adds `Image.flatten/1` which flattens an alpha layer out of an image\n\n* `Image.Options.Write.validate_options/2` now validates options appropriate to each image type in order to make validation more robust.\n\n* Adds `:minimize_file_size` option to `Image.write/2` for JPEG and PNG files which if `true` will apply a range of techniques to minimize the size of the image file at the expense of time to save the image and potentially image quality.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.22.1 released on January 9th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.22.1 - Changelog","ref":"changelog.html#image-0-22-1"},{"type":"extras","doc":"* Don't compile `Image.Options.Video` unless Evision is configured and compiled.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.22.0 released on January 9th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.22.0 - Changelog","ref":"changelog.html#image-0-22-0"},{"type":"extras","doc":"* Adds `Image.Video.stream!/2` that returns an enumerable stream of frames as images.\n\n* Adds `Image.Video.scrub/2` that scubs the video head forward a number of frames.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.21.0 released on January 8th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.21.0 - Changelog","ref":"changelog.html#image-0-21-0"},{"type":"extras","doc":"* `Image.Video.image_at_millisecond/2` and `Image.Video.image_from_frame/2` are removed and replaced by `Image.Video.image_from_video/2`.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Adds `Image.Video.image_from_video/2` with support for `:frame` and `:millisecond` seek options. Seek options are only supported for video files, not video streams.\n\n* Adds `Image.Video.seek/2` to seek the extraction point to the requested frame or millisecond. Seeking is supported for video files only, not video streams.\n\n* Adds support for capturing images from video streams (not only video files). For example, `Image.Video.open(:default_camera)`. See the updated documentation for `Image.Video.open/1`.  An image stream does not support seeking.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.20.0 released on January 8th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.20.0 - Changelog","ref":"changelog.html#image-0-20-0"},{"type":"extras","doc":"* Fix `Image.from_evision/1` to correctly orient the dimensions as `{width, height, bands}`","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add support for extracting frames from video as images using `eVision`.  See `Image.Video`.\n\n* Supports `vix` upcoming prebuilt `libvips`.  The prebuilt `libvips` may not include the FFT dependency so `Image.skew_angle/1` and `Image.fft/1` are only included if `Vix.Vips.Operation.fft!/1` is available.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.19.0 released on December 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.19.0 - Changelog","ref":"changelog.html#image-0-19-0"},{"type":"extras","doc":"* Adds `Image.Generation.text_to_image/2` the uses [Stable Diffusion](https://en.wikipedia.org/wiki/Stable_Diffusion) support in [Bumblebee](https://hex.pm/packages/bumblebee) to generate an image from a text description of scene.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.18.1 released on December 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.18.1 - Changelog","ref":"changelog.html#image-0-18-1"},{"type":"extras","doc":"* Fix `Image.Application.start/2`. Previously it would return `nil` if Bumblebee was not configured and `nil` is not a valid return from an application start function. Thanks to @haste for the report and PR.  Closes #34.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.18.0 released on December 20th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.18.0 - Changelog","ref":"changelog.html#image-0-18-0"},{"type":"extras","doc":"* Adds `Image.Classification.classify/2` and `Image.Classification.labels/2` to execute image classification models over an image using [Bumblebee](https://hex.pm/packages/bumblebee).\n\n* Adds an option `:max_height` to `Image.Kino.show/2`. Thanks to @kwando for the PR.  Closes #33.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.17.0 released on December 19, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.17.0 - Changelog","ref":"changelog.html#image-0-17-0"},{"type":"extras","doc":"* Rename `Image.orientation/1` to be `Image.aspect/1` to better reflect its purpose. Orientation has a more specific meaning in image metadata and in `Vips.Vix.Image.orientation/1`.","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Fix `Image.aspect/1` for exactly square images.\n\n* Draw functions now default to opaque if the base image has an alpha band (previously they would be transparent). Thanks for @kwando for the collaboration. Closes #32.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds a `:fit` option to `Image.thumbnail/3` that uses the same terminology as the CSS [object-fit](https://www.w3schools.com/css/css3_object-fit.asp) property. This option sets overwrites the options `:crop` and `:resize` to produce the specified outcome.\n\n* Add `Image.Draw.point!/4`, `Image.Draw.rect!/6`, `Image.Draw.circle!/5` and `Image.Draw.line!/6`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.16.0 released on Decmber 18th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.16.0 - Changelog","ref":"changelog.html#image-0-16-0"},{"type":"extras","doc":"* Allow percentages to be specified as `Image.crop/5` parameters for left, top, width and height.  Percentages are expressed as floats in the range -1.0 to 1.0 (for left and top) and greater than 0.0 and less than or equal to 1.0 (for width and height). Thanks to @tmjoen for the suggestion.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.15.1 released on Decmber 13th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.15.1 - Changelog","ref":"changelog.html#image-0-15-1"},{"type":"extras","doc":"* Fixes interpretation of color encoded as `#xxxxxx`. Closes #26. Thanks to @a8t for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.15.0 released on Decmber 4th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.15.0 - Changelog","ref":"changelog.html#image-0-15-0"},{"type":"extras","doc":"* Fix `Image.minimize_metadata/1` which was previously creating malformed exif data.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `:autofit` option to `Image.Text.text/2`. When set to `true`, text is rendered with `Vix.Vips.Operation.text/2`. The default, `false`, uses SVG rendering. There are pros and cons to both strategies. The main difference is that `autofit: true` will automatically size the text and perform line wrapping to fit the specified `:width` and `:height`.  Thanks to @dmitriid for the suggestion!","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.14.4 released on November 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.14.4 - Changelog","ref":"changelog.html#image-0-14-4"},{"type":"extras","doc":"* Fix the return type for `Image.write/3` for `Plug.Conn`. Thanks to @andreyuhai for the PR.\n\n* Fix type specs for `Image.write/3` when the destination is `:memory`. Thanks to @georgfaust for raising the issue.\n\n* Fixes the rbga color model for integer alpha values *again* (which are automatically cast to the appropriate float value). Thanks to @andreyuhai for your patience and collaboration while this was sorted out.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.14.3 released on November 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.14.3 - Changelog","ref":"changelog.html#image-0-14-3"},{"type":"extras","doc":"* Fixes the rbga color model for integer alpha values (which are automatically cast to the appropriate float value). Thanks to @andreyuhai for your patience and collaboration while this was sorted out.\n\n* Casts the color to the correct number of bands in `Image.Draw` functions. This will either add or remove an alpha band to the color of the shape being drawn to match the underlying image.  Thanks to @andreyuhai for the PR. Closes #22.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.14.2 released on November 13th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.14.2 - Changelog","ref":"changelog.html#image-0-14-2"},{"type":"extras","doc":"* Fix `Image.split_bands/1`\n\n* Fix `Image.split_alpha/1`","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.14.1 released on November 11th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.14.1 - Changelog","ref":"changelog.html#image-0-14-1"},{"type":"extras","doc":"* Fix streaming image writes. Previously the stream chunks were being written in reverse order. Closes #19. Thanks to @loics2 for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.14.0 released on November 11th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.14.0 - Changelog","ref":"changelog.html#image-0-14-0"},{"type":"extras","doc":"* Fixes extracting exif data when there is an exif blob but no exif tags. Closes #21.  Thanks to @feld for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `Image.pixelate/2` and `Image.pixelate!/2`\n\n* Add `Image.resize!/3`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.13.1 released on October 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.13.1 - Changelog","ref":"changelog.html#image-0-13-1"},{"type":"extras","doc":"* Since a font named `Impact` isn't available on all systems, default meme generator can produce unexpected results for the rendered text.  The `Impact` font is now included in `Image` and will be used if the font name is `Impact`.","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.13.0 released on October 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.13.0 - Changelog","ref":"changelog.html#image-0-13-0"},{"type":"extras","doc":"* `Image.resize/3` renamed to `Image.thumbnail/3`","title":"Breaking change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* Fix `Image.open/2` when opening JPEG images from a binary. Seems JPEG files agree on the `<<0xff, 0xd8, 0xff>>` header for the first three bytes. But not completely consistent with the following bytes.\n\n* Fix options for `Image.Draw` functions which are expected to be a map after validation (but were a keyword list).","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `Image.chroma_key/2` and `Image.chroma_mask/2`.\n\n* Add `Image.meme/3` and `Image.meme!/3`.\n\n* Add `Image.QRcode.encode/1` and `Image.QRcode.decode/1`.\n\n* Add `Image.blur/2`.\n\n* Add `Image.feather/2`.\n\n* Add `Image.new/2` that creates a new image of the same shape as the provided image.\n\n* Add `Image.resize/3`.\n\n* Add `Image.split_bands/1`.\n\n* Add `Image.if_then_else/3`.\n\n* Add `Image.preview/1` (and `Image.p/1` that delegates to it) to preview an image inline in an iTerm2 terminal windows.\n\n* Add `Image.split_bands/1` to return a list single band images, one for each band in the original image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.12.0 released on October 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.12.0 - Changelog","ref":"changelog.html#image-0-12-0"},{"type":"extras","doc":"* Updates to support [eVision 0.1.11](https://hex.pm/packages/evision/0.1.11) which has API breaking changes. There is no change to the `Image.QRcode.decode/1` function which uses `eVision`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.11.0 released on October 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.11.0 - Changelog","ref":"changelog.html#image-0-11-0"},{"type":"extras","doc":"* Now uses `eVision` version `0.1` or later from [hex.pm](https://hex.pm/packages/evision)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.10.0 released on October 5th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.10.0 - Changelog","ref":"changelog.html#image-0-10-0"},{"type":"extras","doc":"* Since the mix build process does a `File.cwd!/1` to the directory of each dependency we can't use the dirname of the dependency to decide whether to configure `:evision` or not. The strategy is now changed to configure `:evision` only if the environment `CONFIGURE_EVISION` is set.  Note this is only relevant when developing `:image` itself.  Consumers of the library should add `:evision` as a dependency manually in their application `mix.exs` as described in the `readme`.  Thanks to @martosaur for the report.  Closes #13.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Image version 0.9.0 released on October 1st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.9.0 - Changelog","ref":"changelog.html#image-0-9-0"},{"type":"extras","doc":"* `Image.open/2` supports opening `.gif` and `.tif` images from raw binary data in addition to the previous `.jpeg`, `.png` and `.webp`.\n\n* Add `Image.shape/1`\n\n* Add `Image.interpretation/1`\n\n* Add `Image.type/1`\n\n* Add initial support for [eVision](https://github.com/cocoa-xu/evision). In this release the function `Image.QRcode.decode/1` is provided to decode images that contain a QRcode. See the `eVision` repository for installation instructions since this library is not yet on `hex.pm`.\n\n* Removed most dialyzer warnings. The remaining warnings require an update to `Vix` (a PR has been submitted).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.8.0 released on September 30, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.8.0 - Changelog","ref":"changelog.html#image-0-8-0"},{"type":"extras","doc":"* `Image.open/2` now accepts raw image data for the image types `.jpeg`, `.png`, `.webp`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.7.0 released on September 30, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.7.0 - Changelog","ref":"changelog.html#image-0-7-0"},{"type":"extras","doc":"* Set the environment variable `VIPS_BLOCK_UNTRUSTED` at application start if it is not already set. As of [libvips 8.13](https://www.libvips.org/2022/05/28/What's-new-in-8.13.html) this environment variable will cause `libvips` to not use any image loaders that are \"unfuzzed\".\n\n* Add mutable draw operations. These operations mutate an image directly and hence special care is taken to avoid race conditions. All mutuable operations are serialized via a `GenServer`. See the `Image.Draw` module.  These functions are experimental for now pending additional testing.\n\n* Add `Image.from_binary/2` to support creating an image from a raw binary.\n\n* Thanks to @timothyvanderaerden for the PR to support getting dialyzer under control.  Work will continue on this over the next several releases.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.6.0 released on July 19th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.6.0 - Changelog","ref":"changelog.html#image-0-6-0"},{"type":"extras","doc":"* Don't attempt to compile code that refers to `Plug.t` if `Plug` is not configured. Thanks to @kwando. Closes #7.","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Image.dshash/1` to return a 512-bit image hash.\n\n* Adds `Image.hamming_distance/2` to compare the similarity of two images or two image hashes.\n\n* Adds `Image.radial_gradient/3` to great a radial gradient image. This could be used to composite over another image to add a vignette.\n\n* Adds `Image.Math` logical functions `boolean_and/2`, `boolean_or/2`, `boolean_xor/2`, `boolean_lshift/2` and `boolean_rshift/2`. Also includes the `!` versions.\n\n* Add operator `use Image.Math` overloads for image `&&&` (`and`), `|||` (`or`), `<<<` (`lshift`) and `>>>` (`rshift`).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.5.0 released on June 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.5.0 - Changelog","ref":"changelog.html#image-0-5-0"},{"type":"extras","doc":"* Adds `Image.to_nx/1` to convert an image to an Nx tensor.\n\n* Adds `Image.from_nx/1` to convert an Nx tensor into an image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.4.0 released on June 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.4.0 - Changelog","ref":"changelog.html#image-0-4-0"},{"type":"extras","doc":"* Adds support for opening streaming images. This allows images to be streamed from `File.stream!/3` or from any `t:Stream.t/0` including those created from [ExAws.S3](https://hexdocs.pm/ex_aws_s3/ExAws.S3.html) by [ExAws.stream!/2](https://hexdocs.pm/ex_aws/ExAws.html#stream!/2).\n\n* Adds support writing streaming images. This allows images to be streamed as an enumerable which can then be consumed by `Plug.Conn.chunk/2`, by `ExAws.S3.upload/3`, `File.stream/3` or any other function that processes stream resources. See the `test/stream_image_test.exs` for examples.\n\n* Adds a `:memory` option to `Image.write/3`. Instead of a path name or stream, use `:memory` if you'd like to return a `binary` form of an image in its formatted type. Note that this will run the image transformation pipeline resulting in the entire final image being loaded into memory. Therefore this option should be used sparingly since most use cases do not require this option. It is primarily added to facilitate passing images to other libraries in the Elixir ecosystem.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.3.0 released on June 4th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.3.0 - Changelog","ref":"changelog.html#image-0-3-0"},{"type":"extras","doc":"* Add `Image.dominant_color/2` to return the dominant color of an image\n\n* Add `Image.histogram/1` to return a histogram of an image\n\n* Add `Image.get_pixel` to get the pixel value at a given `x` and `y` offset into an image.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.2.0 released on May 18th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.2.0 - Changelog","ref":"changelog.html#image-0-2-0"},{"type":"extras","doc":"* Adds `Image.Text` to support generating an image from a string. See `Image.Text.text/2`.\n\n* Adds `Image.Shape` to support generating images from shapes. In this release there is a generalised support for polygons and stars.  See `Image.Shape.polygon/2` and `Image.Shape.star/2`.\n\n* Improves `Image.compose/3` to support composing with image lists, relative image placement and more.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Image version 0.1.0 released on May 4th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-image/image/tags)","title":"Image 0.1.0 - Changelog","ref":"changelog.html#image-0-1-0"},{"type":"extras","doc":"* Initial release","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}